"""Request Body Schemas for API Tools

DO NOT EDIT THIS MODULE DIRECTLY.

THIS MODULE WAS AUTO-GENERATED AND CONTAINS OpenAPI REQUEST BODY SCHEMAS
FOR TOOLS WITH COMPLEX REQUEST BODIES. ANY CHANGES TO THIS MODULE WILL
BE OVERWRITTEN BY THE TRANSPILER.
"""

from typing import Any

REQUEST_BODY_SCHEMAS: dict[str, Any] = {
    "CREATEBANKACCOUNT_REQUEST_BODY_SCHEMA": {
        "properties": {
            "account_code": {"description": "Code of the Account", "type": "string"},
            "account_name": {
                "description": "Name of the account",
                "example": "Corporate Account",
                "type": "string",
            },
            "account_number": {
                "description": "Number associated with the Bank Account",
                "example": "80000009823",
                "type": "string",
            },
            "account_type": {
                "description": "Type of the account",
                "example": "bank",
                "type": "string",
            },
            "bank_name": {
                "description": "Name of the Bank",
                "example": "Xavier Bank",
                "type": "string",
            },
            "currency_code": {
                "description": "Code of the currency associated with the Bank Account",
                "example": "USD",
                "type": "string",
            },
            "currency_id": {
                "description": "ID of the Currency associated with the Account",
                "example": "460000000000097",
                "type": "string",
            },
            "description": {
                "description": "Description of the Account",
                "example": "Salary details.",
                "type": "string",
            },
            "is_paypal_account": {
                "description": "Check if the Account is Paypal Account",
                "example": True,
                "type": "boolean",
            },
            "is_primary_account": {
                "description": "Check if the Account is Primary Account in Zoho Books",
                "example": False,
                "type": "boolean",
            },
            "paypal_email_address": {
                "description": "Email Address of the Paypal account.",
                "example": "johnsmith@zilliuminc.com",
                "type": "string",
            },
            "paypal_type": {
                "description": "The type of Payment for the Paypal "
                "Account. Allowed Values : "
                "<code>standard</code> and "
                "<code>adaptive</code>",
                "type": "string",
            },
            "routing_number": {
                "description": "Routing Number of the Account",
                "example": "123456789",
                "type": "string",
            },
        },
        "required": ["account_name", "account_type"],
        "type": "object",
    },
    "UPDATEBANKACCOUNTZOHOBOOKS_REQUEST_BODY_SCHEMA": {
        "properties": {
            "account_code": {"description": "Code of the Account", "type": "string"},
            "account_name": {
                "description": "Name of the account",
                "example": "Corporate Account",
                "type": "string",
            },
            "account_number": {
                "description": "Number associated with the Bank Account",
                "example": "80000009823",
                "type": "string",
            },
            "account_type": {
                "description": "Type of the account",
                "example": "bank",
                "type": "string",
            },
            "bank_name": {
                "description": "Name of the Bank",
                "example": "Xavier Bank",
                "type": "string",
            },
            "currency_code": {
                "description": "Code of the currency associated with the Bank Account",
                "example": "USD",
                "type": "string",
            },
            "currency_id": {
                "description": "ID of the Currency associated with the Account",
                "example": "460000000000097",
                "type": "string",
            },
            "description": {
                "description": "Description of the Account",
                "example": "Salary details.",
                "type": "string",
            },
            "is_paypal_account": {
                "description": "Check if the Account is Paypal Account",
                "example": True,
                "type": "boolean",
            },
            "is_primary_account": {
                "description": "Check if the Account is Primary Account in Zoho Books",
                "example": False,
                "type": "boolean",
            },
            "paypal_email_address": {
                "description": "Email Address of the Paypal account.",
                "example": "johnsmith@zilliuminc.com",
                "type": "string",
            },
            "paypal_type": {
                "description": "The type of Payment for the Paypal "
                "Account. Allowed Values : "
                "<code>standard</code> and "
                "<code>adaptive</code>",
                "type": "string",
            },
            "routing_number": {
                "description": "Routing Number of the Account",
                "example": "123456789",
                "type": "string",
            },
        },
        "required": ["account_name", "account_type"],
        "type": "object",
    },
    "IMPORTBANKSTATEMENTS_REQUEST_BODY_SCHEMA": {
        "properties": {
            "account_id": {
                "description": "ID of the Bank/Credit Card account",
                "example": "460000000050127",
                "type": "string",
            },
            "end_date": {
                "description": "Greatest date in the transaction set",
                "example": "2019-01-02",
                "type": "string",
            },
            "start_date": {
                "description": "Least date in the transaction set",
                "example": "2019-01-01",
                "type": "string",
            },
            "transactions": {
                "items": {
                    "properties": {
                        "amount": {
                            "description": "Amount involved in the transaction",
                            "example": 7500,
                            "format": "double",
                            "type": "number",
                        },
                        "date": {
                            "description": "Date of the transaction",
                            "example": "2012-01-14",
                            "type": "string",
                        },
                        "debit_or_credit": {
                            "description": "Indicates if transaction is  Debit or Credit",
                            "example": "credit",
                            "type": "string",
                        },
                        "description": {
                            "description": "Transaction description",
                            "example": "Electronics purchase",
                            "type": "string",
                        },
                        "payee": {
                            "description": "Payee involved in the transaction",
                            "example": "Bowman and Co",
                            "type": "string",
                        },
                        "reference_number": {
                            "description": "Reference Number of the transaction",
                            "example": "Ref-2134",
                            "type": "string",
                        },
                        "transaction_id": {
                            "description": "Unique ID that is specific to the transaction",
                            "example": "XXXXSCD01",
                            "type": "string",
                        },
                    },
                    "required": ["date", "debit_or_credit", "amount"],
                    "type": "object",
                },
                "type": "array",
            },
        },
        "required": ["account_id", "transactions"],
        "type": "object",
    },
    "CREATEFINANCIALACCOUNTRULE_REQUEST_BODY_SCHEMA": {
        "properties": {
            "account_id": {
                "description": "Account which is involved in the rule with the target account.",
                "example": 460000000049001,
                "format": "int64",
                "type": "integer",
            },
            "apply_to": {
                "description": "Rule applies to either deposits or "
                "withdrawals for bank accounts and to "
                "refunds or charges for credit card "
                "account. Allowed Values : "
                "<code>withdrawals</code>, "
                "<code>deposits</code>, "
                "<code>refunds</code> and "
                "<code>charges</code>.",
                "example": "deposits",
                "type": "string",
            },
            "criteria_type": {
                "description": "Specifies whether all the criteria "
                "have to be satisfied or not. Allowed "
                "Values : <code>and</code> and "
                "<code>or</code>",
                "example": "and",
                "type": "string",
            },
            "criterion": {
                "items": {
                    "properties": {
                        "comparator": {
                            "description": "Comparator used in Criteria",
                            "example": "greater_than_or_equals",
                            "type": "string",
                        },
                        "field": {
                            "description": "Field involved in the Criteria",
                            "example": "amount",
                            "type": "string",
                        },
                        "value": {
                            "description": "Value to be compared with",
                            "example": "500.00",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "customer_id": {
                "description": "ID of the customer.(Applicable for "
                "sales_without_invoices,deposit, "
                "expense)",
                "example": 46000000000111,
                "format": "int64",
                "type": "integer",
            },
            "is_reverse_charge_applied": {
                "description": "(Required if customer "
                "tax treatment is "
                "<code>vat_registered</code>)<br/>Used "
                "to specify whether the "
                "transaction is "
                "applicable for Domestic "
                "Reverse Charge (DRC) or "
                "not.",
                "example": True,
                "type": "boolean",
                "x-node_available_in": ["za"],
                "x-node_unavailable_in": [],
            },
            "product_type": {
                "description": "Product Type associated with the "
                "Rule. Allowed values:<br/> <b>For UK "
                "and Europe: "
                "</b><code>digital_service</code>, "
                "<code>goods</code> and "
                "<code>service</code>.<br/><b>For "
                "SouthAfrica Edition:</b> "
                "<code>service</code>, "
                "<code>goods</code>, "
                "<code>capital_service</code> and "
                "<code>capital_goods</code>.",
                "type": "string",
                "x-node_available_in": ["uk", "za", "eu"],
                "x-node_unavailable_in": [],
            },
            "record_as": {
                "description": "Record transaction based on value "
                "specified in apply_to node. For bank "
                "accounts: If apply_to is deposits: "
                "sales_without_invoices, transfer_fund, "
                "interest_income, other_income, "
                "expense_refund, deposit. If apply_to is "
                "withdrawals: expense, transfer_fund, "
                "card_payment, owner_drawings. For "
                "credit_card accounts: If apply_to is "
                "refunds: card_payment, transfer_fund, "
                "expense_refund, refund. If apply_to is "
                "charges: expense, transfer_fund. Allowed "
                "Values: <code>expense</code>, "
                "<code>deposit</code>, "
                "<code>refund</code>, "
                "<code>transfer_fund</code>, "
                "<code>card_payment</code>, "
                "<code>sales_without_invoices</code>, "
                "<code>expense_refund</code>, "
                "<code>interest_income</code>, "
                "<code>other_income</code> and "
                "<code>owner_drawings</code>",
                "example": "deposit",
                "type": "string",
            },
            "reference_number": {
                "description": "Specifies if Reference number is "
                "manual or generated from the "
                "statement. Allowed Values: "
                "<code>manual</code> and "
                "<code>from_statement</code>",
                "example": "manual",
                "type": "string",
            },
            "rule_name": {
                "description": "Name of the Rule",
                "example": "Minimum Deposit Rule",
                "type": "string",
            },
            "target_account_id": {
                "description": "The account on which the rule has to be applied.",
                "example": 460000000048001,
                "format": "int64",
                "type": "integer",
            },
            "tax_authority_id": {
                "description": "ID of the Tax Authority Associated with the Rule",
                "type": "string",
                "x-node_available_in": ["us"],
                "x-node_unavailable_in": [],
            },
            "tax_exemption_id": {
                "description": "ID of the Tax Exemption Associated with the Rule",
                "type": "string",
                "x-node_available_in": ["in", "us"],
                "x-node_unavailable_in": [],
            },
            "tax_id": {
                "description": "Tax ID involved in the transaction.",
                "example": "460000000048238",
                "type": "string",
            },
            "tax_treatment": {
                "description": "VAT treatment for the bank "
                "transaction.Choose whether the "
                "contact falls under: "
                "<code>vat_registered</code>,<code>vat_not_registered</code>,<code>gcc_vat_not_registered</code>,<code>gcc_vat_registered</code>,<code>non_gcc</code>.</br><code>dz_vat_registered</code> "
                "and "
                "<code>dz_vat_not_registered</code> "
                "are supported only for "
                "<b>UAE</b>.<br/><b>For Kenya "
                "Edition:</b> "
                "<code>vat_registered</code> "
                ",<code>vat_not_registered</code> "
                ",<code>non_kenya</code>(A business "
                "that is located outside "
                "Kenya).<br/><b>For SouthAfrica "
                "Edition:</b> "
                "<code>vat_registered</code>, "
                "<code>vat_not_registered</code>, "
                "<code>overseas</code>(A business "
                "that is located outside "
                "SouthAfrica).",
                "example": "vat_registered",
                "type": "string",
                "x-node_available_in": ["gcc", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "vat_treatment": {
                "description": "(Optional) VAT treatment for the "
                "bank rules. VAT treatment denotes "
                "the location of the customer, if the "
                "customer resides in UK then the VAT "
                "treatment is <code>uk</code>. If the "
                "customer is in an EU country & VAT "
                "registered, you are resides in "
                "Northen Ireland and "
                "selling/purchasing Goods then his "
                "VAT treatment is "
                "<code>eu_vat_registered</code>, if "
                "he resides outside of the UK then "
                "his VAT treatment is "
                "<code>overseas</code> (For Pre "
                "Brexit, this can be split as "
                "<code>eu_vat_registered</code>, "
                "<code>eu_vat_not_registered</code> "
                "and <code>non_eu</code>).",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
        },
        "required": [
            "rule_name",
            "target_account_id",
            "apply_to",
            "criteria_type",
            "criterion",
            "record_as",
        ],
        "type": "object",
    },
    "UPDATEBANKACCOUNTRULE_REQUEST_BODY_SCHEMA": {
        "properties": {
            "account_id": {
                "description": "Account which is involved in the rule with the target account.",
                "example": 460000000049001,
                "format": "int64",
                "type": "integer",
            },
            "apply_to": {
                "description": "Rule applies to either deposits or "
                "withdrawals for bank accounts and to "
                "refunds or charges for credit card "
                "account. Allowed Values : "
                "<code>withdrawals</code>, "
                "<code>deposits</code>, "
                "<code>refunds</code> and "
                "<code>charges</code>.",
                "example": "deposits",
                "type": "string",
            },
            "criteria_type": {
                "description": "Specifies whether all the criteria "
                "have to be satisfied or not. Allowed "
                "Values : <code>and</code> and "
                "<code>or</code>",
                "example": "and",
                "type": "string",
            },
            "criterion": {
                "items": {
                    "properties": {
                        "comparator": {
                            "description": "Comparator used in Criteria",
                            "example": "greater_than_or_equals",
                            "type": "string",
                        },
                        "criteria_id": {
                            "description": "ID of the Criteria",
                            "example": "460000000048009",
                            "type": "string",
                        },
                        "field": {
                            "description": "Field involved in the Criteria",
                            "example": "amount",
                            "type": "string",
                        },
                        "value": {
                            "description": "Value to be compared with",
                            "example": "500.00",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "customer_id": {
                "description": "ID of the customer.(Applicable for "
                "sales_without_invoices,deposit, "
                "expense)",
                "example": 46000000000111,
                "format": "int64",
                "type": "integer",
            },
            "is_reverse_charge_applied": {
                "description": "(Required if customer "
                "tax treatment is "
                "<code>vat_registered</code>)<br/>Used "
                "to specify whether the "
                "transaction is "
                "applicable for Domestic "
                "Reverse Charge (DRC) or "
                "not.",
                "example": True,
                "type": "boolean",
                "x-node_available_in": ["za"],
                "x-node_unavailable_in": [],
            },
            "product_type": {
                "description": "Product Type associated with the "
                "Rule. Allowed values:<br/> <b>For UK "
                "and Europe: "
                "</b><code>digital_service</code>, "
                "<code>goods</code> and "
                "<code>service</code>.<br/><b>For "
                "SouthAfrica Edition:</b> "
                "<code>service</code>, "
                "<code>goods</code>, "
                "<code>capital_service</code> and "
                "<code>capital_goods</code>.",
                "type": "string",
                "x-node_available_in": ["uk", "za", "eu"],
                "x-node_unavailable_in": [],
            },
            "record_as": {
                "description": "Record transaction based on value "
                "specified in apply_to node. For bank "
                "accounts: If apply_to is deposits: "
                "sales_without_invoices, transfer_fund, "
                "interest_income, other_income, "
                "expense_refund, deposit. If apply_to is "
                "withdrawals: expense, transfer_fund, "
                "card_payment, owner_drawings. For "
                "credit_card accounts: If apply_to is "
                "refunds: card_payment, transfer_fund, "
                "expense_refund, refund. If apply_to is "
                "charges: expense, transfer_fund. Allowed "
                "Values: <code>expense</code>, "
                "<code>deposit</code>, "
                "<code>refund</code>, "
                "<code>transfer_fund</code>, "
                "<code>card_payment</code>, "
                "<code>sales_without_invoices</code>, "
                "<code>expense_refund</code>, "
                "<code>interest_income</code>, "
                "<code>other_income</code> and "
                "<code>owner_drawings</code>",
                "example": "deposit",
                "type": "string",
            },
            "reference_number": {
                "description": "Specifies if Reference number is "
                "manual or generated from the "
                "statement. Allowed Values: "
                "<code>manual</code> and "
                "<code>from_statement</code>",
                "example": "manual",
                "type": "string",
            },
            "rule_name": {
                "description": "Name of the Rule",
                "example": "Minimum Deposit Rule",
                "type": "string",
            },
            "target_account_id": {
                "description": "The account on which the rule has to be applied.",
                "example": 460000000048001,
                "format": "int64",
                "type": "integer",
            },
            "tax_authority_id": {
                "description": "ID of the Tax Authority Associated with the Rule",
                "type": "string",
                "x-node_available_in": ["us"],
                "x-node_unavailable_in": [],
            },
            "tax_exemption_id": {
                "description": "ID of the Tax Exemption Associated with the Rule",
                "type": "string",
                "x-node_available_in": ["in", "us"],
                "x-node_unavailable_in": [],
            },
            "tax_id": {
                "description": "Tax ID involved in the transaction.",
                "example": "460000000048238",
                "type": "string",
            },
            "tax_treatment": {
                "description": "VAT treatment for the bank "
                "transaction.Choose whether the "
                "contact falls under: "
                "<code>vat_registered</code>,<code>vat_not_registered</code>,<code>gcc_vat_not_registered</code>,<code>gcc_vat_registered</code>,<code>non_gcc</code>.</br><code>dz_vat_registered</code> "
                "and "
                "<code>dz_vat_not_registered</code> "
                "are supported only for "
                "<b>UAE</b>.<br/><b>For Kenya "
                "Edition:</b> "
                "<code>vat_registered</code> "
                ",<code>vat_not_registered</code> "
                ",<code>non_kenya</code>(A business "
                "that is located outside "
                "Kenya).<br/><b>For SouthAfrica "
                "Edition:</b> "
                "<code>vat_registered</code>, "
                "<code>vat_not_registered</code>, "
                "<code>overseas</code>(A business "
                "that is located outside "
                "SouthAfrica).",
                "example": "vat_registered",
                "type": "string",
                "x-node_available_in": ["gcc", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "vat_treatment": {
                "description": "(Optional) VAT treatment for the "
                "bank rules. VAT treatment denotes "
                "the location of the customer, if the "
                "customer resides in UK then the VAT "
                "treatment is <code>uk</code>. If the "
                "customer is in an EU country & VAT "
                "registered, you are resides in "
                "Northen Ireland and "
                "selling/purchasing Goods then his "
                "VAT treatment is "
                "<code>eu_vat_registered</code>, if "
                "he resides outside of the UK then "
                "his VAT treatment is "
                "<code>overseas</code> (For Pre "
                "Brexit, this can be split as "
                "<code>eu_vat_registered</code>, "
                "<code>eu_vat_not_registered</code> "
                "and <code>non_eu</code>).",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
        },
        "required": [
            "rule_name",
            "target_account_id",
            "apply_to",
            "criteria_type",
            "criterion",
            "record_as",
        ],
        "type": "object",
    },
    "CREATEBANKTRANSACTION_REQUEST_BODY_SCHEMA": {
        "properties": {
            "amount": {
                "description": "Amount of the transaction",
                "example": 2000,
                "format": "double",
                "type": "number",
            },
            "bank_charges": {
                "description": "Bank Charges applied to the transaction",
                "example": 0,
                "format": "double",
                "type": "number",
            },
            "currency_id": {
                "description": "The currency ID involved in the transaction.",
                "example": "460000000000097",
                "type": "string",
            },
            "custom_fields": {
                "items": {
                    "properties": {
                        "custom_field_id": {"format": "int64", "type": "integer"},
                        "index": {"description": "Index of the custom field", "type": "integer"},
                        "label": {"description": "Label of the Custom Field", "type": "string"},
                        "value": {"description": "Value of the Custom Field", "type": "string"},
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "customer_id": {
                "description": "ID of the customer or vendor.",
                "example": "460000000000111",
                "type": "string",
            },
            "date": {"description": "Transaction date.", "example": "2013-10-01", "type": "string"},
            "description": {
                "description": "A brief description about the transaction.",
                "type": "string",
            },
            "documents": {
                "description": "List of files to be attached to a particular transaction.",
                "items": {
                    "properties": {
                        "document_id": {"description": "Unique ID of the attached file."},
                        "file_name": {"description": "Name of the attached file."},
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "exchange_rate": {
                "description": "The foreign currency exchange rate value.",
                "example": 1,
                "type": "integer",
            },
            "from_account_id": {
                "description": "The account ID from which money "
                "will be transferred(Mandatory for "
                "specific type of transactions). "
                "These accounts differ with respect "
                "to transaction_type. Ex: To a bank "
                "account, from-account can be: bank "
                ", card, income, refund. To a card "
                "account, from account can be: "
                "bank, card, refund.",
                "example": "460000000070003",
                "type": "string",
            },
            "from_account_tags": {
                "items": {
                    "properties": {
                        "tag_id": {
                            "description": "ID of the Tag",
                            "format": "int64",
                            "type": "integer",
                        },
                        "tag_option_id": {
                            "description": "Id of the Tag Option",
                            "format": "int64",
                            "type": "integer",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "is_inclusive_tax": {
                "description": "Check if transaction is tax Inclusive",
                "example": False,
                "type": "boolean",
            },
            "payment_mode": {
                "description": "Mode of payment for the transaction. "
                "(not applicable for transfer_fund, "
                "card_payment, owner_drawings). "
                "Ex:cash, cheque, etc.,",
                "example": "Cash",
                "type": "string",
            },
            "reference_number": {
                "description": "Reference Number of the transaction",
                "example": "Ref-121",
                "type": "string",
            },
            "tags": {
                "items": {
                    "properties": {
                        "tag_id": {
                            "description": "ID of the Tag",
                            "format": "int64",
                            "type": "integer",
                        },
                        "tag_option_id": {
                            "description": "Id of the Tag Option",
                            "format": "int64",
                            "type": "integer",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "tax_authority_id": {
                "description": "ID of the Tax Authority",
                "type": "string",
                "x-node_available_in": ["us", "au", "ca"],
                "x-node_unavailable_in": [],
            },
            "tax_exemption_id": {
                "description": "ID of the Tax Exemption",
                "type": "string",
                "x-node_available_in": ["in", "us", "au", "ca"],
                "x-node_unavailable_in": [],
            },
            "tax_id": {
                "description": "ID of the tax or tax group applied",
                "type": "string",
                "x-node_available_in": [],
                "x-node_unavailable_in": ["us"],
            },
            "to_account_id": {
                "description": "ID of the account to which the money "
                "gets transferred(Mandatory for "
                "specific type of transactions). Ex: "
                "From a bank account, to-account can "
                "be: bank, card, drawings, "
                "expense,credit notes. From a card "
                "account, to-account can be: card, "
                "bank, expense.",
                "example": "460000000048001",
                "type": "string",
            },
            "to_account_tags": {
                "items": {
                    "properties": {
                        "tag_id": {
                            "description": "ID of the Tag",
                            "format": "int64",
                            "type": "integer",
                        },
                        "tag_option_id": {
                            "description": "Id of the Tag Option",
                            "format": "int64",
                            "type": "integer",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "transaction_type": {
                "description": "Type of the transaction. <br> "
                "<strong>Allowed transaction "
                "types</strong> : deposit, "
                "refund(*Supported only in Credit "
                "Card accounts), transfer_fund, "
                "card_payment, "
                "sales_without_invoices, "
                "expense_refund, "
                "owner_contribution, "
                "interest_income, other_income, "
                "owner_drawings, sales_return <br> "
                "<strong>Note:</strong> You will "
                "not be able to create the "
                "following module-specific "
                "transaction types under Bank "
                "Transaction endpoints :<div> <a "
                'href="#Expenses">Expense</a>, <a '
                'href="#Vendor-Payments">Vendor '
                "Advance/Vendor Payment/Bill "
                "Payment</a>, <a "
                'href="#Vendor-Credits_Refund_a_vendor_credit">Vendor '
                "Credit Refund</a>, <a "
                'href="#Vendor-Payments_Refund_an_excess_vendor_payment">Vendor '
                "Payment Refund</a>, <a "
                'href="#Customer-Payments">Customer '
                "Advance/Customer Payment</a>, <a "
                'href="#Credit-Notes_Refund_credit_note">Credit '
                "Note Refund</a>, <a "
                'href="#Customer-Payments_Refund_an_excess_customer_payment">Payment '
                "Refund</a>. Hence, refer them in "
                "their repective modules.</div>",
                "example": "deposit",
                "type": "string",
            },
            "user_id": {
                "description": "ID of the User involved in the Transaction",
                "format": "int64",
                "type": "integer",
            },
        },
        "required": ["transaction_type"],
        "type": "object",
    },
    "UPDATEBANKTRANSACTION_REQUEST_BODY_SCHEMA": {
        "properties": {
            "amount": {
                "description": "Amount of the transaction",
                "example": 2000,
                "format": "double",
                "type": "number",
            },
            "bank_charges": {
                "description": "Bank Charges applied to the transaction",
                "example": 0,
                "format": "double",
                "type": "number",
            },
            "currency_id": {
                "description": "The currency ID involved in the transaction.",
                "example": "460000000000097",
                "type": "string",
            },
            "custom_fields": {
                "items": {
                    "properties": {
                        "custom_field_id": {"format": "int64", "type": "integer"},
                        "index": {"description": "Index of the custom field", "type": "integer"},
                        "label": {"description": "Label of the Custom Field", "type": "string"},
                        "value": {"description": "Value of the Custom Field", "type": "string"},
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "customer_id": {
                "description": "ID of the customer or vendor.",
                "example": "460000000000111",
                "type": "string",
            },
            "date": {"description": "Transaction date.", "example": "2013-10-01", "type": "string"},
            "description": {
                "description": "A brief description about the transaction.",
                "type": "string",
            },
            "documents": {
                "description": "List of files to be attached to a particular transaction.",
                "items": {
                    "properties": {
                        "document_id": {"description": "Unique ID of the attached file."},
                        "file_name": {"description": "Name of the attached file."},
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "exchange_rate": {
                "description": "The foreign currency exchange rate value.",
                "example": 1,
                "type": "integer",
            },
            "from_account_id": {
                "description": "The account ID from which money "
                "will be transferred(Mandatory for "
                "specific type of transactions). "
                "These accounts differ with respect "
                "to transaction_type. Ex: To a bank "
                "account, from-account can be: bank "
                ", card, income, refund. To a card "
                "account, from account can be: "
                "bank, card, refund.",
                "example": "460000000070003",
                "type": "string",
            },
            "from_account_tags": {
                "items": {
                    "properties": {
                        "tag_id": {
                            "description": "ID of the Tag",
                            "format": "int64",
                            "type": "integer",
                        },
                        "tag_option_id": {
                            "description": "Id of the Tag Option",
                            "format": "int64",
                            "type": "integer",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "is_inclusive_tax": {
                "description": "Check if transaction is tax Inclusive",
                "example": False,
                "type": "boolean",
            },
            "line_items": {
                "items": {
                    "properties": {
                        "account_id": {
                            "description": "Mandatory "
                            "Account "
                            "id "
                            "for "
                            "which "
                            "transactions "
                            "are "
                            "to "
                            "be "
                            "listed.",
                            "example": "460000000048001",
                            "type": "string",
                        },
                        "account_name": {
                            "description": "Name of the Account",
                            "example": "Petty Cash",
                            "type": "string",
                        },
                        "description": {
                            "description": "A brief description about the transaction.",
                            "type": "string",
                        },
                        "item_order": {
                            "description": "Order of the Item",
                            "example": 1,
                            "type": "integer",
                        },
                        "item_total": {
                            "description": "Total of the Item",
                            "example": 7500,
                            "format": "double",
                            "type": "number",
                        },
                        "item_total_inclusive_of_tax": {
                            "description": "Total of the Item inclusive of Tax",
                            "example": 7500,
                            "format": "double",
                            "type": "number",
                        },
                        "line_id": {
                            "description": "ID of the Line in Bank Transactions",
                            "example": "46000000001234",
                            "format": "int64",
                            "type": "integer",
                        },
                        "tags": {
                            "items": {
                                "properties": {
                                    "tag_id": {
                                        "description": "ID of the Tag",
                                        "format": "int64",
                                        "type": "integer",
                                    },
                                    "tag_option_id": {
                                        "description": "Id of the Tag Option",
                                        "format": "int64",
                                        "type": "integer",
                                    },
                                },
                                "type": "object",
                            },
                            "type": "array",
                        },
                        "tax_amount": {
                            "description": "Amount of Tax",
                            "example": 0,
                            "format": "double",
                            "type": "number",
                        },
                        "tax_id": {
                            "description": "ID of the tax or tax group applied",
                            "type": "string",
                            "x-node_available_in": [],
                            "x-node_unavailable_in": ["us"],
                        },
                        "tax_name": {"description": "Name of the Tax", "type": "string"},
                        "tax_percentage": {
                            "description": "Percentage of the Tax",
                            "example": 0,
                            "format": "double",
                            "type": "number",
                        },
                        "tax_type": {"example": "tax", "type": "string"},
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "payment_mode": {
                "description": "Mode of payment for the transaction. "
                "(not applicable for transfer_fund, "
                "card_payment, owner_drawings). "
                "Ex:cash, cheque, etc.,",
                "example": "Cash",
                "type": "string",
            },
            "reference_number": {
                "description": "Reference Number of the transaction",
                "example": "Ref-121",
                "type": "string",
            },
            "tags": {
                "items": {
                    "properties": {
                        "tag_id": {
                            "description": "ID of the Tag",
                            "format": "int64",
                            "type": "integer",
                        },
                        "tag_option_id": {
                            "description": "Id of the Tag Option",
                            "format": "int64",
                            "type": "integer",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "tax_authority_id": {
                "description": "ID of the Tax Authority",
                "type": "string",
                "x-node_available_in": ["us", "au", "ca"],
                "x-node_unavailable_in": [],
            },
            "tax_exemption_id": {
                "description": "ID of the Tax Exemption",
                "type": "string",
                "x-node_available_in": ["in", "us", "au", "ca"],
                "x-node_unavailable_in": [],
            },
            "tax_id": {
                "description": "ID of the tax or tax group applied",
                "type": "string",
                "x-node_available_in": [],
                "x-node_unavailable_in": ["us"],
            },
            "to_account_id": {
                "description": "ID of the account to which the money "
                "gets transferred(Mandatory for "
                "specific type of transactions). Ex: "
                "From a bank account, to-account can "
                "be: bank, card, drawings, "
                "expense,credit notes. From a card "
                "account, to-account can be: card, "
                "bank, expense.",
                "example": "460000000048001",
                "type": "string",
            },
            "to_account_tags": {
                "items": {
                    "properties": {
                        "tag_id": {
                            "description": "ID of the Tag",
                            "format": "int64",
                            "type": "integer",
                        },
                        "tag_option_id": {
                            "description": "Id of the Tag Option",
                            "format": "int64",
                            "type": "integer",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "transaction_type": {
                "description": "Type of the transaction. <br> "
                "<strong>Allowed transaction "
                "types</strong> : deposit, "
                "refund(*Supported only in Credit "
                "Card accounts), transfer_fund, "
                "card_payment, "
                "sales_without_invoices, "
                "expense_refund, "
                "owner_contribution, "
                "interest_income, other_income, "
                "owner_drawings, sales_return <br> "
                "<strong>Note:</strong> You will "
                "not be able to create the "
                "following module-specific "
                "transaction types under Bank "
                "Transaction endpoints :<div> <a "
                'href="#Expenses">Expense</a>, <a '
                'href="#Vendor-Payments">Vendor '
                "Advance/Vendor Payment/Bill "
                "Payment</a>, <a "
                'href="#Vendor-Credits_Refund_a_vendor_credit">Vendor '
                "Credit Refund</a>, <a "
                'href="#Vendor-Payments_Refund_an_excess_vendor_payment">Vendor '
                "Payment Refund</a>, <a "
                'href="#Customer-Payments">Customer '
                "Advance/Customer Payment</a>, <a "
                'href="#Credit-Notes_Refund_credit_note">Credit '
                "Note Refund</a>, <a "
                'href="#Customer-Payments_Refund_an_excess_customer_payment">Payment '
                "Refund</a>. Hence, refer them in "
                "their repective modules.</div>",
                "example": "deposit",
                "type": "string",
            },
            "user_id": {
                "description": "ID of the User involved in the Transaction",
                "format": "int64",
                "type": "integer",
            },
        },
        "required": ["transaction_type"],
        "type": "object",
    },
    "MATCHBANKTRANSACTION_REQUEST_BODY_SCHEMA": {
        "properties": {
            "transactions_to_be_matched": {
                "items": {
                    "properties": {
                        "transaction_id": {
                            "description": "ID of the Transaction",
                            "example": "460000000048017",
                            "type": "string",
                        },
                        "transaction_type": {
                            "description": "Type "
                            "of "
                            "the "
                            "transaction. "
                            "<br> "
                            "<strong>Allowed "
                            "transaction "
                            "types</strong> "
                            ": "
                            "deposit, "
                            "refund(*Supported "
                            "only "
                            "in "
                            "Credit "
                            "Card "
                            "accounts), "
                            "transfer_fund, "
                            "card_payment, "
                            "sales_without_invoices, "
                            "expense_refund, "
                            "owner_contribution, "
                            "interest_income, "
                            "other_income, "
                            "owner_drawings, "
                            "sales_return "
                            "<br> "
                            "<strong>Note:</strong> "
                            "You "
                            "will "
                            "not "
                            "be "
                            "able "
                            "to "
                            "create "
                            "the "
                            "following "
                            "module-specific "
                            "transaction "
                            "types "
                            "under "
                            "Bank "
                            "Transaction "
                            "endpoints "
                            ":<div> "
                            "<a "
                            'href="#Expenses">Expense</a>, '
                            "<a "
                            'href="#Vendor-Payments">Vendor '
                            "Advance/Vendor "
                            "Payment/Bill "
                            "Payment</a>, "
                            "<a "
                            'href="#Vendor-Credits_Refund_a_vendor_credit">Vendor '
                            "Credit "
                            "Refund</a>, "
                            "<a "
                            'href="#Vendor-Payments_Refund_an_excess_vendor_payment">Vendor '
                            "Payment "
                            "Refund</a>, "
                            "<a "
                            'href="#Customer-Payments">Customer '
                            "Advance/Customer "
                            "Payment</a>, "
                            "<a "
                            'href="#Credit-Notes_Refund_credit_note">Credit '
                            "Note "
                            "Refund</a>, "
                            "<a "
                            'href="#Customer-Payments_Refund_an_excess_customer_payment">Payment '
                            "Refund</a>. "
                            "Hence, "
                            "refer "
                            "them "
                            "in "
                            "their "
                            "repective "
                            "modules.</div>",
                            "example": "deposit",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            }
        },
        "type": "object",
    },
    "CATEGORIZEBANKTRANSACTION_REQUEST_BODY_SCHEMA": {
        "properties": {
            "amount": {
                "description": "Amount of the transaction",
                "example": 2000,
                "format": "double",
                "type": "number",
            },
            "bank_charges": {
                "description": "Bank Charges applied to the transaction",
                "example": 0,
                "format": "double",
                "type": "number",
            },
            "currency_id": {
                "description": "The currency ID involved in the transaction.",
                "example": "460000000000097",
                "type": "string",
            },
            "custom_fields": {
                "items": {
                    "properties": {
                        "custom_field_id": {"format": "int64", "type": "integer"},
                        "index": {"description": "Index of the custom field", "type": "integer"},
                        "label": {"description": "Label of the Custom Field", "type": "string"},
                        "value": {"description": "Value of the Custom Field", "type": "string"},
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "customer_id": {
                "description": "ID of the customer or vendor.",
                "example": "460000000000111",
                "type": "string",
            },
            "date": {"description": "Transaction date.", "example": "2013-10-01", "type": "string"},
            "description": {
                "description": "A brief description about the transaction.",
                "type": "string",
            },
            "documents": {
                "description": "List of files to be attached to a particular transaction.",
                "items": {
                    "properties": {
                        "document_id": {"description": "Unique ID of the attached file."},
                        "file_name": {"description": "Name of the attached file."},
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "exchange_rate": {
                "description": "The foreign currency exchange rate value.",
                "example": 1,
                "type": "integer",
            },
            "from_account_id": {
                "description": "The account ID from which money "
                "will be transferred(Mandatory for "
                "specific type of transactions). "
                "These accounts differ with respect "
                "to transaction_type. Ex: To a bank "
                "account, from-account can be: bank "
                ", card, income, refund. To a card "
                "account, from account can be: "
                "bank, card, refund.",
                "example": "460000000070003",
                "type": "string",
            },
            "from_account_tags": {
                "items": {
                    "properties": {
                        "tag_id": {
                            "description": "ID of the Tag",
                            "format": "int64",
                            "type": "integer",
                        },
                        "tag_option_id": {
                            "description": "Id of the Tag Option",
                            "format": "int64",
                            "type": "integer",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "is_inclusive_tax": {
                "description": "Check if transaction is tax Inclusive",
                "example": False,
                "type": "boolean",
            },
            "line_items": {
                "items": {
                    "properties": {
                        "account_id": {
                            "description": "Mandatory "
                            "Account "
                            "id "
                            "for "
                            "which "
                            "transactions "
                            "are "
                            "to "
                            "be "
                            "listed.",
                            "example": "460000000048001",
                            "type": "string",
                        },
                        "account_name": {
                            "description": "Name of the Account",
                            "example": "Petty Cash",
                            "type": "string",
                        },
                        "description": {
                            "description": "A brief description about the transaction.",
                            "type": "string",
                        },
                        "item_order": {
                            "description": "Order of the Item",
                            "example": 1,
                            "type": "integer",
                        },
                        "item_total": {
                            "description": "Total of the Item",
                            "example": 7500,
                            "format": "double",
                            "type": "number",
                        },
                        "item_total_inclusive_of_tax": {
                            "description": "Total of the Item inclusive of Tax",
                            "example": 7500,
                            "format": "double",
                            "type": "number",
                        },
                        "line_id": {
                            "description": "ID of the Line in Bank Transactions",
                            "example": "46000000001234",
                            "format": "int64",
                            "type": "integer",
                        },
                        "tags": {
                            "items": {
                                "properties": {
                                    "tag_id": {
                                        "description": "ID of the Tag",
                                        "format": "int64",
                                        "type": "integer",
                                    },
                                    "tag_option_id": {
                                        "description": "Id of the Tag Option",
                                        "format": "int64",
                                        "type": "integer",
                                    },
                                },
                                "type": "object",
                            },
                            "type": "array",
                        },
                        "tax_amount": {
                            "description": "Amount of Tax",
                            "example": 0,
                            "format": "double",
                            "type": "number",
                        },
                        "tax_id": {
                            "description": "ID of the tax or tax group applied",
                            "type": "string",
                            "x-node_available_in": [],
                            "x-node_unavailable_in": ["us"],
                        },
                        "tax_name": {"description": "Name of the Tax", "type": "string"},
                        "tax_percentage": {
                            "description": "Percentage of the Tax",
                            "example": 0,
                            "format": "double",
                            "type": "number",
                        },
                        "tax_type": {"example": "tax", "type": "string"},
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "payment_mode": {
                "description": "Mode of payment for the transaction. "
                "(not applicable for transfer_fund, "
                "card_payment, owner_drawings). "
                "Ex:cash, cheque, etc.,",
                "example": "Cash",
                "type": "string",
            },
            "reference_number": {
                "description": "Reference Number of the transaction",
                "example": "Ref-121",
                "type": "string",
            },
            "tags": {
                "items": {
                    "properties": {
                        "tag_id": {
                            "description": "ID of the Tag",
                            "format": "int64",
                            "type": "integer",
                        },
                        "tag_option_id": {
                            "description": "Id of the Tag Option",
                            "format": "int64",
                            "type": "integer",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "tax_authority_id": {
                "description": "ID of the Tax Authority",
                "type": "string",
                "x-node_available_in": ["us", "au", "ca"],
                "x-node_unavailable_in": [],
            },
            "tax_exemption_id": {
                "description": "ID of the Tax Exemption",
                "type": "string",
                "x-node_available_in": ["in", "us", "au", "ca"],
                "x-node_unavailable_in": [],
            },
            "tax_id": {
                "description": "ID of the tax or tax group applied",
                "type": "string",
                "x-node_available_in": [],
                "x-node_unavailable_in": ["us"],
            },
            "to_account_id": {
                "description": "ID of the account to which the money "
                "gets transferred(Mandatory for "
                "specific type of transactions). Ex: "
                "From a bank account, to-account can "
                "be: bank, card, drawings, "
                "expense,credit notes. From a card "
                "account, to-account can be: card, "
                "bank, expense.",
                "example": "460000000048001",
                "type": "string",
            },
            "to_account_tags": {
                "items": {
                    "properties": {
                        "tag_id": {
                            "description": "ID of the Tag",
                            "format": "int64",
                            "type": "integer",
                        },
                        "tag_option_id": {
                            "description": "Id of the Tag Option",
                            "format": "int64",
                            "type": "integer",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "transaction_type": {
                "description": "Type of the transaction. <br> "
                "<strong>Allowed transaction "
                "types</strong> : deposit, "
                "refund(*Supported only in Credit "
                "Card accounts), transfer_fund, "
                "card_payment, "
                "sales_without_invoices, "
                "expense_refund, "
                "owner_contribution, "
                "interest_income, other_income, "
                "owner_drawings, sales_return <br> "
                "<strong>Note:</strong> You will "
                "not be able to create the "
                "following module-specific "
                "transaction types under Bank "
                "Transaction endpoints :<div> <a "
                'href="#Expenses">Expense</a>, <a '
                'href="#Vendor-Payments">Vendor '
                "Advance/Vendor Payment/Bill "
                "Payment</a>, <a "
                'href="#Vendor-Credits_Refund_a_vendor_credit">Vendor '
                "Credit Refund</a>, <a "
                'href="#Vendor-Payments_Refund_an_excess_vendor_payment">Vendor '
                "Payment Refund</a>, <a "
                'href="#Customer-Payments">Customer '
                "Advance/Customer Payment</a>, <a "
                'href="#Credit-Notes_Refund_credit_note">Credit '
                "Note Refund</a>, <a "
                'href="#Customer-Payments_Refund_an_excess_customer_payment">Payment '
                "Refund</a>. Hence, refer them in "
                "their repective modules.</div>",
                "example": "deposit",
                "type": "string",
            },
            "user_id": {
                "description": "ID of the User involved in the Transaction",
                "format": "int64",
                "type": "integer",
            },
        },
        "required": ["transaction_type"],
        "type": "object",
    },
    "CATEGORIZEBANKTRANSACTIONASEXPENSE_REQUEST_BODY_SCHEMA": {
        "properties": {
            "account_id": {
                "description": "Mandatory Account id for which transactions are to be listed.",
                "example": "460000000048001",
                "type": "string",
            },
            "acquisition_vat_id": {
                "description": "(Optional) This is the ID of "
                "the tax applied in case this is "
                "an EU - goods purchase or "
                "expense and acquisition VAT "
                "needs to be reported.",
                "type": "string",
                "x-node_available_in": ["uk", "eu"],
                "x-node_unavailable_in": [],
            },
            "amount": {
                "description": "Amount of the transaction",
                "example": 2000,
                "format": "double",
                "type": "number",
            },
            "can_reclaim_vat_on_mileage": {
                "description": "Check if VAT can be reclaimed on mileage",
                "type": "boolean",
                "x-node_available_in": ["uk", "eu"],
                "x-node_unavailable_in": [],
            },
            "currency_id": {
                "description": "The currency ID involved in the transaction.",
                "example": "460000000000097",
                "type": "string",
            },
            "custom_fields": {
                "items": {
                    "properties": {
                        "index": {"description": "Index of the custom field", "type": "integer"},
                        "value": {"description": "Value of the Custom Field", "type": "string"},
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "customer_id": {
                "description": "ID of the customer or vendor.",
                "example": "460000000000111",
                "type": "string",
            },
            "date": {"description": "Transaction date.", "example": "2013-10-01", "type": "string"},
            "description": {
                "description": "A brief description about the transaction.",
                "type": "string",
            },
            "distance": {
                "description": "Distance Covered",
                "example": 4,
                "format": "double",
                "type": "number",
            },
            "documents": {
                "description": "List of files to be attached to a particular transaction.",
                "items": {
                    "properties": {
                        "document_id": {"description": "Unique ID of the attached file."},
                        "file_name": {"description": "Name of the attached file."},
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "employee_id": {
                "description": "ID of the Employee",
                "format": "int64",
                "type": "integer",
            },
            "end_reading": {"description": "End Reading of the Odometer", "type": "string"},
            "engine_capacity_range": {
                "description": "Type of Fuel Used. Allowed "
                "Values : "
                "<code>less_than_1400cc</code>, "
                "<code>between_1401cc_and_1600cc</code>, "
                "<code>between_1601cc_and_2000cc</code> "
                "and "
                "<code>more_than_2000cc</code>",
                "type": "string",
                "x-node_available_in": ["uk", "eu"],
                "x-node_unavailable_in": [],
            },
            "exchange_rate": {
                "description": "The foreign currency exchange rate value.",
                "example": 1,
                "type": "integer",
            },
            "expense_type": {
                "description": "Type of Expense",
                "example": "non_mileage",
                "type": "string",
            },
            "fuel_type": {
                "description": "Type of Fuel Used. Allowed Values : "
                "<code>petrol</code>, <code>lpg</code>, "
                "<code>diesel</code>",
                "type": "string",
                "x-node_available_in": ["uk", "eu"],
                "x-node_unavailable_in": [],
            },
            "is_billable": {
                "description": "A boolean value to specify if the expense is billable.",
                "type": "boolean",
            },
            "is_inclusive_tax": {
                "description": "Check if transaction is tax Inclusive",
                "example": False,
                "type": "boolean",
            },
            "is_update_customer": {
                "description": "Check if Customer should be updated",
                "example": False,
                "type": "boolean",
            },
            "line_items": {
                "items": {
                    "properties": {
                        "account_id": {
                            "description": "Mandatory "
                            "Account "
                            "id "
                            "for "
                            "which "
                            "transactions "
                            "are "
                            "to "
                            "be "
                            "listed.",
                            "example": "460000000048001",
                            "type": "string",
                        },
                        "acquisition_vat_id": {
                            "description": "(Optional) "
                            "This "
                            "is "
                            "the "
                            "ID "
                            "of "
                            "the "
                            "tax "
                            "applied "
                            "in "
                            "case "
                            "this "
                            "is "
                            "an "
                            "EU "
                            "- "
                            "goods "
                            "purchase "
                            "or "
                            "expense "
                            "and "
                            "acquisition "
                            "VAT "
                            "needs "
                            "to "
                            "be "
                            "reported.",
                            "type": "string",
                            "x-node_available_in": ["uk", "eu"],
                            "x-node_unavailable_in": [],
                        },
                        "amount": {
                            "description": "Amount of the transaction",
                            "example": 2000,
                            "format": "double",
                            "type": "number",
                        },
                        "description": {
                            "description": "A brief description about the transaction.",
                            "type": "string",
                        },
                        "item_order": {
                            "description": "Order of the Item",
                            "example": 1,
                            "type": "integer",
                        },
                        "line_item_id": {
                            "description": "ID of the Line Item",
                            "example": "460000000012834",
                            "format": "int64",
                            "type": "integer",
                        },
                        "product_type": {
                            "description": "Type "
                            "of "
                            "the "
                            "transaction. "
                            "This "
                            "denotes "
                            "whether "
                            "the "
                            "transaction "
                            "line "
                            "item "
                            "is "
                            "to "
                            "be "
                            "treated "
                            "as "
                            "goods "
                            "or "
                            "as "
                            "a "
                            "service. "
                            "Allowed "
                            "Values: "
                            "<br/> "
                            "<b>For "
                            "UK "
                            "and "
                            "Europe: "
                            "</b><code>digital_service</code>, "
                            "<code>goods</code> "
                            "and "
                            "<code>service</code>.<br/><b>For "
                            "SouthAfrica "
                            "Edition:</b> "
                            "<code>service</code>, "
                            "<code>goods</code>, "
                            "<code>capital_service</code> "
                            "and "
                            "<code>capital_goods</code>",
                            "type": "string",
                            "x-node_available_in": ["uk", "eu", "za"],
                            "x-node_unavailable_in": [],
                        },
                        "reverse_charge_vat_id": {
                            "description": "(Optional) "
                            "This "
                            "is "
                            "the "
                            "ID "
                            "of "
                            "the "
                            "tax "
                            "applied "
                            "in "
                            "case "
                            "this "
                            "is "
                            "a "
                            "non "
                            "UK "
                            "- "
                            "service "
                            "purchase "
                            "or "
                            "expense "
                            "and "
                            "reverse "
                            "charge "
                            "VAT "
                            "needs "
                            "to "
                            "be "
                            "reported.",
                            "type": "string",
                            "x-node_available_in": ["uk", "eu"],
                            "x-node_unavailable_in": [],
                        },
                        "tags": {
                            "items": {
                                "properties": {
                                    "tag_id": {
                                        "description": "ID of the Tag",
                                        "format": "int64",
                                        "type": "integer",
                                    },
                                    "tag_option_id": {
                                        "description": "Id of the Tag Option",
                                        "format": "int64",
                                        "type": "integer",
                                    },
                                },
                                "type": "object",
                            },
                            "type": "array",
                        },
                        "tax_exemption_code": {
                            "description": "Code of the Tax Exemption",
                            "type": "string",
                            "x-node_available_in": ["in", "us", "au", "ca"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_exemption_id": {
                            "description": "ID of the Tax Exemption",
                            "type": "string",
                            "x-node_available_in": ["in", "us", "au", "ca"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_id": {
                            "description": "ID of the tax or tax group applied",
                            "type": "string",
                            "x-node_available_in": [],
                            "x-node_unavailable_in": ["us"],
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "mileage_rate": {
                "description": "Mileage Rate to be Applied",
                "example": 0,
                "format": "double",
                "type": "number",
            },
            "mileage_type": {
                "description": "Type of Mileage. Allowed Values : "
                "<code>gmaps</code>,<code>imaps</code>,<code>gps</code>,<code>odometer</code>,<code>wmaps</code>,<code>manual</code>,<code>non_mileage</code> "
                "and <code>per_diem</code>",
                "example": "non_mileage",
                "type": "string",
            },
            "mileage_unit": {"description": "Unit of Mileage", "example": "km", "type": "string"},
            "paid_through_account_id": {
                "description": "ID of the credit/ bank account the payment is made.",
                "example": "460000000000358",
                "type": "string",
            },
            "product_type": {
                "description": "Type of the transaction. This denotes "
                "whether the transaction line item is "
                "to be treated as goods or as a "
                "service. Allowed Values: <br/> <b>For "
                "UK and Europe: "
                "</b><code>digital_service</code>, "
                "<code>goods</code> and "
                "<code>service</code>.<br/><b>For "
                "SouthAfrica Edition:</b> "
                "<code>service</code>, "
                "<code>goods</code>, "
                "<code>capital_service</code> and "
                "<code>capital_goods</code>",
                "type": "string",
                "x-node_available_in": ["uk", "eu", "za"],
                "x-node_unavailable_in": [],
            },
            "project_id": {
                "description": "ID of the project associated with the expense.",
                "type": "string",
            },
            "reason": {"description": "Reason", "type": "string"},
            "recurring_expense_id": {
                "description": "ID of the Recurring Expense",
                "format": "int64",
                "type": "integer",
            },
            "reference_number": {
                "description": "Reference Number of the transaction",
                "example": "Ref-121",
                "type": "string",
            },
            "reverse_charge_vat_id": {
                "description": "(Optional) This is the ID of "
                "the tax applied in case this "
                "is a non UK - service "
                "purchase or expense and "
                "reverse charge VAT needs to "
                "be reported.",
                "type": "string",
                "x-node_available_in": ["uk", "eu"],
                "x-node_unavailable_in": [],
            },
            "start_reading": {"description": "Start Reading of the Odometer", "type": "string"},
            "tags": {
                "items": {
                    "properties": {
                        "tag_id": {
                            "description": "ID of the Tag",
                            "format": "int64",
                            "type": "integer",
                        },
                        "tag_option_id": {
                            "description": "Id of the Tag Option",
                            "format": "int64",
                            "type": "integer",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "tax_exemption_code": {
                "description": "Code of the Tax Exemption",
                "type": "string",
                "x-node_available_in": ["in", "us", "au", "ca"],
                "x-node_unavailable_in": [],
            },
            "tax_exemption_id": {
                "description": "ID of the Tax Exemption",
                "type": "string",
                "x-node_available_in": ["in", "us", "au", "ca"],
                "x-node_unavailable_in": [],
            },
            "tax_id": {
                "description": "ID of the tax or tax group applied",
                "type": "string",
                "x-node_available_in": [],
                "x-node_unavailable_in": ["us"],
            },
            "tax_treatment": {
                "description": "VAT treatment for the bank "
                "transaction.Choose whether the "
                "contact falls under: "
                "<code>vat_registered</code>,<code>vat_not_registered</code>,<code>gcc_vat_not_registered</code>,<code>gcc_vat_registered</code>,<code>non_gcc</code>.</br><code>dz_vat_registered</code> "
                "and "
                "<code>dz_vat_not_registered</code> "
                "are supported only for "
                "<b>UAE</b>.<br/><b>For Kenya "
                "Edition:</b> "
                "<code>vat_registered</code> "
                ",<code>vat_not_registered</code> "
                ",<code>non_kenya</code>(A business "
                "that is located outside "
                "Kenya).<br/><b>For SouthAfrica "
                "Edition:</b> "
                "<code>vat_registered</code>, "
                "<code>vat_not_registered</code>, "
                "<code>overseas</code>(A business "
                "that is located outside "
                "SouthAfrica).",
                "example": "vat_registered",
                "type": "string",
                "x-node_available_in": ["gcc", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "taxes": {
                "items": {
                    "properties": {
                        "tax_amount": {
                            "description": "Amount of Tax",
                            "example": 0,
                            "format": "double",
                            "type": "number",
                        },
                        "tax_id": {
                            "description": "ID of the tax or tax group applied",
                            "type": "string",
                            "x-node_available_in": [],
                            "x-node_unavailable_in": ["us"],
                        },
                        "tax_name": {"description": "Name of the Tax", "type": "string"},
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "vat_treatment": {
                "description": "VAT treatment for the bank "
                "transaction. VAT treatment denotes "
                "the location of the customer or "
                "vendor. If the customer or vendor "
                "resides in the UK then the VAT "
                "treatment is <code>uk</code>. If the "
                "customer or vendor is in an EU "
                "country & VAT registered, you are "
                "resides in Northen Ireland and "
                "purchasing/selling Goods then his "
                "VAT treatment is "
                "<code>eu_vat_registered</code>. And, "
                "if he resides outside the UK then "
                "his VAT treatment is "
                "<code>overseas</code>.",
                "type": "string",
                "x-node_available_in": ["uk", "eu"],
                "x-node_unavailable_in": [],
            },
            "vehicle_id": {"description": "ID of the Vehicle", "type": "string"},
            "vendor_id": {
                "description": "ID of the Vendor",
                "example": "460000000026049",
                "type": "string",
            },
            "zcrm_potential_id": {"format": "int64", "type": "integer"},
            "zp_client_id": {"description": "ID of client", "format": "int64", "type": "integer"},
            "zp_project_id": {
                "description": "ID of the Project",
                "format": "int64",
                "type": "integer",
            },
            "zp_project_name": {"description": "Name of the Project", "type": "string"},
        },
        "type": "object",
    },
    "CATEGORIZETRANSACTIONASVENDORPAYMENT_REQUEST_BODY_SCHEMA": {
        "properties": {
            "amount": {
                "description": "Amount of the transaction",
                "example": 2000,
                "format": "double",
                "type": "number",
            },
            "bills": {
                "items": {
                    "properties": {
                        "amount_applied": {
                            "description": "Amount applied to the Entity",
                            "example": 150,
                            "format": "double",
                            "type": "number",
                        },
                        "bill_id": {
                            "description": "ID of the Bill",
                            "example": "460000000053199",
                            "type": "string",
                        },
                        "bill_payment_id": {
                            "description": "ID of the Bill Payment",
                            "type": "string",
                        },
                        "tax_amount_withheld": {"example": 0, "format": "double", "type": "number"},
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "check_details": {
                "items": {
                    "properties": {
                        "check_number": {
                            "description": "Number of the Check Created",
                            "type": "string",
                        },
                        "memo": {"type": "string"},
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "custom_fields": {
                "items": {
                    "properties": {
                        "index": {"description": "Index of the custom field", "type": "integer"},
                        "value": {"description": "Value of the Custom Field", "type": "string"},
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "date": {"description": "Transaction date.", "example": "2013-10-01", "type": "string"},
            "description": {
                "description": "A brief description about the transaction.",
                "type": "string",
            },
            "exchange_rate": {
                "description": "The foreign currency exchange rate value.",
                "example": 1,
                "type": "integer",
            },
            "is_paid_via_print_check": {
                "description": "Is the entity paid via print check",
                "example": False,
                "type": "boolean",
                "x-node_available_in": ["us", "ca"],
                "x-node_unavailable_in": [],
            },
            "paid_through_account_id": {
                "description": "ID of the credit/ bank account the payment is made.",
                "example": "460000000000358",
                "type": "string",
            },
            "payment_mode": {
                "description": "Mode of payment for the transaction. "
                "(not applicable for transfer_fund, "
                "card_payment, owner_drawings). "
                "Ex:cash, cheque, etc.,",
                "example": "Cash",
                "type": "string",
            },
            "reference_number": {
                "description": "Reference Number of the transaction",
                "example": "Ref-121",
                "type": "string",
            },
            "vendor_id": {
                "description": "ID of the Vendor",
                "example": "460000000026049",
                "type": "string",
            },
        },
        "type": "object",
    },
    "CATEGORIZETRANSACTIONASPAYMENT_REQUEST_BODY_SCHEMA": {
        "properties": {
            "account_id": {
                "description": "Mandatory Account id for which transactions are to be listed.",
                "example": "460000000048001",
                "type": "string",
            },
            "amount": {
                "description": "Amount of the transaction",
                "example": 2000,
                "format": "double",
                "type": "number",
            },
            "bank_charges": {
                "description": "Bank Charges applied to the transaction",
                "example": 0,
                "format": "double",
                "type": "number",
            },
            "contact_persons": {
                "description": "Array of contact person(s) for whom invoice has to be sent.",
                "example": ["460000000870911", "460000000870915"],
                "items": {"type": "string"},
                "type": "array",
            },
            "custom_fields": {
                "items": {
                    "properties": {
                        "index": {"description": "Index of the custom field", "type": "integer"},
                        "value": {"description": "Value of the Custom Field", "type": "string"},
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "customer_id": {
                "description": "ID of the customer or vendor.",
                "example": "460000000000111",
                "type": "string",
            },
            "date": {"description": "Transaction date.", "example": "2013-10-01", "type": "string"},
            "description": {
                "description": "A brief description about the transaction.",
                "type": "string",
            },
            "documents": {
                "description": "List of files to be attached to a particular transaction.",
                "items": {
                    "properties": {
                        "document_id": {"description": "Unique ID of the attached file."},
                        "file_name": {"description": "Name of the attached file."},
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "exchange_rate": {
                "description": "The foreign currency exchange rate value.",
                "example": 1,
                "type": "integer",
            },
            "invoices": {
                "items": {
                    "properties": {
                        "amount_applied": {
                            "description": "Amount applied to the Entity",
                            "example": 150,
                            "format": "double",
                            "type": "number",
                        },
                        "discount_amount": {
                            "description": "Amount of discount in the Invoice",
                            "example": 20,
                            "format": "double",
                            "type": "number",
                        },
                        "invoice_id": {
                            "description": "ID of the Invoice",
                            "example": "460000000000481",
                            "format": "int64",
                            "type": "integer",
                        },
                        "invoice_payment_id": {
                            "description": "ID of the Invoice Payment",
                            "example": "460000000134123",
                            "format": "int64",
                            "type": "integer",
                        },
                        "tax_amount_withheld": {"example": 0, "format": "double", "type": "number"},
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "payment_mode": {
                "description": "Mode of payment for the transaction. "
                "(not applicable for transfer_fund, "
                "card_payment, owner_drawings). "
                "Ex:cash, cheque, etc.,",
                "example": "Cash",
                "type": "string",
            },
            "reference_number": {
                "description": "Reference Number of the transaction",
                "example": "Ref-121",
                "type": "string",
            },
            "retainerinvoice_id": {
                "description": "ID of the Retainer Invoice",
                "format": "int64",
                "type": "integer",
            },
            "template_id": {
                "description": "ID of the template",
                "format": "int64",
                "type": "integer",
            },
        },
        "type": "object",
    },
    "CATEGORIZETRANSACTIONASREFUND_REQUEST_BODY_SCHEMA": {
        "properties": {
            "amount": {
                "description": "Amount of the transaction",
                "example": 2000,
                "format": "double",
                "type": "number",
            },
            "creditnote_id": {
                "description": "ID of the credit note that has to be refunded.",
                "example": "4000000030049",
                "type": "string",
            },
            "date": {"description": "Transaction date.", "example": "2013-10-01", "type": "string"},
            "description": {
                "description": "A brief description about the transaction.",
                "type": "string",
            },
            "exchange_rate": {
                "description": "The foreign currency exchange rate value.",
                "example": 1,
                "type": "integer",
            },
            "from_account_id": {
                "description": "The account ID from which money "
                "will be transferred(Mandatory for "
                "specific type of transactions). "
                "These accounts differ with respect "
                "to transaction_type. Ex: To a bank "
                "account, from-account can be: bank "
                ", card, income, refund. To a card "
                "account, from account can be: "
                "bank, card, refund.",
                "example": "460000000070003",
                "type": "string",
            },
            "reference_number": {
                "description": "Reference Number of the transaction",
                "example": "Ref-121",
                "type": "string",
            },
            "refund_mode": {
                "description": "Mode of refund. Ex - Cash, Cheque etc.,",
                "example": "Cash",
                "type": "string",
            },
        },
        "required": ["creditnote_id", "date"],
        "type": "object",
    },
    "CATEGORIZEREFUNDVENDORCREDIT_REQUEST_BODY_SCHEMA": {
        "properties": {
            "account_id": {
                "description": "Mandatory Account id for which transactions are to be listed.",
                "example": "460000000048001",
                "type": "string",
            },
            "amount": {
                "description": "Amount of the transaction",
                "example": 2000,
                "format": "double",
                "type": "number",
            },
            "date": {"description": "Transaction date.", "example": "2013-10-01", "type": "string"},
            "description": {
                "description": "A brief description about the transaction.",
                "type": "string",
            },
            "exchange_rate": {
                "description": "The foreign currency exchange rate value.",
                "example": 1,
                "type": "integer",
            },
            "reference_number": {
                "description": "Reference Number of the transaction",
                "example": "Ref-121",
                "type": "string",
            },
            "refund_mode": {
                "description": "Mode of refund. Ex - Cash, Cheque etc.,",
                "example": "Cash",
                "type": "string",
            },
            "vendor_credit_id": {
                "description": "ID of the vendor credit that has to be refunded.",
                "example": "460000000030049",
                "type": "string",
            },
        },
        "required": ["vendor_credit_id", "date"],
        "type": "object",
    },
    "CATEGORIZEBANKTRANSACTIONPAYMENTREFUND_REQUEST_BODY_SCHEMA": {
        "properties": {
            "amount": {
                "description": "Amount of the transaction",
                "example": 2000,
                "format": "double",
                "type": "number",
            },
            "date": {"description": "Transaction date.", "example": "2013-10-01", "type": "string"},
            "description": {
                "description": "A brief description about the transaction.",
                "type": "string",
            },
            "exchange_rate": {
                "description": "The foreign currency exchange rate value.",
                "example": 1,
                "type": "integer",
            },
            "from_account_id": {
                "description": "The account ID from which money "
                "will be transferred(Mandatory for "
                "specific type of transactions). "
                "These accounts differ with respect "
                "to transaction_type. Ex: To a bank "
                "account, from-account can be: bank "
                ", card, income, refund. To a card "
                "account, from account can be: "
                "bank, card, refund.",
                "example": "460000000070003",
                "type": "string",
            },
            "reference_number": {
                "description": "Reference Number of the transaction",
                "example": "Ref-121",
                "type": "string",
            },
            "refund_mode": {
                "description": "Mode of refund. Ex - Cash, Cheque etc.,",
                "example": "Cash",
                "type": "string",
            },
        },
        "required": ["date", "amount", "from_account_id"],
        "type": "object",
    },
    "CATEGORIZEVENDORPAYMENTREFUND_REQUEST_BODY_SCHEMA": {
        "properties": {
            "amount": {
                "description": "Amount of the transaction",
                "example": 2000,
                "format": "double",
                "type": "number",
            },
            "date": {"description": "Transaction date.", "example": "2013-10-01", "type": "string"},
            "description": {
                "description": "A brief description about the transaction.",
                "type": "string",
            },
            "exchange_rate": {
                "description": "The foreign currency exchange rate value.",
                "example": 1,
                "type": "integer",
            },
            "reference_number": {
                "description": "Reference Number of the transaction",
                "example": "Ref-121",
                "type": "string",
            },
            "refund_mode": {
                "description": "Mode of refund. Ex - Cash, Cheque etc.,",
                "example": "Cash",
                "type": "string",
            },
            "to_account_id": {
                "description": "ID of the account to which the money "
                "gets transferred(Mandatory for "
                "specific type of transactions). Ex: "
                "From a bank account, to-account can "
                "be: bank, card, drawings, "
                "expense,credit notes. From a card "
                "account, to-account can be: card, "
                "bank, expense.",
                "example": "460000000048001",
                "type": "string",
            },
            "vendorpayment_id": {
                "description": "Vendor Payment to which you want to record the refund.",
                "example": "460000000012345",
                "type": "string",
            },
        },
        "required": ["date", "amount", "to_account_id"],
        "type": "object",
    },
    "CREATECURRENCYADJUSTMENT_REQUEST_BODY_SCHEMA": {
        "properties": {
            "adjustment_date": {
                "description": "Date of adjustment.",
                "example": "2013-09-05",
                "type": "string",
            },
            "currency_id": {
                "description": "ID of currency for which we need to post adjustment.",
                "example": "460000000000109",
                "type": "string",
            },
            "exchange_rate": {
                "description": "Exchange rate of the currency.",
                "example": 1,
                "format": "double",
                "type": "number",
            },
            "notes": {
                "description": "Notes for base currency adjustment.",
                "example": "Base Currency Adjustment against EUR",
                "type": "string",
            },
        },
        "required": ["currency_id", "adjustment_date", "exchange_rate", "notes"],
        "type": "object",
    },
    "CREATEVENDORBILL_REQUEST_BODY_SCHEMA": {
        "properties": {
            "adjustment": {
                "description": "Additional amount added to or "
                "subtracted from bill total. Positive "
                "values increase total, negative values "
                "decrease total. Used for discounts, "
                "surcharges, rounding adjustments, or "
                "other modifications. Affects final bill "
                "amount, tax calculations, and payment "
                "processing.",
                "example": 0,
                "format": "double",
                "type": "number",
            },
            "adjustment_description": {
                "description": "Text description explaining "
                "the reason for bill "
                "adjustment. Examples: "
                '"Early payment discount", '
                '"Volume discount", '
                '"Rounding adjustment", '
                '"Handling fee". Helps in '
                "audit trails and reporting. "
                "Required when adjustment "
                "amount is non-zero. Used in "
                "financial reports, tax "
                "returns, and vendor "
                "communications. Should be "
                "clear and specific for "
                "compliance purposes.",
                "example": " ",
                "type": "string",
            },
            "approvers": {
                "items": {
                    "properties": {
                        "approver_id": {
                            "description": "ID of the Approver",
                            "format": "int64",
                            "type": "integer",
                        },
                        "order": {"description": "Order of the Approver", "type": "integer"},
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "bill_number": {
                "description": "Unique sequential identifier for the "
                "bill. Used for tracking and reference "
                "purposes. Format varies by "
                "organization settings. Can be "
                "auto-generated or manually entered. "
                "Must be unique within the "
                "organization.",
                "example": "00454",
                "type": "string",
            },
            "currency_id": {
                "description": "Unique identifier for the currency "
                "used in the bill transaction. Can be "
                "fetched from the Currencies API if "
                "multi-currency is enabled.",
                "example": "460000000000099",
                "type": "string",
            },
            "custom_fields": {
                "items": {
                    "properties": {
                        "index": {"description": "Index of the custom field", "type": "integer"},
                        "value": {"description": "Value of the Custom Field", "type": "string"},
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "date": {
                "description": "Date when the bill was issued by the vendor. "
                "Format: yyyy-mm-dd. Used for payment terms "
                "and aging calculations. This date determines "
                "when payment terms begin and affects aging "
                "reports, late payment calculations, and "
                "financial reporting.",
                "example": "2013-09-11",
                "type": "string",
            },
            "destination_of_supply": {
                "description": "State code where "
                "goods/services are "
                "delivered. Used for GST "
                "calculations in India. "
                "Defaults to organization "
                "home state if not specified. "
                "Supports 2-letter state "
                "codes (e.g., AP for Andhra "
                "Pradesh, TN for Tamil Nadu).",
                "example": "TN",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "documents": {
                "items": {
                    "properties": {
                        "document_id": {
                            "description": "ID of the Document",
                            "format": "int64",
                            "type": "integer",
                        },
                        "file_name": {"description": "Name of the file", "type": "string"},
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "due_date": {
                "description": "Date when payment is due for the bill. "
                "Used for payment tracking, aging reports, "
                "and overdue calculations. Calculated "
                "based on bill date and payment terms. "
                "Bills become overdue after this date, "
                "affecting vendor relationships and cash "
                "flow planning.",
                "example": "2013-09-26",
                "type": "string",
            },
            "exchange_rate": {
                "description": "Exchange rate from bill currency to "
                "organization base currency. Used for "
                "multi-currency transactions. 1.0 "
                "indicates same as base currency. "
                "Required when currency differs from "
                "organization default. Affects "
                "financial reporting, profit/loss "
                "calculations, and tax computations. "
                "Can be manually set or auto-fetched "
                "from currency exchange services.",
                "example": 1.23,
                "format": "double",
                "type": "number",
            },
            "gst_no": {
                "description": "15 digit GST identification number of the vendor.",
                "example": "22AAAAA0000A1Z5",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "gst_treatment": {
                "description": "Choose whether the contact is GST "
                "registered/unregistered/consumer/overseas. "
                "Allowed values are <code> "
                "business_gst </code> , <code> "
                "business_none </code> , <code> "
                "overseas </code> , <code> consumer "
                "</code>.",
                "example": "business_gst",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "is_inclusive_tax": {
                "description": "Flag indicating whether line item "
                "rates include tax amounts. When "
                "true, tax is calculated on top of "
                "displayed rates. When false, tax "
                "is added separately. Affects "
                "total calculations and tax "
                "reporting. Common in countries "
                "where tax-inclusive pricing is "
                "standard. Impacts customer-facing "
                "documents and tax return "
                "preparation.",
                "example": False,
                "type": "boolean",
                "x-node_unavailable_in": ["us"],
            },
            "is_item_level_tax_calc": {
                "description": "Flag indicating whether "
                "taxes are calculated at "
                "individual line item level "
                "rather than bill total. "
                "Enables different tax rates "
                "for different items. "
                "Provides more accurate tax "
                "calculations for mixed tax "
                "scenarios. When enabled, "
                "each line item can have "
                "different tax rates based "
                "on item type, location, or "
                "tax rules. Improves tax "
                "compliance and reporting "
                "accuracy.",
                "example": False,
                "type": "boolean",
            },
            "is_update_customer": {
                "description": "Flag to determine if customer "
                "information should be updated "
                "when creating the bill.",
                "example": False,
                "type": "boolean",
            },
            "line_items": {
                "description": "Line items of a bill.",
                "items": {
                    "properties": {
                        "account_id": {
                            "description": "Unique "
                            "identifier "
                            "for "
                            "the "
                            "chart "
                            "of "
                            "accounts "
                            "entry. "
                            "Can "
                            "be "
                            "fetched "
                            "from "
                            "the "
                            "Chart "
                            "of "
                            "Accounts "
                            "API. "
                            "Determines "
                            "how "
                            "this "
                            "expense "
                            "is "
                            "categorized "
                            "in "
                            "financial "
                            "reports "
                            "and "
                            "general "
                            "ledger. "
                            "Required "
                            "for "
                            "proper "
                            "expense "
                            "classification "
                            "and "
                            "accounting "
                            "compliance.",
                            "example": "460000000000403",
                            "type": "string",
                        },
                        "acquisition_vat_id": {
                            "description": "(Optional) "
                            "This "
                            "is "
                            "the "
                            "ID "
                            "of "
                            "the "
                            "tax "
                            "applied "
                            "in "
                            "case "
                            "this "
                            "is "
                            "an "
                            "EU "
                            "- "
                            "goods "
                            "purchase "
                            "and "
                            "acquisition "
                            "VAT "
                            "needs "
                            "to "
                            "be "
                            "reported.",
                            "type": "string",
                            "x-node_available_in": ["uk"],
                            "x-node_unavailable_in": [],
                        },
                        "customer_id": {"description": "ID of the Customer", "type": "string"},
                        "description": {
                            "description": "Detailed "
                            "description "
                            "of "
                            "the "
                            "line "
                            "item. "
                            "Provides "
                            "additional "
                            "context "
                            "about "
                            "the "
                            "product, "
                            "service, "
                            "or "
                            "expense. "
                            "Used "
                            "for "
                            "vendor "
                            "communication, "
                            "internal "
                            "documentation, "
                            "and "
                            "expense "
                            "justification. "
                            "Can "
                            "include "
                            "specifications, "
                            "requirements, "
                            "or "
                            "special "
                            "instructions.",
                            "type": "string",
                        },
                        "hsn_or_sac": {
                            "description": "Add HSN/SAC code for your goods/services",
                            "example": 80540,
                            "type": "string",
                            "x-node_available_in": ["in", "ke", "za"],
                            "x-node_unavailable_in": [],
                        },
                        "is_billable": {
                            "description": "Boolean "
                            "flag "
                            "indicating "
                            "whether "
                            "the "
                            "line "
                            "item "
                            "or "
                            "entity "
                            "can "
                            "be "
                            "billed "
                            "to "
                            "customers "
                            "or "
                            "clients. "
                            "Determines "
                            "if "
                            "costs "
                            "are "
                            "recoverable "
                            "through "
                            "customer "
                            "billing, "
                            "affects "
                            "project "
                            "profitability "
                            "calculations, "
                            "and "
                            "controls "
                            "expense "
                            "allocation "
                            "for "
                            "client "
                            "projects "
                            "and "
                            "service "
                            "delivery.",
                            "example": False,
                            "type": "boolean",
                        },
                        "item_custom_fields": {
                            "items": {
                                "properties": {
                                    "custom_field_id": {"format": "int64", "type": "integer"},
                                    "index": {
                                        "description": "Index of the custom field",
                                        "type": "integer",
                                    },
                                    "label": {
                                        "description": "Label of the Custom Field",
                                        "type": "string",
                                    },
                                    "value": {
                                        "description": "Value of the Custom Field",
                                        "type": "string",
                                    },
                                },
                                "type": "object",
                            },
                            "type": "array",
                        },
                        "item_id": {
                            "description": "Unique "
                            "identifier "
                            "for "
                            "the "
                            "product "
                            "or "
                            "service "
                            "item. "
                            "Can "
                            "be "
                            "fetched "
                            "from "
                            "the "
                            "Items "
                            "API. "
                            "When "
                            "specified, "
                            "automatically "
                            "populates "
                            "item "
                            "details "
                            "like "
                            "name, "
                            "description, "
                            "and "
                            "default "
                            "rates. "
                            "Required "
                            "for "
                            "inventory "
                            "tracking "
                            "and "
                            "item-based "
                            "reporting.",
                            "example": "460000000054135",
                            "type": "string",
                        },
                        "item_order": {"example": 1, "type": "integer"},
                        "line_item_id": {
                            "description": "Unique "
                            "identifier "
                            "for "
                            "this "
                            "specific "
                            "line "
                            "item "
                            "within "
                            "the "
                            "bill. "
                            "Auto-generated "
                            "when "
                            "line "
                            "item "
                            "is "
                            "created. "
                            "Used "
                            "for "
                            "updating, "
                            "deleting, "
                            "or "
                            "referencing "
                            "specific "
                            "line "
                            "items "
                            "in "
                            "API "
                            "operations.",
                            "example": "460000000067009",
                            "type": "string",
                        },
                        "location_id": {
                            "description": "Unique "
                            "identifier "
                            "for "
                            "the "
                            "business "
                            "location "
                            "where "
                            "the "
                            "bill "
                            "transaction "
                            "occurs. "
                            "Used "
                            "for "
                            "multi-location "
                            "organizations "
                            "to "
                            "track "
                            "expenses "
                            "by "
                            "location. "
                            "Affects "
                            "reporting "
                            "and "
                            "tax "
                            "calculations "
                            "based "
                            "on "
                            "location-specific "
                            "rules. "
                            "Can "
                            "be "
                            "fetched "
                            "from "
                            "the "
                            "Locations "
                            "API. "
                            "Required "
                            "for "
                            "organizations "
                            "with "
                            "multiple "
                            "locations. "
                            "Influences "
                            "tax "
                            "rates, "
                            "reporting "
                            "structures, "
                            "and "
                            "approval "
                            "workflows "
                            "based "
                            "on "
                            "location-specific "
                            "configurations.",
                            "example": "460000000038080",
                            "type": "string",
                        },
                        "name": {
                            "description": "Name "
                            "or "
                            "description "
                            "of "
                            "the "
                            "line "
                            "item. "
                            "Can "
                            "be "
                            "manually "
                            "entered "
                            "or "
                            "auto-populated "
                            "from "
                            "item "
                            "details. "
                            "Should "
                            "clearly "
                            "describe "
                            "the "
                            "product, "
                            "service, "
                            "or "
                            "expense "
                            "for "
                            "vendor "
                            "and "
                            "accounting "
                            "purposes.",
                            "type": "string",
                        },
                        "product_type": {
                            "description": "Type "
                            "of "
                            "the "
                            "bill. "
                            "This "
                            "denotes "
                            "whether "
                            "the "
                            "bill "
                            "line "
                            "item "
                            "is "
                            "to "
                            "be "
                            "treated "
                            "as "
                            "a "
                            "goods "
                            "or "
                            "service "
                            "purchase. "
                            "This "
                            "only "
                            "need "
                            "to "
                            "be "
                            "specified "
                            "in "
                            "case "
                            "purchase "
                            "order "
                            "is "
                            "not "
                            "enabled. "
                            "Allowed "
                            "Values: "
                            "<code> "
                            "digital_service</code>, "
                            "<code>goods</code> "
                            "and "
                            "<code>service</code>.",
                            "type": "string",
                            "x-node_available_in": ["eu", "uk"],
                            "x-node_unavailable_in": [],
                        },
                        "project_id": {"description": "ID of the Project", "type": "string"},
                        "purchaseorder_item_id": {
                            "description": "Unique "
                            "identifier "
                            "linking "
                            "this "
                            "line "
                            "item "
                            "to "
                            "a "
                            "specific "
                            "item "
                            "in "
                            "the "
                            "purchase "
                            "order. "
                            "Used "
                            "for "
                            "tracking "
                            "PO-to-bill "
                            "conversions "
                            "and "
                            "maintaining "
                            "audit "
                            "trails. "
                            "Required "
                            "when "
                            "converting "
                            "purchase "
                            "orders "
                            "to "
                            "bills.",
                            "type": "string",
                        },
                        "quantity": {
                            "description": "Number "
                            "of "
                            "units "
                            "for "
                            "the "
                            "line "
                            "item. "
                            "Used "
                            "to "
                            "calculate "
                            "line "
                            "item "
                            "totals "
                            "(quantity "
                            "x "
                            "rate). "
                            "Supports "
                            "decimal "
                            "quantities "
                            "for "
                            "items "
                            "sold "
                            "by "
                            "weight, "
                            "length, "
                            "or "
                            "other "
                            "non-whole "
                            "units. "
                            "Required "
                            "for "
                            "accurate "
                            "billing "
                            "and "
                            "inventory "
                            "tracking.",
                            "example": 1,
                            "format": "double",
                            "type": "number",
                        },
                        "rate": {
                            "description": "Unit "
                            "price "
                            "or "
                            "rate "
                            "for "
                            "the "
                            "line "
                            "item. "
                            "Can "
                            "be "
                            "manually "
                            "entered "
                            "or "
                            "auto-populated "
                            "from "
                            "item "
                            "details "
                            "or "
                            "price "
                            "books. "
                            "Used "
                            "to "
                            "calculate "
                            "line "
                            "item "
                            "totals. "
                            "Supports "
                            "decimal "
                            "precision "
                            "based "
                            "on "
                            "currency "
                            "settings.",
                            "example": 10,
                            "format": "double",
                            "type": "number",
                        },
                        "reverse_charge_tax_id": {
                            "description": "Reverse charge tax ID",
                            "example": 460000000038056,
                            "type": "string",
                            "x-node_available_in": ["in", "gcc", "za"],
                            "x-node_unavailable_in": [],
                        },
                        "reverse_charge_vat_id": {
                            "description": "(Optional) "
                            "This "
                            "is "
                            "the "
                            "ID "
                            "of "
                            "the "
                            "tax "
                            "applied "
                            "in "
                            "case "
                            "this "
                            "is "
                            "a "
                            "non "
                            "UK "
                            "- "
                            "service "
                            "purchase "
                            "and "
                            "reverse "
                            "charge "
                            "VAT "
                            "needs "
                            "to "
                            "be "
                            "reported.",
                            "type": "string",
                            "x-node_available_in": ["uk"],
                            "x-node_unavailable_in": [],
                        },
                        "serial_numbers": {"items": {"type": "string"}, "type": "array"},
                        "tags": {
                            "items": {
                                "properties": {
                                    "tag_id": {
                                        "description": "ID of the Tag",
                                        "example": "460000000054178",
                                        "format": "int64",
                                        "type": "integer",
                                    },
                                    "tag_option_id": {
                                        "description": "Id of the Tag Option",
                                        "example": "460000000054180",
                                        "format": "int64",
                                        "type": "integer",
                                    },
                                },
                                "type": "object",
                            },
                            "type": "array",
                        },
                        "tax_exemption_code": {
                            "description": "Code of the Tax Exemption Applied",
                            "type": "string",
                            "x-node_available_in": ["in", "au", "ca", "mx"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_exemption_id": {
                            "description": "ID of the Tax Exemption Applied",
                            "type": "string",
                            "x-node_available_in": ["in", "au", "ca"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_id": {
                            "description": "Unique "
                            "identifier "
                            "for "
                            "the "
                            "tax "
                            "or "
                            "tax "
                            "group "
                            "applied "
                            "to "
                            "this "
                            "line "
                            "item. "
                            "Can "
                            "be "
                            "fetched "
                            "from "
                            "the "
                            "Taxes "
                            "API. "
                            "Determines "
                            "tax "
                            "rate "
                            "and "
                            "calculations "
                            "for "
                            "the "
                            "line "
                            "item. "
                            "Required "
                            "when "
                            "tax "
                            "calculations "
                            "are "
                            "enabled. "
                            "Affects "
                            "final "
                            "line "
                            "item "
                            "total "
                            "and "
                            "tax "
                            "reporting.",
                            "example": "460000000027005",
                            "type": "string",
                            "x-node_available_in": [],
                            "x-node_unavailable_in": ["us"],
                        },
                        "tax_treatment_code": {
                            "description": "Specify "
                            "reason "
                            "for "
                            "using "
                            "out "
                            "of "
                            "scope.</br>Supported "
                            "values "
                            "for "
                            "<b>UAE</b> "
                            "are "
                            "<code>uae_same_tax_group</code>, "
                            "<code>uae_reimbursed_expense</code> "
                            "and "
                            "<code>uae_others</code>.</br> "
                            "Supported "
                            "values "
                            "for "
                            "<b>Bahrain</b> "
                            "are "
                            "<code>bahrain_same_tax_group</code>, "
                            "<code>bahrain_transfer_of_concern</code>, "
                            "<code>bahrain_disbursement</code>, "
                            "<code>bahrain_head_to_branch_transaction</code> "
                            "and "
                            "<code>bahrain_others</code>.</br> "
                            "Supported "
                            "values "
                            "for "
                            "<b>KSA</b> "
                            "are "
                            "<code>ksa_reimbursed_expense</code>.",
                            "example": "uae_others",
                            "type": "string",
                            "x-node_available_in": ["gcc"],
                            "x-node_unavailable_in": [],
                        },
                        "tds_tax_id": {
                            "description": "TDS "
                            "ID "
                            "of "
                            "the "
                            "tax "
                            "or "
                            "tax "
                            "group "
                            "applied "
                            "to "
                            "the "
                            "line "
                            "item",
                            "example": "460000000027009",
                            "type": "string",
                            "x-node_available_in": ["mx"],
                            "x-node_unavailable_in": [],
                        },
                        "unit": {
                            "description": "Unit "
                            "of "
                            "measurement "
                            "for "
                            "the "
                            "item "
                            "quantity. "
                            "Examples: "
                            "pieces, "
                            "kgs, "
                            "liters, "
                            "hours, "
                            "days. "
                            "Used "
                            "for "
                            "accurate "
                            "billing "
                            "and "
                            "inventory "
                            "tracking. "
                            "Auto-populated "
                            "when "
                            "item_id "
                            "is "
                            "specified. "
                            "Important "
                            "for "
                            "vendor "
                            "communication "
                            "and "
                            "expense "
                            "categorization.",
                            "example": "kgs",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "location_id": {
                "description": "Unique identifier for the business "
                "location where the bill transaction "
                "occurs. Used for multi-location "
                "organizations to track expenses by "
                "location. Affects reporting and tax "
                "calculations based on "
                "location-specific rules. Can be "
                "fetched from the Locations API. "
                "Required for organizations with "
                "multiple locations. Influences tax "
                "rates, reporting structures, and "
                "approval workflows based on "
                "location-specific configurations.",
                "example": "460000000038080",
                "type": "string",
            },
            "notes": {
                "description": "Additional information or comments about the "
                "bill. Used for internal communication, "
                "vendor instructions, or special handling "
                "requirements. Visible to vendors and "
                "included in bill communications. Useful for "
                "tracking special arrangements or payment "
                "instructions.",
                "example": "Thanks for your business.",
                "type": "string",
            },
            "payment_terms": {
                "description": "Numeric identifier for payment terms "
                "configuration. Defines when payment "
                "is due relative to bill date. 0 = "
                "Due on Receipt, positive numbers = "
                "days after bill date, negative "
                "numbers = days before bill date. "
                "Common values: 0 (Due on Receipt), "
                "15 (Net 15), 30 (Net 30), 45 (Net "
                "45). Affects due date calculation "
                "and aging reports.",
                "example": 0,
                "type": "integer",
            },
            "payment_terms_label": {
                "description": "Label of the Payment Terms",
                "example": "Due on Receipt",
                "type": "string",
            },
            "permit_number": {
                "description": "The permit number for the bill.",
                "type": "string",
                "x-node_available_in": ["uae"],
                "x-node_unavailable_in": [],
            },
            "place_of_supply": {
                "description": "The place of supply is where a "
                "transaction is considered to have "
                "occurred for VAT purposes. For the "
                "supply of goods, the place of "
                "supply is the location of the "
                "goods when the supply occurs. For "
                "the supply of services, the place "
                "of supply should be where the "
                "supplier is established. (If not "
                "given, <code>place of "
                "contact</code> given for the "
                "contact will be "
                "taken)<br/>Supported codes for UAE "
                "emirates are : </br>Abu Dhabi - "
                "<code>AB</code>,</br>Ajman - "
                "<code>AJ</code>,</br>Dubai - "
                "<code>DU</code>,</br>Fujairah - "
                "<code>FU</code>,</br>Ras "
                "al-Khaimah - "
                "<code>RA</code>,</br>Sharjah - "
                "<code>SH</code>,</br>Umm al-Quwain "
                "- <code>UM</code>.<br/>Supported "
                "codes for the GCC countries are : "
                "</br>United Arab Emirates - "
                "<code>AE</code>,</br>Saudi Arabia "
                "- <code>SA</code>,</br>Bahrain - "
                "<code>BH</code>,</br>Kuwait - "
                "<code>KW</code>,</br>Oman - "
                "<code>OM</code>,</br>Qatar - "
                "<code>QA</code>.",
                "example": "DU",
                "type": "string",
                "x-node_available_in": ["gcc"],
                "x-node_unavailable_in": [],
            },
            "pricebook_id": {
                "description": "Identifier for the price book "
                "containing item rates and pricing "
                "rules. Used to apply standardized "
                "pricing across bills. If not "
                "specified, default pricing from items "
                "will be used. Helps maintain "
                "consistent pricing across multiple "
                "transactions.",
                "example": 460000000038090,
                "type": "string",
            },
            "purchaseorder_ids": {
                "description": "Array of purchase order "
                "identifiers linked to this bill "
                "for tracking purposes.",
                "example": [460000000068231, 460000000068233],
                "items": {"type": "string"},
                "type": "array",
            },
            "recurring_bill_id": {
                "description": "Identifier linking this bill to "
                "a recurring bill template. Used "
                "for bills that are automatically "
                "generated on a schedule (weekly, "
                "monthly, quarterly, etc.). "
                "Enables automated bill "
                "generation, consistent billing "
                "cycles, and reduces manual data "
                "entry. Can be modified to change "
                "recurring schedule.",
                "type": "string",
            },
            "reference_number": {
                "description": "External reference number from "
                "vendor invoice or purchase order. "
                "Used for cross-referencing with "
                "vendor documents. Helps in "
                "reconciliation and tracking "
                "payments. Can include invoice "
                "numbers, PO references, or any "
                "vendor-specific identifiers.",
                "example": "4321133",
                "type": "string",
            },
            "source_of_supply": {
                "description": "State code where goods/services "
                "originate. Used for GST "
                "calculations in India. Defaults "
                "to vendor contact location if not "
                "specified. Supports 2-letter "
                "state codes (e.g., AP for Andhra "
                "Pradesh, TN for Tamil Nadu).",
                "example": "AP",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "tax_treatment": {
                "description": "VAT treatment for the bill. Choose "
                "whether the vendor falls under: "
                "<code>vat_registered</code>,<code>vat_not_registered</code>,<code>gcc_vat_not_registered</code>,<code>gcc_vat_registered</code>,<code>non_gcc</code>.</br><code>dz_vat_registered</code> "
                "and "
                "<code>dz_vat_not_registered</code> "
                "are supported only for "
                "<b>UAE</b>.</b></br><code>home_country_mexico</code>,<code>border_region_mexico</code>,<code>non_mexico</code> "
                "supported only for "
                "<b>MX</b>.<br/><b>For Kenya "
                "Edition:</b> "
                "<code>vat_registered</code> "
                ",<code>vat_not_registered</code> "
                ",<code>non_kenya</code>(A business "
                "that is located outside "
                "Kenya).<br/><b>For SouthAfrica "
                "Edition:</b> "
                "<code>vat_registered</code>, "
                "<code>vat_not_registered</code>, "
                "<code>overseas</code>(A business "
                "that is located outside "
                "SouthAfrica).",
                "example": "vat_registered",
                "type": "string",
                "x-node_available_in": ["gcc", "mx", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "taxes": {
                "items": {
                    "properties": {
                        "tax_amount": {
                            "description": "Amount of Tax in the Bill",
                            "example": 1.25,
                            "type": "string",
                        },
                        "tax_id": {
                            "description": "Unique "
                            "identifier "
                            "for the "
                            "tax or "
                            "tax "
                            "group "
                            "applied "
                            "to this "
                            "line "
                            "item. "
                            "Can be "
                            "fetched "
                            "from the "
                            "Taxes "
                            "API. "
                            "Determines "
                            "tax rate "
                            "and "
                            "calculations "
                            "for the "
                            "line "
                            "item. "
                            "Required "
                            "when tax "
                            "calculations "
                            "are "
                            "enabled. "
                            "Affects "
                            "final "
                            "line "
                            "item "
                            "total "
                            "and tax "
                            "reporting.",
                            "example": "460000000027005",
                            "type": "string",
                            "x-node_available_in": [],
                            "x-node_unavailable_in": ["us"],
                        },
                        "tax_name": {
                            "description": "Name of the Tax",
                            "example": "VAT (12.5%)",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "terms": {
                "description": "Terms and conditions that apply to the bill "
                "transaction. Includes payment terms, "
                "delivery conditions, warranty information, "
                "or other contractual obligations. Displayed "
                "on bill documents and vendor communications. "
                "Important for legal compliance and vendor "
                "relationship management.",
                "example": "Terms and conditions apply.",
                "type": "string",
            },
            "vat_treatment": {
                "description": "(Optional) VAT treatment for the "
                "bill. VAT treatment denotes the "
                "location of the vendor, if the "
                "vendor resides in UK then the VAT "
                "treatment is <code>uk</code>. If the "
                "vendor is in an EU country & VAT "
                "registered, you are resides in "
                "Northen Ireland and purchasing Goods "
                "then his VAT treatment is "
                "<code>eu_vat_registered</code>, if "
                "he resides outside of the UK then "
                "his VAT treatment is "
                "<code>overseas</code> (For Pre "
                "Brexit, this can be split as "
                "<code>eu_vat_registered</code>, "
                "<code>eu_vat_not_registered</code> "
                "and <code>non_eu</code>).",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
            "vendor_id": {
                "description": "Unique identifier for the vendor who "
                "supplied the goods/services. Can be "
                "fetched from the Get Contacts API.",
                "example": "460000000038029",
                "type": "string",
            },
        },
        "required": ["vendor_id", "bill_number"],
        "type": "object",
    },
    "UPDATEBILLBYCUSTOMFIELD_REQUEST_BODY_SCHEMA": {
        "properties": {
            "adjustment": {
                "description": "Additional amount added to or "
                "subtracted from bill total. Positive "
                "values increase total, negative values "
                "decrease total. Used for discounts, "
                "surcharges, rounding adjustments, or "
                "other modifications. Affects final bill "
                "amount, tax calculations, and payment "
                "processing.",
                "example": 0,
                "format": "double",
                "type": "number",
            },
            "adjustment_description": {
                "description": "Text description explaining "
                "the reason for bill "
                "adjustment. Examples: "
                '"Early payment discount", '
                '"Volume discount", '
                '"Rounding adjustment", '
                '"Handling fee". Helps in '
                "audit trails and reporting. "
                "Required when adjustment "
                "amount is non-zero. Used in "
                "financial reports, tax "
                "returns, and vendor "
                "communications. Should be "
                "clear and specific for "
                "compliance purposes.",
                "example": " ",
                "type": "string",
            },
            "approvers": {
                "items": {
                    "properties": {
                        "approver_id": {
                            "description": "ID of the Approver",
                            "format": "int64",
                            "type": "integer",
                        },
                        "order": {"description": "Order of the Approver", "type": "integer"},
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "bill_number": {
                "description": "Unique sequential identifier for the "
                "bill. Used for tracking and reference "
                "purposes. Format varies by "
                "organization settings. Can be "
                "auto-generated or manually entered. "
                "Must be unique within the "
                "organization.",
                "example": "00454",
                "type": "string",
            },
            "currency_id": {
                "description": "Unique identifier for the currency "
                "used in the bill transaction. Can be "
                "fetched from the Currencies API if "
                "multi-currency is enabled.",
                "example": "460000000000099",
                "type": "string",
            },
            "custom_fields": {
                "items": {
                    "properties": {
                        "index": {"description": "Index of the custom field", "type": "integer"},
                        "value": {"description": "Value of the Custom Field", "type": "string"},
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "date": {
                "description": "Date when the bill was issued by the vendor. "
                "Format: yyyy-mm-dd. Used for payment terms "
                "and aging calculations. This date determines "
                "when payment terms begin and affects aging "
                "reports, late payment calculations, and "
                "financial reporting.",
                "example": "2013-09-11",
                "type": "string",
            },
            "destination_of_supply": {
                "description": "State code where "
                "goods/services are "
                "delivered. Used for GST "
                "calculations in India. "
                "Defaults to organization "
                "home state if not specified. "
                "Supports 2-letter state "
                "codes (e.g., AP for Andhra "
                "Pradesh, TN for Tamil Nadu).",
                "example": "TN",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "documents": {
                "items": {
                    "properties": {
                        "document_id": {
                            "description": "ID of the Document",
                            "format": "int64",
                            "type": "integer",
                        },
                        "file_name": {"description": "Name of the file", "type": "string"},
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "due_date": {
                "description": "Date when payment is due for the bill. "
                "Used for payment tracking, aging reports, "
                "and overdue calculations. Calculated "
                "based on bill date and payment terms. "
                "Bills become overdue after this date, "
                "affecting vendor relationships and cash "
                "flow planning.",
                "example": "2013-09-26",
                "type": "string",
            },
            "exchange_rate": {
                "description": "Exchange rate from bill currency to "
                "organization base currency. Used for "
                "multi-currency transactions. 1.0 "
                "indicates same as base currency. "
                "Required when currency differs from "
                "organization default. Affects "
                "financial reporting, profit/loss "
                "calculations, and tax computations. "
                "Can be manually set or auto-fetched "
                "from currency exchange services.",
                "example": 1.23,
                "format": "double",
                "type": "number",
            },
            "gst_no": {
                "description": "15 digit GST identification number of the vendor.",
                "example": "22AAAAA0000A1Z5",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "gst_treatment": {
                "description": "Choose whether the contact is GST "
                "registered/unregistered/consumer/overseas. "
                "Allowed values are <code> "
                "business_gst </code> , <code> "
                "business_none </code> , <code> "
                "overseas </code> , <code> consumer "
                "</code>.",
                "example": "business_gst",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "is_inclusive_tax": {
                "description": "Flag indicating whether line item "
                "rates include tax amounts. When "
                "true, tax is calculated on top of "
                "displayed rates. When false, tax "
                "is added separately. Affects "
                "total calculations and tax "
                "reporting. Common in countries "
                "where tax-inclusive pricing is "
                "standard. Impacts customer-facing "
                "documents and tax return "
                "preparation.",
                "example": False,
                "type": "boolean",
                "x-node_unavailable_in": ["us"],
            },
            "is_item_level_tax_calc": {
                "description": "Flag indicating whether "
                "taxes are calculated at "
                "individual line item level "
                "rather than bill total. "
                "Enables different tax rates "
                "for different items. "
                "Provides more accurate tax "
                "calculations for mixed tax "
                "scenarios. When enabled, "
                "each line item can have "
                "different tax rates based "
                "on item type, location, or "
                "tax rules. Improves tax "
                "compliance and reporting "
                "accuracy.",
                "example": False,
                "type": "boolean",
            },
            "is_update_customer": {
                "description": "Flag to determine if customer "
                "information should be updated "
                "when creating the bill.",
                "example": False,
                "type": "boolean",
            },
            "line_items": {
                "description": "Line items of a bill.",
                "items": {
                    "properties": {
                        "account_id": {
                            "description": "Unique "
                            "identifier "
                            "for "
                            "the "
                            "chart "
                            "of "
                            "accounts "
                            "entry. "
                            "Can "
                            "be "
                            "fetched "
                            "from "
                            "the "
                            "Chart "
                            "of "
                            "Accounts "
                            "API. "
                            "Determines "
                            "how "
                            "this "
                            "expense "
                            "is "
                            "categorized "
                            "in "
                            "financial "
                            "reports "
                            "and "
                            "general "
                            "ledger. "
                            "Required "
                            "for "
                            "proper "
                            "expense "
                            "classification "
                            "and "
                            "accounting "
                            "compliance.",
                            "example": "460000000000403",
                            "type": "string",
                        },
                        "acquisition_vat_id": {
                            "description": "(Optional) "
                            "This "
                            "is "
                            "the "
                            "ID "
                            "of "
                            "the "
                            "tax "
                            "applied "
                            "in "
                            "case "
                            "this "
                            "is "
                            "an "
                            "EU "
                            "- "
                            "goods "
                            "purchase "
                            "and "
                            "acquisition "
                            "VAT "
                            "needs "
                            "to "
                            "be "
                            "reported.",
                            "type": "string",
                            "x-node_available_in": ["uk"],
                            "x-node_unavailable_in": [],
                        },
                        "customer_id": {"description": "ID of the Customer", "type": "string"},
                        "description": {
                            "description": "Detailed "
                            "description "
                            "of "
                            "the "
                            "line "
                            "item. "
                            "Provides "
                            "additional "
                            "context "
                            "about "
                            "the "
                            "product, "
                            "service, "
                            "or "
                            "expense. "
                            "Used "
                            "for "
                            "vendor "
                            "communication, "
                            "internal "
                            "documentation, "
                            "and "
                            "expense "
                            "justification. "
                            "Can "
                            "include "
                            "specifications, "
                            "requirements, "
                            "or "
                            "special "
                            "instructions.",
                            "type": "string",
                        },
                        "hsn_or_sac": {
                            "description": "Add HSN/SAC code for your goods/services",
                            "example": 80540,
                            "type": "string",
                            "x-node_available_in": ["in", "ke", "za"],
                            "x-node_unavailable_in": [],
                        },
                        "is_billable": {
                            "description": "Boolean "
                            "flag "
                            "indicating "
                            "whether "
                            "the "
                            "line "
                            "item "
                            "or "
                            "entity "
                            "can "
                            "be "
                            "billed "
                            "to "
                            "customers "
                            "or "
                            "clients. "
                            "Determines "
                            "if "
                            "costs "
                            "are "
                            "recoverable "
                            "through "
                            "customer "
                            "billing, "
                            "affects "
                            "project "
                            "profitability "
                            "calculations, "
                            "and "
                            "controls "
                            "expense "
                            "allocation "
                            "for "
                            "client "
                            "projects "
                            "and "
                            "service "
                            "delivery.",
                            "example": False,
                            "type": "boolean",
                        },
                        "item_custom_fields": {
                            "items": {
                                "properties": {
                                    "custom_field_id": {"format": "int64", "type": "integer"},
                                    "index": {
                                        "description": "Index of the custom field",
                                        "type": "integer",
                                    },
                                    "label": {
                                        "description": "Label of the Custom Field",
                                        "type": "string",
                                    },
                                    "value": {
                                        "description": "Value of the Custom Field",
                                        "type": "string",
                                    },
                                },
                                "type": "object",
                            },
                            "type": "array",
                        },
                        "item_id": {
                            "description": "Unique "
                            "identifier "
                            "for "
                            "the "
                            "product "
                            "or "
                            "service "
                            "item. "
                            "Can "
                            "be "
                            "fetched "
                            "from "
                            "the "
                            "Items "
                            "API. "
                            "When "
                            "specified, "
                            "automatically "
                            "populates "
                            "item "
                            "details "
                            "like "
                            "name, "
                            "description, "
                            "and "
                            "default "
                            "rates. "
                            "Required "
                            "for "
                            "inventory "
                            "tracking "
                            "and "
                            "item-based "
                            "reporting.",
                            "example": "460000000054135",
                            "type": "string",
                        },
                        "item_order": {"example": 1, "type": "integer"},
                        "line_item_id": {
                            "description": "Unique "
                            "identifier "
                            "for "
                            "this "
                            "specific "
                            "line "
                            "item "
                            "within "
                            "the "
                            "bill. "
                            "Auto-generated "
                            "when "
                            "line "
                            "item "
                            "is "
                            "created. "
                            "Used "
                            "for "
                            "updating, "
                            "deleting, "
                            "or "
                            "referencing "
                            "specific "
                            "line "
                            "items "
                            "in "
                            "API "
                            "operations.",
                            "example": "460000000067009",
                            "type": "string",
                        },
                        "location_id": {
                            "description": "Unique "
                            "identifier "
                            "for "
                            "the "
                            "business "
                            "location "
                            "where "
                            "the "
                            "bill "
                            "transaction "
                            "occurs. "
                            "Used "
                            "for "
                            "multi-location "
                            "organizations "
                            "to "
                            "track "
                            "expenses "
                            "by "
                            "location. "
                            "Affects "
                            "reporting "
                            "and "
                            "tax "
                            "calculations "
                            "based "
                            "on "
                            "location-specific "
                            "rules. "
                            "Can "
                            "be "
                            "fetched "
                            "from "
                            "the "
                            "Locations "
                            "API. "
                            "Required "
                            "for "
                            "organizations "
                            "with "
                            "multiple "
                            "locations. "
                            "Influences "
                            "tax "
                            "rates, "
                            "reporting "
                            "structures, "
                            "and "
                            "approval "
                            "workflows "
                            "based "
                            "on "
                            "location-specific "
                            "configurations.",
                            "example": "460000000038080",
                            "type": "string",
                        },
                        "name": {
                            "description": "Name "
                            "or "
                            "description "
                            "of "
                            "the "
                            "line "
                            "item. "
                            "Can "
                            "be "
                            "manually "
                            "entered "
                            "or "
                            "auto-populated "
                            "from "
                            "item "
                            "details. "
                            "Should "
                            "clearly "
                            "describe "
                            "the "
                            "product, "
                            "service, "
                            "or "
                            "expense "
                            "for "
                            "vendor "
                            "and "
                            "accounting "
                            "purposes.",
                            "type": "string",
                        },
                        "product_type": {
                            "description": "Type "
                            "of "
                            "the "
                            "bill. "
                            "This "
                            "denotes "
                            "whether "
                            "the "
                            "bill "
                            "line "
                            "item "
                            "is "
                            "to "
                            "be "
                            "treated "
                            "as "
                            "a "
                            "goods "
                            "or "
                            "service "
                            "purchase. "
                            "This "
                            "only "
                            "need "
                            "to "
                            "be "
                            "specified "
                            "in "
                            "case "
                            "purchase "
                            "order "
                            "is "
                            "not "
                            "enabled. "
                            "Allowed "
                            "Values: "
                            "<code> "
                            "digital_service</code>, "
                            "<code>goods</code> "
                            "and "
                            "<code>service</code>.",
                            "type": "string",
                            "x-node_available_in": ["eu", "uk"],
                            "x-node_unavailable_in": [],
                        },
                        "project_id": {"description": "ID of the Project", "type": "string"},
                        "purchaseorder_item_id": {
                            "description": "Unique "
                            "identifier "
                            "linking "
                            "this "
                            "line "
                            "item "
                            "to "
                            "a "
                            "specific "
                            "item "
                            "in "
                            "the "
                            "purchase "
                            "order. "
                            "Used "
                            "for "
                            "tracking "
                            "PO-to-bill "
                            "conversions "
                            "and "
                            "maintaining "
                            "audit "
                            "trails. "
                            "Required "
                            "when "
                            "converting "
                            "purchase "
                            "orders "
                            "to "
                            "bills.",
                            "type": "string",
                        },
                        "quantity": {
                            "description": "Number "
                            "of "
                            "units "
                            "for "
                            "the "
                            "line "
                            "item. "
                            "Used "
                            "to "
                            "calculate "
                            "line "
                            "item "
                            "totals "
                            "(quantity "
                            "x "
                            "rate). "
                            "Supports "
                            "decimal "
                            "quantities "
                            "for "
                            "items "
                            "sold "
                            "by "
                            "weight, "
                            "length, "
                            "or "
                            "other "
                            "non-whole "
                            "units. "
                            "Required "
                            "for "
                            "accurate "
                            "billing "
                            "and "
                            "inventory "
                            "tracking.",
                            "example": 1,
                            "format": "double",
                            "type": "number",
                        },
                        "rate": {
                            "description": "Unit "
                            "price "
                            "or "
                            "rate "
                            "for "
                            "the "
                            "line "
                            "item. "
                            "Can "
                            "be "
                            "manually "
                            "entered "
                            "or "
                            "auto-populated "
                            "from "
                            "item "
                            "details "
                            "or "
                            "price "
                            "books. "
                            "Used "
                            "to "
                            "calculate "
                            "line "
                            "item "
                            "totals. "
                            "Supports "
                            "decimal "
                            "precision "
                            "based "
                            "on "
                            "currency "
                            "settings.",
                            "example": 10,
                            "format": "double",
                            "type": "number",
                        },
                        "reverse_charge_tax_id": {
                            "description": "Reverse charge tax ID",
                            "example": 460000000038056,
                            "type": "string",
                            "x-node_available_in": ["in", "gcc", "za"],
                            "x-node_unavailable_in": [],
                        },
                        "reverse_charge_vat_id": {
                            "description": "(Optional) "
                            "This "
                            "is "
                            "the "
                            "ID "
                            "of "
                            "the "
                            "tax "
                            "applied "
                            "in "
                            "case "
                            "this "
                            "is "
                            "a "
                            "non "
                            "UK "
                            "- "
                            "service "
                            "purchase "
                            "and "
                            "reverse "
                            "charge "
                            "VAT "
                            "needs "
                            "to "
                            "be "
                            "reported.",
                            "type": "string",
                            "x-node_available_in": ["uk"],
                            "x-node_unavailable_in": [],
                        },
                        "serial_numbers": {"items": {"type": "string"}, "type": "array"},
                        "tags": {
                            "items": {
                                "properties": {
                                    "tag_id": {
                                        "description": "ID of the Tag",
                                        "example": "460000000054178",
                                        "format": "int64",
                                        "type": "integer",
                                    },
                                    "tag_option_id": {
                                        "description": "Id of the Tag Option",
                                        "example": "460000000054180",
                                        "format": "int64",
                                        "type": "integer",
                                    },
                                },
                                "type": "object",
                            },
                            "type": "array",
                        },
                        "tax_exemption_code": {
                            "description": "Code of the Tax Exemption Applied",
                            "type": "string",
                            "x-node_available_in": ["in", "au", "ca", "mx"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_exemption_id": {
                            "description": "ID of the Tax Exemption Applied",
                            "type": "string",
                            "x-node_available_in": ["in", "au", "ca"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_id": {
                            "description": "Unique "
                            "identifier "
                            "for "
                            "the "
                            "tax "
                            "or "
                            "tax "
                            "group "
                            "applied "
                            "to "
                            "this "
                            "line "
                            "item. "
                            "Can "
                            "be "
                            "fetched "
                            "from "
                            "the "
                            "Taxes "
                            "API. "
                            "Determines "
                            "tax "
                            "rate "
                            "and "
                            "calculations "
                            "for "
                            "the "
                            "line "
                            "item. "
                            "Required "
                            "when "
                            "tax "
                            "calculations "
                            "are "
                            "enabled. "
                            "Affects "
                            "final "
                            "line "
                            "item "
                            "total "
                            "and "
                            "tax "
                            "reporting.",
                            "example": "460000000027005",
                            "type": "string",
                            "x-node_available_in": [],
                            "x-node_unavailable_in": ["us"],
                        },
                        "tax_treatment_code": {
                            "description": "Specify "
                            "reason "
                            "for "
                            "using "
                            "out "
                            "of "
                            "scope.</br>Supported "
                            "values "
                            "for "
                            "<b>UAE</b> "
                            "are "
                            "<code>uae_same_tax_group</code>, "
                            "<code>uae_reimbursed_expense</code> "
                            "and "
                            "<code>uae_others</code>.</br> "
                            "Supported "
                            "values "
                            "for "
                            "<b>Bahrain</b> "
                            "are "
                            "<code>bahrain_same_tax_group</code>, "
                            "<code>bahrain_transfer_of_concern</code>, "
                            "<code>bahrain_disbursement</code>, "
                            "<code>bahrain_head_to_branch_transaction</code> "
                            "and "
                            "<code>bahrain_others</code>.</br> "
                            "Supported "
                            "values "
                            "for "
                            "<b>KSA</b> "
                            "are "
                            "<code>ksa_reimbursed_expense</code>.",
                            "example": "uae_others",
                            "type": "string",
                            "x-node_available_in": ["gcc"],
                            "x-node_unavailable_in": [],
                        },
                        "tds_tax_id": {
                            "description": "TDS "
                            "ID "
                            "of "
                            "the "
                            "tax "
                            "or "
                            "tax "
                            "group "
                            "applied "
                            "to "
                            "the "
                            "line "
                            "item",
                            "example": "460000000027009",
                            "type": "string",
                            "x-node_available_in": ["mx"],
                            "x-node_unavailable_in": [],
                        },
                        "unit": {
                            "description": "Unit "
                            "of "
                            "measurement "
                            "for "
                            "the "
                            "item "
                            "quantity. "
                            "Examples: "
                            "pieces, "
                            "kgs, "
                            "liters, "
                            "hours, "
                            "days. "
                            "Used "
                            "for "
                            "accurate "
                            "billing "
                            "and "
                            "inventory "
                            "tracking. "
                            "Auto-populated "
                            "when "
                            "item_id "
                            "is "
                            "specified. "
                            "Important "
                            "for "
                            "vendor "
                            "communication "
                            "and "
                            "expense "
                            "categorization.",
                            "example": "kgs",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "location_id": {
                "description": "Unique identifier for the business "
                "location where the bill transaction "
                "occurs. Used for multi-location "
                "organizations to track expenses by "
                "location. Affects reporting and tax "
                "calculations based on "
                "location-specific rules. Can be "
                "fetched from the Locations API. "
                "Required for organizations with "
                "multiple locations. Influences tax "
                "rates, reporting structures, and "
                "approval workflows based on "
                "location-specific configurations.",
                "example": "460000000038080",
                "type": "string",
            },
            "notes": {
                "description": "Additional information or comments about the "
                "bill. Used for internal communication, "
                "vendor instructions, or special handling "
                "requirements. Visible to vendors and "
                "included in bill communications. Useful for "
                "tracking special arrangements or payment "
                "instructions.",
                "example": "Thanks for your business.",
                "type": "string",
            },
            "payment_terms": {
                "description": "Numeric identifier for payment terms "
                "configuration. Defines when payment "
                "is due relative to bill date. 0 = "
                "Due on Receipt, positive numbers = "
                "days after bill date, negative "
                "numbers = days before bill date. "
                "Common values: 0 (Due on Receipt), "
                "15 (Net 15), 30 (Net 30), 45 (Net "
                "45). Affects due date calculation "
                "and aging reports.",
                "example": 0,
                "type": "integer",
            },
            "payment_terms_label": {
                "description": "Label of the Payment Terms",
                "example": "Due on Receipt",
                "type": "string",
            },
            "permit_number": {
                "description": "The permit number for the bill.",
                "type": "string",
                "x-node_available_in": ["uae"],
                "x-node_unavailable_in": [],
            },
            "place_of_supply": {
                "description": "The place of supply is where a "
                "transaction is considered to have "
                "occurred for VAT purposes. For the "
                "supply of goods, the place of "
                "supply is the location of the "
                "goods when the supply occurs. For "
                "the supply of services, the place "
                "of supply should be where the "
                "supplier is established. (If not "
                "given, <code>place of "
                "contact</code> given for the "
                "contact will be "
                "taken)<br/>Supported codes for UAE "
                "emirates are : </br>Abu Dhabi - "
                "<code>AB</code>,</br>Ajman - "
                "<code>AJ</code>,</br>Dubai - "
                "<code>DU</code>,</br>Fujairah - "
                "<code>FU</code>,</br>Ras "
                "al-Khaimah - "
                "<code>RA</code>,</br>Sharjah - "
                "<code>SH</code>,</br>Umm al-Quwain "
                "- <code>UM</code>.<br/>Supported "
                "codes for the GCC countries are : "
                "</br>United Arab Emirates - "
                "<code>AE</code>,</br>Saudi Arabia "
                "- <code>SA</code>,</br>Bahrain - "
                "<code>BH</code>,</br>Kuwait - "
                "<code>KW</code>,</br>Oman - "
                "<code>OM</code>,</br>Qatar - "
                "<code>QA</code>.",
                "example": "DU",
                "type": "string",
                "x-node_available_in": ["gcc"],
                "x-node_unavailable_in": [],
            },
            "pricebook_id": {
                "description": "Identifier for the price book "
                "containing item rates and pricing "
                "rules. Used to apply standardized "
                "pricing across bills. If not "
                "specified, default pricing from items "
                "will be used. Helps maintain "
                "consistent pricing across multiple "
                "transactions.",
                "example": 460000000038090,
                "type": "string",
            },
            "purchaseorder_ids": {
                "description": "Array of purchase order "
                "identifiers linked to this bill "
                "for tracking purposes.",
                "example": [460000000068231, 460000000068233],
                "items": {"type": "string"},
                "type": "array",
            },
            "recurring_bill_id": {
                "description": "Identifier linking this bill to "
                "a recurring bill template. Used "
                "for bills that are automatically "
                "generated on a schedule (weekly, "
                "monthly, quarterly, etc.). "
                "Enables automated bill "
                "generation, consistent billing "
                "cycles, and reduces manual data "
                "entry. Can be modified to change "
                "recurring schedule.",
                "type": "string",
            },
            "reference_number": {
                "description": "External reference number from "
                "vendor invoice or purchase order. "
                "Used for cross-referencing with "
                "vendor documents. Helps in "
                "reconciliation and tracking "
                "payments. Can include invoice "
                "numbers, PO references, or any "
                "vendor-specific identifiers.",
                "example": "4321133",
                "type": "string",
            },
            "source_of_supply": {
                "description": "State code where goods/services "
                "originate. Used for GST "
                "calculations in India. Defaults "
                "to vendor contact location if not "
                "specified. Supports 2-letter "
                "state codes (e.g., AP for Andhra "
                "Pradesh, TN for Tamil Nadu).",
                "example": "AP",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "tax_treatment": {
                "description": "VAT treatment for the bill. Choose "
                "whether the vendor falls under: "
                "<code>vat_registered</code>,<code>vat_not_registered</code>,<code>gcc_vat_not_registered</code>,<code>gcc_vat_registered</code>,<code>non_gcc</code>.</br><code>dz_vat_registered</code> "
                "and "
                "<code>dz_vat_not_registered</code> "
                "are supported only for "
                "<b>UAE</b>.</b></br><code>home_country_mexico</code>,<code>border_region_mexico</code>,<code>non_mexico</code> "
                "supported only for "
                "<b>MX</b>.<br/><b>For Kenya "
                "Edition:</b> "
                "<code>vat_registered</code> "
                ",<code>vat_not_registered</code> "
                ",<code>non_kenya</code>(A business "
                "that is located outside "
                "Kenya).<br/><b>For SouthAfrica "
                "Edition:</b> "
                "<code>vat_registered</code>, "
                "<code>vat_not_registered</code>, "
                "<code>overseas</code>(A business "
                "that is located outside "
                "SouthAfrica).",
                "example": "vat_registered",
                "type": "string",
                "x-node_available_in": ["gcc", "mx", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "taxes": {
                "items": {
                    "properties": {
                        "tax_amount": {
                            "description": "Amount of Tax in the Bill",
                            "example": 1.25,
                            "type": "string",
                        },
                        "tax_id": {
                            "description": "Unique "
                            "identifier "
                            "for the "
                            "tax or "
                            "tax "
                            "group "
                            "applied "
                            "to this "
                            "line "
                            "item. "
                            "Can be "
                            "fetched "
                            "from the "
                            "Taxes "
                            "API. "
                            "Determines "
                            "tax rate "
                            "and "
                            "calculations "
                            "for the "
                            "line "
                            "item. "
                            "Required "
                            "when tax "
                            "calculations "
                            "are "
                            "enabled. "
                            "Affects "
                            "final "
                            "line "
                            "item "
                            "total "
                            "and tax "
                            "reporting.",
                            "example": "460000000027005",
                            "type": "string",
                            "x-node_available_in": [],
                            "x-node_unavailable_in": ["us"],
                        },
                        "tax_name": {
                            "description": "Name of the Tax",
                            "example": "VAT (12.5%)",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "terms": {
                "description": "Terms and conditions that apply to the bill "
                "transaction. Includes payment terms, "
                "delivery conditions, warranty information, "
                "or other contractual obligations. Displayed "
                "on bill documents and vendor communications. "
                "Important for legal compliance and vendor "
                "relationship management.",
                "example": "Terms and conditions apply.",
                "type": "string",
            },
            "vat_treatment": {
                "description": "(Optional) VAT treatment for the "
                "bill. VAT treatment denotes the "
                "location of the vendor, if the "
                "vendor resides in UK then the VAT "
                "treatment is <code>uk</code>. If the "
                "vendor is in an EU country & VAT "
                "registered, you are resides in "
                "Northen Ireland and purchasing Goods "
                "then his VAT treatment is "
                "<code>eu_vat_registered</code>, if "
                "he resides outside of the UK then "
                "his VAT treatment is "
                "<code>overseas</code> (For Pre "
                "Brexit, this can be split as "
                "<code>eu_vat_registered</code>, "
                "<code>eu_vat_not_registered</code> "
                "and <code>non_eu</code>).",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
            "vendor_id": {
                "description": "Unique identifier for the vendor who "
                "supplied the goods/services. Can be "
                "fetched from the Get Contacts API.",
                "example": "460000000038029",
                "type": "string",
            },
        },
        "required": ["vendor_id", "bill_number"],
        "type": "object",
    },
    "UPDATEBILLINZOHO_REQUEST_BODY_SCHEMA": {
        "properties": {
            "adjustment": {
                "description": "Additional amount added to or "
                "subtracted from bill total. Positive "
                "values increase total, negative values "
                "decrease total. Used for discounts, "
                "surcharges, rounding adjustments, or "
                "other modifications. Affects final bill "
                "amount, tax calculations, and payment "
                "processing.",
                "example": 0,
                "format": "double",
                "type": "number",
            },
            "adjustment_description": {
                "description": "Text description explaining "
                "the reason for bill "
                "adjustment. Examples: "
                '"Early payment discount", '
                '"Volume discount", '
                '"Rounding adjustment", '
                '"Handling fee". Helps in '
                "audit trails and reporting. "
                "Required when adjustment "
                "amount is non-zero. Used in "
                "financial reports, tax "
                "returns, and vendor "
                "communications. Should be "
                "clear and specific for "
                "compliance purposes.",
                "example": " ",
                "type": "string",
            },
            "approvers": {
                "items": {
                    "properties": {
                        "approver_id": {
                            "description": "ID of the Approver",
                            "format": "int64",
                            "type": "integer",
                        },
                        "order": {"description": "Order of the Approver", "type": "integer"},
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "bill_number": {
                "description": "Unique sequential identifier for the "
                "bill. Used for tracking and reference "
                "purposes. Format varies by "
                "organization settings. Can be "
                "auto-generated or manually entered. "
                "Must be unique within the "
                "organization.",
                "example": "00454",
                "type": "string",
            },
            "currency_id": {
                "description": "Unique identifier for the currency "
                "used in the bill transaction. Can be "
                "fetched from the Currencies API if "
                "multi-currency is enabled.",
                "example": "460000000000099",
                "type": "string",
            },
            "custom_fields": {
                "items": {
                    "properties": {
                        "index": {"description": "Index of the custom field", "type": "integer"},
                        "value": {"description": "Value of the Custom Field", "type": "string"},
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "date": {
                "description": "Date when the bill was issued by the vendor. "
                "Format: yyyy-mm-dd. Used for payment terms "
                "and aging calculations. This date determines "
                "when payment terms begin and affects aging "
                "reports, late payment calculations, and "
                "financial reporting.",
                "example": "2013-09-11",
                "type": "string",
            },
            "destination_of_supply": {
                "description": "State code where "
                "goods/services are "
                "delivered. Used for GST "
                "calculations in India. "
                "Defaults to organization "
                "home state if not specified. "
                "Supports 2-letter state "
                "codes (e.g., AP for Andhra "
                "Pradesh, TN for Tamil Nadu).",
                "example": "TN",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "documents": {
                "items": {
                    "properties": {
                        "document_id": {
                            "description": "ID of the Document",
                            "format": "int64",
                            "type": "integer",
                        },
                        "file_name": {"description": "Name of the file", "type": "string"},
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "due_date": {
                "description": "Date when payment is due for the bill. "
                "Used for payment tracking, aging reports, "
                "and overdue calculations. Calculated "
                "based on bill date and payment terms. "
                "Bills become overdue after this date, "
                "affecting vendor relationships and cash "
                "flow planning.",
                "example": "2013-09-26",
                "type": "string",
            },
            "exchange_rate": {
                "description": "Exchange rate from bill currency to "
                "organization base currency. Used for "
                "multi-currency transactions. 1.0 "
                "indicates same as base currency. "
                "Required when currency differs from "
                "organization default. Affects "
                "financial reporting, profit/loss "
                "calculations, and tax computations. "
                "Can be manually set or auto-fetched "
                "from currency exchange services.",
                "example": 1.23,
                "format": "double",
                "type": "number",
            },
            "gst_no": {
                "description": "15 digit GST identification number of the vendor.",
                "example": "22AAAAA0000A1Z5",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "gst_treatment": {
                "description": "Choose whether the contact is GST "
                "registered/unregistered/consumer/overseas. "
                "Allowed values are <code> "
                "business_gst </code> , <code> "
                "business_none </code> , <code> "
                "overseas </code> , <code> consumer "
                "</code>.",
                "example": "business_gst",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "is_inclusive_tax": {
                "description": "Flag indicating whether line item "
                "rates include tax amounts. When "
                "true, tax is calculated on top of "
                "displayed rates. When false, tax "
                "is added separately. Affects "
                "total calculations and tax "
                "reporting. Common in countries "
                "where tax-inclusive pricing is "
                "standard. Impacts customer-facing "
                "documents and tax return "
                "preparation.",
                "example": False,
                "type": "boolean",
                "x-node_unavailable_in": ["us"],
            },
            "is_item_level_tax_calc": {
                "description": "Flag indicating whether "
                "taxes are calculated at "
                "individual line item level "
                "rather than bill total. "
                "Enables different tax rates "
                "for different items. "
                "Provides more accurate tax "
                "calculations for mixed tax "
                "scenarios. When enabled, "
                "each line item can have "
                "different tax rates based "
                "on item type, location, or "
                "tax rules. Improves tax "
                "compliance and reporting "
                "accuracy.",
                "example": False,
                "type": "boolean",
            },
            "is_update_customer": {
                "description": "Flag to determine if customer "
                "information should be updated "
                "when creating the bill.",
                "example": False,
                "type": "boolean",
            },
            "line_items": {
                "description": "Line items of a bill.",
                "items": {
                    "properties": {
                        "account_id": {
                            "description": "Unique "
                            "identifier "
                            "for "
                            "the "
                            "chart "
                            "of "
                            "accounts "
                            "entry. "
                            "Can "
                            "be "
                            "fetched "
                            "from "
                            "the "
                            "Chart "
                            "of "
                            "Accounts "
                            "API. "
                            "Determines "
                            "how "
                            "this "
                            "expense "
                            "is "
                            "categorized "
                            "in "
                            "financial "
                            "reports "
                            "and "
                            "general "
                            "ledger. "
                            "Required "
                            "for "
                            "proper "
                            "expense "
                            "classification "
                            "and "
                            "accounting "
                            "compliance.",
                            "example": "460000000000403",
                            "type": "string",
                        },
                        "acquisition_vat_id": {
                            "description": "(Optional) "
                            "This "
                            "is "
                            "the "
                            "ID "
                            "of "
                            "the "
                            "tax "
                            "applied "
                            "in "
                            "case "
                            "this "
                            "is "
                            "an "
                            "EU "
                            "- "
                            "goods "
                            "purchase "
                            "and "
                            "acquisition "
                            "VAT "
                            "needs "
                            "to "
                            "be "
                            "reported.",
                            "type": "string",
                            "x-node_available_in": ["uk"],
                            "x-node_unavailable_in": [],
                        },
                        "customer_id": {"description": "ID of the Customer", "type": "string"},
                        "description": {
                            "description": "Detailed "
                            "description "
                            "of "
                            "the "
                            "line "
                            "item. "
                            "Provides "
                            "additional "
                            "context "
                            "about "
                            "the "
                            "product, "
                            "service, "
                            "or "
                            "expense. "
                            "Used "
                            "for "
                            "vendor "
                            "communication, "
                            "internal "
                            "documentation, "
                            "and "
                            "expense "
                            "justification. "
                            "Can "
                            "include "
                            "specifications, "
                            "requirements, "
                            "or "
                            "special "
                            "instructions.",
                            "type": "string",
                        },
                        "hsn_or_sac": {
                            "description": "Add HSN/SAC code for your goods/services",
                            "example": 80540,
                            "type": "string",
                            "x-node_available_in": ["in", "ke", "za"],
                            "x-node_unavailable_in": [],
                        },
                        "is_billable": {
                            "description": "Boolean "
                            "flag "
                            "indicating "
                            "whether "
                            "the "
                            "line "
                            "item "
                            "or "
                            "entity "
                            "can "
                            "be "
                            "billed "
                            "to "
                            "customers "
                            "or "
                            "clients. "
                            "Determines "
                            "if "
                            "costs "
                            "are "
                            "recoverable "
                            "through "
                            "customer "
                            "billing, "
                            "affects "
                            "project "
                            "profitability "
                            "calculations, "
                            "and "
                            "controls "
                            "expense "
                            "allocation "
                            "for "
                            "client "
                            "projects "
                            "and "
                            "service "
                            "delivery.",
                            "example": False,
                            "type": "boolean",
                        },
                        "item_custom_fields": {
                            "items": {
                                "properties": {
                                    "custom_field_id": {"format": "int64", "type": "integer"},
                                    "index": {
                                        "description": "Index of the custom field",
                                        "type": "integer",
                                    },
                                    "label": {
                                        "description": "Label of the Custom Field",
                                        "type": "string",
                                    },
                                    "value": {
                                        "description": "Value of the Custom Field",
                                        "type": "string",
                                    },
                                },
                                "type": "object",
                            },
                            "type": "array",
                        },
                        "item_id": {
                            "description": "Unique "
                            "identifier "
                            "for "
                            "the "
                            "product "
                            "or "
                            "service "
                            "item. "
                            "Can "
                            "be "
                            "fetched "
                            "from "
                            "the "
                            "Items "
                            "API. "
                            "When "
                            "specified, "
                            "automatically "
                            "populates "
                            "item "
                            "details "
                            "like "
                            "name, "
                            "description, "
                            "and "
                            "default "
                            "rates. "
                            "Required "
                            "for "
                            "inventory "
                            "tracking "
                            "and "
                            "item-based "
                            "reporting.",
                            "example": "460000000054135",
                            "type": "string",
                        },
                        "item_order": {"example": 1, "type": "integer"},
                        "line_item_id": {
                            "description": "Unique "
                            "identifier "
                            "for "
                            "this "
                            "specific "
                            "line "
                            "item "
                            "within "
                            "the "
                            "bill. "
                            "Auto-generated "
                            "when "
                            "line "
                            "item "
                            "is "
                            "created. "
                            "Used "
                            "for "
                            "updating, "
                            "deleting, "
                            "or "
                            "referencing "
                            "specific "
                            "line "
                            "items "
                            "in "
                            "API "
                            "operations.",
                            "example": "460000000067009",
                            "type": "string",
                        },
                        "location_id": {
                            "description": "Unique "
                            "identifier "
                            "for "
                            "the "
                            "business "
                            "location "
                            "where "
                            "the "
                            "bill "
                            "transaction "
                            "occurs. "
                            "Used "
                            "for "
                            "multi-location "
                            "organizations "
                            "to "
                            "track "
                            "expenses "
                            "by "
                            "location. "
                            "Affects "
                            "reporting "
                            "and "
                            "tax "
                            "calculations "
                            "based "
                            "on "
                            "location-specific "
                            "rules. "
                            "Can "
                            "be "
                            "fetched "
                            "from "
                            "the "
                            "Locations "
                            "API. "
                            "Required "
                            "for "
                            "organizations "
                            "with "
                            "multiple "
                            "locations. "
                            "Influences "
                            "tax "
                            "rates, "
                            "reporting "
                            "structures, "
                            "and "
                            "approval "
                            "workflows "
                            "based "
                            "on "
                            "location-specific "
                            "configurations.",
                            "example": "460000000038080",
                            "type": "string",
                        },
                        "name": {
                            "description": "Name "
                            "or "
                            "description "
                            "of "
                            "the "
                            "line "
                            "item. "
                            "Can "
                            "be "
                            "manually "
                            "entered "
                            "or "
                            "auto-populated "
                            "from "
                            "item "
                            "details. "
                            "Should "
                            "clearly "
                            "describe "
                            "the "
                            "product, "
                            "service, "
                            "or "
                            "expense "
                            "for "
                            "vendor "
                            "and "
                            "accounting "
                            "purposes.",
                            "type": "string",
                        },
                        "product_type": {
                            "description": "Type "
                            "of "
                            "the "
                            "bill. "
                            "This "
                            "denotes "
                            "whether "
                            "the "
                            "bill "
                            "line "
                            "item "
                            "is "
                            "to "
                            "be "
                            "treated "
                            "as "
                            "a "
                            "goods "
                            "or "
                            "service "
                            "purchase. "
                            "This "
                            "only "
                            "need "
                            "to "
                            "be "
                            "specified "
                            "in "
                            "case "
                            "purchase "
                            "order "
                            "is "
                            "not "
                            "enabled. "
                            "Allowed "
                            "Values: "
                            "<code> "
                            "digital_service</code>, "
                            "<code>goods</code> "
                            "and "
                            "<code>service</code>.",
                            "type": "string",
                            "x-node_available_in": ["eu", "uk"],
                            "x-node_unavailable_in": [],
                        },
                        "project_id": {"description": "ID of the Project", "type": "string"},
                        "purchaseorder_item_id": {
                            "description": "Unique "
                            "identifier "
                            "linking "
                            "this "
                            "line "
                            "item "
                            "to "
                            "a "
                            "specific "
                            "item "
                            "in "
                            "the "
                            "purchase "
                            "order. "
                            "Used "
                            "for "
                            "tracking "
                            "PO-to-bill "
                            "conversions "
                            "and "
                            "maintaining "
                            "audit "
                            "trails. "
                            "Required "
                            "when "
                            "converting "
                            "purchase "
                            "orders "
                            "to "
                            "bills.",
                            "type": "string",
                        },
                        "quantity": {
                            "description": "Number "
                            "of "
                            "units "
                            "for "
                            "the "
                            "line "
                            "item. "
                            "Used "
                            "to "
                            "calculate "
                            "line "
                            "item "
                            "totals "
                            "(quantity "
                            "x "
                            "rate). "
                            "Supports "
                            "decimal "
                            "quantities "
                            "for "
                            "items "
                            "sold "
                            "by "
                            "weight, "
                            "length, "
                            "or "
                            "other "
                            "non-whole "
                            "units. "
                            "Required "
                            "for "
                            "accurate "
                            "billing "
                            "and "
                            "inventory "
                            "tracking.",
                            "example": 1,
                            "format": "double",
                            "type": "number",
                        },
                        "rate": {
                            "description": "Unit "
                            "price "
                            "or "
                            "rate "
                            "for "
                            "the "
                            "line "
                            "item. "
                            "Can "
                            "be "
                            "manually "
                            "entered "
                            "or "
                            "auto-populated "
                            "from "
                            "item "
                            "details "
                            "or "
                            "price "
                            "books. "
                            "Used "
                            "to "
                            "calculate "
                            "line "
                            "item "
                            "totals. "
                            "Supports "
                            "decimal "
                            "precision "
                            "based "
                            "on "
                            "currency "
                            "settings.",
                            "example": 10,
                            "format": "double",
                            "type": "number",
                        },
                        "reverse_charge_tax_id": {
                            "description": "Reverse charge tax ID",
                            "example": 460000000038056,
                            "type": "string",
                            "x-node_available_in": ["in", "gcc", "za"],
                            "x-node_unavailable_in": [],
                        },
                        "reverse_charge_vat_id": {
                            "description": "(Optional) "
                            "This "
                            "is "
                            "the "
                            "ID "
                            "of "
                            "the "
                            "tax "
                            "applied "
                            "in "
                            "case "
                            "this "
                            "is "
                            "a "
                            "non "
                            "UK "
                            "- "
                            "service "
                            "purchase "
                            "and "
                            "reverse "
                            "charge "
                            "VAT "
                            "needs "
                            "to "
                            "be "
                            "reported.",
                            "type": "string",
                            "x-node_available_in": ["uk"],
                            "x-node_unavailable_in": [],
                        },
                        "serial_numbers": {"items": {"type": "string"}, "type": "array"},
                        "tags": {
                            "items": {
                                "properties": {
                                    "tag_id": {
                                        "description": "ID of the Tag",
                                        "example": "460000000054178",
                                        "format": "int64",
                                        "type": "integer",
                                    },
                                    "tag_option_id": {
                                        "description": "Id of the Tag Option",
                                        "example": "460000000054180",
                                        "format": "int64",
                                        "type": "integer",
                                    },
                                },
                                "type": "object",
                            },
                            "type": "array",
                        },
                        "tax_exemption_code": {
                            "description": "Code of the Tax Exemption Applied",
                            "type": "string",
                            "x-node_available_in": ["in", "au", "ca", "mx"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_exemption_id": {
                            "description": "ID of the Tax Exemption Applied",
                            "type": "string",
                            "x-node_available_in": ["in", "au", "ca"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_id": {
                            "description": "Unique "
                            "identifier "
                            "for "
                            "the "
                            "tax "
                            "or "
                            "tax "
                            "group "
                            "applied "
                            "to "
                            "this "
                            "line "
                            "item. "
                            "Can "
                            "be "
                            "fetched "
                            "from "
                            "the "
                            "Taxes "
                            "API. "
                            "Determines "
                            "tax "
                            "rate "
                            "and "
                            "calculations "
                            "for "
                            "the "
                            "line "
                            "item. "
                            "Required "
                            "when "
                            "tax "
                            "calculations "
                            "are "
                            "enabled. "
                            "Affects "
                            "final "
                            "line "
                            "item "
                            "total "
                            "and "
                            "tax "
                            "reporting.",
                            "example": "460000000027005",
                            "type": "string",
                            "x-node_available_in": [],
                            "x-node_unavailable_in": ["us"],
                        },
                        "tax_treatment_code": {
                            "description": "Specify "
                            "reason "
                            "for "
                            "using "
                            "out "
                            "of "
                            "scope.</br>Supported "
                            "values "
                            "for "
                            "<b>UAE</b> "
                            "are "
                            "<code>uae_same_tax_group</code>, "
                            "<code>uae_reimbursed_expense</code> "
                            "and "
                            "<code>uae_others</code>.</br> "
                            "Supported "
                            "values "
                            "for "
                            "<b>Bahrain</b> "
                            "are "
                            "<code>bahrain_same_tax_group</code>, "
                            "<code>bahrain_transfer_of_concern</code>, "
                            "<code>bahrain_disbursement</code>, "
                            "<code>bahrain_head_to_branch_transaction</code> "
                            "and "
                            "<code>bahrain_others</code>.</br> "
                            "Supported "
                            "values "
                            "for "
                            "<b>KSA</b> "
                            "are "
                            "<code>ksa_reimbursed_expense</code>.",
                            "example": "uae_others",
                            "type": "string",
                            "x-node_available_in": ["gcc"],
                            "x-node_unavailable_in": [],
                        },
                        "tds_tax_id": {
                            "description": "TDS "
                            "ID "
                            "of "
                            "the "
                            "tax "
                            "or "
                            "tax "
                            "group "
                            "applied "
                            "to "
                            "the "
                            "line "
                            "item",
                            "example": "460000000027009",
                            "type": "string",
                            "x-node_available_in": ["mx"],
                            "x-node_unavailable_in": [],
                        },
                        "unit": {
                            "description": "Unit "
                            "of "
                            "measurement "
                            "for "
                            "the "
                            "item "
                            "quantity. "
                            "Examples: "
                            "pieces, "
                            "kgs, "
                            "liters, "
                            "hours, "
                            "days. "
                            "Used "
                            "for "
                            "accurate "
                            "billing "
                            "and "
                            "inventory "
                            "tracking. "
                            "Auto-populated "
                            "when "
                            "item_id "
                            "is "
                            "specified. "
                            "Important "
                            "for "
                            "vendor "
                            "communication "
                            "and "
                            "expense "
                            "categorization.",
                            "example": "kgs",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "location_id": {
                "description": "Unique identifier for the business "
                "location where the bill transaction "
                "occurs. Used for multi-location "
                "organizations to track expenses by "
                "location. Affects reporting and tax "
                "calculations based on "
                "location-specific rules. Can be "
                "fetched from the Locations API. "
                "Required for organizations with "
                "multiple locations. Influences tax "
                "rates, reporting structures, and "
                "approval workflows based on "
                "location-specific configurations.",
                "example": "460000000038080",
                "type": "string",
            },
            "notes": {
                "description": "Additional information or comments about the "
                "bill. Used for internal communication, "
                "vendor instructions, or special handling "
                "requirements. Visible to vendors and "
                "included in bill communications. Useful for "
                "tracking special arrangements or payment "
                "instructions.",
                "example": "Thanks for your business.",
                "type": "string",
            },
            "payment_terms": {
                "description": "Numeric identifier for payment terms "
                "configuration. Defines when payment "
                "is due relative to bill date. 0 = "
                "Due on Receipt, positive numbers = "
                "days after bill date, negative "
                "numbers = days before bill date. "
                "Common values: 0 (Due on Receipt), "
                "15 (Net 15), 30 (Net 30), 45 (Net "
                "45). Affects due date calculation "
                "and aging reports.",
                "example": 0,
                "type": "integer",
            },
            "payment_terms_label": {
                "description": "Label of the Payment Terms",
                "example": "Due on Receipt",
                "type": "string",
            },
            "permit_number": {
                "description": "The permit number for the bill.",
                "type": "string",
                "x-node_available_in": ["uae"],
                "x-node_unavailable_in": [],
            },
            "place_of_supply": {
                "description": "The place of supply is where a "
                "transaction is considered to have "
                "occurred for VAT purposes. For the "
                "supply of goods, the place of "
                "supply is the location of the "
                "goods when the supply occurs. For "
                "the supply of services, the place "
                "of supply should be where the "
                "supplier is established. (If not "
                "given, <code>place of "
                "contact</code> given for the "
                "contact will be "
                "taken)<br/>Supported codes for UAE "
                "emirates are : </br>Abu Dhabi - "
                "<code>AB</code>,</br>Ajman - "
                "<code>AJ</code>,</br>Dubai - "
                "<code>DU</code>,</br>Fujairah - "
                "<code>FU</code>,</br>Ras "
                "al-Khaimah - "
                "<code>RA</code>,</br>Sharjah - "
                "<code>SH</code>,</br>Umm al-Quwain "
                "- <code>UM</code>.<br/>Supported "
                "codes for the GCC countries are : "
                "</br>United Arab Emirates - "
                "<code>AE</code>,</br>Saudi Arabia "
                "- <code>SA</code>,</br>Bahrain - "
                "<code>BH</code>,</br>Kuwait - "
                "<code>KW</code>,</br>Oman - "
                "<code>OM</code>,</br>Qatar - "
                "<code>QA</code>.",
                "example": "DU",
                "type": "string",
                "x-node_available_in": ["gcc"],
                "x-node_unavailable_in": [],
            },
            "pricebook_id": {
                "description": "Identifier for the price book "
                "containing item rates and pricing "
                "rules. Used to apply standardized "
                "pricing across bills. If not "
                "specified, default pricing from items "
                "will be used. Helps maintain "
                "consistent pricing across multiple "
                "transactions.",
                "example": 460000000038090,
                "type": "string",
            },
            "purchaseorder_ids": {
                "description": "Array of purchase order "
                "identifiers linked to this bill "
                "for tracking purposes.",
                "example": [460000000068231, 460000000068233],
                "items": {"type": "string"},
                "type": "array",
            },
            "recurring_bill_id": {
                "description": "Identifier linking this bill to "
                "a recurring bill template. Used "
                "for bills that are automatically "
                "generated on a schedule (weekly, "
                "monthly, quarterly, etc.). "
                "Enables automated bill "
                "generation, consistent billing "
                "cycles, and reduces manual data "
                "entry. Can be modified to change "
                "recurring schedule.",
                "type": "string",
            },
            "reference_number": {
                "description": "External reference number from "
                "vendor invoice or purchase order. "
                "Used for cross-referencing with "
                "vendor documents. Helps in "
                "reconciliation and tracking "
                "payments. Can include invoice "
                "numbers, PO references, or any "
                "vendor-specific identifiers.",
                "example": "4321133",
                "type": "string",
            },
            "source_of_supply": {
                "description": "State code where goods/services "
                "originate. Used for GST "
                "calculations in India. Defaults "
                "to vendor contact location if not "
                "specified. Supports 2-letter "
                "state codes (e.g., AP for Andhra "
                "Pradesh, TN for Tamil Nadu).",
                "example": "AP",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "tax_treatment": {
                "description": "VAT treatment for the bill. Choose "
                "whether the vendor falls under: "
                "<code>vat_registered</code>,<code>vat_not_registered</code>,<code>gcc_vat_not_registered</code>,<code>gcc_vat_registered</code>,<code>non_gcc</code>.</br><code>dz_vat_registered</code> "
                "and "
                "<code>dz_vat_not_registered</code> "
                "are supported only for "
                "<b>UAE</b>.</b></br><code>home_country_mexico</code>,<code>border_region_mexico</code>,<code>non_mexico</code> "
                "supported only for "
                "<b>MX</b>.<br/><b>For Kenya "
                "Edition:</b> "
                "<code>vat_registered</code> "
                ",<code>vat_not_registered</code> "
                ",<code>non_kenya</code>(A business "
                "that is located outside "
                "Kenya).<br/><b>For SouthAfrica "
                "Edition:</b> "
                "<code>vat_registered</code>, "
                "<code>vat_not_registered</code>, "
                "<code>overseas</code>(A business "
                "that is located outside "
                "SouthAfrica).",
                "example": "vat_registered",
                "type": "string",
                "x-node_available_in": ["gcc", "mx", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "taxes": {
                "items": {
                    "properties": {
                        "tax_amount": {
                            "description": "Amount of Tax in the Bill",
                            "example": 1.25,
                            "type": "string",
                        },
                        "tax_id": {
                            "description": "Unique "
                            "identifier "
                            "for the "
                            "tax or "
                            "tax "
                            "group "
                            "applied "
                            "to this "
                            "line "
                            "item. "
                            "Can be "
                            "fetched "
                            "from the "
                            "Taxes "
                            "API. "
                            "Determines "
                            "tax rate "
                            "and "
                            "calculations "
                            "for the "
                            "line "
                            "item. "
                            "Required "
                            "when tax "
                            "calculations "
                            "are "
                            "enabled. "
                            "Affects "
                            "final "
                            "line "
                            "item "
                            "total "
                            "and tax "
                            "reporting.",
                            "example": "460000000027005",
                            "type": "string",
                            "x-node_available_in": [],
                            "x-node_unavailable_in": ["us"],
                        },
                        "tax_name": {
                            "description": "Name of the Tax",
                            "example": "VAT (12.5%)",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "terms": {
                "description": "Terms and conditions that apply to the bill "
                "transaction. Includes payment terms, "
                "delivery conditions, warranty information, "
                "or other contractual obligations. Displayed "
                "on bill documents and vendor communications. "
                "Important for legal compliance and vendor "
                "relationship management.",
                "example": "Terms and conditions apply.",
                "type": "string",
            },
            "vat_treatment": {
                "description": "(Optional) VAT treatment for the "
                "bill. VAT treatment denotes the "
                "location of the vendor, if the "
                "vendor resides in UK then the VAT "
                "treatment is <code>uk</code>. If the "
                "vendor is in an EU country & VAT "
                "registered, you are resides in "
                "Northen Ireland and purchasing Goods "
                "then his VAT treatment is "
                "<code>eu_vat_registered</code>, if "
                "he resides outside of the UK then "
                "his VAT treatment is "
                "<code>overseas</code> (For Pre "
                "Brexit, this can be split as "
                "<code>eu_vat_registered</code>, "
                "<code>eu_vat_not_registered</code> "
                "and <code>non_eu</code>).",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
            "vendor_id": {
                "description": "Unique identifier for the vendor who "
                "supplied the goods/services. Can be "
                "fetched from the Get Contacts API.",
                "example": "460000000038029",
                "type": "string",
            },
        },
        "required": ["vendor_id", "bill_number"],
        "type": "object",
    },
    "UPDATECUSTOMFIELDSINBILL_REQUEST_BODY_SCHEMA": {
        "items": {
            "properties": {
                "custom_field_id": {"format": "int64", "type": "integer"},
                "index": {"description": "Index of the custom field", "type": "integer"},
                "label": {"description": "Label of the Custom Field", "type": "string"},
                "value": {"description": "Value of the Custom Field", "type": "string"},
            },
            "type": "object",
        },
        "type": "array",
    },
    "UPDATEBILLINGADDRESS_REQUEST_BODY_SCHEMA": {
        "properties": {
            "address": {"description": "Address involved in the Bill", "type": "string"},
            "attention": {"type": "string"},
            "city": {"description": "City in the Address", "type": "string"},
            "country": {"description": "Country Involved in the Address", "type": "string"},
            "fax": {"description": "Fax of the Vendor", "type": "string"},
            "is_update_customer": {
                "description": "Flag to determine if customer "
                "information should be updated "
                "when creating the bill.",
                "example": False,
                "type": "boolean",
            },
            "state": {"description": "State involved in the Address", "type": "string"},
            "zip": {"description": "ZIP Code involved in the Address", "type": "string"},
        },
        "type": "object",
    },
    "APPLYVENDORCREDITSTOBILL_REQUEST_BODY_SCHEMA": {
        "properties": {
            "apply_vendor_credits": {
                "items": {
                    "properties": {
                        "amount_applied": {
                            "description": "Amount applied to the bill.",
                            "example": 31.25,
                            "format": "double",
                            "type": "number",
                        },
                        "vendor_credit_id": {
                            "description": "ID of the Vendor Credit",
                            "example": "4600000053221",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "bill_payments": {
                "items": {
                    "properties": {
                        "amount_applied": {
                            "description": "Amount applied to the bill.",
                            "example": 31.25,
                            "format": "double",
                            "type": "number",
                        },
                        "payment_id": {
                            "description": "ID of the Payment",
                            "example": "460000000042059",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
        },
        "type": "object",
    },
    "ADDCOMMENTTOBILL_REQUEST_BODY_SCHEMA": {
        "properties": {
            "description": {
                "description": "Detailed description of the line item. "
                "Provides additional context about the "
                "product, service, or expense. Used for "
                "vendor communication, internal "
                "documentation, and expense "
                "justification. Can include "
                "specifications, requirements, or "
                "special instructions.",
                "type": "string",
            }
        },
        "required": ["description"],
        "type": "object",
    },
    "CREATECHARTOFACCOUNT_REQUEST_BODY_SCHEMA": {
        "properties": {
            "account_code": {"description": "Code Associated with the Account", "type": "string"},
            "account_name": {
                "description": "Name of the account",
                "example": "Notes Payable",
                "type": "string",
            },
            "account_type": {
                "description": "Type of the account. Allowed Values: "
                "<code>other_asset</code>, "
                "<code>other_current_asset</code>, "
                "<code>intangible_asset</code>, "
                "<code>right_to_use_asset</code>,<code>financial_asset</code>,<code>contingent_asset</code>,<code>contract_asset</code>,  "
                "<code>cash</code>, <code>bank</code>, "
                "<code>fixed_asset</code>, "
                "<code>other_current_liability</code>, "
                "<code>contract_liability</code> , "
                "<code>refund_liability</code>, "
                "<code>credit_card</code>, "
                "<code>long_term_liability</code>, "
                "<code>loans_and_borrowing</code> "
                ",<code>lease_liability</code> "
                ",<code>employee_benefit_liability</code> "
                ",<code>contingent_liability</code> "
                ",<code>financial_liability</code> , "
                "<code>other_liability</code>, "
                "<code>equity</code>, "
                "<code>income</code>,<code>finance_income</code> "
                ",<code>other_comprehensive_income</code> "
                ", <code>other_income</code>, "
                "<code>expense</code>, "
                "<code>manufacturing_expense</code> "
                ",<code>impairment_expense</code> "
                ",<code>depreciation_expense</code> "
                ",<code>employee_benefit_expense</code> "
                ",<code>lease_expense</code> "
                ",<code>finance_expense</code> "
                ",<code>tax_expense</code> , "
                "<code>cost_of_goods_sold</code>, "
                "<code>other_expense</code>, "
                "<code>accounts_receivable</code> and "
                "<code>accounts_payable</code>.",
                "example": "long_term_liability",
                "type": "string",
            },
            "can_show_in_ze": {"example": False, "type": "boolean"},
            "currency_id": {
                "description": "ID of the account currency.",
                "example": "460000000000097",
                "type": "string",
            },
            "custom_fields": {
                "items": {
                    "properties": {
                        "customfield_id": {
                            "description": "ID of the Custom Field",
                            "example": "460000000080163",
                            "type": "string",
                        },
                        "value": {
                            "description": "Value of the Custom Field",
                            "example": "Normal",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "description": {
                "description": "Description of the account",
                "example": "A Liability account which can be paid off "
                "in a time period longer than one year.",
                "type": "string",
            },
            "include_in_vat_return": {
                "description": "Boolean to include an account in VAT returns.",
                "type": "boolean",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
            "parent_account_id": {
                "description": "ID of the Parent Account",
                "example": "460000000009097",
                "type": "string",
            },
            "show_on_dashboard": {"example": False, "type": "boolean"},
        },
        "type": "object",
    },
    "UPDATEACCOUNTINFO_REQUEST_BODY_SCHEMA": {
        "properties": {
            "account_code": {"description": "Code Associated with the Account", "type": "string"},
            "account_name": {
                "description": "Name of the account",
                "example": "Notes Payable",
                "type": "string",
            },
            "account_type": {
                "description": "Type of the account. Allowed Values: "
                "<code>other_asset</code>, "
                "<code>other_current_asset</code>, "
                "<code>intangible_asset</code>, "
                "<code>right_to_use_asset</code>,<code>financial_asset</code>,<code>contingent_asset</code>,<code>contract_asset</code>,  "
                "<code>cash</code>, <code>bank</code>, "
                "<code>fixed_asset</code>, "
                "<code>other_current_liability</code>, "
                "<code>contract_liability</code> , "
                "<code>refund_liability</code>, "
                "<code>credit_card</code>, "
                "<code>long_term_liability</code>, "
                "<code>loans_and_borrowing</code> "
                ",<code>lease_liability</code> "
                ",<code>employee_benefit_liability</code> "
                ",<code>contingent_liability</code> "
                ",<code>financial_liability</code> , "
                "<code>other_liability</code>, "
                "<code>equity</code>, "
                "<code>income</code>,<code>finance_income</code> "
                ",<code>other_comprehensive_income</code> "
                ", <code>other_income</code>, "
                "<code>expense</code>, "
                "<code>manufacturing_expense</code> "
                ",<code>impairment_expense</code> "
                ",<code>depreciation_expense</code> "
                ",<code>employee_benefit_expense</code> "
                ",<code>lease_expense</code> "
                ",<code>finance_expense</code> "
                ",<code>tax_expense</code> , "
                "<code>cost_of_goods_sold</code>, "
                "<code>other_expense</code>, "
                "<code>accounts_receivable</code> and "
                "<code>accounts_payable</code>.",
                "example": "long_term_liability",
                "type": "string",
            },
            "can_show_in_ze": {"example": False, "type": "boolean"},
            "currency_id": {
                "description": "ID of the account currency.",
                "example": "460000000000097",
                "type": "string",
            },
            "custom_fields": {
                "items": {
                    "properties": {
                        "customfield_id": {
                            "description": "ID of the Custom Field",
                            "example": "460000000080163",
                            "type": "string",
                        },
                        "value": {
                            "description": "Value of the Custom Field",
                            "example": "Normal",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "description": {
                "description": "Description of the account",
                "example": "A Liability account which can be paid off "
                "in a time period longer than one year.",
                "type": "string",
            },
            "include_in_vat_return": {
                "description": "Boolean to include an account in VAT returns.",
                "type": "boolean",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
            "parent_account_id": {
                "description": "ID of the Parent Account",
                "example": "460000000009097",
                "type": "string",
            },
            "show_on_dashboard": {"example": False, "type": "boolean"},
        },
        "type": "object",
    },
    "CREATECONTACTPERSON_REQUEST_BODY_SCHEMA": {
        "properties": {
            "communication_preference": {
                "description": "Preferred modes of communication for the contact person.",
                "properties": {
                    "is_whatsapp_enabled": {
                        "description": "Used "
                        "to "
                        "check "
                        "if "
                        "WhatsApp "
                        "communication "
                        "preference "
                        "is "
                        "enabled "
                        "for "
                        "the "
                        "contact "
                        "person.",
                        "example": True,
                        "type": "boolean",
                        "x-node_available_in": ["WhatsApp integration"],
                    }
                },
                "type": "object",
            },
            "contact_id": {
                "description": "Contact id of the contact",
                "example": 460000000026049,
                "type": "string",
            },
            "department": {
                "description": "department on which a person belongs. Max-length [50]",
                "example": "Sales",
                "type": "string",
            },
            "designation": {
                "description": "designation of a person. Max-length [50]",
                "example": "Sales Engineer",
                "type": "string",
            },
            "email": {
                "description": "Email address of the contact person.  Max-length [100]",
                "example": "willsmith@bowmanfurniture.com",
                "type": "string",
            },
            "enable_portal": {
                "description": "option to enable the portal access. "
                "allowed values "
                "<code>true</code>,<code>false</code>",
                "example": True,
                "type": "boolean",
            },
            "first_name": {
                "description": "First name of the contact person. Max-length [100]",
                "example": "Will",
                "type": "string",
            },
            "last_name": {
                "description": "Last name of the contact person. Max-length [100]",
                "example": "Smith",
                "type": "string",
            },
            "mobile": {
                "description": "Max-length [50]",
                "example": "+1-4054439562",
                "type": "string",
            },
            "phone": {
                "description": "Max-length [50]",
                "example": "+1-925-921-9201",
                "type": "string",
            },
            "salutation": {
                "description": "Salutation for the contact. Max-length [25]",
                "example": "Mr",
                "type": "string",
            },
            "skype": {
                "description": "skype address. Max-length [50]",
                "example": "zoho",
                "type": "string",
            },
        },
        "required": ["first_name"],
        "type": "object",
    },
    "UPDATECONTACTPERSON_REQUEST_BODY_SCHEMA": {
        "properties": {
            "communication_preference": {
                "description": "Preferred modes of communication for the contact person.",
                "properties": {
                    "is_whatsapp_enabled": {
                        "description": "Used "
                        "to "
                        "check "
                        "if "
                        "WhatsApp "
                        "communication "
                        "preference "
                        "is "
                        "enabled "
                        "for "
                        "the "
                        "contact "
                        "person.",
                        "example": True,
                        "type": "boolean",
                        "x-node_available_in": ["WhatsApp integration"],
                    }
                },
                "type": "object",
            },
            "contact_id": {
                "description": "Contact id of the contact",
                "example": 460000000026049,
                "type": "string",
            },
            "department": {
                "description": "department on which a person belongs. Max-length [50]",
                "example": "Sales",
                "type": "string",
            },
            "designation": {
                "description": "designation of a person. Max-length [50]",
                "example": "Sales Engineer",
                "type": "string",
            },
            "email": {
                "description": "Email address of the contact person.  Max-length [100]",
                "example": "willsmith@bowmanfurniture.com",
                "type": "string",
            },
            "enable_portal": {
                "description": "option to enable the portal access. "
                "allowed values "
                "<code>true</code>,<code>false</code>",
                "example": True,
                "type": "boolean",
            },
            "first_name": {
                "description": "First name of the contact person. Max-length [100]",
                "example": "Will",
                "type": "string",
            },
            "is_primary_contact": {
                "description": "To mark contact person as primary for contact",
                "example": True,
                "type": "boolean",
            },
            "last_name": {
                "description": "Last name of the contact person. Max-length [100]",
                "example": "Smith",
                "type": "string",
            },
            "mobile": {
                "description": "Max-length [50]",
                "example": "+1-4054439562",
                "type": "string",
            },
            "phone": {
                "description": "Max-length [50]",
                "example": "+1-925-921-9201",
                "type": "string",
            },
            "salutation": {
                "description": "Salutation for the contact. Max-length [25]",
                "example": "Mr",
                "type": "string",
            },
            "skype": {
                "description": "skype address. Max-length [50]",
                "example": "zoho",
                "type": "string",
            },
        },
        "required": ["contact_id", "first_name"],
        "type": "object",
    },
    "CREATEBUSINESSCONTACT_REQUEST_BODY_SCHEMA": {
        "properties": {
            "avatax_exempt_no": {
                "description": "Exemption certificate number of the customer.",
                "type": "string",
                "x-node_available_in": ["Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "avatax_use_code": {
                "description": "Used to group like customers for "
                "exemption purposes. It is a custom "
                "value that links customers to a "
                "tax rule. Select from Avalara "
                "[standard codes][1] or enter a "
                "custom code.",
                "type": "string",
                "x-node_available_in": ["Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "billing_address": {
                "description": "Billing address information for the contact.",
                "properties": {
                    "address": {
                        "description": "Street 1 address for the contact. Max-length [500].",
                        "example": "4900 Hopyard Rd",
                        "type": "string",
                    },
                    "attention": {
                        "description": "Attention "
                        "for "
                        "proper "
                        "delivery "
                        "and "
                        "routing "
                        "of "
                        "business "
                        "correspondence. "
                        "Max-length "
                        "[100].",
                        "example": "Mr.John",
                        "type": "string",
                    },
                    "city": {
                        "description": "City name for the address. Max-length [100].",
                        "example": "Pleasanton",
                        "type": "string",
                    },
                    "country": {
                        "description": "Country name for the address. Max-length [100].",
                        "example": "U.S.A",
                        "type": "string",
                    },
                    "fax": {
                        "description": "Fax number for the address. Max-length [50].",
                        "example": "+1-925-924-9600",
                        "type": "string",
                    },
                    "phone": {
                        "description": "The "
                        "contact "
                        "phone "
                        "number "
                        "associated "
                        "with the "
                        "address. "
                        "Max-length "
                        "[50]",
                        "example": "+1-925-921-9201",
                        "type": "string",
                    },
                    "state": {
                        "description": "State for the address. Max-length [100].",
                        "example": "CA",
                        "type": "string",
                    },
                    "state_code": {
                        "description": "State or province code for the address. Max-length [100].",
                        "example": "CA",
                        "type": "string",
                    },
                    "street2": {
                        "description": "Street 2 address for the contact. Max-length [255].",
                        "example": "Suite 310",
                        "type": "string",
                    },
                    "zip": {
                        "description": "Postal or ZIP code for the address. Max-length [50].",
                        "example": 94588,
                        "type": "string",
                    },
                },
                "type": "object",
            },
            "company_name": {
                "description": "Legal or registered contact's company "
                "name. Used for legal documents and "
                "formal communications. Max-length "
                "[200].",
                "example": "Bowman and Co",
                "type": "string",
            },
            "contact_name": {
                "description": "Display name for the contact. It is "
                "used for searching and displaying "
                "contacts.",
                "example": "Bowman and Co",
                "type": "string",
            },
            "contact_number": {
                "description": "Contact number associated with the "
                "contact for internal tracking and "
                "identification purposes. Max-length "
                "[200].",
                "example": "CNT-001234",
                "type": "string",
            },
            "contact_persons": {
                "items": {
                    "properties": {
                        "communication_preference": {
                            "description": "Preferred "
                            "modes "
                            "of "
                            "communication "
                            "for "
                            "the "
                            "contact "
                            "person.",
                            "properties": {
                                "is_sms_enabled": {
                                    "description": "Whether "
                                    "SMS "
                                    "text "
                                    "messages "
                                    "are "
                                    "allowed "
                                    "for "
                                    "the "
                                    "contact "
                                    "person.",
                                    "example": False,
                                    "type": "boolean",
                                    "x-node_available_in": ["SMS integration"],
                                },
                                "is_whatsapp_enabled": {
                                    "description": "Whether "
                                    "WhatsApp "
                                    "messaging "
                                    "is "
                                    "allowed "
                                    "for "
                                    "the "
                                    "contact "
                                    "person.",
                                    "example": False,
                                    "type": "boolean",
                                    "x-node_available_in": ["WhatsApp integration"],
                                },
                            },
                            "type": "object",
                        },
                        "department": {
                            "description": "Department "
                            "of "
                            "the "
                            "contact "
                            "person "
                            "within "
                            "the "
                            "contact's "
                            "company. "
                            "Max-length "
                            "[50].",
                            "example": "Sales and Marketing",
                            "type": "string",
                        },
                        "designation": {
                            "description": "Designation "
                            "of "
                            "the "
                            "contact "
                            "person "
                            "within "
                            "the "
                            "contact's "
                            "company. "
                            "Max-length "
                            "[100].",
                            "example": "Sales Executive",
                            "type": "string",
                        },
                        "email": {
                            "description": "Email "
                            "address "
                            "of "
                            "the "
                            "contact "
                            "person "
                            "for "
                            "business "
                            "communications. "
                            "Max-length "
                            "[100].",
                            "example": "willsmith@bowmanfurniture.com",
                            "type": "string",
                        },
                        "enable_portal": {
                            "description": "Indicates "
                            "whether "
                            "the "
                            "contact "
                            "person "
                            "should "
                            "have "
                            "access "
                            "to "
                            "the "
                            "client "
                            "portal. "
                            "Allowed "
                            "values: "
                            "<code>true</code> "
                            "and "
                            "<code>false</code>.",
                            "example": True,
                            "type": "boolean",
                        },
                        "first_name": {
                            "description": "First name of the contact person. Max-length [100].",
                            "example": "Will",
                            "type": "string",
                        },
                        "is_primary_contact": {
                            "description": "Indicates "
                            "whether "
                            "this "
                            "contact "
                            "person "
                            "is "
                            "the "
                            "primary "
                            "contact. "
                            "Only "
                            "one "
                            "per "
                            "contact. "
                            "Allowed "
                            "values: "
                            "<code>true</code> "
                            "and "
                            "<code>false</code>.",
                            "example": True,
                            "type": "boolean",
                        },
                        "last_name": {
                            "description": "Last name of the contact person. Max-length [100].",
                            "example": "Smith",
                            "type": "string",
                        },
                        "mobile": {
                            "description": "Mobile number of the contact person. Max-length [50].",
                            "example": "+1-4054439562",
                            "type": "string",
                        },
                        "phone": {
                            "description": "Phone number of the contact person. Max-length [50].",
                            "example": "+1-925-921-9201",
                            "type": "string",
                        },
                        "salutation": {
                            "description": "Salutation for the contact. Max-length [25]",
                            "example": "Mr",
                            "type": "string",
                        },
                        "skype": {
                            "description": "Skype username of the contact person. Max-length [50].",
                            "example": "Zoho",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "contact_type": {
                "description": "Determines how the contact is treated "
                "in the system. Allowed values: "
                "<code>customer</code>, "
                "<code>vendor</code>.",
                "example": "customer",
                "type": "string",
            },
            "country_code": {
                "description": "<b>For UK Edition:</b> Two letter "
                "country code of a contact<br/> <b>For "
                "Avalara:</b> Two letter country code "
                "for the customer country, if your "
                "customer is not in US. Refer [AvaTax "
                "Codes for Countries and "
                "States][2].<br/> <b>For GCC Editions "
                ":</b> Two Letter country code for the "
                "GCC Country or the UAE emirate of the "
                "contact which will be considered as "
                "<b>place of supply</b>.<br/>Supported "
                "codes for UAE emirates are : </br>Abu "
                "Dhabi - <code>AB</code>,</br>Ajman - "
                "<code>AJ</code>,</br>Dubai - "
                "<code>DU</code>,</br>Fujairah - "
                "<code>FU</code>,</br>Ras al-Khaimah - "
                "<code>RA</code>,</br>Sharjah - "
                "<code>SH</code>,</br>Umm al-Quwain - "
                "<code>UM</code>.<br/>Supported codes "
                "for the GCC countries are : "
                "</br>United Arab Emirates - "
                "<code>AE</code>,</br>Saudi Arabia - "
                "<code>SA</code>,</br>Bahrain - "
                "<code>BH</code>,</br>Kuwait - "
                "<code>KW</code>,</br>Oman - "
                "<code>OM</code>,</br>Qatar - "
                "<code>QA</code>.",
                "type": "string",
                "x-node_available_in": ["uk", "gcc", "Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "credit_limit": {
                "description": "<b>For Customer Only :</b> The "
                "maximum credit amount that can be "
                "allowed for the customer. Once the "
                "customer's outstanding receivables "
                "reach this limit, the system will "
                "restrict the customer from creating "
                "any further transactions.",
                "example": 1000,
                "format": "double",
                "type": "number",
            },
            "currency_id": {
                "description": "Unique identifier for the currency "
                "assigned to this contact. The "
                "currency_id must correspond to a valid "
                "currency configuration in the system.",
                "example": 460000000000097,
                "type": "string",
            },
            "custom_fields": {
                "description": "Custom fields of the contact.",
                "items": {
                    "properties": {
                        "index": {
                            "description": "Index "
                            "of "
                            "the "
                            "custom "
                            "field. "
                            "It "
                            "can "
                            "hold "
                            "any "
                            "value "
                            "from "
                            "1 "
                            "to "
                            "10.",
                            "example": 1,
                            "type": "integer",
                        },
                        "value": {
                            "description": "Value of the custom field.",
                            "example": "GBGD078",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "customer_sub_type": {
                "description": "<b>For Customer Only :</b> "
                "Additional classification for "
                "customers. Allowed values: "
                "<code>individual</code>, "
                "<code>business</code>.",
                "example": "business",
                "type": "string",
            },
            "default_templates": {
                "properties": {
                    "bill_template_id": {
                        "description": "Default "
                        "bill "
                        "template "
                        "id "
                        "used "
                        "for "
                        "this "
                        "vendor "
                        "while "
                        "creating "
                        "bill.",
                        "example": 460000000000103,
                        "type": "string",
                    },
                    "creditnote_email_template_id": {
                        "description": "Default "
                        "credit "
                        "note "
                        "email "
                        "template "
                        "id "
                        "used "
                        "for "
                        "this "
                        "customer "
                        "while "
                        "sending "
                        "credit "
                        "notes.",
                        "example": 460000000052075,
                        "type": "string",
                    },
                    "creditnote_template_id": {
                        "description": "Default "
                        "credit "
                        "note "
                        "template "
                        "id "
                        "used "
                        "for "
                        "this "
                        "customer "
                        "while "
                        "creating "
                        "credit "
                        "note.",
                        "example": 460000000000211,
                        "type": "string",
                    },
                    "estimate_email_template_id": {
                        "description": "Default "
                        "estimate "
                        "email "
                        "template "
                        "id "
                        "used "
                        "for "
                        "this "
                        "customer "
                        "while "
                        "sending "
                        "estimates.",
                        "example": 460000000052073,
                        "type": "string",
                    },
                    "estimate_template_id": {
                        "description": "Default "
                        "estimate "
                        "template "
                        "id "
                        "used "
                        "for "
                        "this "
                        "customer "
                        "while "
                        "creating "
                        "estimate.",
                        "example": 460000000000179,
                        "type": "string",
                    },
                    "invoice_email_template_id": {
                        "description": "Default "
                        "invoice "
                        "email "
                        "template "
                        "id "
                        "used "
                        "for "
                        "this "
                        "customer "
                        "while "
                        "sending "
                        "invoices.",
                        "example": 460000000052071,
                        "type": "string",
                    },
                    "invoice_template_id": {
                        "description": "Default "
                        "invoice "
                        "template "
                        "id "
                        "used "
                        "for "
                        "this "
                        "customer "
                        "while "
                        "creating "
                        "invoice.",
                        "example": 460000000052069,
                        "type": "string",
                    },
                    "payment_remittance_email_template_id": {
                        "description": "Default "
                        "payment "
                        "remittance "
                        "email "
                        "template "
                        "id "
                        "used "
                        "for "
                        "this "
                        "contact "
                        "while "
                        "sending "
                        "payment "
                        "remittances.",
                        "example": 460000000000102,
                        "type": "string",
                    },
                    "paymentthankyou_email_template_id": {
                        "description": "Default "
                        "payment "
                        "thank "
                        "you "
                        "email "
                        "template "
                        "id "
                        "used "
                        "for "
                        "this "
                        "contact "
                        "while "
                        "sending "
                        "payment "
                        "acknowledgment.",
                        "example": 460000000000221,
                        "type": "string",
                    },
                    "paymentthankyou_template_id": {
                        "description": "Default "
                        "payment "
                        "thank "
                        "you "
                        "template "
                        "id "
                        "used "
                        "for "
                        "this "
                        "contact "
                        "while "
                        "sending "
                        "payment "
                        "acknowledgment.",
                        "example": 460000000000216,
                        "type": "string",
                    },
                    "purchaseorder_email_template_id": {
                        "description": "Default "
                        "purchase "
                        "order "
                        "email "
                        "template "
                        "id "
                        "used "
                        "for "
                        "this "
                        "vendor "
                        "while "
                        "sending "
                        "purchase "
                        "order.",
                        "example": 460000000000218,
                        "type": "string",
                    },
                    "purchaseorder_template_id": {
                        "description": "Default "
                        "purchase "
                        "order "
                        "template "
                        "id "
                        "used "
                        "for "
                        "this "
                        "vendor "
                        "while "
                        "creating "
                        "purchase "
                        "order.",
                        "example": 460000000000213,
                        "type": "string",
                    },
                    "retainerinvoice_email_template_id": {
                        "description": "Default "
                        "retainer "
                        "invoice "
                        "email "
                        "template "
                        "id "
                        "used "
                        "for "
                        "this "
                        "contact "
                        "while "
                        "sending "
                        "retainer "
                        "invoice.",
                        "example": 460000000000220,
                        "type": "string",
                    },
                    "retainerinvoice_paymentthankyou_email_template_id": {
                        "description": "Default "
                        "retainer "
                        "invoice "
                        "payment "
                        "thank "
                        "you "
                        "email "
                        "template "
                        "id "
                        "used "
                        "for "
                        "this "
                        "customer "
                        "while "
                        "sending "
                        "payment "
                        "acknowledgment "
                        "for "
                        "retainer "
                        "invoices.",
                        "example": 460000000000222,
                        "type": "string",
                    },
                    "retainerinvoice_paymentthankyou_template_id": {
                        "description": "Default "
                        "retainer "
                        "invoice "
                        "payment "
                        "thank "
                        "you "
                        "template "
                        "id "
                        "used "
                        "for "
                        "this "
                        "customer "
                        "while "
                        "sending "
                        "payment "
                        "acknowledgment "
                        "for "
                        "retainer "
                        "invoices.",
                        "example": 460000000000217,
                        "type": "string",
                    },
                    "retainerinvoice_template_id": {
                        "description": "Default "
                        "retainer "
                        "invoice "
                        "template "
                        "id "
                        "used "
                        "for "
                        "this "
                        "customer "
                        "while "
                        "creating "
                        "retainer "
                        "invoice.",
                        "example": 460000000000215,
                        "type": "string",
                    },
                    "salesorder_email_template_id": {
                        "description": "Default "
                        "sales "
                        "order "
                        "email "
                        "template "
                        "id "
                        "used "
                        "for "
                        "this "
                        "customer "
                        "while "
                        "sending "
                        "sales "
                        "order.",
                        "example": 460000000000219,
                        "type": "string",
                    },
                    "salesorder_template_id": {
                        "description": "Default "
                        "sales "
                        "order "
                        "template "
                        "id "
                        "used "
                        "for "
                        "this "
                        "customer "
                        "while "
                        "creating "
                        "sales "
                        "order.",
                        "example": 460000000000214,
                        "type": "string",
                    },
                    "statement_template_id": {
                        "description": "Default "
                        "statement "
                        "template "
                        "id "
                        "used "
                        "for "
                        "this "
                        "contact "
                        "while "
                        "creating "
                        "statement.",
                        "example": 460000000000101,
                        "type": "string",
                    },
                },
                "type": "object",
            },
            "facebook": {
                "description": "Facebook profile URL for the contact. Max-length [100].",
                "example": "zoho",
                "type": "string",
            },
            "gst_no": {
                "description": "15-digit GST identification number of the "
                "contact as issued by the Indian tax "
                "authorities.",
                "example": "22AAAAA0000A1Z5",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "gst_treatment": {
                "description": "Choose whether the contact is GST "
                "registered/unregistered/consumer/overseas. "
                "Allowed values are <code> "
                "business_gst </code> , <code> "
                "business_none </code> , <code> "
                "overseas </code> , <code> consumer "
                "</code>.",
                "example": "business_gst",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "ignore_auto_number_generation": {
                "description": "Indicates whether "
                "the auto generation "
                "contact_number is "
                "ignored or not for "
                "the contact. Allowed "
                "values: "
                "<code>true</code>, "
                "<code>false</code>.",
                "example": False,
                "type": "boolean",
            },
            "is_portal_enabled": {
                "description": "Indicates whether portal access "
                "is enabled for the primary "
                "contact person. Allowed value: "
                "<code>true</code> and "
                "<code>false</code>.",
                "example": True,
                "type": "boolean",
            },
            "is_taxable": {
                "description": "Indicates whether the customer is "
                "subject to tax collection. Tax-related "
                "fields are only available when this "
                "field is set to true. Allowed values: "
                "<code>true</code> and "
                "<code>false</code>.",
                "example": True,
                "type": "boolean",
                "x-node_available_in": ["us", "ca", "au", "in", "mx", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "is_tds_registered": {
                "description": "Indicates whether the contact is "
                "registered for Tax Deducted at "
                "Source (TDS) in Mexico.",
                "type": "boolean",
                "x-node_available_in": ["mx"],
                "x-node_unavailable_in": [],
            },
            "language_code": {
                "description": "Preferred language for the contact. "
                "Determines portal language. Allowed "
                "values: "
                "<code>de,en,es,fr,it,ja,nl,pt,pt_br,sv,zh,en_gb</code>",
                "type": "string",
            },
            "legal_name": {
                "description": "Official legal name of the contact as "
                "registered with tax authorities in "
                "Mexico.",
                "example": "ESCUELA KEMPER URGATE",
                "type": "string",
                "x-node_available_in": ["mx"],
                "x-node_unavailable_in": [],
            },
            "notes": {
                "description": "Additional comments or notes about the contact.",
                "example": "Payment option : Through check",
                "type": "string",
            },
            "opening_balances": {
                "items": {
                    "properties": {
                        "exchange_rate": {
                            "description": "Currency "
                            "exchange "
                            "rate "
                            "used "
                            "to "
                            "convert "
                            "opening "
                            "balance "
                            "to "
                            "organization's "
                            "base "
                            "currency.",
                            "example": 1,
                            "format": "double",
                            "type": "number",
                        },
                        "location_id": {
                            "description": "Unique "
                            "identifier "
                            "for "
                            "the "
                            "business "
                            "location "
                            "associated "
                            "with "
                            "this "
                            "opening "
                            "balance.",
                            "example": "460000000038080",
                            "type": "string",
                        },
                        "opening_balance_amount": {
                            "description": "Initial "
                            "balance "
                            "amount "
                            "for "
                            "the "
                            "contact "
                            "at "
                            "the "
                            "time "
                            "of "
                            "creation.",
                            "example": 1200,
                            "format": "double",
                            "type": "number",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "owner_id": {
                "description": "<b>For Customer Only :</b> Unique "
                "identifier for the user assigned as the "
                "owner of the contact. This field "
                "specifies which user in the organization "
                "is responsible for managing the business "
                "relationship with this contact.",
                "example": 460000000016051,
                "type": "string",
            },
            "payment_terms": {
                "description": "Number of days allowed for payment after the invoice date.",
                "example": 15,
                "type": "integer",
            },
            "payment_terms_label": {
                "description": "Human-readable label of "
                "payment terms displayed on "
                "invoices and other "
                "transactions. Max-length "
                "[200].",
                "example": "Net 15",
                "type": "string",
            },
            "place_of_contact": {
                "description": "State or union territory code "
                "where the contact is located for "
                "Indian tax purposes. (This node "
                "identifies the place of supply "
                "and source of supply when "
                "invoices/bills are raised for the "
                "customer/vendor respectively. "
                "This is not applicable for "
                "Overseas contacts)",
                "example": "TN",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "pricebook_id": {
                "description": "Pricebook id which is associated with "
                "the contact. Max-length [200].",
                "example": 460000000000123,
                "type": "string",
            },
            "shipping_address": {
                "description": "Shipping address information for the contact.",
                "properties": {
                    "address": {
                        "description": "Street 1 address for the contact. Max-length [500].",
                        "example": "4900 Hopyard Rd",
                        "type": "string",
                    },
                    "attention": {
                        "description": "Attention "
                        "for "
                        "proper "
                        "delivery "
                        "and "
                        "routing "
                        "of "
                        "business "
                        "correspondence. "
                        "Max-length "
                        "[100].",
                        "example": "Mr.John",
                        "type": "string",
                    },
                    "city": {
                        "description": "City name for the address. Max-length [100].",
                        "example": "Pleasanton",
                        "type": "string",
                    },
                    "country": {
                        "description": "Country name for the address. Max-length [100].",
                        "example": "U.S.A",
                        "type": "string",
                    },
                    "fax": {
                        "description": "Fax number for the address. Max-length [50].",
                        "example": "+1-925-924-9600",
                        "type": "string",
                    },
                    "phone": {
                        "description": "The "
                        "contact "
                        "phone "
                        "number "
                        "associated "
                        "with the "
                        "address. "
                        "Max-length "
                        "[50]",
                        "example": "+1-925-921-9201",
                        "type": "string",
                    },
                    "state": {
                        "description": "State for the address. Max-length [100].",
                        "example": "CA",
                        "type": "string",
                    },
                    "state_code": {
                        "description": "State or province code for the address. Max-length [100].",
                        "example": "CA",
                        "type": "string",
                    },
                    "street2": {
                        "description": "Street 2 address for the contact. Max-length [255].",
                        "example": "Suite 310",
                        "type": "string",
                    },
                    "zip": {
                        "description": "Postal or ZIP code for the address. Max-length [50].",
                        "example": 94588,
                        "type": "string",
                    },
                },
                "type": "object",
            },
            "tags": {
                "description": "Filter all your reports based on the tag",
                "items": {
                    "properties": {
                        "tag_id": {
                            "description": "ID of the reporting tag",
                            "example": 462000000009070,
                            "type": "string",
                        },
                        "tag_option_id": {
                            "description": "ID of the reporting tag's option",
                            "example": 462000000002670,
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "tax_authority_id": {
                "description": "Unique identifier for the tax "
                "authority responsible for the "
                "customer's tax jurisdiction. Tax "
                "authority depends on the location "
                "of the customer. For example, if "
                "the customer is located in NY, "
                "then the tax authority is NY tax "
                "authority.",
                "example": 11149000000061052,
                "type": "string",
                "x-node_available_in": ["us"],
                "x-node_unavailable_in": [],
            },
            "tax_authority_name": {
                "description": "Display name of the tax "
                "authority responsible for the "
                "customer's tax jurisdiction.",
                "type": "string",
            },
            "tax_exemption_certificate_number": {
                "description": "Tax Exemption "
                "Certificate "
                "number is issued "
                "by the Kenya "
                "Revenue Authority "
                "(KRA) to "
                "organizations or "
                "individuals who "
                "qualify for tax "
                "exemption",
                "example": "KRAEXM0043310521",
                "type": "string",
                "x-node_available_in": ["ke"],
                "x-node_unavailable_in": [],
            },
            "tax_exemption_code": {
                "description": "Code identifier for the tax exemption assigned to the contact.",
                "type": "string",
                "x-node_available_in": ["us", "ca", "au", "in"],
                "x-node_unavailable_in": [],
            },
            "tax_exemption_id": {
                "description": "Unique identifier for the tax "
                "exemption configuration assigned "
                "to this contact.",
                "example": 11149000000061054,
                "type": "string",
                "x-node_available_in": ["us", "ca", "au", "in"],
                "x-node_unavailable_in": [],
            },
            "tax_id": {
                "description": "Unique identifier for the tax or tax group "
                "assigned to the contact. Available only "
                "when <code>is_taxable</code> is "
                "<code>true</code>.",
                "example": 11149000000061058,
                "type": "string",
                "x-node_available_in": ["in", "us"],
                "x-node_unavailable_in": [],
            },
            "tax_id_type": {
                "description": "Tax ID type of the contact, it can be SSN, ATIN, ITIN or EIN.",
                "type": "string",
                "x-node_available_in": ["us"],
                "x-node_unavailable_in": [],
            },
            "tax_id_value": {
                "description": "Tax ID of the contact.",
                "type": "string",
                "x-node_available_in": ["us"],
                "x-node_unavailable_in": [],
            },
            "tax_reg_no": {
                "description": "<b>For GCC Edition:</b> 15 digit Tax "
                "Registration number of a contact with "
                "Tax treatment as "
                "<code>vat_registered</code>,<code>gcc_vat_registered</code>,<code>dz_vat_registered</code>.<br/><b>For "
                "Mexico Edition:</b> 12 digit Tax "
                "Registration number of a contact with "
                "Tax treatment as </br> "
                "<code>home_country_mexico</code>, "
                "<code>border_region_mexico</code>, "
                "<code>non_mexico</code>.</br> Consumers "
                "generic RFC: "
                "<code>XAXX010101000</code>, Overseas "
                "generic RFC: "
                "<code>XEXX010101000</code>.<br/><b>For "
                "Kenya Edition:</b> 11 digit Tax "
                "Registration number of a contact with "
                "Tax treatment as "
                "<code>vat_registered</code><br/><b>For "
                "SouthAfrica Edition:</b> 10 digit Tax "
                "Registration number of a contact with "
                "Tax treatment as "
                "<code>vat_registered</code>",
                "example": 12345678912345,
                "type": "string",
                "x-node_available_in": ["gcc", "mx", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "tax_regime": {
                "description": "Tax Regime of the contact.Allowed "
                "Values: "
                "<code>general_legal_person</code>, "
                "<code>legal_entities_non_profit</code>, "
                "<code>resident_abroad</code>, "
                "<code>production_cooperative_societies</code>, "
                "<code>agricultural_livestock</code>, "
                "<code>optional_group_of_companies</code>, "
                "<code>coordinated</code>, "
                "<code>simplified_trust</code>, "
                "<code>wages_salaries_income</code>, "
                "<code>lease</code>, "
                "<code>property_disposal_acquisition</code>, "
                "<code>other_income</code>, "
                "<code>resident_abroad</code>, "
                "<code>divident_income</code>, "
                "<code>individual_business_professional</code>, "
                "<code>interest_income</code>, "
                "<code>income_obtaining_price</code>, "
                "<code>no_tax_obligation</code>, "
                "<code>tax_incorporation</code>, "
                "<code>income_through_technology_platform</code>, "
                "<code>simplified_trust</code>.",
                "example": "general_legal_person",
                "type": "string",
                "x-node_available_in": ["mx"],
                "x-node_unavailable_in": [],
            },
            "tax_treatment": {
                "description": "Tax treatment of the "
                "contact.<br/>Allowed Values: "
                "<code>vat_registered</code>,<code>vat_not_registered</code>,<code>gcc_vat_not_registered</code>,<code>gcc_vat_registered</code>,<code>non_gcc</code>,<code>dz_vat_registered</code> "
                "and "
                "<code>dz_vat_not_registered</code></br><code>home_country_mexico</code> "
                "(A business that is located within "
                "MX)</br><code>border_region_mexico</code> "
                "(A business that is located in the "
                "northern and southern border regions "
                "in MX)</br><code>non_mexico</code> "
                "(A business that is located outside "
                "MX).<br/><b>For Kenya Edition:</b> "
                "<code>vat_registered</code> "
                ",<code>vat_not_registered</code> "
                ",<code>non_kenya</code>(A business "
                "that is located outside "
                "Kenya).<br/><b>For SouthAfrica "
                "Edition:</b> "
                "<code>vat_registered</code>, "
                "<code>vat_not_registered</code>, "
                "<code>overseas</code>(A business "
                "that is located outside "
                "SouthAfrica).",
                "type": "string",
                "x-node_available_in": ["gcc", "mx", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "tds_tax_id": {
                "description": "Unique identifier for the Tax Deducted "
                "at Source (TDS) tax configuration "
                "assigned to the contact.",
                "example": "982000000557012",
                "type": "string",
                "x-node_available_in": ["mx"],
                "x-node_unavailable_in": [],
            },
            "track_1099": {
                "description": "Boolean to track a contact for 1099 reporting.",
                "type": "boolean",
                "x-node_available_in": ["us"],
                "x-node_unavailable_in": [],
            },
            "twitter": {
                "description": "X profile URL for the contact. Max-length [100].",
                "example": "zoho",
                "type": "string",
            },
            "vat_reg_no": {
                "description": "<b>For UK Edition:</b> VAT Registration "
                "number of a contact with length should "
                "be between 2 and 12 characters.<br/> "
                "<b>For Avalara:</b> If you are doing "
                "sales in the European Union (EU) then "
                "provide VAT Registration Number of your "
                "customers here. This is used to "
                "calculate VAT for B2B sales, from "
                "Avalara.",
                "type": "string",
                "x-node_available_in": ["uk", "Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "vat_treatment": {
                "description": "VAT treatment of the contact.Allowed "
                "Values: <br/><code>uk</code> (A "
                "business that is located in the "
                "UK.),<br/><code>eu_vat_registered</code> "
                "(A business that is reg for VAT and "
                "trade goods between Northern Ireland "
                "and EU. This node is available only "
                "for organizations enabled for NI "
                "protocal in VAT Settings.) "
                "and<br/><code>overseas</code> (A "
                "business that is located outside UK. "
                "Pre Brexit, this was split as "
                "<code>eu_vat_registered</code>, "
                "<code>eu_vat_not_registered</code> "
                "and <code>non_eu</code> ).",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
            "website": {
                "description": "Official website URL of the contact.",
                "example": "www.bowmanfurniture.com",
                "type": "string",
            },
        },
        "required": ["contact_name"],
        "type": "object",
    },
    "UPDATECONTACTBYCUSTOMFIELD_REQUEST_BODY_SCHEMA": {
        "properties": {
            "avatax_exempt_no": {
                "description": "Exemption certificate number of the customer.",
                "type": "string",
                "x-node_available_in": ["Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "avatax_use_code": {
                "description": "Used to group like customers for "
                "exemption purposes. It is a custom "
                "value that links customers to a "
                "tax rule. Select from Avalara "
                "[standard codes][1] or enter a "
                "custom code.",
                "type": "string",
                "x-node_available_in": ["Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "billing_address": {
                "description": "Billing address information for the contact.",
                "properties": {
                    "address": {
                        "description": "Street 1 address for the contact. Max-length [500].",
                        "example": "4900 Hopyard Rd",
                        "type": "string",
                    },
                    "attention": {
                        "description": "Attention "
                        "for "
                        "proper "
                        "delivery "
                        "and "
                        "routing "
                        "of "
                        "business "
                        "correspondence. "
                        "Max-length "
                        "[100].",
                        "example": "Mr.John",
                        "type": "string",
                    },
                    "city": {
                        "description": "City name for the address. Max-length [100].",
                        "example": "Pleasanton",
                        "type": "string",
                    },
                    "country": {
                        "description": "Country name for the address. Max-length [100].",
                        "example": "U.S.A",
                        "type": "string",
                    },
                    "fax": {
                        "description": "Fax number for the address. Max-length [50].",
                        "example": "+1-925-924-9600",
                        "type": "string",
                    },
                    "phone": {
                        "description": "The "
                        "contact "
                        "phone "
                        "number "
                        "associated "
                        "with the "
                        "address. "
                        "Max-length "
                        "[50]",
                        "example": "+1-925-921-9201",
                        "type": "string",
                    },
                    "state": {
                        "description": "State for the address. Max-length [100].",
                        "example": "CA",
                        "type": "string",
                    },
                    "state_code": {
                        "description": "State or province code for the address. Max-length [100].",
                        "example": "CA",
                        "type": "string",
                    },
                    "street2": {
                        "description": "Street 2 address for the contact. Max-length [255].",
                        "example": "Suite 310",
                        "type": "string",
                    },
                    "zip": {
                        "description": "Postal or ZIP code for the address. Max-length [50].",
                        "example": 94588,
                        "type": "string",
                    },
                },
                "type": "object",
            },
            "company_name": {
                "description": "Legal or registered contact's company "
                "name. Used for legal documents and "
                "formal communications. Max-length "
                "[200].",
                "example": "Bowman and Co",
                "type": "string",
            },
            "contact_name": {
                "description": "Display name for the contact. It is "
                "used for searching and displaying "
                "contacts.",
                "example": "Bowman and Co",
                "type": "string",
            },
            "contact_number": {
                "description": "Contact number associated with the "
                "contact for internal tracking and "
                "identification purposes. Max-length "
                "[200].",
                "example": "CNT-001234",
                "type": "string",
            },
            "contact_persons": {
                "items": {
                    "properties": {
                        "communication_preference": {
                            "description": "Preferred "
                            "modes "
                            "of "
                            "communication "
                            "for "
                            "the "
                            "contact "
                            "person.",
                            "properties": {
                                "is_sms_enabled": {
                                    "description": "Whether "
                                    "SMS "
                                    "text "
                                    "messages "
                                    "are "
                                    "allowed "
                                    "for "
                                    "the "
                                    "contact "
                                    "person.",
                                    "example": False,
                                    "type": "boolean",
                                    "x-node_available_in": ["SMS integration"],
                                },
                                "is_whatsapp_enabled": {
                                    "description": "Whether "
                                    "WhatsApp "
                                    "messaging "
                                    "is "
                                    "allowed "
                                    "for "
                                    "the "
                                    "contact "
                                    "person.",
                                    "example": False,
                                    "type": "boolean",
                                    "x-node_available_in": ["WhatsApp integration"],
                                },
                            },
                            "type": "object",
                        },
                        "contact_person_id": {
                            "description": "ID "
                            "of "
                            "the "
                            "contact "
                            "person. "
                            "For "
                            "an "
                            "existing "
                            "contact "
                            "person, "
                            "pass "
                            "the "
                            "<code>contact_person_id</code>.",
                            "example": 460000000026051,
                            "type": "string",
                        },
                        "department": {
                            "description": "Department "
                            "of "
                            "the "
                            "contact "
                            "person "
                            "within "
                            "the "
                            "contact's "
                            "company. "
                            "Max-length "
                            "[50].",
                            "example": "Sales and Marketing",
                            "type": "string",
                        },
                        "designation": {
                            "description": "Designation "
                            "of "
                            "the "
                            "contact "
                            "person "
                            "within "
                            "the "
                            "contact's "
                            "company. "
                            "Max-length "
                            "[100].",
                            "example": "Sales Executive",
                            "type": "string",
                        },
                        "email": {
                            "description": "Email "
                            "address "
                            "of "
                            "the "
                            "contact "
                            "person "
                            "for "
                            "business "
                            "communications. "
                            "Max-length "
                            "[100].",
                            "example": "willsmith@bowmanfurniture.com",
                            "type": "string",
                        },
                        "enable_portal": {
                            "description": "Indicates "
                            "whether "
                            "the "
                            "contact "
                            "person "
                            "should "
                            "have "
                            "access "
                            "to "
                            "the "
                            "client "
                            "portal. "
                            "Allowed "
                            "values: "
                            "<code>true</code> "
                            "and "
                            "<code>false</code>.",
                            "example": True,
                            "type": "boolean",
                        },
                        "first_name": {
                            "description": "First name of the contact person. Max-length [100].",
                            "example": "Will",
                            "type": "string",
                        },
                        "is_primary_contact": {
                            "description": "Indicates "
                            "whether "
                            "this "
                            "contact "
                            "person "
                            "is "
                            "the "
                            "primary "
                            "contact. "
                            "Only "
                            "one "
                            "per "
                            "contact. "
                            "Allowed "
                            "values: "
                            "<code>true</code> "
                            "and "
                            "<code>false</code>.",
                            "example": True,
                            "type": "boolean",
                        },
                        "last_name": {
                            "description": "Last name of the contact person. Max-length [100].",
                            "example": "Smith",
                            "type": "string",
                        },
                        "mobile": {
                            "description": "Mobile number of the contact person. Max-length [50].",
                            "example": "+1-4054439562",
                            "type": "string",
                        },
                        "phone": {
                            "description": "Phone number of the contact person. Max-length [50].",
                            "example": "+1-925-921-9201",
                            "type": "string",
                        },
                        "salutation": {
                            "description": "Salutation for the contact. Max-length [25]",
                            "example": "Mr",
                            "type": "string",
                        },
                        "skype": {
                            "description": "Skype username of the contact person. Max-length [50].",
                            "example": "Zoho",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "contact_type": {
                "description": "Determines how the contact is treated "
                "in the system. Allowed values: "
                "<code>customer</code>, "
                "<code>vendor</code>.",
                "example": "customer",
                "type": "string",
            },
            "country_code": {
                "description": "<b>For UK Edition:</b> Two letter "
                "country code of a contact<br/> <b>For "
                "Avalara:</b> Two letter country code "
                "for the customer country, if your "
                "customer is not in US. Refer [AvaTax "
                "Codes for Countries and "
                "States][2].<br/> <b>For GCC Editions "
                ":</b> Two Letter country code for the "
                "GCC Country or the UAE emirate of the "
                "contact which will be considered as "
                "<b>place of supply</b>.<br/>Supported "
                "codes for UAE emirates are : </br>Abu "
                "Dhabi - <code>AB</code>,</br>Ajman - "
                "<code>AJ</code>,</br>Dubai - "
                "<code>DU</code>,</br>Fujairah - "
                "<code>FU</code>,</br>Ras al-Khaimah - "
                "<code>RA</code>,</br>Sharjah - "
                "<code>SH</code>,</br>Umm al-Quwain - "
                "<code>UM</code>.<br/>Supported codes "
                "for the GCC countries are : "
                "</br>United Arab Emirates - "
                "<code>AE</code>,</br>Saudi Arabia - "
                "<code>SA</code>,</br>Bahrain - "
                "<code>BH</code>,</br>Kuwait - "
                "<code>KW</code>,</br>Oman - "
                "<code>OM</code>,</br>Qatar - "
                "<code>QA</code>.",
                "type": "string",
                "x-node_available_in": ["uk", "gcc", "Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "credit_limit": {
                "description": "<b>For Customer Only :</b> The "
                "maximum credit amount that can be "
                "allowed for the customer. Once the "
                "customer's outstanding receivables "
                "reach this limit, the system will "
                "restrict the customer from creating "
                "any further transactions.",
                "example": 1000,
                "format": "double",
                "type": "number",
            },
            "currency_id": {
                "description": "Unique identifier for the currency "
                "assigned to this contact. The "
                "currency_id must correspond to a valid "
                "currency configuration in the system.",
                "example": 460000000000097,
                "type": "string",
            },
            "custom_fields": {
                "items": {
                    "properties": {
                        "index": {
                            "description": "Index "
                            "of "
                            "the "
                            "custom "
                            "field. "
                            "It "
                            "can "
                            "hold "
                            "any "
                            "value "
                            "from "
                            "1 "
                            "to "
                            "10.",
                            "example": 1,
                            "type": "integer",
                        },
                        "label": {
                            "description": "Label of the custom field.",
                            "example": "VAT ID",
                            "type": "string",
                        },
                        "value": {
                            "description": "Value of the custom field.",
                            "example": "GBGD078",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "customer_sub_type": {
                "description": "<b>For Customer Only :</b> "
                "Additional classification for "
                "customers. Allowed values: "
                "<code>individual</code>, "
                "<code>business</code>.",
                "example": "business",
                "type": "string",
            },
            "default_templates": {
                "properties": {
                    "bill_template_id": {
                        "description": "Default "
                        "bill "
                        "template "
                        "id "
                        "used "
                        "for "
                        "this "
                        "vendor "
                        "while "
                        "creating "
                        "bill.",
                        "example": 460000000000103,
                        "type": "string",
                    },
                    "creditnote_email_template_id": {
                        "description": "Default "
                        "credit "
                        "note "
                        "email "
                        "template "
                        "id "
                        "used "
                        "for "
                        "this "
                        "customer "
                        "while "
                        "sending "
                        "credit "
                        "notes.",
                        "example": 460000000052075,
                        "type": "string",
                    },
                    "creditnote_template_id": {
                        "description": "Default "
                        "credit "
                        "note "
                        "template "
                        "id "
                        "used "
                        "for "
                        "this "
                        "customer "
                        "while "
                        "creating "
                        "credit "
                        "note.",
                        "example": 460000000000211,
                        "type": "string",
                    },
                    "estimate_email_template_id": {
                        "description": "Default "
                        "estimate "
                        "email "
                        "template "
                        "id "
                        "used "
                        "for "
                        "this "
                        "customer "
                        "while "
                        "sending "
                        "estimates.",
                        "example": 460000000052073,
                        "type": "string",
                    },
                    "estimate_template_id": {
                        "description": "Default "
                        "estimate "
                        "template "
                        "id "
                        "used "
                        "for "
                        "this "
                        "customer "
                        "while "
                        "creating "
                        "estimate.",
                        "example": 460000000000179,
                        "type": "string",
                    },
                    "invoice_email_template_id": {
                        "description": "Default "
                        "invoice "
                        "email "
                        "template "
                        "id "
                        "used "
                        "for "
                        "this "
                        "customer "
                        "while "
                        "sending "
                        "invoices.",
                        "example": 460000000052071,
                        "type": "string",
                    },
                    "invoice_template_id": {
                        "description": "Default "
                        "invoice "
                        "template "
                        "id "
                        "used "
                        "for "
                        "this "
                        "customer "
                        "while "
                        "creating "
                        "invoice.",
                        "example": 460000000052069,
                        "type": "string",
                    },
                    "payment_remittance_email_template_id": {
                        "description": "Default "
                        "payment "
                        "remittance "
                        "email "
                        "template "
                        "id "
                        "used "
                        "for "
                        "this "
                        "contact "
                        "while "
                        "sending "
                        "payment "
                        "remittances.",
                        "example": 460000000000102,
                        "type": "string",
                    },
                    "paymentthankyou_email_template_id": {
                        "description": "Default "
                        "payment "
                        "thank "
                        "you "
                        "email "
                        "template "
                        "id "
                        "used "
                        "for "
                        "this "
                        "contact "
                        "while "
                        "sending "
                        "payment "
                        "acknowledgment.",
                        "example": 460000000000221,
                        "type": "string",
                    },
                    "paymentthankyou_template_id": {
                        "description": "Default "
                        "payment "
                        "thank "
                        "you "
                        "template "
                        "id "
                        "used "
                        "for "
                        "this "
                        "contact "
                        "while "
                        "sending "
                        "payment "
                        "acknowledgment.",
                        "example": 460000000000216,
                        "type": "string",
                    },
                    "purchaseorder_email_template_id": {
                        "description": "Default "
                        "purchase "
                        "order "
                        "email "
                        "template "
                        "id "
                        "used "
                        "for "
                        "this "
                        "vendor "
                        "while "
                        "sending "
                        "purchase "
                        "order.",
                        "example": 460000000000218,
                        "type": "string",
                    },
                    "purchaseorder_template_id": {
                        "description": "Default "
                        "purchase "
                        "order "
                        "template "
                        "id "
                        "used "
                        "for "
                        "this "
                        "vendor "
                        "while "
                        "creating "
                        "purchase "
                        "order.",
                        "example": 460000000000213,
                        "type": "string",
                    },
                    "retainerinvoice_email_template_id": {
                        "description": "Default "
                        "retainer "
                        "invoice "
                        "email "
                        "template "
                        "id "
                        "used "
                        "for "
                        "this "
                        "contact "
                        "while "
                        "sending "
                        "retainer "
                        "invoice.",
                        "example": 460000000000220,
                        "type": "string",
                    },
                    "retainerinvoice_paymentthankyou_email_template_id": {
                        "description": "Default "
                        "retainer "
                        "invoice "
                        "payment "
                        "thank "
                        "you "
                        "email "
                        "template "
                        "id "
                        "used "
                        "for "
                        "this "
                        "customer "
                        "while "
                        "sending "
                        "payment "
                        "acknowledgment "
                        "for "
                        "retainer "
                        "invoices.",
                        "example": 460000000000222,
                        "type": "string",
                    },
                    "retainerinvoice_paymentthankyou_template_id": {
                        "description": "Default "
                        "retainer "
                        "invoice "
                        "payment "
                        "thank "
                        "you "
                        "template "
                        "id "
                        "used "
                        "for "
                        "this "
                        "customer "
                        "while "
                        "sending "
                        "payment "
                        "acknowledgment "
                        "for "
                        "retainer "
                        "invoices.",
                        "example": 460000000000217,
                        "type": "string",
                    },
                    "retainerinvoice_template_id": {
                        "description": "Default "
                        "retainer "
                        "invoice "
                        "template "
                        "id "
                        "used "
                        "for "
                        "this "
                        "customer "
                        "while "
                        "creating "
                        "retainer "
                        "invoice.",
                        "example": 460000000000215,
                        "type": "string",
                    },
                    "salesorder_email_template_id": {
                        "description": "Default "
                        "sales "
                        "order "
                        "email "
                        "template "
                        "id "
                        "used "
                        "for "
                        "this "
                        "customer "
                        "while "
                        "sending "
                        "sales "
                        "order.",
                        "example": 460000000000219,
                        "type": "string",
                    },
                    "salesorder_template_id": {
                        "description": "Default "
                        "sales "
                        "order "
                        "template "
                        "id "
                        "used "
                        "for "
                        "this "
                        "customer "
                        "while "
                        "creating "
                        "sales "
                        "order.",
                        "example": 460000000000214,
                        "type": "string",
                    },
                    "statement_template_id": {
                        "description": "Default "
                        "statement "
                        "template "
                        "id "
                        "used "
                        "for "
                        "this "
                        "contact "
                        "while "
                        "creating "
                        "statement.",
                        "example": 460000000000101,
                        "type": "string",
                    },
                },
                "type": "object",
            },
            "facebook": {
                "description": "Facebook profile URL for the contact. Max-length [100].",
                "example": "zoho",
                "type": "string",
            },
            "gst_no": {
                "description": "15-digit GST identification number of the "
                "contact as issued by the Indian tax "
                "authorities.",
                "example": "22AAAAA0000A1Z5",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "gst_treatment": {
                "description": "Choose whether the contact is GST "
                "registered/unregistered/consumer/overseas. "
                "Allowed values are <code> "
                "business_gst </code> , <code> "
                "business_none </code> , <code> "
                "overseas </code> , <code> consumer "
                "</code>.",
                "example": "business_gst",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "ignore_auto_number_generation": {
                "description": "Indicates whether "
                "the auto generation "
                "contact_number is "
                "ignored or not for "
                "the contact. Allowed "
                "values: "
                "<code>true</code>, "
                "<code>false</code>.",
                "example": False,
                "type": "boolean",
            },
            "is_taxable": {
                "description": "Indicates whether the customer is "
                "subject to tax collection. Tax-related "
                "fields are only available when this "
                "field is set to true. Allowed values: "
                "<code>true</code> and "
                "<code>false</code>.",
                "example": True,
                "type": "boolean",
                "x-node_available_in": ["us", "ca", "au", "in", "mx", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "is_tds_registered": {
                "description": "Indicates whether the contact is "
                "registered for Tax Deducted at "
                "Source (TDS) in Mexico.",
                "type": "boolean",
                "x-node_available_in": ["mx"],
                "x-node_unavailable_in": [],
            },
            "legal_name": {
                "description": "Official legal name of the contact as "
                "registered with tax authorities in "
                "Mexico.",
                "example": "ESCUELA KEMPER URGATE",
                "type": "string",
                "x-node_available_in": ["mx"],
                "x-node_unavailable_in": [],
            },
            "notes": {
                "description": "Additional comments or notes about the contact.",
                "example": "Payment option : Through check",
                "type": "string",
            },
            "opening_balances": {
                "items": {
                    "properties": {
                        "exchange_rate": {
                            "description": "Currency "
                            "exchange "
                            "rate "
                            "used "
                            "to "
                            "convert "
                            "opening "
                            "balance "
                            "to "
                            "organization's "
                            "base "
                            "currency.",
                            "example": 1,
                            "format": "double",
                            "type": "number",
                        },
                        "location_id": {
                            "description": "Unique "
                            "identifier "
                            "for "
                            "the "
                            "business "
                            "location "
                            "associated "
                            "with "
                            "this "
                            "opening "
                            "balance.",
                            "example": "460000000038080",
                            "type": "string",
                        },
                        "opening_balance_amount": {
                            "description": "Initial "
                            "balance "
                            "amount "
                            "for "
                            "the "
                            "contact "
                            "at "
                            "the "
                            "time "
                            "of "
                            "creation.",
                            "example": 1200,
                            "format": "double",
                            "type": "number",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "owner_id": {
                "description": "<b>For Customer Only :</b> Unique "
                "identifier for the user assigned as the "
                "owner of the contact. This field "
                "specifies which user in the organization "
                "is responsible for managing the business "
                "relationship with this contact.",
                "example": 460000000016051,
                "type": "string",
            },
            "payment_terms": {
                "description": "Number of days allowed for payment after the invoice date.",
                "example": 15,
                "type": "integer",
            },
            "payment_terms_label": {
                "description": "Human-readable label of "
                "payment terms displayed on "
                "invoices and other "
                "transactions. Max-length "
                "[200].",
                "example": "Net 15",
                "type": "string",
            },
            "place_of_contact": {
                "description": "State or union territory code "
                "where the contact is located for "
                "Indian tax purposes. (This node "
                "identifies the place of supply "
                "and source of supply when "
                "invoices/bills are raised for the "
                "customer/vendor respectively. "
                "This is not applicable for "
                "Overseas contacts)",
                "example": "TN",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "pricebook_id": {
                "description": "Pricebook id which is associated with "
                "the contact. Max-length [200].",
                "example": 460000000000123,
                "type": "string",
            },
            "shipping_address": {
                "description": "Shipping address information for the contact.",
                "properties": {
                    "address": {
                        "description": "Street 1 address for the contact. Max-length [500].",
                        "example": "4900 Hopyard Rd",
                        "type": "string",
                    },
                    "attention": {
                        "description": "Attention "
                        "for "
                        "proper "
                        "delivery "
                        "and "
                        "routing "
                        "of "
                        "business "
                        "correspondence. "
                        "Max-length "
                        "[100].",
                        "example": "Mr.John",
                        "type": "string",
                    },
                    "city": {
                        "description": "City name for the address. Max-length [100].",
                        "example": "Pleasanton",
                        "type": "string",
                    },
                    "country": {
                        "description": "Country name for the address. Max-length [100].",
                        "example": "U.S.A",
                        "type": "string",
                    },
                    "fax": {
                        "description": "Fax number for the address. Max-length [50].",
                        "example": "+1-925-924-9600",
                        "type": "string",
                    },
                    "phone": {
                        "description": "The "
                        "contact "
                        "phone "
                        "number "
                        "associated "
                        "with the "
                        "address. "
                        "Max-length "
                        "[50]",
                        "example": "+1-925-921-9201",
                        "type": "string",
                    },
                    "state": {
                        "description": "State for the address. Max-length [100].",
                        "example": "CA",
                        "type": "string",
                    },
                    "state_code": {
                        "description": "State or province code for the address. Max-length [100].",
                        "example": "CA",
                        "type": "string",
                    },
                    "street2": {
                        "description": "Street 2 address for the contact. Max-length [255].",
                        "example": "Suite 310",
                        "type": "string",
                    },
                    "zip": {
                        "description": "Postal or ZIP code for the address. Max-length [50].",
                        "example": 94588,
                        "type": "string",
                    },
                },
                "type": "object",
            },
            "tags": {
                "description": "Filter all your reports based on the tag",
                "items": {
                    "properties": {
                        "tag_id": {
                            "description": "ID of the reporting tag",
                            "example": 462000000009070,
                            "type": "string",
                        },
                        "tag_option_id": {
                            "description": "ID of the reporting tag's option",
                            "example": 462000000002670,
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "tax_authority_id": {
                "description": "Unique identifier for the tax "
                "authority responsible for the "
                "customer's tax jurisdiction. Tax "
                "authority depends on the location "
                "of the customer. For example, if "
                "the customer is located in NY, "
                "then the tax authority is NY tax "
                "authority.",
                "example": 11149000000061052,
                "type": "string",
                "x-node_available_in": ["us"],
                "x-node_unavailable_in": [],
            },
            "tax_authority_name": {
                "description": "Display name of the tax "
                "authority responsible for the "
                "customer's tax jurisdiction.",
                "type": "string",
            },
            "tax_exemption_certificate_number": {
                "description": "Tax Exemption "
                "Certificate "
                "number is issued "
                "by the Kenya "
                "Revenue Authority "
                "(KRA) to "
                "organizations or "
                "individuals who "
                "qualify for tax "
                "exemption",
                "example": "KRAEXM0043310521",
                "type": "string",
                "x-node_available_in": ["ke"],
                "x-node_unavailable_in": [],
            },
            "tax_exemption_code": {
                "description": "Code identifier for the tax exemption assigned to the contact.",
                "type": "string",
                "x-node_available_in": ["us", "ca", "au", "in"],
                "x-node_unavailable_in": [],
            },
            "tax_exemption_id": {
                "description": "Unique identifier for the tax "
                "exemption configuration assigned "
                "to this contact.",
                "example": 11149000000061054,
                "type": "string",
                "x-node_available_in": ["us", "ca", "au", "in"],
                "x-node_unavailable_in": [],
            },
            "tax_id": {
                "description": "Unique identifier for the tax or tax group "
                "assigned to the contact. Available only "
                "when <code>is_taxable</code> is "
                "<code>true</code>.",
                "example": 11149000000061058,
                "type": "string",
                "x-node_available_in": ["in", "us"],
                "x-node_unavailable_in": [],
            },
            "tax_id_type": {
                "description": "Tax ID type of the contact, it can be SSN, ATIN, ITIN or EIN.",
                "type": "string",
                "x-node_available_in": ["us"],
                "x-node_unavailable_in": [],
            },
            "tax_id_value": {
                "description": "Tax ID of the contact.",
                "type": "string",
                "x-node_available_in": ["us"],
                "x-node_unavailable_in": [],
            },
            "tax_reg_no": {
                "description": "<b>For GCC Edition:</b> 15 digit Tax "
                "Registration number of a contact with "
                "Tax treatment as "
                "<code>vat_registered</code>,<code>gcc_vat_registered</code>,<code>dz_vat_registered</code>.<br/><b>For "
                "Mexico Edition:</b> 12 digit Tax "
                "Registration number of a contact with "
                "Tax treatment as </br> "
                "<code>home_country_mexico</code>, "
                "<code>border_region_mexico</code>, "
                "<code>non_mexico</code>.</br> Consumers "
                "generic RFC: "
                "<code>XAXX010101000</code>, Overseas "
                "generic RFC: "
                "<code>XEXX010101000</code>.<br/><b>For "
                "Kenya Edition:</b> 11 digit Tax "
                "Registration number of a contact with "
                "Tax treatment as "
                "<code>vat_registered</code><br/><b>For "
                "SouthAfrica Edition:</b> 10 digit Tax "
                "Registration number of a contact with "
                "Tax treatment as "
                "<code>vat_registered</code>",
                "example": 12345678912345,
                "type": "string",
                "x-node_available_in": ["gcc", "mx", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "tax_regime": {
                "description": "Tax Regime of the contact.Allowed "
                "Values: "
                "<code>general_legal_person</code>, "
                "<code>legal_entities_non_profit</code>, "
                "<code>resident_abroad</code>, "
                "<code>production_cooperative_societies</code>, "
                "<code>agricultural_livestock</code>, "
                "<code>optional_group_of_companies</code>, "
                "<code>coordinated</code>, "
                "<code>simplified_trust</code>, "
                "<code>wages_salaries_income</code>, "
                "<code>lease</code>, "
                "<code>property_disposal_acquisition</code>, "
                "<code>other_income</code>, "
                "<code>resident_abroad</code>, "
                "<code>divident_income</code>, "
                "<code>individual_business_professional</code>, "
                "<code>interest_income</code>, "
                "<code>income_obtaining_price</code>, "
                "<code>no_tax_obligation</code>, "
                "<code>tax_incorporation</code>, "
                "<code>income_through_technology_platform</code>, "
                "<code>simplified_trust</code>.",
                "example": "general_legal_person",
                "type": "string",
                "x-node_available_in": ["mx"],
                "x-node_unavailable_in": [],
            },
            "tax_treatment": {
                "description": "Tax treatment of the "
                "contact.<br/>Allowed Values: "
                "<code>vat_registered</code>,<code>vat_not_registered</code>,<code>gcc_vat_not_registered</code>,<code>gcc_vat_registered</code>,<code>non_gcc</code>,<code>dz_vat_registered</code> "
                "and "
                "<code>dz_vat_not_registered</code></br><code>home_country_mexico</code> "
                "(A business that is located within "
                "MX)</br><code>border_region_mexico</code> "
                "(A business that is located in the "
                "northern and southern border regions "
                "in MX)</br><code>non_mexico</code> "
                "(A business that is located outside "
                "MX).<br/><b>For Kenya Edition:</b> "
                "<code>vat_registered</code> "
                ",<code>vat_not_registered</code> "
                ",<code>non_kenya</code>(A business "
                "that is located outside "
                "Kenya).<br/><b>For SouthAfrica "
                "Edition:</b> "
                "<code>vat_registered</code>, "
                "<code>vat_not_registered</code>, "
                "<code>overseas</code>(A business "
                "that is located outside "
                "SouthAfrica).",
                "type": "string",
                "x-node_available_in": ["gcc", "mx", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "track_1099": {
                "description": "Boolean to track a contact for 1099 reporting.",
                "type": "boolean",
                "x-node_available_in": ["us"],
                "x-node_unavailable_in": [],
            },
            "twitter": {
                "description": "X profile URL for the contact. Max-length [100].",
                "example": "zoho",
                "type": "string",
            },
            "vat_reg_no": {
                "description": "<b>For UK Edition:</b> VAT Registration "
                "number of a contact with length should "
                "be between 2 and 12 characters.<br/> "
                "<b>For Avalara:</b> If you are doing "
                "sales in the European Union (EU) then "
                "provide VAT Registration Number of your "
                "customers here. This is used to "
                "calculate VAT for B2B sales, from "
                "Avalara.",
                "type": "string",
                "x-node_available_in": ["uk", "Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "vat_treatment": {
                "description": "VAT treatment of the contact.Allowed "
                "Values: <br/><code>uk</code> (A "
                "business that is located in the "
                "UK.),<br/><code>eu_vat_registered</code> "
                "(A business that is reg for VAT and "
                "trade goods between Northern Ireland "
                "and EU. This node is available only "
                "for organizations enabled for NI "
                "protocal in VAT Settings.) "
                "and<br/><code>overseas</code> (A "
                "business that is located outside UK. "
                "Pre Brexit, this was split as "
                "<code>eu_vat_registered</code>, "
                "<code>eu_vat_not_registered</code> "
                "and <code>non_eu</code> ).",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
            "website": {
                "description": "Official website URL of the contact.",
                "example": "www.bowmanfurniture.com",
                "type": "string",
            },
        },
        "required": ["contact_name"],
        "type": "object",
    },
    "UPDATEBUSINESSCONTACT_REQUEST_BODY_SCHEMA": {
        "properties": {
            "avatax_exempt_no": {
                "description": "Exemption certificate number of the customer.",
                "type": "string",
                "x-node_available_in": ["Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "avatax_use_code": {
                "description": "Used to group like customers for "
                "exemption purposes. It is a custom "
                "value that links customers to a "
                "tax rule. Select from Avalara "
                "[standard codes][1] or enter a "
                "custom code.",
                "type": "string",
                "x-node_available_in": ["Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "billing_address": {
                "description": "Billing address information for the contact.",
                "properties": {
                    "address": {
                        "description": "Street 1 address for the contact. Max-length [500].",
                        "example": "4900 Hopyard Rd",
                        "type": "string",
                    },
                    "attention": {
                        "description": "Attention "
                        "for "
                        "proper "
                        "delivery "
                        "and "
                        "routing "
                        "of "
                        "business "
                        "correspondence. "
                        "Max-length "
                        "[100].",
                        "example": "Mr.John",
                        "type": "string",
                    },
                    "city": {
                        "description": "City name for the address. Max-length [100].",
                        "example": "Pleasanton",
                        "type": "string",
                    },
                    "country": {
                        "description": "Country name for the address. Max-length [100].",
                        "example": "U.S.A",
                        "type": "string",
                    },
                    "fax": {
                        "description": "Fax number for the address. Max-length [50].",
                        "example": "+1-925-924-9600",
                        "type": "string",
                    },
                    "phone": {
                        "description": "The "
                        "contact "
                        "phone "
                        "number "
                        "associated "
                        "with the "
                        "address. "
                        "Max-length "
                        "[50]",
                        "example": "+1-925-921-9201",
                        "type": "string",
                    },
                    "state": {
                        "description": "State for the address. Max-length [100].",
                        "example": "CA",
                        "type": "string",
                    },
                    "state_code": {
                        "description": "State or province code for the address. Max-length [100].",
                        "example": "CA",
                        "type": "string",
                    },
                    "street2": {
                        "description": "Street 2 address for the contact. Max-length [255].",
                        "example": "Suite 310",
                        "type": "string",
                    },
                    "zip": {
                        "description": "Postal or ZIP code for the address. Max-length [50].",
                        "example": 94588,
                        "type": "string",
                    },
                },
                "type": "object",
            },
            "company_name": {
                "description": "Legal or registered contact's company "
                "name. Used for legal documents and "
                "formal communications. Max-length "
                "[200].",
                "example": "Bowman and Co",
                "type": "string",
            },
            "contact_name": {
                "description": "Display name for the contact. It is "
                "used for searching and displaying "
                "contacts.",
                "example": "Bowman and Co",
                "type": "string",
            },
            "contact_number": {
                "description": "Contact number associated with the "
                "contact for internal tracking and "
                "identification purposes. Max-length "
                "[200].",
                "example": "CNT-001234",
                "type": "string",
            },
            "contact_persons": {
                "items": {
                    "properties": {
                        "communication_preference": {
                            "description": "Preferred "
                            "modes "
                            "of "
                            "communication "
                            "for "
                            "the "
                            "contact "
                            "person.",
                            "properties": {
                                "is_sms_enabled": {
                                    "description": "Whether "
                                    "SMS "
                                    "text "
                                    "messages "
                                    "are "
                                    "allowed "
                                    "for "
                                    "the "
                                    "contact "
                                    "person.",
                                    "example": False,
                                    "type": "boolean",
                                    "x-node_available_in": ["SMS integration"],
                                },
                                "is_whatsapp_enabled": {
                                    "description": "Whether "
                                    "WhatsApp "
                                    "messaging "
                                    "is "
                                    "allowed "
                                    "for "
                                    "the "
                                    "contact "
                                    "person.",
                                    "example": False,
                                    "type": "boolean",
                                    "x-node_available_in": ["WhatsApp integration"],
                                },
                            },
                            "type": "object",
                        },
                        "contact_person_id": {
                            "description": "ID "
                            "of "
                            "the "
                            "contact "
                            "person. "
                            "For "
                            "an "
                            "existing "
                            "contact "
                            "person, "
                            "pass "
                            "the "
                            "<code>contact_person_id</code>.",
                            "example": 460000000026051,
                            "type": "string",
                        },
                        "department": {
                            "description": "Department "
                            "of "
                            "the "
                            "contact "
                            "person "
                            "within "
                            "the "
                            "contact's "
                            "company. "
                            "Max-length "
                            "[50].",
                            "example": "Sales and Marketing",
                            "type": "string",
                        },
                        "designation": {
                            "description": "Designation "
                            "of "
                            "the "
                            "contact "
                            "person "
                            "within "
                            "the "
                            "contact's "
                            "company. "
                            "Max-length "
                            "[100].",
                            "example": "Sales Executive",
                            "type": "string",
                        },
                        "email": {
                            "description": "Email "
                            "address "
                            "of "
                            "the "
                            "contact "
                            "person "
                            "for "
                            "business "
                            "communications. "
                            "Max-length "
                            "[100].",
                            "example": "willsmith@bowmanfurniture.com",
                            "type": "string",
                        },
                        "enable_portal": {
                            "description": "Indicates "
                            "whether "
                            "the "
                            "contact "
                            "person "
                            "should "
                            "have "
                            "access "
                            "to "
                            "the "
                            "client "
                            "portal. "
                            "Allowed "
                            "values: "
                            "<code>true</code> "
                            "and "
                            "<code>false</code>.",
                            "example": True,
                            "type": "boolean",
                        },
                        "first_name": {
                            "description": "First name of the contact person. Max-length [100].",
                            "example": "Will",
                            "type": "string",
                        },
                        "is_primary_contact": {
                            "description": "Indicates "
                            "whether "
                            "this "
                            "contact "
                            "person "
                            "is "
                            "the "
                            "primary "
                            "contact. "
                            "Only "
                            "one "
                            "per "
                            "contact. "
                            "Allowed "
                            "values: "
                            "<code>true</code> "
                            "and "
                            "<code>false</code>.",
                            "example": True,
                            "type": "boolean",
                        },
                        "last_name": {
                            "description": "Last name of the contact person. Max-length [100].",
                            "example": "Smith",
                            "type": "string",
                        },
                        "mobile": {
                            "description": "Mobile number of the contact person. Max-length [50].",
                            "example": "+1-4054439562",
                            "type": "string",
                        },
                        "phone": {
                            "description": "Phone number of the contact person. Max-length [50].",
                            "example": "+1-925-921-9201",
                            "type": "string",
                        },
                        "salutation": {
                            "description": "Salutation for the contact. Max-length [25]",
                            "example": "Mr",
                            "type": "string",
                        },
                        "skype": {
                            "description": "Skype username of the contact person. Max-length [50].",
                            "example": "Zoho",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "contact_type": {
                "description": "Determines how the contact is treated "
                "in the system. Allowed values: "
                "<code>customer</code>, "
                "<code>vendor</code>.",
                "example": "customer",
                "type": "string",
            },
            "country_code": {
                "description": "<b>For UK Edition:</b> Two letter "
                "country code of a contact<br/> <b>For "
                "Avalara:</b> Two letter country code "
                "for the customer country, if your "
                "customer is not in US. Refer [AvaTax "
                "Codes for Countries and "
                "States][2].<br/> <b>For GCC Editions "
                ":</b> Two Letter country code for the "
                "GCC Country or the UAE emirate of the "
                "contact which will be considered as "
                "<b>place of supply</b>.<br/>Supported "
                "codes for UAE emirates are : </br>Abu "
                "Dhabi - <code>AB</code>,</br>Ajman - "
                "<code>AJ</code>,</br>Dubai - "
                "<code>DU</code>,</br>Fujairah - "
                "<code>FU</code>,</br>Ras al-Khaimah - "
                "<code>RA</code>,</br>Sharjah - "
                "<code>SH</code>,</br>Umm al-Quwain - "
                "<code>UM</code>.<br/>Supported codes "
                "for the GCC countries are : "
                "</br>United Arab Emirates - "
                "<code>AE</code>,</br>Saudi Arabia - "
                "<code>SA</code>,</br>Bahrain - "
                "<code>BH</code>,</br>Kuwait - "
                "<code>KW</code>,</br>Oman - "
                "<code>OM</code>,</br>Qatar - "
                "<code>QA</code>.",
                "type": "string",
                "x-node_available_in": ["uk", "gcc", "Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "credit_limit": {
                "description": "<b>For Customer Only :</b> The "
                "maximum credit amount that can be "
                "allowed for the customer. Once the "
                "customer's outstanding receivables "
                "reach this limit, the system will "
                "restrict the customer from creating "
                "any further transactions.",
                "example": 1000,
                "format": "double",
                "type": "number",
            },
            "currency_id": {
                "description": "Unique identifier for the currency "
                "assigned to this contact. The "
                "currency_id must correspond to a valid "
                "currency configuration in the system.",
                "example": 460000000000097,
                "type": "string",
            },
            "custom_fields": {
                "items": {
                    "properties": {
                        "index": {
                            "description": "Index "
                            "of "
                            "the "
                            "custom "
                            "field. "
                            "It "
                            "can "
                            "hold "
                            "any "
                            "value "
                            "from "
                            "1 "
                            "to "
                            "10.",
                            "example": 1,
                            "type": "integer",
                        },
                        "label": {
                            "description": "Label of the custom field.",
                            "example": "VAT ID",
                            "type": "string",
                        },
                        "value": {
                            "description": "Value of the custom field.",
                            "example": "GBGD078",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "customer_sub_type": {
                "description": "<b>For Customer Only :</b> "
                "Additional classification for "
                "customers. Allowed values: "
                "<code>individual</code>, "
                "<code>business</code>.",
                "example": "business",
                "type": "string",
            },
            "default_templates": {
                "properties": {
                    "bill_template_id": {
                        "description": "Default "
                        "bill "
                        "template "
                        "id "
                        "used "
                        "for "
                        "this "
                        "vendor "
                        "while "
                        "creating "
                        "bill.",
                        "example": 460000000000103,
                        "type": "string",
                    },
                    "creditnote_email_template_id": {
                        "description": "Default "
                        "credit "
                        "note "
                        "email "
                        "template "
                        "id "
                        "used "
                        "for "
                        "this "
                        "customer "
                        "while "
                        "sending "
                        "credit "
                        "notes.",
                        "example": 460000000052075,
                        "type": "string",
                    },
                    "creditnote_template_id": {
                        "description": "Default "
                        "credit "
                        "note "
                        "template "
                        "id "
                        "used "
                        "for "
                        "this "
                        "customer "
                        "while "
                        "creating "
                        "credit "
                        "note.",
                        "example": 460000000000211,
                        "type": "string",
                    },
                    "estimate_email_template_id": {
                        "description": "Default "
                        "estimate "
                        "email "
                        "template "
                        "id "
                        "used "
                        "for "
                        "this "
                        "customer "
                        "while "
                        "sending "
                        "estimates.",
                        "example": 460000000052073,
                        "type": "string",
                    },
                    "estimate_template_id": {
                        "description": "Default "
                        "estimate "
                        "template "
                        "id "
                        "used "
                        "for "
                        "this "
                        "customer "
                        "while "
                        "creating "
                        "estimate.",
                        "example": 460000000000179,
                        "type": "string",
                    },
                    "invoice_email_template_id": {
                        "description": "Default "
                        "invoice "
                        "email "
                        "template "
                        "id "
                        "used "
                        "for "
                        "this "
                        "customer "
                        "while "
                        "sending "
                        "invoices.",
                        "example": 460000000052071,
                        "type": "string",
                    },
                    "invoice_template_id": {
                        "description": "Default "
                        "invoice "
                        "template "
                        "id "
                        "used "
                        "for "
                        "this "
                        "customer "
                        "while "
                        "creating "
                        "invoice.",
                        "example": 460000000052069,
                        "type": "string",
                    },
                    "payment_remittance_email_template_id": {
                        "description": "Default "
                        "payment "
                        "remittance "
                        "email "
                        "template "
                        "id "
                        "used "
                        "for "
                        "this "
                        "contact "
                        "while "
                        "sending "
                        "payment "
                        "remittances.",
                        "example": 460000000000102,
                        "type": "string",
                    },
                    "paymentthankyou_email_template_id": {
                        "description": "Default "
                        "payment "
                        "thank "
                        "you "
                        "email "
                        "template "
                        "id "
                        "used "
                        "for "
                        "this "
                        "contact "
                        "while "
                        "sending "
                        "payment "
                        "acknowledgment.",
                        "example": 460000000000221,
                        "type": "string",
                    },
                    "paymentthankyou_template_id": {
                        "description": "Default "
                        "payment "
                        "thank "
                        "you "
                        "template "
                        "id "
                        "used "
                        "for "
                        "this "
                        "contact "
                        "while "
                        "sending "
                        "payment "
                        "acknowledgment.",
                        "example": 460000000000216,
                        "type": "string",
                    },
                    "purchaseorder_email_template_id": {
                        "description": "Default "
                        "purchase "
                        "order "
                        "email "
                        "template "
                        "id "
                        "used "
                        "for "
                        "this "
                        "vendor "
                        "while "
                        "sending "
                        "purchase "
                        "order.",
                        "example": 460000000000218,
                        "type": "string",
                    },
                    "purchaseorder_template_id": {
                        "description": "Default "
                        "purchase "
                        "order "
                        "template "
                        "id "
                        "used "
                        "for "
                        "this "
                        "vendor "
                        "while "
                        "creating "
                        "purchase "
                        "order.",
                        "example": 460000000000213,
                        "type": "string",
                    },
                    "retainerinvoice_email_template_id": {
                        "description": "Default "
                        "retainer "
                        "invoice "
                        "email "
                        "template "
                        "id "
                        "used "
                        "for "
                        "this "
                        "contact "
                        "while "
                        "sending "
                        "retainer "
                        "invoice.",
                        "example": 460000000000220,
                        "type": "string",
                    },
                    "retainerinvoice_paymentthankyou_email_template_id": {
                        "description": "Default "
                        "retainer "
                        "invoice "
                        "payment "
                        "thank "
                        "you "
                        "email "
                        "template "
                        "id "
                        "used "
                        "for "
                        "this "
                        "customer "
                        "while "
                        "sending "
                        "payment "
                        "acknowledgment "
                        "for "
                        "retainer "
                        "invoices.",
                        "example": 460000000000222,
                        "type": "string",
                    },
                    "retainerinvoice_paymentthankyou_template_id": {
                        "description": "Default "
                        "retainer "
                        "invoice "
                        "payment "
                        "thank "
                        "you "
                        "template "
                        "id "
                        "used "
                        "for "
                        "this "
                        "customer "
                        "while "
                        "sending "
                        "payment "
                        "acknowledgment "
                        "for "
                        "retainer "
                        "invoices.",
                        "example": 460000000000217,
                        "type": "string",
                    },
                    "retainerinvoice_template_id": {
                        "description": "Default "
                        "retainer "
                        "invoice "
                        "template "
                        "id "
                        "used "
                        "for "
                        "this "
                        "customer "
                        "while "
                        "creating "
                        "retainer "
                        "invoice.",
                        "example": 460000000000215,
                        "type": "string",
                    },
                    "salesorder_email_template_id": {
                        "description": "Default "
                        "sales "
                        "order "
                        "email "
                        "template "
                        "id "
                        "used "
                        "for "
                        "this "
                        "customer "
                        "while "
                        "sending "
                        "sales "
                        "order.",
                        "example": 460000000000219,
                        "type": "string",
                    },
                    "salesorder_template_id": {
                        "description": "Default "
                        "sales "
                        "order "
                        "template "
                        "id "
                        "used "
                        "for "
                        "this "
                        "customer "
                        "while "
                        "creating "
                        "sales "
                        "order.",
                        "example": 460000000000214,
                        "type": "string",
                    },
                    "statement_template_id": {
                        "description": "Default "
                        "statement "
                        "template "
                        "id "
                        "used "
                        "for "
                        "this "
                        "contact "
                        "while "
                        "creating "
                        "statement.",
                        "example": 460000000000101,
                        "type": "string",
                    },
                },
                "type": "object",
            },
            "facebook": {
                "description": "Facebook profile URL for the contact. Max-length [100].",
                "example": "zoho",
                "type": "string",
            },
            "gst_no": {
                "description": "15-digit GST identification number of the "
                "contact as issued by the Indian tax "
                "authorities.",
                "example": "22AAAAA0000A1Z5",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "gst_treatment": {
                "description": "Choose whether the contact is GST "
                "registered/unregistered/consumer/overseas. "
                "Allowed values are <code> "
                "business_gst </code> , <code> "
                "business_none </code> , <code> "
                "overseas </code> , <code> consumer "
                "</code>.",
                "example": "business_gst",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "ignore_auto_number_generation": {
                "description": "Indicates whether "
                "the auto generation "
                "contact_number is "
                "ignored or not for "
                "the contact. Allowed "
                "values: "
                "<code>true</code>, "
                "<code>false</code>.",
                "example": False,
                "type": "boolean",
            },
            "is_taxable": {
                "description": "Indicates whether the customer is "
                "subject to tax collection. Tax-related "
                "fields are only available when this "
                "field is set to true. Allowed values: "
                "<code>true</code> and "
                "<code>false</code>.",
                "example": True,
                "type": "boolean",
                "x-node_available_in": ["us", "ca", "au", "in", "mx", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "is_tds_registered": {
                "description": "Indicates whether the contact is "
                "registered for Tax Deducted at "
                "Source (TDS) in Mexico.",
                "type": "boolean",
                "x-node_available_in": ["mx"],
                "x-node_unavailable_in": [],
            },
            "legal_name": {
                "description": "Official legal name of the contact as "
                "registered with tax authorities in "
                "Mexico.",
                "example": "ESCUELA KEMPER URGATE",
                "type": "string",
                "x-node_available_in": ["mx"],
                "x-node_unavailable_in": [],
            },
            "notes": {
                "description": "Additional comments or notes about the contact.",
                "example": "Payment option : Through check",
                "type": "string",
            },
            "opening_balances": {
                "items": {
                    "properties": {
                        "exchange_rate": {
                            "description": "Currency "
                            "exchange "
                            "rate "
                            "used "
                            "to "
                            "convert "
                            "opening "
                            "balance "
                            "to "
                            "organization's "
                            "base "
                            "currency.",
                            "example": 1,
                            "format": "double",
                            "type": "number",
                        },
                        "location_id": {
                            "description": "Unique "
                            "identifier "
                            "for "
                            "the "
                            "business "
                            "location "
                            "associated "
                            "with "
                            "this "
                            "opening "
                            "balance.",
                            "example": "460000000038080",
                            "type": "string",
                        },
                        "opening_balance_amount": {
                            "description": "Initial "
                            "balance "
                            "amount "
                            "for "
                            "the "
                            "contact "
                            "at "
                            "the "
                            "time "
                            "of "
                            "creation.",
                            "example": 1200,
                            "format": "double",
                            "type": "number",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "owner_id": {
                "description": "<b>For Customer Only :</b> Unique "
                "identifier for the user assigned as the "
                "owner of the contact. This field "
                "specifies which user in the organization "
                "is responsible for managing the business "
                "relationship with this contact.",
                "example": 460000000016051,
                "type": "string",
            },
            "payment_terms": {
                "description": "Number of days allowed for payment after the invoice date.",
                "example": 15,
                "type": "integer",
            },
            "payment_terms_label": {
                "description": "Human-readable label of "
                "payment terms displayed on "
                "invoices and other "
                "transactions. Max-length "
                "[200].",
                "example": "Net 15",
                "type": "string",
            },
            "place_of_contact": {
                "description": "State or union territory code "
                "where the contact is located for "
                "Indian tax purposes. (This node "
                "identifies the place of supply "
                "and source of supply when "
                "invoices/bills are raised for the "
                "customer/vendor respectively. "
                "This is not applicable for "
                "Overseas contacts)",
                "example": "TN",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "pricebook_id": {
                "description": "Pricebook id which is associated with "
                "the contact. Max-length [200].",
                "example": 460000000000123,
                "type": "string",
            },
            "shipping_address": {
                "description": "Shipping address information for the contact.",
                "properties": {
                    "address": {
                        "description": "Street 1 address for the contact. Max-length [500].",
                        "example": "4900 Hopyard Rd",
                        "type": "string",
                    },
                    "attention": {
                        "description": "Attention "
                        "for "
                        "proper "
                        "delivery "
                        "and "
                        "routing "
                        "of "
                        "business "
                        "correspondence. "
                        "Max-length "
                        "[100].",
                        "example": "Mr.John",
                        "type": "string",
                    },
                    "city": {
                        "description": "City name for the address. Max-length [100].",
                        "example": "Pleasanton",
                        "type": "string",
                    },
                    "country": {
                        "description": "Country name for the address. Max-length [100].",
                        "example": "U.S.A",
                        "type": "string",
                    },
                    "fax": {
                        "description": "Fax number for the address. Max-length [50].",
                        "example": "+1-925-924-9600",
                        "type": "string",
                    },
                    "phone": {
                        "description": "The "
                        "contact "
                        "phone "
                        "number "
                        "associated "
                        "with the "
                        "address. "
                        "Max-length "
                        "[50]",
                        "example": "+1-925-921-9201",
                        "type": "string",
                    },
                    "state": {
                        "description": "State for the address. Max-length [100].",
                        "example": "CA",
                        "type": "string",
                    },
                    "state_code": {
                        "description": "State or province code for the address. Max-length [100].",
                        "example": "CA",
                        "type": "string",
                    },
                    "street2": {
                        "description": "Street 2 address for the contact. Max-length [255].",
                        "example": "Suite 310",
                        "type": "string",
                    },
                    "zip": {
                        "description": "Postal or ZIP code for the address. Max-length [50].",
                        "example": 94588,
                        "type": "string",
                    },
                },
                "type": "object",
            },
            "tags": {
                "description": "Filter all your reports based on the tag",
                "items": {
                    "properties": {
                        "tag_id": {
                            "description": "ID of the reporting tag",
                            "example": 462000000009070,
                            "type": "string",
                        },
                        "tag_option_id": {
                            "description": "ID of the reporting tag's option",
                            "example": 462000000002670,
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "tax_authority_id": {
                "description": "Unique identifier for the tax "
                "authority responsible for the "
                "customer's tax jurisdiction. Tax "
                "authority depends on the location "
                "of the customer. For example, if "
                "the customer is located in NY, "
                "then the tax authority is NY tax "
                "authority.",
                "example": 11149000000061052,
                "type": "string",
                "x-node_available_in": ["us"],
                "x-node_unavailable_in": [],
            },
            "tax_authority_name": {
                "description": "Display name of the tax "
                "authority responsible for the "
                "customer's tax jurisdiction.",
                "type": "string",
            },
            "tax_exemption_certificate_number": {
                "description": "Tax Exemption "
                "Certificate "
                "number is issued "
                "by the Kenya "
                "Revenue Authority "
                "(KRA) to "
                "organizations or "
                "individuals who "
                "qualify for tax "
                "exemption",
                "example": "KRAEXM0043310521",
                "type": "string",
                "x-node_available_in": ["ke"],
                "x-node_unavailable_in": [],
            },
            "tax_exemption_code": {
                "description": "Code identifier for the tax exemption assigned to the contact.",
                "type": "string",
                "x-node_available_in": ["us", "ca", "au", "in"],
                "x-node_unavailable_in": [],
            },
            "tax_exemption_id": {
                "description": "Unique identifier for the tax "
                "exemption configuration assigned "
                "to this contact.",
                "example": 11149000000061054,
                "type": "string",
                "x-node_available_in": ["us", "ca", "au", "in"],
                "x-node_unavailable_in": [],
            },
            "tax_id": {
                "description": "Unique identifier for the tax or tax group "
                "assigned to the contact. Available only "
                "when <code>is_taxable</code> is "
                "<code>true</code>.",
                "example": 11149000000061058,
                "type": "string",
                "x-node_available_in": ["in", "us"],
                "x-node_unavailable_in": [],
            },
            "tax_id_type": {
                "description": "Tax ID type of the contact, it can be SSN, ATIN, ITIN or EIN.",
                "type": "string",
                "x-node_available_in": ["us"],
                "x-node_unavailable_in": [],
            },
            "tax_id_value": {
                "description": "Tax ID of the contact.",
                "type": "string",
                "x-node_available_in": ["us"],
                "x-node_unavailable_in": [],
            },
            "tax_reg_no": {
                "description": "<b>For GCC Edition:</b> 15 digit Tax "
                "Registration number of a contact with "
                "Tax treatment as "
                "<code>vat_registered</code>,<code>gcc_vat_registered</code>,<code>dz_vat_registered</code>.<br/><b>For "
                "Mexico Edition:</b> 12 digit Tax "
                "Registration number of a contact with "
                "Tax treatment as </br> "
                "<code>home_country_mexico</code>, "
                "<code>border_region_mexico</code>, "
                "<code>non_mexico</code>.</br> Consumers "
                "generic RFC: "
                "<code>XAXX010101000</code>, Overseas "
                "generic RFC: "
                "<code>XEXX010101000</code>.<br/><b>For "
                "Kenya Edition:</b> 11 digit Tax "
                "Registration number of a contact with "
                "Tax treatment as "
                "<code>vat_registered</code><br/><b>For "
                "SouthAfrica Edition:</b> 10 digit Tax "
                "Registration number of a contact with "
                "Tax treatment as "
                "<code>vat_registered</code>",
                "example": 12345678912345,
                "type": "string",
                "x-node_available_in": ["gcc", "mx", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "tax_regime": {
                "description": "Tax Regime of the contact.Allowed "
                "Values: "
                "<code>general_legal_person</code>, "
                "<code>legal_entities_non_profit</code>, "
                "<code>resident_abroad</code>, "
                "<code>production_cooperative_societies</code>, "
                "<code>agricultural_livestock</code>, "
                "<code>optional_group_of_companies</code>, "
                "<code>coordinated</code>, "
                "<code>simplified_trust</code>, "
                "<code>wages_salaries_income</code>, "
                "<code>lease</code>, "
                "<code>property_disposal_acquisition</code>, "
                "<code>other_income</code>, "
                "<code>resident_abroad</code>, "
                "<code>divident_income</code>, "
                "<code>individual_business_professional</code>, "
                "<code>interest_income</code>, "
                "<code>income_obtaining_price</code>, "
                "<code>no_tax_obligation</code>, "
                "<code>tax_incorporation</code>, "
                "<code>income_through_technology_platform</code>, "
                "<code>simplified_trust</code>.",
                "example": "general_legal_person",
                "type": "string",
                "x-node_available_in": ["mx"],
                "x-node_unavailable_in": [],
            },
            "tax_treatment": {
                "description": "Tax treatment of the "
                "contact.<br/>Allowed Values: "
                "<code>vat_registered</code>,<code>vat_not_registered</code>,<code>gcc_vat_not_registered</code>,<code>gcc_vat_registered</code>,<code>non_gcc</code>,<code>dz_vat_registered</code> "
                "and "
                "<code>dz_vat_not_registered</code></br><code>home_country_mexico</code> "
                "(A business that is located within "
                "MX)</br><code>border_region_mexico</code> "
                "(A business that is located in the "
                "northern and southern border regions "
                "in MX)</br><code>non_mexico</code> "
                "(A business that is located outside "
                "MX).<br/><b>For Kenya Edition:</b> "
                "<code>vat_registered</code> "
                ",<code>vat_not_registered</code> "
                ",<code>non_kenya</code>(A business "
                "that is located outside "
                "Kenya).<br/><b>For SouthAfrica "
                "Edition:</b> "
                "<code>vat_registered</code>, "
                "<code>vat_not_registered</code>, "
                "<code>overseas</code>(A business "
                "that is located outside "
                "SouthAfrica).",
                "type": "string",
                "x-node_available_in": ["gcc", "mx", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "track_1099": {
                "description": "Boolean to track a contact for 1099 reporting.",
                "type": "boolean",
                "x-node_available_in": ["us"],
                "x-node_unavailable_in": [],
            },
            "twitter": {
                "description": "X profile URL for the contact. Max-length [100].",
                "example": "zoho",
                "type": "string",
            },
            "vat_reg_no": {
                "description": "<b>For UK Edition:</b> VAT Registration "
                "number of a contact with length should "
                "be between 2 and 12 characters.<br/> "
                "<b>For Avalara:</b> If you are doing "
                "sales in the European Union (EU) then "
                "provide VAT Registration Number of your "
                "customers here. This is used to "
                "calculate VAT for B2B sales, from "
                "Avalara.",
                "type": "string",
                "x-node_available_in": ["uk", "Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "vat_treatment": {
                "description": "VAT treatment of the contact.Allowed "
                "Values: <br/><code>uk</code> (A "
                "business that is located in the "
                "UK.),<br/><code>eu_vat_registered</code> "
                "(A business that is reg for VAT and "
                "trade goods between Northern Ireland "
                "and EU. This node is available only "
                "for organizations enabled for NI "
                "protocal in VAT Settings.) "
                "and<br/><code>overseas</code> (A "
                "business that is located outside UK. "
                "Pre Brexit, this was split as "
                "<code>eu_vat_registered</code>, "
                "<code>eu_vat_not_registered</code> "
                "and <code>non_eu</code> ).",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
            "website": {
                "description": "Official website URL of the contact.",
                "example": "www.bowmanfurniture.com",
                "type": "string",
            },
        },
        "required": ["contact_name"],
        "type": "object",
    },
    "ENABLECONTACTPORTALACCESS_REQUEST_BODY_SCHEMA": {
        "properties": {
            "contact_persons": {
                "items": {
                    "properties": {
                        "contact_person_id": {
                            "description": "Unique "
                            "identifier "
                            "for "
                            "the "
                            "contact "
                            "person. "
                            "System-generated "
                            "ID "
                            "for "
                            "API "
                            "operations.",
                            "example": 460000000026051,
                            "type": "string",
                        }
                    },
                    "type": "object",
                },
                "type": "array",
            }
        },
        "required": ["contact_persons"],
        "type": "object",
    },
    "EMAILCONTACTSTATEMENT_REQUEST_BODY_SCHEMA": {
        "properties": {
            "body": {
                "description": "Body of an email has to be sent. Max-length [5000]",
                "example": "Dear Customer,     <br/>We have attached with "
                "this email a list of all your transactions with "
                "us for the period 01 Sep 2013 to 30 Sep 2013. You "
                "can write to us or call us if you need any "
                "assistance or clarifications.     <br/>Thanks for "
                "your business.<br/>Regards<br/>Zillium Inc",
                "type": "string",
            },
            "cc_mail_ids": {
                "description": "Array of email address of the recipients to be cced.",
                "example": ["peterparker@bowmanfurniture.com"],
                "items": {"type": "string"},
                "type": "array",
            },
            "send_from_org_email_id": {
                "description": "Boolean to trigger the email from the organization's email address",
                "example": True,
                "type": "boolean",
            },
            "subject": {
                "description": "Subject of an email has to be sent. Max-length [1000]",
                "example": "Statement of transactions with Zillium Inc",
                "type": "string",
            },
            "to_mail_ids": {
                "description": "Array of email address of the recipients.",
                "example": ["willsmith@bowmanfurniture.com"],
                "items": {"type": "string"},
                "type": "array",
            },
        },
        "required": ["to_mail_ids", "subject", "body"],
        "type": "object",
    },
    "SENDEMAILTOCONTACT_REQUEST_BODY_SCHEMA": {
        "properties": {
            "attachments": {
                "description": "Files to be attached to the email. It "
                "has to be sent in multipart/formdata",
                "format": "binary",
                "type": "string",
            },
            "body": {
                "description": "Body of an email has to be sent. Max-length [5000]",
                "example": "Dear Customer,     <br/>We have attached with "
                "this email a list of all your transactions with "
                "us for the period 01 Sep 2013 to 30 Sep 2013. You "
                "can write to us or call us if you need any "
                "assistance or clarifications.     <br/>Thanks for "
                "your business.<br/>Regards<br/>Zillium Inc",
                "type": "string",
            },
            "subject": {
                "description": "Subject of an email has to be sent. Max-length [1000]",
                "example": "Welcome to Zillium Inc .",
                "type": "string",
            },
            "to_mail_ids": {
                "description": "Array of email address of the recipients.",
                "example": ["willsmith@bowmanfurniture.com"],
                "items": {"type": "string"},
                "type": "array",
            },
        },
        "required": ["to_mail_ids", "subject", "body"],
        "type": "object",
    },
    "ADDCONTACTADDRESS_REQUEST_BODY_SCHEMA": {
        "properties": {
            "address": {
                "description": "Street 1 address for the contact. Max-length [500].",
                "example": "4900 Hopyard Rd",
                "type": "string",
            },
            "attention": {
                "description": "Attention for proper delivery and "
                "routing of business correspondence. "
                "Max-length [100].",
                "example": "Mr.John",
                "type": "string",
            },
            "city": {
                "description": "City name for the address. Max-length [100].",
                "example": "Pleasanton",
                "type": "string",
            },
            "country": {
                "description": "Country name for the address. Max-length [100].",
                "example": "U.S.A",
                "type": "string",
            },
            "fax": {
                "description": "Fax number for the address. Max-length [50].",
                "example": "+1-925-924-9600",
                "type": "string",
            },
            "phone": {
                "description": "The contact phone number associated with the "
                "address. Max-length [50]",
                "example": "+1-925-921-9201",
                "type": "string",
            },
            "state": {
                "description": "State for the address. Max-length [100].",
                "example": "CA",
                "type": "string",
            },
            "street2": {
                "description": "Street 2 address for the contact. Max-length [255].",
                "example": "Suite 310",
                "type": "string",
            },
            "zip": {
                "description": "Postal or ZIP code for the address. Max-length [50].",
                "example": 94588,
                "type": "string",
            },
        },
        "type": "object",
    },
    "UPDATECONTACTADDRESS_REQUEST_BODY_SCHEMA": {
        "properties": {
            "address": {
                "description": "Street 1 address for the contact. Max-length [500].",
                "example": "4900 Hopyard Rd",
                "type": "string",
            },
            "address_id": {
                "description": "Address id of the address",
                "example": 1053791000000186000,
                "type": "string",
            },
            "attention": {
                "description": "Attention for proper delivery and "
                "routing of business correspondence. "
                "Max-length [100].",
                "example": "Mr.John",
                "type": "string",
            },
            "city": {
                "description": "City name for the address. Max-length [100].",
                "example": "Pleasanton",
                "type": "string",
            },
            "country": {
                "description": "Country name for the address. Max-length [100].",
                "example": "U.S.A",
                "type": "string",
            },
            "fax": {
                "description": "Fax number for the address. Max-length [50].",
                "example": "+1-925-924-9600",
                "type": "string",
            },
            "phone": {
                "description": "The contact phone number associated with the "
                "address. Max-length [50]",
                "example": "+1-925-921-9201",
                "type": "string",
            },
            "state": {
                "description": "State for the address. Max-length [100].",
                "example": "CA",
                "type": "string",
            },
            "street2": {
                "description": "Street 2 address for the contact. Max-length [255].",
                "example": "Suite 310",
                "type": "string",
            },
            "zip": {
                "description": "Postal or ZIP code for the address. Max-length [50].",
                "example": 94588,
                "type": "string",
            },
        },
        "required": ["address_id"],
        "type": "object",
    },
    "CREATECREDITNOTE_REQUEST_BODY_SCHEMA": {
        "properties": {
            "avatax_exempt_no": {
                "description": "Exemption certificate number of the customer. Max-length [25]",
                "type": "string",
                "x-node_available_in": ["Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "avatax_tax_code": {
                "description": "A tax code is a unique label used "
                "to group Items (products, "
                "services, or charges) together. "
                "Refer the [link][2] for more "
                "deails. Max-length [25]",
                "type": "string",
                "x-node_available_in": ["Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "avatax_use_code": {
                "description": "Used to group like customers for "
                "exemption purposes. It is a custom "
                "value that links customers to a "
                "tax rule. Select from Avalara "
                "[standard codes][1] or enter a "
                "custom code. Max-length [25]",
                "type": "string",
                "x-node_available_in": ["Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "cfdi_reference_type": {
                "description": "Choose CFDI Reference "
                "Type.</br>Allowed values: "
                "<code>credit_note</code>, "
                "<code>debit_note</code>, "
                "<code>return_of_merchandise</code>, "
                "<code>substitution_previous_cfdi</code>, "
                "<code>transfer_of_goods</code>, "
                "<code>invoice_generated_from_order</code>, "
                "<code>cfdi_for_advance</code>.",
                "example": "return_of_merchandise",
                "type": "string",
                "x-node_available_in": ["mx"],
                "x-node_unavailable_in": [],
            },
            "cfdi_usage": {
                "description": "Choose CFDI Usage.</br>Allowed values: "
                "<code>acquisition_of_merchandise</code>, "
                "<code>return_discount_bonus</code>, "
                "<code>general_expense</code>, "
                "<code>buildings</code>, "
                "<code>furniture_office_equipment</code>, "
                "<code>transport_equipment</code>, "
                "<code>computer_equipmentdye_molds_tools</code>, "
                "<code>telephone_communication</code>, "
                "<code>satellite_communication</code>, "
                "<code>other_machinery_equipment</code>, "
                "<code>hospital_expense</code>, "
                "<code>medical_expense_disability</code>, "
                "<code>funeral_expense</code>, "
                "<code>donation</code>, "
                "<code>interest_mortage_loans</code>, "
                "<code>contribution_sar</code>, "
                "<code>medical_expense_insurance_pormium</code>, "
                "<code>school_transportation_expense</code>, "
                "<code>deposit_saving_account</code>, "
                "<code>payment_educational_service</code>, "
                "<code>no_tax_effect</code>, "
                "<code>payment</code>, "
                "<code>payroll</code>.",
                "example": "acquisition_of_merchandise",
                "type": "string",
                "x-node_available_in": ["mx"],
                "x-node_unavailable_in": [],
            },
            "contact_persons_associated": {
                "description": "Contact Persons associated with the transaction.",
                "items": {
                    "properties": {
                        "communication_preference": {
                            "description": "Preferred "
                            "modes "
                            "of "
                            "communication "
                            "for "
                            "the "
                            "contact "
                            "person "
                            "at "
                            "transaction "
                            "level.",
                            "properties": {
                                "is_email_enabled": {
                                    "description": "Used "
                                    "to "
                                    "check "
                                    "if "
                                    "Email "
                                    "communication "
                                    "preference "
                                    "is "
                                    "enabled "
                                    "for "
                                    "the "
                                    "contact "
                                    "person "
                                    "at "
                                    "transaction "
                                    "level.",
                                    "example": True,
                                    "type": "boolean",
                                },
                                "is_whatsapp_enabled": {
                                    "description": "Used "
                                    "to "
                                    "check "
                                    "if "
                                    "WhatsApp "
                                    "communication "
                                    "preference "
                                    "is "
                                    "enabled "
                                    "for "
                                    "the "
                                    "contact "
                                    "person "
                                    "at "
                                    "transaction "
                                    "level.",
                                    "example": True,
                                    "type": "boolean",
                                    "x-node_available_in": ["WhatsApp integration"],
                                },
                            },
                            "type": "object",
                        },
                        "contact_person_id": {
                            "description": "Unique ID of the Contact Person.",
                            "example": 982000000567003,
                            "format": "int64",
                            "type": "integer",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "creditnote_number": {
                "description": "Unique credit note number "
                "displayed in the interface. "
                "Auto-generated with CN prefix "
                "unless "
                "ignore_auto_number_generation is "
                "true. Max-Length [100]",
                "example": "CN-29",
                "type": "string",
            },
            "currency_id": {
                "description": "Unique identifier for the currency "
                "used in the credit note. Can differ "
                "from customer currency if "
                "multi-currency is enabled. Retrieve "
                "currency IDs from the List Currencies "
                "API endpoint in the currency section.",
                "example": "982000000567240",
                "type": "string",
            },
            "custom_fields": {
                "description": "Additional fields for the Credit-Notes.",
                "items": {"type": "string"},
                "type": "array",
            },
            "customer_id": {
                "description": "Unique identifier for the customer "
                "contact. Retrieve customer IDs from "
                "the Get Customers API endpoint in the "
                "contacts section. This ID links the "
                "credit note to the specific customer "
                "record.",
                "example": "903000000000099",
                "type": "string",
            },
            "date": {
                "description": "The date on which the credit note is raised. "
                "Must be in yyyy-mm-dd format. This date "
                "determines the accounting period and affects "
                "tax calculations.",
                "example": "2016-06-05",
                "type": "string",
            },
            "exchange_rate": {
                "description": "Exchange rate for converting the "
                "credit note currency to base "
                "currency. Required when currency "
                "differs from base currency. Retrieve "
                "rates from currency exchange rate "
                "APIs.",
                "example": "5.5",
                "type": "string",
            },
            "gst_no": {
                "description": "15 digit GST identification number of the customer.",
                "example": "22AAAAA0000A1Z5",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "gst_treatment": {
                "description": "Choose whether the contact is GST "
                "registered/unregistered/consumer/overseas. "
                "Allowed values are <code> "
                "business_gst </code> , <code> "
                "business_none </code> , <code> "
                "overseas </code> , <code> consumer "
                "</code>.",
                "example": "business_gst",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "ignore_auto_number_generation": {
                "description": "Set to true to "
                "provide a custom "
                "credit note number "
                "instead of "
                "auto-generated CN "
                "prefix. When true, "
                "you must specify "
                "creditnote_number "
                "manually.",
                "example": False,
                "type": "boolean",
            },
            "is_draft": {
                "description": "Set to true to create the credit note in "
                "draft status. Draft credit notes are not "
                "finalized and can be modified before "
                "sending to customers.",
                "example": True,
                "type": "boolean",
            },
            "is_inclusive_tax": {
                "description": "Used to specify whether the line "
                "item rates are inclusive or "
                "exclusive of tax.",
                "example": "fasle",
                "type": "boolean",
                "x-node_available_in": [],
                "x-node_unavailable_in": ["us", "ca"],
            },
            "is_reverse_charge_applied": {
                "description": "(Required if customer "
                "tax treatment is "
                "<code>vat_registered</code>)<br/>Used "
                "to specify whether the "
                "transaction is "
                "applicable for Domestic "
                "Reverse Charge (DRC) or "
                "not.",
                "example": True,
                "type": "boolean",
                "x-node_available_in": ["za"],
                "x-node_unavailable_in": [],
            },
            "line_items": {
                "description": "Array of line items for the credit "
                "note. Each line item represents a "
                "product or service being credited to "
                "the customer.",
                "items": {
                    "properties": {
                        "account_id": {
                            "description": "Unique "
                            "identifier "
                            "for "
                            "the "
                            "chart "
                            "of "
                            "accounts "
                            "entry. "
                            "Retrieve "
                            "account "
                            "IDs "
                            "from "
                            "the "
                            "List "
                            "Chart "
                            "of "
                            "Accounts "
                            "API "
                            "endpoint. "
                            "Determines "
                            "which "
                            "account "
                            "the "
                            "line "
                            "item "
                            "affects "
                            "for "
                            "accounting "
                            "purposes.",
                            "example": "903000000000388",
                            "type": "string",
                        },
                        "account_name": {
                            "description": "Name "
                            "of "
                            "the "
                            "chart "
                            "of "
                            "accounts "
                            "entry. "
                            "Displays "
                            "the "
                            "account "
                            "name "
                            "for "
                            "reference "
                            "and "
                            "reporting "
                            "purposes. "
                            "Should "
                            "match "
                            "the "
                            "account_id "
                            "provided.",
                            "example": "Sales",
                            "type": "string",
                        },
                        "code": {
                            "description": "Unique "
                            "code "
                            "or "
                            "SKU "
                            "for "
                            "the "
                            "line "
                            "item. "
                            "Used "
                            "for "
                            "product "
                            "identification "
                            "and "
                            "inventory "
                            "tracking. "
                            "Helps "
                            "distinguish "
                            "between "
                            "different "
                            "variants "
                            "of "
                            "the "
                            "same "
                            "product.",
                            "example": "basic-monthly",
                            "type": "string",
                        },
                        "description": {
                            "description": "Detailed "
                            "description "
                            "of "
                            "the "
                            "line "
                            "item. "
                            "Provides "
                            "additional "
                            "information "
                            "about "
                            "the "
                            "product "
                            "or "
                            "service "
                            "being "
                            "credited. "
                            "Displayed "
                            "on "
                            "the "
                            "credit "
                            "note "
                            "document.",
                            "example": "prorated amount for items",
                            "type": "string",
                        },
                        "invoice_id": {
                            "description": "Invoice ID of the required invoice.",
                            "example": "90300000079426",
                            "type": "string",
                        },
                        "invoice_item_id": {
                            "description": "Unique "
                            "identifier "
                            "of "
                            "the "
                            "invoice "
                            "line "
                            "item "
                            "that "
                            "this "
                            "credit "
                            "note "
                            "line "
                            "item "
                            "references. "
                            "Use "
                            "this "
                            "when "
                            "creating "
                            "a "
                            "credit "
                            "note "
                            "for "
                            "a "
                            "specific "
                            "invoice "
                            "line "
                            "item.",
                            "example": "982000000567021",
                            "type": "string",
                        },
                        "item_id": {
                            "description": "Unique "
                            "identifier "
                            "for "
                            "the "
                            "item "
                            "in "
                            "the "
                            "line "
                            "item. "
                            "Retrieve "
                            "item "
                            "IDs "
                            "from "
                            "the "
                            "List "
                            "Items "
                            "API "
                            "endpoint "
                            "in "
                            "the "
                            "items "
                            "section. "
                            "Links "
                            "the "
                            "line "
                            "item "
                            "to "
                            "a "
                            "specific "
                            "product "
                            "or "
                            "service.",
                            "example": "90300000081501",
                            "type": "string",
                        },
                        "location_id": {
                            "description": "Unique "
                            "identifier "
                            "for "
                            "the "
                            "business "
                            "location "
                            "associated "
                            "with "
                            "the "
                            "line "
                            "item. "
                            "Retrieve "
                            "location "
                            "IDs "
                            "from "
                            "the "
                            "List "
                            "Locations "
                            "API "
                            "endpoint "
                            "in "
                            "the "
                            "locations "
                            "section. "
                            "Determines "
                            "tax "
                            "settings "
                            "and "
                            "business "
                            "rules "
                            "for "
                            "this "
                            "line "
                            "item.",
                            "example": "460000000038080",
                            "type": "string",
                        },
                        "name": {
                            "description": "Name "
                            "or "
                            "title "
                            "of "
                            "the "
                            "line "
                            "item. "
                            "Describes "
                            "the "
                            "product "
                            "or "
                            "service "
                            "being "
                            "credited. "
                            "This "
                            "name "
                            "is "
                            "displayed "
                            "on "
                            "the "
                            "credit "
                            "note "
                            "document.",
                            "example": "Basic Monthly",
                            "type": "string",
                        },
                        "product_type": {
                            "description": "Type "
                            "of "
                            "product "
                            "or "
                            "service "
                            "for "
                            "the "
                            "line "
                            "item. "
                            "Standard "
                            "values: "
                            "<code>goods</code> "
                            "or "
                            "<code>services</code>. "
                            "For "
                            "South "
                            "Africa: "
                            "<code>service</code>, "
                            "<code>goods</code>, "
                            "<code>capital_service</code>, "
                            "and "
                            "<code>capital_goods</code>.",
                            "example": "goods",
                            "type": "string",
                        },
                        "project_id": {
                            "description": "Unique "
                            "identifier "
                            "for "
                            "the "
                            "project "
                            "associated "
                            "with "
                            "the "
                            "line "
                            "item. "
                            "Links "
                            "the "
                            "credit "
                            "to "
                            "a "
                            "specific "
                            "project "
                            "for "
                            "project-based "
                            "accounting "
                            "and "
                            "reporting.",
                            "example": 90300000087378,
                            "type": "string",
                        },
                        "quantity": {
                            "description": "Number "
                            "of "
                            "units "
                            "being "
                            "credited "
                            "for "
                            "this "
                            "line "
                            "item. "
                            "Must "
                            "be "
                            "a "
                            "positive "
                            "number. "
                            "Used "
                            "to "
                            "calculate "
                            "the "
                            "total "
                            "amount "
                            "for "
                            "the "
                            "line "
                            "item.",
                            "example": 1,
                            "format": "int32",
                            "type": "integer",
                        },
                        "sat_item_key_code": {
                            "description": "Add "
                            "SAT "
                            "Item "
                            "Key "
                            "Code "
                            "for "
                            "your "
                            "goods/services. "
                            "Download "
                            "the "
                            "<a "
                            "href= "
                            "http://omawww.sat.gob.mx/tramitesyservicios/Paginas/documentos/catCFDI_V_4_07122022.xls  "
                            ">CFDI "
                            "Catalogs.</a>",
                            "example": 71121206,
                            "type": "string",
                            "x-node_available_in": ["mx"],
                            "x-node_unavailable_in": [],
                        },
                        "serial_numbers": {
                            "description": "Serial "
                            "numbers "
                            "of "
                            "the "
                            "items "
                            "being "
                            "credited. "
                            "Used "
                            "for "
                            "tracking "
                            "specific "
                            "units "
                            "of "
                            "inventory "
                            "or "
                            "equipment. "
                            "Important "
                            "for "
                            "warranty "
                            "and "
                            "return "
                            "tracking.",
                            "type": "string",
                        },
                        "tax_id": {
                            "description": "Unique "
                            "identifier "
                            "for "
                            "the "
                            "tax "
                            "applied "
                            "to "
                            "the "
                            "line "
                            "item. "
                            "Retrieve "
                            "tax "
                            "IDs "
                            "from "
                            "the "
                            "List "
                            "Taxes "
                            "API "
                            "endpoint "
                            "in "
                            "the "
                            "taxes "
                            "section. "
                            "Determines "
                            "tax "
                            "calculations "
                            "for "
                            "this "
                            "specific "
                            "line "
                            "item.",
                            "example": "903000000000356",
                            "type": "string",
                        },
                        "tax_treatment_code": {
                            "description": "Specify "
                            "reason "
                            "for "
                            "using "
                            "out "
                            "of "
                            "scope.</br>Supported "
                            "values "
                            "for "
                            "UAE "
                            "are "
                            "<code>uae_same_tax_group</code>, "
                            "<code>uae_reimbursed_expense</code> "
                            "and "
                            "<code>uae_others</code>.</br> "
                            "Supported "
                            "values "
                            "for "
                            "Bahrain "
                            "are "
                            "<code>bahrain_same_tax_group</code>, "
                            "<code>bahrain_transfer_of_concern</code>, "
                            "<code>bahrain_disbursement</code>, "
                            "<code>bahrain_head_to_branch_transaction</code>, "
                            "<code>bahrain_warranty_repair_services</code> "
                            "and "
                            "<code>bahrain_others</code>.</br>Supported "
                            "values "
                            "for "
                            "Saudi "
                            "Arabia "
                            "are "
                            "<code>ksa_pvt_health</code>, "
                            "<code>ksa_pvt_edu</code>, "
                            "<code>ksa_reimbursed_expense</code> "
                            "and "
                            "<code>ksa_house_sales</code>.",
                            "example": "uae_others",
                            "type": "string",
                            "x-node_available_in": ["gcc"],
                            "x-node_unavailable_in": [],
                        },
                        "tds_tax_id": {
                            "description": "Unique "
                            "ID "
                            "to "
                            "denote "
                            "the "
                            "TDS "
                            "tax "
                            "associated "
                            "to "
                            "the "
                            "creditnote",
                            "example": "903000000000357",
                            "type": "string",
                            "x-node_available_in": ["mx"],
                            "x-node_unavailable_in": [],
                        },
                        "type": {
                            "description": "Type "
                            "of "
                            "the "
                            "credit "
                            "note "
                            "line "
                            "item. "
                            "Numeric "
                            "value "
                            "indicating "
                            "the "
                            "line "
                            "item "
                            "type "
                            "(e.g., "
                            "1 for "
                            "product, "
                            "2 for "
                            "service). "
                            "Used "
                            "for "
                            "categorization "
                            "and "
                            "reporting "
                            "purposes.",
                            "example": 1,
                            "type": "integer",
                        },
                        "unitkey_code": {
                            "description": "Add "
                            "Unit "
                            "Key "
                            "Code "
                            "for "
                            "your "
                            "goods/services. "
                            "Download "
                            "the "
                            "<a "
                            "href= "
                            "http://omawww.sat.gob.mx/tramitesyservicios/Paginas/documentos/catCFDI_V_4_07122022.xls  "
                            ">CFDI "
                            "Catalogs.</a>",
                            "example": "box",
                            "type": "string",
                            "x-node_available_in": ["mx"],
                            "x-node_unavailable_in": [],
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "location_id": {
                "description": "Unique identifier for the business "
                "location associated with the line "
                "item. Retrieve location IDs from the "
                "List Locations API endpoint in the "
                "locations section. Determines tax "
                "settings and business rules for this "
                "line item.",
                "example": "460000000038080",
                "type": "string",
            },
            "notes": {
                "description": "Additional notes or comments for the credit "
                "note. Displayed on the credit note document "
                "for customer reference. Max-length [5000]",
                "example": "Offer for the referral",
                "type": "string",
            },
            "place_of_supply": {
                "description": "Place where the goods/services are "
                "supplied to. (If not given, "
                "<code>place of contact</code> "
                "given for the contact will be "
                "taken)<br/>Supported codes for UAE "
                "emirates are : </br>Abu Dhabi - "
                "<code>AB</code>,</br>Ajman - "
                "<code>AJ</code>,</br>Dubai - "
                "<code>DU</code>,</br>Fujairah - "
                "<code>FU</code>,</br>Ras "
                "al-Khaimah - "
                "<code>RA</code>,</br>Sharjah - "
                "<code>SH</code>,</br>Umm al-Quwain "
                "- <code>UM</code><br/>Supported "
                "codes for the GCC countries are : "
                "</br>United Arab Emirates - "
                "<code>AE</code>,</br>Saudi Arabia "
                "- <code>SA</code>,</br>Bahrain - "
                "<code>BH</code>,</br>Kuwait - "
                "<code>KW</code>,</br>Oman - "
                "<code>OM</code>,</br>Qatar - "
                "<code>QA</code>.",
                "example": "TN",
                "type": "string",
                "x-node_available_in": ["in", "gcc"],
                "x-node_unavailable_in": [],
            },
            "reference_number": {
                "description": "Optional reference number for "
                "tracking purposes. Can be any "
                "custom string or auto-generated. "
                "Useful for linking to external "
                "systems or internal tracking. "
                "Max-Length [100]",
                "example": "INV-384",
                "type": "string",
            },
            "tax_authority_id": {
                "description": "Unique ID of the tax authority. "
                "Tax authority depends on the "
                "location of the customer. For "
                "example, if the customer is "
                "located in NY, then the tax "
                "authority is NY tax authority.",
                "example": "903000006345",
                "type": "string",
                "x-node_available_in": ["us"],
                "x-node_unavailable_in": [],
            },
            "tax_exemption_id": {
                "description": "Unique ID of the tax exemption.",
                "example": "903000006345",
                "type": "string",
                "x-node_available_in": ["in", "us", "au", "ca"],
                "x-node_unavailable_in": [],
            },
            "tax_id": {
                "description": "Unique identifier for the tax applied to "
                "the line item. Retrieve tax IDs from the "
                "List Taxes API endpoint in the taxes "
                "section. Determines tax calculations for "
                "this specific line item.",
                "example": "903000000000356",
                "type": "string",
            },
            "tax_treatment": {
                "description": "VAT treatment for the credit note "
                ".Choose whether the contact falls "
                "under: "
                "<code>vat_registered</code>,<code>vat_not_registered</code>,<code>gcc_vat_not_registered</code>,<code>gcc_vat_registered</code>,<code>non_gcc</code>.</br><code>dz_vat_registered</code> "
                "and "
                "<code>dz_vat_not_registered</code> "
                "supported only for "
                "<b>UAE</b>.</b></br><code>home_country_mexico</code>,<code>border_region_mexico</code>,<code>non_mexico</code> "
                "supported only for <b>MX</b>. "
                "<br/><b>For Kenya Edition:</b> "
                "<code>vat_registered</code> "
                ",<code>vat_not_registered</code> "
                ",<code>non_kenya</code>(A business "
                "that is located outside "
                "Kenya).<br/><b>For SouthAfrica "
                "Edition:</b> "
                "<code>vat_registered</code>, "
                "<code>vat_not_registered</code>, "
                "<code>overseas</code>(A business "
                "that is located outside "
                "SouthAfrica).",
                "example": "vat_registered",
                "type": "string",
                "x-node_available_in": ["gcc", "mx", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "template_id": {
                "description": "Unique identifier for the credit note "
                "PDF template. Retrieve template IDs "
                "from the List Credit Note Templates "
                "API endpoint. Determines the visual "
                "layout and branding of the credit note "
                "document.",
                "example": "90300000001336",
                "type": "string",
            },
            "terms": {
                "description": "Terms and conditions displayed on the credit "
                "note document. Include payment terms, return "
                "policies, or other business conditions. "
                "Max-length [10000]",
                "example": "",
                "type": "string",
            },
            "vat_treatment": {
                "description": "(Optional) VAT treatment for the "
                "invoices. VAT treatment denotes the "
                "location of the customer, if the "
                "customer resides in UK then the VAT "
                "treatment is <code>uk</code>. If the "
                "customer is in an EU country & VAT "
                "registered, you are resides in "
                "Northen Ireland and selling Goods "
                "then his VAT treatment is "
                "<code>eu_vat_registered</code>, if "
                "he resides outside of the UK then "
                "his VAT treatment is "
                "<code>overseas</code> (For Pre "
                "Brexit, this can be split as "
                "<code>eu_vat_registered</code>, "
                "<code>eu_vat_not_registered</code> "
                "and <code>non_eu</code>).",
                "example": "overseas",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
        },
        "required": ["customer_id", "date", "creditnote_number", "line_items"],
        "type": "object",
    },
    "UPDATECREDITNOTEWITHCUSTOMFIELD_REQUEST_BODY_SCHEMA": {
        "properties": {
            "account_id": {
                "description": "Unique identifier for the chart of "
                "accounts entry. Retrieve account IDs "
                "from the List Chart of Accounts API "
                "endpoint. Determines which account the "
                "line item affects for accounting "
                "purposes.",
                "example": "903000000000388",
                "type": "string",
            },
            "avatax_exempt_no": {
                "description": "Exemption certificate number of the customer. Max-length [25]",
                "type": "string",
                "x-node_available_in": ["Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "avatax_tax_code": {
                "description": "A tax code is a unique label used "
                "to group Items (products, "
                "services, or charges) together. "
                "Refer the [link][2] for more "
                "deails. Max-length [25]",
                "type": "string",
                "x-node_available_in": ["Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "avatax_use_code": {
                "description": "Used to group like customers for "
                "exemption purposes. It is a custom "
                "value that links customers to a "
                "tax rule. Select from Avalara "
                "[standard codes][1] or enter a "
                "custom code. Max-length [25]",
                "type": "string",
                "x-node_available_in": ["Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "cfdi_reference_type": {
                "description": "Choose CFDI Reference "
                "Type.</br>Allowed values: "
                "<code>credit_note</code>, "
                "<code>debit_note</code>, "
                "<code>return_of_merchandise</code>, "
                "<code>substitution_previous_cfdi</code>, "
                "<code>transfer_of_goods</code>, "
                "<code>invoice_generated_from_order</code>, "
                "<code>cfdi_for_advance</code>.",
                "example": "return_of_merchandise",
                "type": "string",
                "x-node_available_in": ["mx"],
                "x-node_unavailable_in": [],
            },
            "cfdi_usage": {
                "description": "Choose CFDI Usage.</br>Allowed values: "
                "<code>acquisition_of_merchandise</code>, "
                "<code>return_discount_bonus</code>, "
                "<code>general_expense</code>, "
                "<code>buildings</code>, "
                "<code>furniture_office_equipment</code>, "
                "<code>transport_equipment</code>, "
                "<code>computer_equipmentdye_molds_tools</code>, "
                "<code>telephone_communication</code>, "
                "<code>satellite_communication</code>, "
                "<code>other_machinery_equipment</code>, "
                "<code>hospital_expense</code>, "
                "<code>medical_expense_disability</code>, "
                "<code>funeral_expense</code>, "
                "<code>donation</code>, "
                "<code>interest_mortage_loans</code>, "
                "<code>contribution_sar</code>, "
                "<code>medical_expense_insurance_pormium</code>, "
                "<code>school_transportation_expense</code>, "
                "<code>deposit_saving_account</code>, "
                "<code>payment_educational_service</code>, "
                "<code>no_tax_effect</code>, "
                "<code>payment</code>, "
                "<code>payroll</code>.",
                "example": "acquisition_of_merchandise",
                "type": "string",
                "x-node_available_in": ["mx"],
                "x-node_unavailable_in": [],
            },
            "contact_persons_associated": {
                "description": "Contact Persons associated with the transaction.",
                "items": {
                    "properties": {
                        "communication_preference": {
                            "description": "Preferred "
                            "modes "
                            "of "
                            "communication "
                            "for "
                            "the "
                            "contact "
                            "person "
                            "at "
                            "transaction "
                            "level.",
                            "properties": {
                                "is_email_enabled": {
                                    "description": "Used "
                                    "to "
                                    "check "
                                    "if "
                                    "Email "
                                    "communication "
                                    "preference "
                                    "is "
                                    "enabled "
                                    "for "
                                    "the "
                                    "contact "
                                    "person "
                                    "at "
                                    "transaction "
                                    "level.",
                                    "example": True,
                                    "type": "boolean",
                                },
                                "is_whatsapp_enabled": {
                                    "description": "Used "
                                    "to "
                                    "check "
                                    "if "
                                    "WhatsApp "
                                    "communication "
                                    "preference "
                                    "is "
                                    "enabled "
                                    "for "
                                    "the "
                                    "contact "
                                    "person "
                                    "at "
                                    "transaction "
                                    "level.",
                                    "example": True,
                                    "type": "boolean",
                                    "x-node_available_in": ["WhatsApp integration"],
                                },
                            },
                            "type": "object",
                        },
                        "contact_person_id": {
                            "description": "Unique ID of the Contact Person.",
                            "example": 982000000567003,
                            "format": "int64",
                            "type": "integer",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "creditnote_number": {
                "description": "Unique credit note number "
                "displayed in the interface. "
                "Auto-generated with CN prefix "
                "unless "
                "ignore_auto_number_generation is "
                "true. Max-Length [100]",
                "example": "CN-29",
                "type": "string",
            },
            "currency_id": {
                "description": "Unique identifier for the currency "
                "used in the credit note. Can differ "
                "from customer currency if "
                "multi-currency is enabled. Retrieve "
                "currency IDs from the List Currencies "
                "API endpoint in the currency section.",
                "example": "982000000567240",
                "type": "string",
            },
            "custom_fields": {
                "description": "Additional fields for the Credit-Notes.",
                "items": {"type": "string"},
                "type": "array",
            },
            "customer_id": {
                "description": "Unique identifier for the customer "
                "contact. Retrieve customer IDs from "
                "the Get Customers API endpoint in the "
                "contacts section. This ID links the "
                "credit note to the specific customer "
                "record.",
                "example": "903000000000099",
                "type": "string",
            },
            "date": {
                "description": "The date on which the credit note is raised. "
                "Must be in yyyy-mm-dd format. This date "
                "determines the accounting period and affects "
                "tax calculations.",
                "example": "2016-06-05",
                "type": "string",
            },
            "description": {
                "description": "Detailed description of the line item. "
                "Provides additional information about "
                "the product or service being credited. "
                "Displayed on the credit note document.",
                "example": "prorated amount for items",
                "type": "string",
            },
            "exchange_rate": {
                "description": "Exchange rate for converting the "
                "credit note currency to base "
                "currency. Required when currency "
                "differs from base currency. Retrieve "
                "rates from currency exchange rate "
                "APIs.",
                "example": "5.5",
                "type": "string",
            },
            "gst_no": {
                "description": "15 digit GST identification number of the customer.",
                "example": "22AAAAA0000A1Z5",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "gst_treatment": {
                "description": "Choose whether the contact is GST "
                "registered/unregistered/consumer/overseas. "
                "Allowed values are <code> "
                "business_gst </code> , <code> "
                "business_none </code> , <code> "
                "overseas </code> , <code> consumer "
                "</code>.",
                "example": "business_gst",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "ignore_auto_number_generation": {
                "description": "Set to true to "
                "provide a custom "
                "credit note number "
                "instead of "
                "auto-generated CN "
                "prefix. When true, "
                "you must specify "
                "creditnote_number "
                "manually.",
                "example": False,
                "type": "boolean",
            },
            "is_draft": {
                "description": "Set to true to create the credit note in "
                "draft status. Draft credit notes are not "
                "finalized and can be modified before "
                "sending to customers.",
                "example": True,
                "type": "boolean",
            },
            "is_inclusive_tax": {
                "description": "Used to specify whether the line "
                "item rates are inclusive or "
                "exclusive of tax.",
                "example": "fasle",
                "type": "boolean",
                "x-node_available_in": [],
                "x-node_unavailable_in": ["us", "ca"],
            },
            "is_reverse_charge_applied": {
                "description": "(Required if customer "
                "tax treatment is "
                "<code>vat_registered</code>)<br/>Used "
                "to specify whether the "
                "transaction is "
                "applicable for Domestic "
                "Reverse Charge (DRC) or "
                "not.",
                "example": True,
                "type": "boolean",
                "x-node_available_in": ["za"],
                "x-node_unavailable_in": [],
            },
            "item_id": {
                "description": "Unique identifier for the item in the line "
                "item. Retrieve item IDs from the List "
                "Items API endpoint in the items section. "
                "Links the line item to a specific product "
                "or service.",
                "example": "90300000081501",
                "type": "string",
            },
            "line_items": {
                "description": "Line items of a credit note.",
                "items": {
                    "properties": {
                        "account_id": {
                            "description": "Unique "
                            "identifier "
                            "for "
                            "the "
                            "chart "
                            "of "
                            "accounts "
                            "entry. "
                            "Retrieve "
                            "account "
                            "IDs "
                            "from "
                            "the "
                            "List "
                            "Chart "
                            "of "
                            "Accounts "
                            "API "
                            "endpoint. "
                            "Determines "
                            "which "
                            "account "
                            "the "
                            "line "
                            "item "
                            "affects "
                            "for "
                            "accounting "
                            "purposes.",
                            "example": "903000000000388",
                            "type": "string",
                        },
                        "avatax_tax_code": {
                            "description": "A "
                            "tax "
                            "code "
                            "is "
                            "a "
                            "unique "
                            "label "
                            "used "
                            "to "
                            "group "
                            "Items "
                            "(products, "
                            "services, "
                            "or "
                            "charges) "
                            "together. "
                            "Refer "
                            "the "
                            "[link][2] "
                            "for "
                            "more "
                            "deails. "
                            "Max-length "
                            "[25]",
                            "type": "string",
                            "x-node_available_in": ["Avalara Integration"],
                            "x-node_unavailable_in": [],
                        },
                        "avatax_use_code": {
                            "description": "Used "
                            "to "
                            "group "
                            "like "
                            "customers "
                            "for "
                            "exemption "
                            "purposes. "
                            "It "
                            "is "
                            "a "
                            "custom "
                            "value "
                            "that "
                            "links "
                            "customers "
                            "to "
                            "a "
                            "tax "
                            "rule. "
                            "Select "
                            "from "
                            "Avalara "
                            "[standard "
                            "codes][1] "
                            "or "
                            "enter "
                            "a "
                            "custom "
                            "code. "
                            "Max-length "
                            "[25]",
                            "type": "string",
                            "x-node_available_in": ["Avalara Integration"],
                            "x-node_unavailable_in": [],
                        },
                        "description": {
                            "description": "Detailed "
                            "description "
                            "of "
                            "the "
                            "line "
                            "item. "
                            "Provides "
                            "additional "
                            "information "
                            "about "
                            "the "
                            "product "
                            "or "
                            "service "
                            "being "
                            "credited. "
                            "Displayed "
                            "on "
                            "the "
                            "credit "
                            "note "
                            "document.",
                            "example": "prorated amount for items",
                            "type": "string",
                        },
                        "discount": {
                            "description": "Enter discount percentage.",
                            "example": 10,
                            "format": "double",
                            "type": "number",
                        },
                        "hsn_or_sac": {
                            "description": "Add HSN/SAC code for your goods/services",
                            "example": 80540,
                            "type": "string",
                            "x-node_available_in": ["in", "ke", "za"],
                            "x-node_unavailable_in": [],
                        },
                        "item_custom_fields": {
                            "description": "Enter custom field information",
                            "items": {"type": "string"},
                            "type": "array",
                        },
                        "item_id": {
                            "description": "Unique "
                            "identifier "
                            "for "
                            "the "
                            "item "
                            "in "
                            "the "
                            "line "
                            "item. "
                            "Retrieve "
                            "item "
                            "IDs "
                            "from "
                            "the "
                            "List "
                            "Items "
                            "API "
                            "endpoint "
                            "in "
                            "the "
                            "items "
                            "section. "
                            "Links "
                            "the "
                            "line "
                            "item "
                            "to "
                            "a "
                            "specific "
                            "product "
                            "or "
                            "service.",
                            "example": "90300000081501",
                            "type": "string",
                        },
                        "item_order": {
                            "description": "Enter order of the item",
                            "example": 0,
                            "type": "integer",
                        },
                        "line_item_id": {
                            "description": "Search credit notes by credit note line item id.",
                            "example": 903000006245,
                            "type": "string",
                        },
                        "location_id": {
                            "description": "Unique "
                            "identifier "
                            "for "
                            "the "
                            "business "
                            "location "
                            "associated "
                            "with "
                            "the "
                            "line "
                            "item. "
                            "Retrieve "
                            "location "
                            "IDs "
                            "from "
                            "the "
                            "List "
                            "Locations "
                            "API "
                            "endpoint "
                            "in "
                            "the "
                            "locations "
                            "section. "
                            "Determines "
                            "tax "
                            "settings "
                            "and "
                            "business "
                            "rules "
                            "for "
                            "this "
                            "line "
                            "item.",
                            "example": "460000000038080",
                            "type": "string",
                        },
                        "location_name": {"description": "Name of the location.", "type": "string"},
                        "name": {
                            "description": "Name "
                            "or "
                            "title "
                            "of "
                            "the "
                            "line "
                            "item. "
                            "Describes "
                            "the "
                            "product "
                            "or "
                            "service "
                            "being "
                            "credited. "
                            "This "
                            "name "
                            "is "
                            "displayed "
                            "on "
                            "the "
                            "credit "
                            "note "
                            "document.",
                            "example": "Basic Monthly",
                            "type": "string",
                        },
                        "product_type": {
                            "description": "Type "
                            "of "
                            "product "
                            "or "
                            "service "
                            "for "
                            "the "
                            "line "
                            "item. "
                            "Standard "
                            "values: "
                            "<code>goods</code> "
                            "or "
                            "<code>services</code>. "
                            "For "
                            "South "
                            "Africa: "
                            "<code>service</code>, "
                            "<code>goods</code>, "
                            "<code>capital_service</code>, "
                            "and "
                            "<code>capital_goods</code>.",
                            "example": "goods",
                            "type": "string",
                        },
                        "project_id": {
                            "description": "Unique "
                            "identifier "
                            "for "
                            "the "
                            "project "
                            "associated "
                            "with "
                            "the "
                            "line "
                            "item. "
                            "Links "
                            "the "
                            "credit "
                            "to "
                            "a "
                            "specific "
                            "project "
                            "for "
                            "project-based "
                            "accounting "
                            "and "
                            "reporting.",
                            "example": 90300000087378,
                            "type": "string",
                        },
                        "quantity": {
                            "description": "Number "
                            "of "
                            "units "
                            "being "
                            "credited "
                            "for "
                            "this "
                            "line "
                            "item. "
                            "Must "
                            "be "
                            "a "
                            "positive "
                            "number. "
                            "Used "
                            "to "
                            "calculate "
                            "the "
                            "total "
                            "amount "
                            "for "
                            "the "
                            "line "
                            "item.",
                            "example": 1,
                            "format": "int32",
                            "type": "integer",
                        },
                        "rate": {
                            "description": "Rate of the line item.",
                            "example": 0,
                            "format": "double",
                            "type": "number",
                        },
                        "sat_item_key_code": {
                            "description": "Add "
                            "SAT "
                            "Item "
                            "Key "
                            "Code "
                            "for "
                            "your "
                            "goods/services. "
                            "Download "
                            "the "
                            "<a "
                            "href= "
                            "http://omawww.sat.gob.mx/tramitesyservicios/Paginas/documentos/catCFDI_V_4_07122022.xls  "
                            ">CFDI "
                            "Catalogs.</a>",
                            "example": 71121206,
                            "type": "string",
                            "x-node_available_in": ["mx"],
                            "x-node_unavailable_in": [],
                        },
                        "serial_numbers": {
                            "description": "Serial "
                            "numbers "
                            "of "
                            "the "
                            "items "
                            "being "
                            "credited. "
                            "Used "
                            "for "
                            "tracking "
                            "specific "
                            "units "
                            "of "
                            "inventory "
                            "or "
                            "equipment. "
                            "Important "
                            "for "
                            "warranty "
                            "and "
                            "return "
                            "tracking.",
                            "type": "string",
                        },
                        "tax_exemption_code": {
                            "description": "Unique code of the tax exemption.",
                            "example": "GST FREE",
                            "type": "string",
                            "x-node_available_in": ["in", "us", "au", "ca", "mx"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_exemption_id": {
                            "description": "Unique ID of the tax exemption.",
                            "example": "903000006345",
                            "type": "string",
                            "x-node_available_in": ["in", "us", "au", "ca"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_id": {
                            "description": "Unique "
                            "identifier "
                            "for "
                            "the "
                            "tax "
                            "applied "
                            "to "
                            "the "
                            "line "
                            "item. "
                            "Retrieve "
                            "tax "
                            "IDs "
                            "from "
                            "the "
                            "List "
                            "Taxes "
                            "API "
                            "endpoint "
                            "in "
                            "the "
                            "taxes "
                            "section. "
                            "Determines "
                            "tax "
                            "calculations "
                            "for "
                            "this "
                            "specific "
                            "line "
                            "item.",
                            "example": "903000000000356",
                            "type": "string",
                        },
                        "tax_treatment_code": {
                            "description": "Specify "
                            "reason "
                            "for "
                            "using "
                            "out "
                            "of "
                            "scope.</br>Supported "
                            "values "
                            "for "
                            "UAE "
                            "are "
                            "<code>uae_same_tax_group</code>, "
                            "<code>uae_reimbursed_expense</code> "
                            "and "
                            "<code>uae_others</code>.</br> "
                            "Supported "
                            "values "
                            "for "
                            "Bahrain "
                            "are "
                            "<code>bahrain_same_tax_group</code>, "
                            "<code>bahrain_transfer_of_concern</code>, "
                            "<code>bahrain_disbursement</code>, "
                            "<code>bahrain_head_to_branch_transaction</code>, "
                            "<code>bahrain_warranty_repair_services</code> "
                            "and "
                            "<code>bahrain_others</code>.</br>Supported "
                            "values "
                            "for "
                            "Saudi "
                            "Arabia "
                            "are "
                            "<code>ksa_pvt_health</code>, "
                            "<code>ksa_pvt_edu</code>, "
                            "<code>ksa_reimbursed_expense</code> "
                            "and "
                            "<code>ksa_house_sales</code>.",
                            "example": "uae_others",
                            "type": "string",
                            "x-node_available_in": ["gcc"],
                            "x-node_unavailable_in": [],
                        },
                        "tds_tax_id": {
                            "description": "Unique "
                            "ID "
                            "to "
                            "denote "
                            "the "
                            "TDS "
                            "tax "
                            "associated "
                            "to "
                            "the "
                            "creditnote",
                            "example": "903000000000357",
                            "type": "string",
                            "x-node_available_in": ["mx"],
                            "x-node_unavailable_in": [],
                        },
                        "unit": {
                            "description": "Unit of the line item. E.g: kgs, Nos.",
                            "example": "kgs",
                            "type": "string",
                        },
                        "unitkey_code": {
                            "description": "Add "
                            "Unit "
                            "Key "
                            "Code "
                            "for "
                            "your "
                            "goods/services. "
                            "Download "
                            "the "
                            "<a "
                            "href= "
                            "http://omawww.sat.gob.mx/tramitesyservicios/Paginas/documentos/catCFDI_V_4_07122022.xls  "
                            ">CFDI "
                            "Catalogs.</a>",
                            "example": "box",
                            "type": "string",
                            "x-node_available_in": ["mx"],
                            "x-node_unavailable_in": [],
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "location_id": {
                "description": "Unique identifier for the business "
                "location associated with the line "
                "item. Retrieve location IDs from the "
                "List Locations API endpoint in the "
                "locations section. Determines tax "
                "settings and business rules for this "
                "line item.",
                "example": "460000000038080",
                "type": "string",
            },
            "name": {
                "description": "Name or title of the line item. Describes the "
                "product or service being credited. This name "
                "is displayed on the credit note document.",
                "example": "Basic Monthly",
                "type": "string",
            },
            "notes": {
                "description": "Additional notes or comments for the credit "
                "note. Displayed on the credit note document "
                "for customer reference. Max-length [5000]",
                "example": "Offer for the referral",
                "type": "string",
            },
            "place_of_supply": {
                "description": "Place where the goods/services are "
                "supplied to. (If not given, "
                "<code>place of contact</code> "
                "given for the contact will be "
                "taken)<br/>Supported codes for UAE "
                "emirates are : </br>Abu Dhabi - "
                "<code>AB</code>,</br>Ajman - "
                "<code>AJ</code>,</br>Dubai - "
                "<code>DU</code>,</br>Fujairah - "
                "<code>FU</code>,</br>Ras "
                "al-Khaimah - "
                "<code>RA</code>,</br>Sharjah - "
                "<code>SH</code>,</br>Umm al-Quwain "
                "- <code>UM</code><br/>Supported "
                "codes for the GCC countries are : "
                "</br>United Arab Emirates - "
                "<code>AE</code>,</br>Saudi Arabia "
                "- <code>SA</code>,</br>Bahrain - "
                "<code>BH</code>,</br>Kuwait - "
                "<code>KW</code>,</br>Oman - "
                "<code>OM</code>,</br>Qatar - "
                "<code>QA</code>.",
                "example": "TN",
                "type": "string",
                "x-node_available_in": ["in", "gcc"],
                "x-node_unavailable_in": [],
            },
            "quantity": {
                "description": "Number of units being credited for this "
                "line item. Must be a positive number. "
                "Used to calculate the total amount for "
                "the line item.",
                "example": 1,
                "format": "int32",
                "type": "integer",
            },
            "rate": {
                "description": "Rate of the line item.",
                "example": 0,
                "format": "double",
                "type": "number",
            },
            "reference_number": {
                "description": "Optional reference number for "
                "tracking purposes. Can be any "
                "custom string or auto-generated. "
                "Useful for linking to external "
                "systems or internal tracking. "
                "Max-Length [100]",
                "example": "INV-384",
                "type": "string",
            },
            "tax_authority_id": {
                "description": "Unique ID of the tax authority. "
                "Tax authority depends on the "
                "location of the customer. For "
                "example, if the customer is "
                "located in NY, then the tax "
                "authority is NY tax authority.",
                "example": "903000006345",
                "type": "string",
                "x-node_available_in": ["us"],
                "x-node_unavailable_in": [],
            },
            "tax_exemption_id": {
                "description": "Unique ID of the tax exemption.",
                "example": "903000006345",
                "type": "string",
                "x-node_available_in": ["in", "us", "au", "ca"],
                "x-node_unavailable_in": [],
            },
            "tax_id": {
                "description": "Unique identifier for the tax applied to "
                "the line item. Retrieve tax IDs from the "
                "List Taxes API endpoint in the taxes "
                "section. Determines tax calculations for "
                "this specific line item.",
                "example": "903000000000356",
                "type": "string",
            },
            "tax_treatment": {
                "description": "VAT treatment for the credit note "
                ".Choose whether the contact falls "
                "under: "
                "<code>vat_registered</code>,<code>vat_not_registered</code>,<code>gcc_vat_not_registered</code>,<code>gcc_vat_registered</code>,<code>non_gcc</code>.</br><code>dz_vat_registered</code> "
                "and "
                "<code>dz_vat_not_registered</code> "
                "supported only for "
                "<b>UAE</b>.</b></br><code>home_country_mexico</code>,<code>border_region_mexico</code>,<code>non_mexico</code> "
                "supported only for <b>MX</b>. "
                "<br/><b>For Kenya Edition:</b> "
                "<code>vat_registered</code> "
                ",<code>vat_not_registered</code> "
                ",<code>non_kenya</code>(A business "
                "that is located outside "
                "Kenya).<br/><b>For SouthAfrica "
                "Edition:</b> "
                "<code>vat_registered</code>, "
                "<code>vat_not_registered</code>, "
                "<code>overseas</code>(A business "
                "that is located outside "
                "SouthAfrica).",
                "example": "vat_registered",
                "type": "string",
                "x-node_available_in": ["gcc", "mx", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "template_id": {
                "description": "Unique identifier for the credit note "
                "PDF template. Retrieve template IDs "
                "from the List Credit Note Templates "
                "API endpoint. Determines the visual "
                "layout and branding of the credit note "
                "document.",
                "example": "90300000001336",
                "type": "string",
            },
            "terms": {
                "description": "Terms and conditions displayed on the credit "
                "note document. Include payment terms, return "
                "policies, or other business conditions. "
                "Max-length [10000]",
                "example": "",
                "type": "string",
            },
            "unit": {
                "description": "Unit of the line item. E.g: kgs, Nos.",
                "example": "kgs",
                "type": "string",
            },
            "vat_treatment": {
                "description": "(Optional) VAT treatment for the "
                "invoices. VAT treatment denotes the "
                "location of the customer, if the "
                "customer resides in UK then the VAT "
                "treatment is <code>uk</code>. If the "
                "customer is in an EU country & VAT "
                "registered, you are resides in "
                "Northen Ireland and selling Goods "
                "then his VAT treatment is "
                "<code>eu_vat_registered</code>, if "
                "he resides outside of the UK then "
                "his VAT treatment is "
                "<code>overseas</code> (For Pre "
                "Brexit, this can be split as "
                "<code>eu_vat_registered</code>, "
                "<code>eu_vat_not_registered</code> "
                "and <code>non_eu</code>).",
                "example": "overseas",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
        },
        "required": ["customer_id", "date", "creditnote_number", "line_items"],
        "type": "object",
    },
    "UPDATECREDITNOTEDETAILS_REQUEST_BODY_SCHEMA": {
        "properties": {
            "account_id": {
                "description": "Unique identifier for the chart of "
                "accounts entry. Retrieve account IDs "
                "from the List Chart of Accounts API "
                "endpoint. Determines which account the "
                "line item affects for accounting "
                "purposes.",
                "example": "903000000000388",
                "type": "string",
            },
            "avatax_exempt_no": {
                "description": "Exemption certificate number of the customer. Max-length [25]",
                "type": "string",
                "x-node_available_in": ["Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "avatax_tax_code": {
                "description": "A tax code is a unique label used "
                "to group Items (products, "
                "services, or charges) together. "
                "Refer the [link][2] for more "
                "deails. Max-length [25]",
                "type": "string",
                "x-node_available_in": ["Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "avatax_use_code": {
                "description": "Used to group like customers for "
                "exemption purposes. It is a custom "
                "value that links customers to a "
                "tax rule. Select from Avalara "
                "[standard codes][1] or enter a "
                "custom code. Max-length [25]",
                "type": "string",
                "x-node_available_in": ["Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "cfdi_reference_type": {
                "description": "Choose CFDI Reference "
                "Type.</br>Allowed values: "
                "<code>credit_note</code>, "
                "<code>debit_note</code>, "
                "<code>return_of_merchandise</code>, "
                "<code>substitution_previous_cfdi</code>, "
                "<code>transfer_of_goods</code>, "
                "<code>invoice_generated_from_order</code>, "
                "<code>cfdi_for_advance</code>.",
                "example": "return_of_merchandise",
                "type": "string",
                "x-node_available_in": ["mx"],
                "x-node_unavailable_in": [],
            },
            "cfdi_usage": {
                "description": "Choose CFDI Usage.</br>Allowed values: "
                "<code>acquisition_of_merchandise</code>, "
                "<code>return_discount_bonus</code>, "
                "<code>general_expense</code>, "
                "<code>buildings</code>, "
                "<code>furniture_office_equipment</code>, "
                "<code>transport_equipment</code>, "
                "<code>computer_equipmentdye_molds_tools</code>, "
                "<code>telephone_communication</code>, "
                "<code>satellite_communication</code>, "
                "<code>other_machinery_equipment</code>, "
                "<code>hospital_expense</code>, "
                "<code>medical_expense_disability</code>, "
                "<code>funeral_expense</code>, "
                "<code>donation</code>, "
                "<code>interest_mortage_loans</code>, "
                "<code>contribution_sar</code>, "
                "<code>medical_expense_insurance_pormium</code>, "
                "<code>school_transportation_expense</code>, "
                "<code>deposit_saving_account</code>, "
                "<code>payment_educational_service</code>, "
                "<code>no_tax_effect</code>, "
                "<code>payment</code>, "
                "<code>payroll</code>.",
                "example": "acquisition_of_merchandise",
                "type": "string",
                "x-node_available_in": ["mx"],
                "x-node_unavailable_in": [],
            },
            "contact_persons_associated": {
                "description": "Contact Persons associated with the transaction.",
                "items": {
                    "properties": {
                        "communication_preference": {
                            "description": "Preferred "
                            "modes "
                            "of "
                            "communication "
                            "for "
                            "the "
                            "contact "
                            "person "
                            "at "
                            "transaction "
                            "level.",
                            "properties": {
                                "is_email_enabled": {
                                    "description": "Used "
                                    "to "
                                    "check "
                                    "if "
                                    "Email "
                                    "communication "
                                    "preference "
                                    "is "
                                    "enabled "
                                    "for "
                                    "the "
                                    "contact "
                                    "person "
                                    "at "
                                    "transaction "
                                    "level.",
                                    "example": True,
                                    "type": "boolean",
                                },
                                "is_whatsapp_enabled": {
                                    "description": "Used "
                                    "to "
                                    "check "
                                    "if "
                                    "WhatsApp "
                                    "communication "
                                    "preference "
                                    "is "
                                    "enabled "
                                    "for "
                                    "the "
                                    "contact "
                                    "person "
                                    "at "
                                    "transaction "
                                    "level.",
                                    "example": True,
                                    "type": "boolean",
                                    "x-node_available_in": ["WhatsApp integration"],
                                },
                            },
                            "type": "object",
                        },
                        "contact_person_id": {
                            "description": "Unique ID of the Contact Person.",
                            "example": 982000000567003,
                            "format": "int64",
                            "type": "integer",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "creditnote_number": {
                "description": "Unique credit note number "
                "displayed in the interface. "
                "Auto-generated with CN prefix "
                "unless "
                "ignore_auto_number_generation is "
                "true. Max-Length [100]",
                "example": "CN-29",
                "type": "string",
            },
            "currency_id": {
                "description": "Unique identifier for the currency "
                "used in the credit note. Can differ "
                "from customer currency if "
                "multi-currency is enabled. Retrieve "
                "currency IDs from the List Currencies "
                "API endpoint in the currency section.",
                "example": "982000000567240",
                "type": "string",
            },
            "custom_fields": {
                "description": "Additional fields for the Credit-Notes.",
                "items": {"type": "string"},
                "type": "array",
            },
            "customer_id": {
                "description": "Unique identifier for the customer "
                "contact. Retrieve customer IDs from "
                "the Get Customers API endpoint in the "
                "contacts section. This ID links the "
                "credit note to the specific customer "
                "record.",
                "example": "903000000000099",
                "type": "string",
            },
            "date": {
                "description": "The date on which the credit note is raised. "
                "Must be in yyyy-mm-dd format. This date "
                "determines the accounting period and affects "
                "tax calculations.",
                "example": "2016-06-05",
                "type": "string",
            },
            "description": {
                "description": "Detailed description of the line item. "
                "Provides additional information about "
                "the product or service being credited. "
                "Displayed on the credit note document.",
                "example": "prorated amount for items",
                "type": "string",
            },
            "exchange_rate": {
                "description": "Exchange rate for converting the "
                "credit note currency to base "
                "currency. Required when currency "
                "differs from base currency. Retrieve "
                "rates from currency exchange rate "
                "APIs.",
                "example": "5.5",
                "type": "string",
            },
            "gst_no": {
                "description": "15 digit GST identification number of the customer.",
                "example": "22AAAAA0000A1Z5",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "gst_treatment": {
                "description": "Choose whether the contact is GST "
                "registered/unregistered/consumer/overseas. "
                "Allowed values are <code> "
                "business_gst </code> , <code> "
                "business_none </code> , <code> "
                "overseas </code> , <code> consumer "
                "</code>.",
                "example": "business_gst",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "ignore_auto_number_generation": {
                "description": "Set to true to "
                "provide a custom "
                "credit note number "
                "instead of "
                "auto-generated CN "
                "prefix. When true, "
                "you must specify "
                "creditnote_number "
                "manually.",
                "example": False,
                "type": "boolean",
            },
            "is_draft": {
                "description": "Set to true to create the credit note in "
                "draft status. Draft credit notes are not "
                "finalized and can be modified before "
                "sending to customers.",
                "example": True,
                "type": "boolean",
            },
            "is_inclusive_tax": {
                "description": "Used to specify whether the line "
                "item rates are inclusive or "
                "exclusive of tax.",
                "example": "fasle",
                "type": "boolean",
                "x-node_available_in": [],
                "x-node_unavailable_in": ["us", "ca"],
            },
            "is_reverse_charge_applied": {
                "description": "(Required if customer "
                "tax treatment is "
                "<code>vat_registered</code>)<br/>Used "
                "to specify whether the "
                "transaction is "
                "applicable for Domestic "
                "Reverse Charge (DRC) or "
                "not.",
                "example": True,
                "type": "boolean",
                "x-node_available_in": ["za"],
                "x-node_unavailable_in": [],
            },
            "item_id": {
                "description": "Unique identifier for the item in the line "
                "item. Retrieve item IDs from the List "
                "Items API endpoint in the items section. "
                "Links the line item to a specific product "
                "or service.",
                "example": "90300000081501",
                "type": "string",
            },
            "line_items": {
                "description": "Line items of a credit note.",
                "items": {
                    "properties": {
                        "account_id": {
                            "description": "Unique "
                            "identifier "
                            "for "
                            "the "
                            "chart "
                            "of "
                            "accounts "
                            "entry. "
                            "Retrieve "
                            "account "
                            "IDs "
                            "from "
                            "the "
                            "List "
                            "Chart "
                            "of "
                            "Accounts "
                            "API "
                            "endpoint. "
                            "Determines "
                            "which "
                            "account "
                            "the "
                            "line "
                            "item "
                            "affects "
                            "for "
                            "accounting "
                            "purposes.",
                            "example": "903000000000388",
                            "type": "string",
                        },
                        "avatax_tax_code": {
                            "description": "A "
                            "tax "
                            "code "
                            "is "
                            "a "
                            "unique "
                            "label "
                            "used "
                            "to "
                            "group "
                            "Items "
                            "(products, "
                            "services, "
                            "or "
                            "charges) "
                            "together. "
                            "Refer "
                            "the "
                            "[link][2] "
                            "for "
                            "more "
                            "deails. "
                            "Max-length "
                            "[25]",
                            "type": "string",
                            "x-node_available_in": ["Avalara Integration"],
                            "x-node_unavailable_in": [],
                        },
                        "avatax_use_code": {
                            "description": "Used "
                            "to "
                            "group "
                            "like "
                            "customers "
                            "for "
                            "exemption "
                            "purposes. "
                            "It "
                            "is "
                            "a "
                            "custom "
                            "value "
                            "that "
                            "links "
                            "customers "
                            "to "
                            "a "
                            "tax "
                            "rule. "
                            "Select "
                            "from "
                            "Avalara "
                            "[standard "
                            "codes][1] "
                            "or "
                            "enter "
                            "a "
                            "custom "
                            "code. "
                            "Max-length "
                            "[25]",
                            "type": "string",
                            "x-node_available_in": ["Avalara Integration"],
                            "x-node_unavailable_in": [],
                        },
                        "description": {
                            "description": "Detailed "
                            "description "
                            "of "
                            "the "
                            "line "
                            "item. "
                            "Provides "
                            "additional "
                            "information "
                            "about "
                            "the "
                            "product "
                            "or "
                            "service "
                            "being "
                            "credited. "
                            "Displayed "
                            "on "
                            "the "
                            "credit "
                            "note "
                            "document.",
                            "example": "prorated amount for items",
                            "type": "string",
                        },
                        "discount": {
                            "description": "Enter discount percentage.",
                            "example": 10,
                            "format": "double",
                            "type": "number",
                        },
                        "hsn_or_sac": {
                            "description": "Add HSN/SAC code for your goods/services",
                            "example": 80540,
                            "type": "string",
                            "x-node_available_in": ["in", "ke", "za"],
                            "x-node_unavailable_in": [],
                        },
                        "item_custom_fields": {
                            "description": "Enter custom field information",
                            "items": {"type": "string"},
                            "type": "array",
                        },
                        "item_id": {
                            "description": "Unique "
                            "identifier "
                            "for "
                            "the "
                            "item "
                            "in "
                            "the "
                            "line "
                            "item. "
                            "Retrieve "
                            "item "
                            "IDs "
                            "from "
                            "the "
                            "List "
                            "Items "
                            "API "
                            "endpoint "
                            "in "
                            "the "
                            "items "
                            "section. "
                            "Links "
                            "the "
                            "line "
                            "item "
                            "to "
                            "a "
                            "specific "
                            "product "
                            "or "
                            "service.",
                            "example": "90300000081501",
                            "type": "string",
                        },
                        "item_order": {
                            "description": "Enter order of the item",
                            "example": 0,
                            "type": "integer",
                        },
                        "line_item_id": {
                            "description": "Search credit notes by credit note line item id.",
                            "example": 903000006245,
                            "type": "string",
                        },
                        "location_id": {
                            "description": "Unique "
                            "identifier "
                            "for "
                            "the "
                            "business "
                            "location "
                            "associated "
                            "with "
                            "the "
                            "line "
                            "item. "
                            "Retrieve "
                            "location "
                            "IDs "
                            "from "
                            "the "
                            "List "
                            "Locations "
                            "API "
                            "endpoint "
                            "in "
                            "the "
                            "locations "
                            "section. "
                            "Determines "
                            "tax "
                            "settings "
                            "and "
                            "business "
                            "rules "
                            "for "
                            "this "
                            "line "
                            "item.",
                            "example": "460000000038080",
                            "type": "string",
                        },
                        "location_name": {"description": "Name of the location.", "type": "string"},
                        "name": {
                            "description": "Name "
                            "or "
                            "title "
                            "of "
                            "the "
                            "line "
                            "item. "
                            "Describes "
                            "the "
                            "product "
                            "or "
                            "service "
                            "being "
                            "credited. "
                            "This "
                            "name "
                            "is "
                            "displayed "
                            "on "
                            "the "
                            "credit "
                            "note "
                            "document.",
                            "example": "Basic Monthly",
                            "type": "string",
                        },
                        "product_type": {
                            "description": "Type "
                            "of "
                            "product "
                            "or "
                            "service "
                            "for "
                            "the "
                            "line "
                            "item. "
                            "Standard "
                            "values: "
                            "<code>goods</code> "
                            "or "
                            "<code>services</code>. "
                            "For "
                            "South "
                            "Africa: "
                            "<code>service</code>, "
                            "<code>goods</code>, "
                            "<code>capital_service</code>, "
                            "and "
                            "<code>capital_goods</code>.",
                            "example": "goods",
                            "type": "string",
                        },
                        "project_id": {
                            "description": "Unique "
                            "identifier "
                            "for "
                            "the "
                            "project "
                            "associated "
                            "with "
                            "the "
                            "line "
                            "item. "
                            "Links "
                            "the "
                            "credit "
                            "to "
                            "a "
                            "specific "
                            "project "
                            "for "
                            "project-based "
                            "accounting "
                            "and "
                            "reporting.",
                            "example": 90300000087378,
                            "type": "string",
                        },
                        "quantity": {
                            "description": "Number "
                            "of "
                            "units "
                            "being "
                            "credited "
                            "for "
                            "this "
                            "line "
                            "item. "
                            "Must "
                            "be "
                            "a "
                            "positive "
                            "number. "
                            "Used "
                            "to "
                            "calculate "
                            "the "
                            "total "
                            "amount "
                            "for "
                            "the "
                            "line "
                            "item.",
                            "example": 1,
                            "format": "int32",
                            "type": "integer",
                        },
                        "rate": {
                            "description": "Rate of the line item.",
                            "example": 0,
                            "format": "double",
                            "type": "number",
                        },
                        "sat_item_key_code": {
                            "description": "Add "
                            "SAT "
                            "Item "
                            "Key "
                            "Code "
                            "for "
                            "your "
                            "goods/services. "
                            "Download "
                            "the "
                            "<a "
                            "href= "
                            "http://omawww.sat.gob.mx/tramitesyservicios/Paginas/documentos/catCFDI_V_4_07122022.xls  "
                            ">CFDI "
                            "Catalogs.</a>",
                            "example": 71121206,
                            "type": "string",
                            "x-node_available_in": ["mx"],
                            "x-node_unavailable_in": [],
                        },
                        "serial_numbers": {
                            "description": "Serial "
                            "numbers "
                            "of "
                            "the "
                            "items "
                            "being "
                            "credited. "
                            "Used "
                            "for "
                            "tracking "
                            "specific "
                            "units "
                            "of "
                            "inventory "
                            "or "
                            "equipment. "
                            "Important "
                            "for "
                            "warranty "
                            "and "
                            "return "
                            "tracking.",
                            "type": "string",
                        },
                        "tax_exemption_code": {
                            "description": "Unique code of the tax exemption.",
                            "example": "GST FREE",
                            "type": "string",
                            "x-node_available_in": ["in", "us", "au", "ca", "mx"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_exemption_id": {
                            "description": "Unique ID of the tax exemption.",
                            "example": "903000006345",
                            "type": "string",
                            "x-node_available_in": ["in", "us", "au", "ca"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_id": {
                            "description": "Unique "
                            "identifier "
                            "for "
                            "the "
                            "tax "
                            "applied "
                            "to "
                            "the "
                            "line "
                            "item. "
                            "Retrieve "
                            "tax "
                            "IDs "
                            "from "
                            "the "
                            "List "
                            "Taxes "
                            "API "
                            "endpoint "
                            "in "
                            "the "
                            "taxes "
                            "section. "
                            "Determines "
                            "tax "
                            "calculations "
                            "for "
                            "this "
                            "specific "
                            "line "
                            "item.",
                            "example": "903000000000356",
                            "type": "string",
                        },
                        "tax_treatment_code": {
                            "description": "Specify "
                            "reason "
                            "for "
                            "using "
                            "out "
                            "of "
                            "scope.</br>Supported "
                            "values "
                            "for "
                            "UAE "
                            "are "
                            "<code>uae_same_tax_group</code>, "
                            "<code>uae_reimbursed_expense</code> "
                            "and "
                            "<code>uae_others</code>.</br> "
                            "Supported "
                            "values "
                            "for "
                            "Bahrain "
                            "are "
                            "<code>bahrain_same_tax_group</code>, "
                            "<code>bahrain_transfer_of_concern</code>, "
                            "<code>bahrain_disbursement</code>, "
                            "<code>bahrain_head_to_branch_transaction</code>, "
                            "<code>bahrain_warranty_repair_services</code> "
                            "and "
                            "<code>bahrain_others</code>.</br>Supported "
                            "values "
                            "for "
                            "Saudi "
                            "Arabia "
                            "are "
                            "<code>ksa_pvt_health</code>, "
                            "<code>ksa_pvt_edu</code>, "
                            "<code>ksa_reimbursed_expense</code> "
                            "and "
                            "<code>ksa_house_sales</code>.",
                            "example": "uae_others",
                            "type": "string",
                            "x-node_available_in": ["gcc"],
                            "x-node_unavailable_in": [],
                        },
                        "tds_tax_id": {
                            "description": "Unique "
                            "ID "
                            "to "
                            "denote "
                            "the "
                            "TDS "
                            "tax "
                            "associated "
                            "to "
                            "the "
                            "creditnote",
                            "example": "903000000000357",
                            "type": "string",
                            "x-node_available_in": ["mx"],
                            "x-node_unavailable_in": [],
                        },
                        "unit": {
                            "description": "Unit of the line item. E.g: kgs, Nos.",
                            "example": "kgs",
                            "type": "string",
                        },
                        "unitkey_code": {
                            "description": "Add "
                            "Unit "
                            "Key "
                            "Code "
                            "for "
                            "your "
                            "goods/services. "
                            "Download "
                            "the "
                            "<a "
                            "href= "
                            "http://omawww.sat.gob.mx/tramitesyservicios/Paginas/documentos/catCFDI_V_4_07122022.xls  "
                            ">CFDI "
                            "Catalogs.</a>",
                            "example": "box",
                            "type": "string",
                            "x-node_available_in": ["mx"],
                            "x-node_unavailable_in": [],
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "location_id": {
                "description": "Unique identifier for the business "
                "location associated with the line "
                "item. Retrieve location IDs from the "
                "List Locations API endpoint in the "
                "locations section. Determines tax "
                "settings and business rules for this "
                "line item.",
                "example": "460000000038080",
                "type": "string",
            },
            "name": {
                "description": "Name or title of the line item. Describes the "
                "product or service being credited. This name "
                "is displayed on the credit note document.",
                "example": "Basic Monthly",
                "type": "string",
            },
            "notes": {
                "description": "Additional notes or comments for the credit "
                "note. Displayed on the credit note document "
                "for customer reference. Max-length [5000]",
                "example": "Offer for the referral",
                "type": "string",
            },
            "place_of_supply": {
                "description": "Place where the goods/services are "
                "supplied to. (If not given, "
                "<code>place of contact</code> "
                "given for the contact will be "
                "taken)<br/>Supported codes for UAE "
                "emirates are : </br>Abu Dhabi - "
                "<code>AB</code>,</br>Ajman - "
                "<code>AJ</code>,</br>Dubai - "
                "<code>DU</code>,</br>Fujairah - "
                "<code>FU</code>,</br>Ras "
                "al-Khaimah - "
                "<code>RA</code>,</br>Sharjah - "
                "<code>SH</code>,</br>Umm al-Quwain "
                "- <code>UM</code><br/>Supported "
                "codes for the GCC countries are : "
                "</br>United Arab Emirates - "
                "<code>AE</code>,</br>Saudi Arabia "
                "- <code>SA</code>,</br>Bahrain - "
                "<code>BH</code>,</br>Kuwait - "
                "<code>KW</code>,</br>Oman - "
                "<code>OM</code>,</br>Qatar - "
                "<code>QA</code>.",
                "example": "TN",
                "type": "string",
                "x-node_available_in": ["in", "gcc"],
                "x-node_unavailable_in": [],
            },
            "quantity": {
                "description": "Number of units being credited for this "
                "line item. Must be a positive number. "
                "Used to calculate the total amount for "
                "the line item.",
                "example": 1,
                "format": "int32",
                "type": "integer",
            },
            "rate": {
                "description": "Rate of the line item.",
                "example": 0,
                "format": "double",
                "type": "number",
            },
            "reference_number": {
                "description": "Optional reference number for "
                "tracking purposes. Can be any "
                "custom string or auto-generated. "
                "Useful for linking to external "
                "systems or internal tracking. "
                "Max-Length [100]",
                "example": "INV-384",
                "type": "string",
            },
            "tax_authority_id": {
                "description": "Unique ID of the tax authority. "
                "Tax authority depends on the "
                "location of the customer. For "
                "example, if the customer is "
                "located in NY, then the tax "
                "authority is NY tax authority.",
                "example": "903000006345",
                "type": "string",
                "x-node_available_in": ["us"],
                "x-node_unavailable_in": [],
            },
            "tax_exemption_id": {
                "description": "Unique ID of the tax exemption.",
                "example": "903000006345",
                "type": "string",
                "x-node_available_in": ["in", "us", "au", "ca"],
                "x-node_unavailable_in": [],
            },
            "tax_id": {
                "description": "Unique identifier for the tax applied to "
                "the line item. Retrieve tax IDs from the "
                "List Taxes API endpoint in the taxes "
                "section. Determines tax calculations for "
                "this specific line item.",
                "example": "903000000000356",
                "type": "string",
            },
            "tax_treatment": {
                "description": "VAT treatment for the credit note "
                ".Choose whether the contact falls "
                "under: "
                "<code>vat_registered</code>,<code>vat_not_registered</code>,<code>gcc_vat_not_registered</code>,<code>gcc_vat_registered</code>,<code>non_gcc</code>.</br><code>dz_vat_registered</code> "
                "and "
                "<code>dz_vat_not_registered</code> "
                "supported only for "
                "<b>UAE</b>.</b></br><code>home_country_mexico</code>,<code>border_region_mexico</code>,<code>non_mexico</code> "
                "supported only for <b>MX</b>. "
                "<br/><b>For Kenya Edition:</b> "
                "<code>vat_registered</code> "
                ",<code>vat_not_registered</code> "
                ",<code>non_kenya</code>(A business "
                "that is located outside "
                "Kenya).<br/><b>For SouthAfrica "
                "Edition:</b> "
                "<code>vat_registered</code>, "
                "<code>vat_not_registered</code>, "
                "<code>overseas</code>(A business "
                "that is located outside "
                "SouthAfrica).",
                "example": "vat_registered",
                "type": "string",
                "x-node_available_in": ["gcc", "mx", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "template_id": {
                "description": "Unique identifier for the credit note "
                "PDF template. Retrieve template IDs "
                "from the List Credit Note Templates "
                "API endpoint. Determines the visual "
                "layout and branding of the credit note "
                "document.",
                "example": "90300000001336",
                "type": "string",
            },
            "terms": {
                "description": "Terms and conditions displayed on the credit "
                "note document. Include payment terms, return "
                "policies, or other business conditions. "
                "Max-length [10000]",
                "example": "",
                "type": "string",
            },
            "unit": {
                "description": "Unit of the line item. E.g: kgs, Nos.",
                "example": "kgs",
                "type": "string",
            },
            "vat_treatment": {
                "description": "(Optional) VAT treatment for the "
                "invoices. VAT treatment denotes the "
                "location of the customer, if the "
                "customer resides in UK then the VAT "
                "treatment is <code>uk</code>. If the "
                "customer is in an EU country & VAT "
                "registered, you are resides in "
                "Northen Ireland and selling Goods "
                "then his VAT treatment is "
                "<code>eu_vat_registered</code>, if "
                "he resides outside of the UK then "
                "his VAT treatment is "
                "<code>overseas</code> (For Pre "
                "Brexit, this can be split as "
                "<code>eu_vat_registered</code>, "
                "<code>eu_vat_not_registered</code> "
                "and <code>non_eu</code>).",
                "example": "overseas",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
        },
        "required": ["customer_id", "date", "creditnote_number", "line_items"],
        "type": "object",
    },
    "EMAILCREDITNOTE_REQUEST_BODY_SCHEMA": {
        "properties": {
            "body": {
                "description": "The body of the email. Max-length [5000]",
                "example": "Please find attached the credit note for your subscription.",
                "type": "string",
            },
            "cc_mail_ids": {
                "description": "The email IDs that have to be copied "
                "when the credit note is to be mailed.",
                "example": ["accounts@bowmanfurniture.com"],
                "items": {"type": "string"},
                "type": "array",
            },
            "subject": {
                "description": "The subject of the email. Max-length [1000]",
                "example": "Credit note for subscription.",
                "type": "string",
            },
            "to_mail_ids": {
                "description": "The email IDs to which the credit note is to be mailed.",
                "example": ["benjamin.george@bowmanfurniture.com", "paul@bowmanfurniture.com"],
                "items": {"type": "string"},
                "type": "array",
            },
        },
        "required": ["to_mail_ids", "subject", "body"],
        "type": "object",
    },
    "UPDATECREDITNOTEBILLINGADDRESS_REQUEST_BODY_SCHEMA": {
        "properties": {
            "address": {
                "description": "Billing address for the invoice",
                "example": "4900 Hopyard Rd, Suite 310",
                "type": "string",
            },
            "city": {
                "description": "City of the customer's billing address.",
                "example": "Pleasanton",
                "type": "string",
            },
            "country": {
                "description": "Country of the customer's billing address.",
                "example": "USA",
                "type": "string",
            },
            "fax": {
                "description": "Customer's fax number.",
                "example": "+1-925-924-9600",
                "type": "string",
            },
            "state": {
                "description": "State of the customer's billing address.",
                "example": "CA",
                "type": "string",
            },
            "zip": {
                "description": "Zip code of the customer's billing address.",
                "example": 94588,
                "type": "string",
            },
        },
        "type": "object",
    },
    "UPDATECREDITNOTESHIPPINGADDRESS_REQUEST_BODY_SCHEMA": {
        "properties": {
            "address": {
                "description": "Billing address for the invoice",
                "example": "Suite 125, McMillan Avenue",
                "type": "string",
            },
            "city": {
                "description": "City of the customer's billing address.",
                "example": "San Francisco",
                "type": "string",
            },
            "country": {
                "description": "Country of the customer's billing address.",
                "example": "USA",
                "type": "string",
            },
            "fax": {
                "description": "Customer's fax number.",
                "example": "+1-925-924-9600",
                "type": "string",
            },
            "state": {
                "description": "State of the customer's billing address.",
                "example": "CA",
                "type": "string",
            },
            "zip": {
                "description": "Zip code of the customer's billing address.",
                "example": 94134,
                "type": "string",
            },
        },
        "type": "object",
    },
    "APPLYCREDITNOTETOINVOICE_REQUEST_BODY_SCHEMA": {
        "properties": {
            "amount_applied": {
                "description": "The total amount applied form the credit note on an invoice.",
                "example": 41.82,
                "format": "double",
                "type": "number",
            },
            "invoice_id": {
                "description": "Invoice ID of the required invoice.",
                "example": "90300000079426",
                "type": "string",
            },
            "invoices": {
                "description": "List of invoices for which the credit "
                "note has been raised. This contains "
                "<code>invoice_id</code> and "
                "<code>amount</code>.",
                "items": {
                    "properties": {
                        "amount_applied": {
                            "description": "The "
                            "total "
                            "amount "
                            "applied "
                            "form "
                            "the "
                            "credit "
                            "note "
                            "on "
                            "an "
                            "invoice.",
                            "example": 41.82,
                            "format": "double",
                            "type": "number",
                        },
                        "invoice_id": {
                            "description": "Invoice ID of the required invoice.",
                            "example": "90300000079426",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
        },
        "required": ["invoice_id", "amount_applied"],
        "type": "object",
    },
    "ADDCREDITNOTECOMMENT_REQUEST_BODY_SCHEMA": {
        "properties": {
            "description": {
                "description": "A small description about the item.",
                "example": "Credits applied to invoice INV-00004",
                "type": "string",
            }
        },
        "type": "object",
    },
    "REFUNDCREDITNOTE_REQUEST_BODY_SCHEMA": {
        "properties": {
            "amount": {
                "description": "Amount paid for the invoice.",
                "example": 450,
                "format": "double",
                "type": "number",
            },
            "date": {
                "description": "The date on which the credit note is raised. "
                "Must be in yyyy-mm-dd format. This date "
                "determines the accounting period and affects "
                "tax calculations.",
                "example": "2016-06-05",
                "type": "string",
            },
            "description": {
                "description": "Detailed description of the line item. "
                "Provides additional information about "
                "the product or service being credited. "
                "Displayed on the credit note document.",
                "example": "prorated amount for items",
                "type": "string",
            },
            "exchange_rate": {
                "description": "Exchange rate for converting the "
                "credit note currency to base "
                "currency. Required when currency "
                "differs from base currency. Retrieve "
                "rates from currency exchange rate "
                "APIs.",
                "example": "5.5",
                "type": "string",
            },
            "from_account_id": {
                "description": "The account from which credit note is refunded.",
                "example": " ",
                "type": "string",
            },
            "payment_form": {
                "description": "Mode of Vendor Payment",
                "example": "cash",
                "type": "string",
                "x-node_available_in": ["mx"],
                "x-node_unavailable_in": [],
            },
            "reference_number": {
                "description": "Optional reference number for "
                "tracking purposes. Can be any "
                "custom string or auto-generated. "
                "Useful for linking to external "
                "systems or internal tracking. "
                "Max-Length [100]",
                "example": "INV-384",
                "type": "string",
            },
            "refund_mode": {
                "description": "The method of refund.",
                "example": "cash",
                "type": "string",
            },
        },
        "type": "object",
    },
    "UPDATEREFUNDTRANSACTION_REQUEST_BODY_SCHEMA": {
        "properties": {
            "amount": {
                "description": "Amount paid for the invoice.",
                "example": 450,
                "format": "double",
                "type": "number",
            },
            "date": {
                "description": "The date on which the credit note is raised. "
                "Must be in yyyy-mm-dd format. This date "
                "determines the accounting period and affects "
                "tax calculations.",
                "example": "2016-06-05",
                "type": "string",
            },
            "description": {
                "description": "Detailed description of the line item. "
                "Provides additional information about "
                "the product or service being credited. "
                "Displayed on the credit note document.",
                "example": "prorated amount for items",
                "type": "string",
            },
            "exchange_rate": {
                "description": "Exchange rate for converting the "
                "credit note currency to base "
                "currency. Required when currency "
                "differs from base currency. Retrieve "
                "rates from currency exchange rate "
                "APIs.",
                "example": "5.5",
                "type": "string",
            },
            "from_account_id": {
                "description": "The account from which credit note is refunded.",
                "example": " ",
                "type": "string",
            },
            "payment_form": {
                "description": "Mode of Vendor Payment",
                "example": "cash",
                "type": "string",
                "x-node_available_in": ["mx"],
                "x-node_unavailable_in": [],
            },
            "reference_number": {
                "description": "Optional reference number for "
                "tracking purposes. Can be any "
                "custom string or auto-generated. "
                "Useful for linking to external "
                "systems or internal tracking. "
                "Max-Length [100]",
                "example": "INV-384",
                "type": "string",
            },
            "refund_mode": {
                "description": "The method of refund.",
                "example": "cash",
                "type": "string",
            },
        },
        "type": "object",
    },
    "CREATECURRENCY_REQUEST_BODY_SCHEMA": {
        "properties": {
            "currency_code": {
                "description": "A unique standard code for the currency. Max-len [100]",
                "example": "AUD",
                "type": "string",
            },
            "currency_format": {
                "description": "The format for the currency to be displayed. Max-len [100]",
                "example": "1,234,567.89",
                "type": "string",
            },
            "currency_symbol": {
                "description": "A unique symbol for the currency. Max-len [4]",
                "example": "$",
                "type": "string",
            },
            "price_precision": {
                "description": "The precision for the price",
                "example": 2,
                "type": "integer",
            },
        },
        "required": ["currency_code", "currency_format"],
        "type": "object",
    },
    "UPDATECURRENCYDETAILS_REQUEST_BODY_SCHEMA": {
        "properties": {
            "currency_code": {
                "description": "A unique standard code for the currency. Max-len [100]",
                "example": "AUD",
                "type": "string",
            },
            "currency_format": {
                "description": "The format for the currency to be displayed. Max-len [100]",
                "example": "1,234,567.89",
                "type": "string",
            },
            "currency_symbol": {
                "description": "A unique symbol for the currency. Max-len [4]",
                "example": "$",
                "type": "string",
            },
            "price_precision": {
                "description": "The precision for the price",
                "example": 2,
                "type": "integer",
            },
        },
        "required": ["currency_code", "currency_format"],
        "type": "object",
    },
    "CREATEEXCHANGERATE_REQUEST_BODY_SCHEMA": {
        "properties": {
            "effective_date": {
                "description": "Date which the exchange rate is applicable for the currency.",
                "example": "2013-09-04",
                "type": "string",
            },
            "rate": {
                "description": "Rate of exchange for the currency with respect to base currency.",
                "example": 1.23,
                "format": "double",
                "type": "number",
            },
        },
        "type": "object",
    },
    "UPDATEEXCHANGERATE_REQUEST_BODY_SCHEMA": {
        "properties": {
            "effective_date": {
                "description": "Date which the exchange rate is applicable for the currency.",
                "example": "2013-09-04",
                "type": "string",
            },
            "rate": {
                "description": "Rate of exchange for the currency with respect to base currency.",
                "example": 1.23,
                "format": "double",
                "type": "number",
            },
        },
        "type": "object",
    },
    "UPDATECUSTOMMODULERECORDS_REQUEST_BODY_SCHEMA": {
        "properties": {
            "cf_debt_amount": {
                "description": "Value of the custom Field",
                "example": 10000,
                "type": "number",
            },
            "module_record_id": {
                "description": "Reeccord IDs",
                "example": "460000000639128,460000000639129",
                "type": "string",
            },
            "record_name": {
                "description": "Name of the record",
                "example": "Alice",
                "type": "string",
            },
        },
        "required": ["record_name"],
        "type": "object",
    },
    "CREATECUSTOMMODULE_REQUEST_BODY_SCHEMA": {
        "properties": {
            "cf_debt_amount": {
                "description": "Value of the custom Field",
                "example": 10000,
                "type": "number",
            },
            "record_name": {
                "description": "Name of the record",
                "example": "Alice",
                "type": "string",
            },
        },
        "required": ["record_name"],
        "type": "object",
    },
    "UPDATECUSTOMMODULERECORD_REQUEST_BODY_SCHEMA": {
        "properties": {
            "cf_debt_amount": {
                "description": "Value of the custom Field",
                "example": 10000,
                "type": "number",
            },
            "record_name": {
                "description": "Name of the record",
                "example": "Alice",
                "type": "string",
            },
        },
        "required": ["record_name"],
        "type": "object",
    },
    "CREATECUSTOMERDEBITNOTE_REQUEST_BODY_SCHEMA": {
        "properties": {
            "contact_persons": {
                "description": "List of contact person IDs",
                "items": {"type": "string"},
                "type": "array",
            },
            "currency_id": {
                "description": "Unique identifier for the currency",
                "example": "982000000000001",
                "type": "string",
            },
            "custom_fields": {
                "items": {
                    "properties": {
                        "customfield_id": {"type": "string"},
                        "value": {"type": "string"},
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "customer_id": {
                "description": "Unique identifier for the customer",
                "example": "982000000567001",
                "type": "string",
            },
            "date": {"description": "Debit note date", "example": "2013-11-17", "type": "string"},
            "due_date": {"description": "Due date", "example": "2013-12-02", "type": "string"},
            "exchange_rate": {"description": "Exchange rate", "example": 1, "type": "number"},
            "invoice_number": {
                "description": "Debit note number",
                "example": "DN-00001",
                "type": "string",
            },
            "line_items": {
                "items": {
                    "properties": {
                        "description": {
                            "description": "Description",
                            "example": "Desktop Units",
                            "type": "string",
                        },
                        "hsn_or_sac": {
                            "description": "HSN or SAC code",
                            "example": "80540",
                            "type": "string",
                        },
                        "item_id": {
                            "description": "Item ID",
                            "example": "982000000030049",
                            "type": "string",
                        },
                        "location_id": {
                            "description": "Location ID",
                            "example": "460000000038080",
                            "type": "string",
                        },
                        "quantity": {"description": "Quantity", "example": 2, "type": "number"},
                        "rate": {"description": "Rate", "example": 20, "type": "number"},
                        "tax_id": {
                            "description": "Tax ID",
                            "example": "982000000567104",
                            "type": "string",
                        },
                    },
                    "required": ["item_id"],
                    "type": "object",
                },
                "type": "array",
            },
            "location_id": {
                "description": "Location ID",
                "example": "460000000038080",
                "type": "string",
            },
            "payment_terms": {
                "description": "Payment terms in days",
                "example": 15,
                "type": "integer",
            },
            "payment_terms_label": {
                "description": "Payment terms label",
                "example": "Net 15",
                "type": "string",
            },
            "reference_invoice_id": {
                "description": "Invoice ID",
                "example": "982000000567005",
                "type": "string",
            },
            "reference_invoice_type": {
                "description": "Invoice type description",
                "example": "registered",
                "type": "string",
            },
            "type": {
                "description": "Type of the document. For customer debit "
                "notes, this should be <code>debit_note</code>",
                "enum": ["debit_note"],
                "example": "debit_note",
                "type": "string",
            },
        },
        "required": ["customer_id", "line_items", "type", "reference_invoice_id"],
        "type": "object",
    },
    "UPDATECUSTOMERDEBITNOTE_REQUEST_BODY_SCHEMA": {
        "properties": {
            "currency_id": {
                "description": "Unique identifier for the currency",
                "example": "982000000000001",
                "type": "string",
            },
            "custom_fields": {
                "items": {
                    "properties": {
                        "customfield_id": {"type": "string"},
                        "value": {"type": "string"},
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "customer_id": {
                "description": "Unique identifier for the customer",
                "example": "982000000567001",
                "type": "string",
            },
            "date": {"description": "Debit note date", "example": "2013-11-17", "type": "string"},
            "discount": {"description": "Discount amount", "example": 0, "type": "number"},
            "due_date": {"description": "Due date", "example": "2013-12-02", "type": "string"},
            "exchange_rate": {"description": "Exchange rate", "example": 1, "type": "number"},
            "invoice_number": {
                "description": "Debit note number",
                "example": "DN-00001",
                "type": "string",
            },
            "line_items": {
                "items": {
                    "properties": {
                        "description": {
                            "description": "Description",
                            "example": "Desktop Units",
                            "type": "string",
                        },
                        "hsn_or_sac": {
                            "description": "HSN or SAC code",
                            "example": "80540",
                            "type": "string",
                        },
                        "item_id": {
                            "description": "Item ID",
                            "example": "982000000030049",
                            "type": "string",
                        },
                        "item_total": {
                            "description": "Item total",
                            "example": 40,
                            "type": "number",
                        },
                        "location_id": {
                            "description": "Location ID",
                            "example": "460000000038080",
                            "type": "string",
                        },
                        "product_type": {
                            "description": "Product type",
                            "example": "goods",
                            "type": "string",
                        },
                        "quantity": {"description": "Quantity", "example": 2, "type": "number"},
                        "rate": {"description": "Rate", "example": 20, "type": "number"},
                        "tax_id": {
                            "description": "Tax ID",
                            "example": "982000000567104",
                            "type": "string",
                        },
                        "unit": {"description": "Unit", "example": "Nos", "type": "string"},
                    },
                    "required": ["item_id"],
                    "type": "object",
                },
                "type": "array",
            },
            "location_id": {
                "description": "Location ID",
                "example": "460000000038080",
                "type": "string",
            },
            "payment_terms": {
                "description": "Payment terms in days",
                "example": 15,
                "type": "integer",
            },
            "payment_terms_label": {
                "description": "Payment terms label",
                "example": "Net 15",
                "type": "string",
            },
            "template_id": {
                "description": "Template ID",
                "example": "982000000000143",
                "type": "string",
            },
            "type": {
                "description": "Type of the document. For customer debit "
                "notes, this should be debit_note",
                "enum": ["debit_note"],
                "example": "debit_note",
                "type": "string",
            },
        },
        "required": ["customer_id", "line_items"],
        "type": "object",
    },
    "CREATECUSTOMERPAYMENT_REQUEST_BODY_SCHEMA": {
        "properties": {
            "account_id": {
                "description": "ID of the cash/bank account the payment has to be deposited.",
                "example": " ",
                "type": "string",
            },
            "amount": {
                "description": "Amount paid in the respective payment.",
                "example": 450,
                "format": "double",
                "type": "number",
            },
            "amount_applied": {
                "description": "Amount paid for the invoice.",
                "example": 450,
                "format": "double",
                "type": "number",
            },
            "bank_charges": {
                "description": "Denotes any additional bank charges.",
                "example": 10,
                "format": "double",
                "type": "number",
            },
            "contact_persons": {
                "description": "IDs of the contact personsthe thank you mail has to be triggered.",
                "example": ["982000000870911", "982000000870915"],
                "items": {"type": "string"},
                "type": "array",
            },
            "custom_fields": {
                "description": "Additional fields for the payments.",
                "items": {
                    "properties": {
                        "label": {
                            "description": "Label of the custom field.",
                            "example": "label",
                            "type": "string",
                        },
                        "value": {
                            "description": "Value of the custom field.",
                            "example": 129890,
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "customer_id": {
                "description": "Customer ID of the customer involved in the payment.",
                "example": "903000000000099",
                "type": "string",
            },
            "date": {
                "description": "Date on which payment is made. Format [yyyy-mm-dd]",
                "example": "2016-06-05",
                "type": "string",
            },
            "description": {
                "description": "Description about the payment.",
                "example": "Payment has been added to INV-384",
                "type": "string",
            },
            "exchange_rate": {
                "default": 1,
                "description": "Exchange rate for the currency used "
                "in the invoices and customer's "
                "currency. The payment amount would "
                "be the multiplicative product of the "
                "original amount and the exchange "
                "rate.",
                "example": 1,
                "format": "double",
                "type": "number",
            },
            "invoice_id": {
                "description": "Invoice ID of the required invoice.",
                "example": "90300000079426",
                "type": "string",
            },
            "invoices": {
                "description": "List of invoices associated with the "
                "payment. Each invoice object contains "
                "<code>invoice_id</code>, "
                "<code>invoice_number</code>, "
                "<code>date</code>, "
                "<code>invoice_amount</code>, "
                "<code>amount_applied</code> and "
                "<code>balance_amount</code>.",
                "items": {
                    "properties": {
                        "amount_applied": {
                            "description": "Amount paid for the invoice.",
                            "example": 450,
                            "format": "double",
                            "type": "number",
                        },
                        "invoice_id": {
                            "description": "Invoice ID of the required invoice.",
                            "example": "90300000079426",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "location_id": {
                "description": "Location ID",
                "example": "460000000038080",
                "type": "string",
            },
            "payment_form": {
                "description": "Mode of Vendor Payment",
                "example": "cash",
                "type": "string",
                "x-node_available_in": ["mx"],
                "x-node_unavailable_in": [],
            },
            "payment_mode": {
                "description": "Mode through which payment is made. "
                "This can be <code>check</code>, "
                "<code>cash</code>, "
                "<code>creditcard</code>, "
                "<code>banktransfer</code>, "
                "<code>bankremittance</code>, "
                "<code>autotransaction</code> or "
                "<code>others</code>. Max-length [100]",
                "example": "cash",
                "type": "string",
            },
            "reference_number": {
                "description": "Reference number generated for "
                "the payment. A string of your "
                "choice can also be used as the "
                "reference number. Max-length "
                "[100]",
                "example": "INV-384",
                "type": "string",
            },
            "retainerinvoice_id": {
                "description": "ID of the retainer invoice associated with the payment",
                "example": "982000000567114",
                "type": "string",
            },
            "tax_amount_withheld": {
                "description": "Amount withheld for tax.",
                "example": 0,
                "format": "double",
                "type": "number",
            },
        },
        "required": [
            "customer_id",
            "payment_mode",
            "amount",
            "invoices",
            "date",
            "invoice_id",
            "amount_applied",
        ],
        "type": "object",
    },
    "UPDATEPAYMENTBYCUSTOMFIELD_REQUEST_BODY_SCHEMA": {
        "properties": {
            "account_id": {
                "description": "ID of the cash/bank account the payment has to be deposited.",
                "example": " ",
                "type": "string",
            },
            "amount": {
                "description": "Amount paid in the respective payment.",
                "example": 450,
                "format": "double",
                "type": "number",
            },
            "amount_applied": {
                "description": "Amount paid for the invoice.",
                "example": 450,
                "format": "double",
                "type": "number",
            },
            "bank_charges": {
                "description": "Denotes any additional bank charges.",
                "example": 10,
                "format": "double",
                "type": "number",
            },
            "custom_fields": {
                "description": "Additional fields for the payments.",
                "items": {
                    "properties": {
                        "label": {
                            "description": "Label of the custom field.",
                            "example": "label",
                            "type": "string",
                        },
                        "value": {
                            "description": "Value of the custom field.",
                            "example": 129890,
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "customer_id": {
                "description": "Customer ID of the customer involved in the payment.",
                "example": "903000000000099",
                "type": "string",
            },
            "date": {
                "description": "Date on which payment is made. Format [yyyy-mm-dd]",
                "example": "2016-06-05",
                "type": "string",
            },
            "description": {
                "description": "Description about the payment.",
                "example": "Payment has been added to INV-384",
                "type": "string",
            },
            "exchange_rate": {
                "default": 1,
                "description": "Exchange rate for the currency used "
                "in the invoices and customer's "
                "currency. The payment amount would "
                "be the multiplicative product of the "
                "original amount and the exchange "
                "rate.",
                "example": 1,
                "format": "double",
                "type": "number",
            },
            "invoice_id": {
                "description": "Invoice ID of the required invoice.",
                "example": "90300000079426",
                "type": "string",
            },
            "invoices": {
                "description": "List of invoices associated with the "
                "payment. Each invoice object contains "
                "<code>invoice_id</code>, "
                "<code>invoice_number</code>, "
                "<code>date</code>, "
                "<code>invoice_amount</code>, "
                "<code>amount_applied</code> and "
                "<code>balance_amount</code>.",
                "items": {
                    "properties": {
                        "amount_applied": {
                            "description": "Amount paid for the invoice.",
                            "example": 450,
                            "format": "double",
                            "type": "number",
                        },
                        "invoice_id": {
                            "description": "Invoice ID of the required invoice.",
                            "example": "90300000079426",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "location_id": {
                "description": "Location ID",
                "example": "460000000038080",
                "type": "string",
            },
            "payment_form": {
                "description": "Mode of Vendor Payment",
                "example": "cash",
                "type": "string",
                "x-node_available_in": ["mx"],
                "x-node_unavailable_in": [],
            },
            "payment_mode": {
                "description": "Mode through which payment is made. "
                "This can be <code>check</code>, "
                "<code>cash</code>, "
                "<code>creditcard</code>, "
                "<code>banktransfer</code>, "
                "<code>bankremittance</code>, "
                "<code>autotransaction</code> or "
                "<code>others</code>. Max-length [100]",
                "example": "cash",
                "type": "string",
            },
            "reference_number": {
                "description": "Reference number generated for "
                "the payment. A string of your "
                "choice can also be used as the "
                "reference number. Max-length "
                "[100]",
                "example": "INV-384",
                "type": "string",
            },
            "retainerinvoice_id": {
                "description": "ID of the retainer invoice associated with the payment",
                "example": "982000000567114",
                "type": "string",
            },
            "tax_amount_withheld": {
                "description": "Amount withheld for tax.",
                "example": 0,
                "format": "double",
                "type": "number",
            },
        },
        "required": [
            "customer_id",
            "payment_mode",
            "amount",
            "invoices",
            "invoice_id",
            "amount_applied",
        ],
        "type": "object",
    },
    "UPDATECUSTOMERPAYMENTINFO_REQUEST_BODY_SCHEMA": {
        "properties": {
            "account_id": {
                "description": "ID of the cash/bank account the payment has to be deposited.",
                "example": " ",
                "type": "string",
            },
            "amount": {
                "description": "Amount paid in the respective payment.",
                "example": 450,
                "format": "double",
                "type": "number",
            },
            "amount_applied": {
                "description": "Amount paid for the invoice.",
                "example": 450,
                "format": "double",
                "type": "number",
            },
            "bank_charges": {
                "description": "Denotes any additional bank charges.",
                "example": 10,
                "format": "double",
                "type": "number",
            },
            "custom_fields": {
                "description": "Additional fields for the payments.",
                "items": {
                    "properties": {
                        "label": {
                            "description": "Label of the custom field.",
                            "example": "label",
                            "type": "string",
                        },
                        "value": {
                            "description": "Value of the custom field.",
                            "example": 129890,
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "customer_id": {
                "description": "Customer ID of the customer involved in the payment.",
                "example": "903000000000099",
                "type": "string",
            },
            "date": {
                "description": "Date on which payment is made. Format [yyyy-mm-dd]",
                "example": "2016-06-05",
                "type": "string",
            },
            "description": {
                "description": "Description about the payment.",
                "example": "Payment has been added to INV-384",
                "type": "string",
            },
            "exchange_rate": {
                "default": 1,
                "description": "Exchange rate for the currency used "
                "in the invoices and customer's "
                "currency. The payment amount would "
                "be the multiplicative product of the "
                "original amount and the exchange "
                "rate.",
                "example": 1,
                "format": "double",
                "type": "number",
            },
            "invoice_id": {
                "description": "Invoice ID of the required invoice.",
                "example": "90300000079426",
                "type": "string",
            },
            "invoices": {
                "description": "List of invoices associated with the "
                "payment. Each invoice object contains "
                "<code>invoice_id</code>, "
                "<code>invoice_number</code>, "
                "<code>date</code>, "
                "<code>invoice_amount</code>, "
                "<code>amount_applied</code> and "
                "<code>balance_amount</code>.",
                "items": {
                    "properties": {
                        "amount_applied": {
                            "description": "Amount paid for the invoice.",
                            "example": 450,
                            "format": "double",
                            "type": "number",
                        },
                        "invoice_id": {
                            "description": "Invoice ID of the required invoice.",
                            "example": "90300000079426",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "location_id": {
                "description": "Location ID",
                "example": "460000000038080",
                "type": "string",
            },
            "payment_form": {
                "description": "Mode of Vendor Payment",
                "example": "cash",
                "type": "string",
                "x-node_available_in": ["mx"],
                "x-node_unavailable_in": [],
            },
            "payment_mode": {
                "description": "Mode through which payment is made. "
                "This can be <code>check</code>, "
                "<code>cash</code>, "
                "<code>creditcard</code>, "
                "<code>banktransfer</code>, "
                "<code>bankremittance</code>, "
                "<code>autotransaction</code> or "
                "<code>others</code>. Max-length [100]",
                "example": "cash",
                "type": "string",
            },
            "reference_number": {
                "description": "Reference number generated for "
                "the payment. A string of your "
                "choice can also be used as the "
                "reference number. Max-length "
                "[100]",
                "example": "INV-384",
                "type": "string",
            },
            "retainerinvoice_id": {
                "description": "ID of the retainer invoice associated with the payment",
                "example": "982000000567114",
                "type": "string",
            },
            "tax_amount_withheld": {
                "description": "Amount withheld for tax.",
                "example": 0,
                "format": "double",
                "type": "number",
            },
        },
        "required": [
            "customer_id",
            "payment_mode",
            "amount",
            "invoices",
            "invoice_id",
            "amount_applied",
        ],
        "type": "object",
    },
    "REFUNDEXCESSPAYMENT_REQUEST_BODY_SCHEMA": {
        "properties": {
            "amount": {
                "description": "Amount paid in the respective payment.",
                "example": 450,
                "format": "double",
                "type": "number",
            },
            "date": {
                "description": "Date on which payment is made. Format [yyyy-mm-dd]",
                "example": "2016-06-05",
                "type": "string",
            },
            "description": {
                "description": "Description about the payment.",
                "example": "Payment has been added to INV-384",
                "type": "string",
            },
            "exchange_rate": {
                "default": 1,
                "description": "Exchange rate for the currency used "
                "in the invoices and customer's "
                "currency. The payment amount would "
                "be the multiplicative product of the "
                "original amount and the exchange "
                "rate.",
                "example": 1,
                "format": "double",
                "type": "number",
            },
            "from_account_id": {
                "description": "The account from which payment is refunded.",
                "example": " ",
                "type": "string",
            },
            "payment_form": {
                "description": "Mode of Vendor Payment",
                "example": "cash",
                "type": "string",
                "x-node_available_in": ["mx"],
                "x-node_unavailable_in": [],
            },
            "reference_number": {
                "description": "Reference number generated for "
                "the payment. A string of your "
                "choice can also be used as the "
                "reference number. Max-length "
                "[100]",
                "example": "INV-384",
                "type": "string",
            },
            "refund_mode": {
                "description": "The method of refund. Max-length [50]",
                "example": "cash",
                "type": "string",
            },
        },
        "required": ["date", "amount", "from_account_id"],
        "type": "object",
    },
    "UPDATECUSTOMERPAYMENTCUSTOMFIELDS_REQUEST_BODY_SCHEMA": {
        "description": "Custom fields for an invoice.",
        "items": {
            "properties": {
                "customfield_id": {
                    "example": "46000000012845",
                    "format": "int64",
                    "type": "integer",
                },
                "value": {
                    "description": "Value of the custom field.",
                    "example": 129890,
                    "type": "string",
                },
            },
            "type": "object",
        },
        "type": "array",
    },
    "UPDATEPAYMENTREFUND_REQUEST_BODY_SCHEMA": {
        "properties": {
            "amount": {
                "description": "Amount paid in the respective payment.",
                "example": 450,
                "format": "double",
                "type": "number",
            },
            "date": {
                "description": "Date on which payment is made. Format [yyyy-mm-dd]",
                "example": "2016-06-05",
                "type": "string",
            },
            "description": {
                "description": "Description about the payment.",
                "example": "Payment has been added to INV-384",
                "type": "string",
            },
            "exchange_rate": {
                "default": 1,
                "description": "Exchange rate for the currency used "
                "in the invoices and customer's "
                "currency. The payment amount would "
                "be the multiplicative product of the "
                "original amount and the exchange "
                "rate.",
                "example": 1,
                "format": "double",
                "type": "number",
            },
            "from_account_id": {
                "description": "The account from which payment is refunded.",
                "example": " ",
                "type": "string",
            },
            "payment_form": {
                "description": "Mode of Vendor Payment",
                "example": "cash",
                "type": "string",
                "x-node_available_in": ["mx"],
                "x-node_unavailable_in": [],
            },
            "reference_number": {
                "description": "Reference number generated for "
                "the payment. A string of your "
                "choice can also be used as the "
                "reference number. Max-length "
                "[100]",
                "example": "INV-384",
                "type": "string",
            },
            "refund_mode": {
                "description": "The method of refund. Max-length [50]",
                "example": "cash",
                "type": "string",
            },
        },
        "required": ["date", "amount", "from_account_id"],
        "type": "object",
    },
    "CREATECUSTOMERESTIMATE_REQUEST_BODY_SCHEMA": {
        "properties": {
            "accept_retainer": {
                "description": "Boolean flag indicating whether a "
                "retainer invoice should be "
                "automatically created if the "
                "customer accepts this estimate. "
                "When set to <code>true</code>, a "
                "retainer invoice is generated upon "
                "acceptance, streamlining the "
                "process for upfront payments or "
                "deposits. Allowed values: "
                "<code>true</code> and "
                "<code>false</code>.",
                "example": True,
                "type": "boolean",
            },
            "adjustment": {
                "description": "Additional charge or credit amount "
                "applied to the estimate total. This can "
                "be used for rounding adjustments, "
                "handling fees, or any other one-time "
                "charges/credits. Positive values add to "
                "the total, negative values reduce the "
                "total. This amount is applied after tax "
                "calculation and affects the final "
                "estimate total.",
                "example": 0,
                "format": "double",
                "type": "number",
            },
            "adjustment_description": {
                "description": "Text description explaining "
                "the reason for the "
                "adjustment amount. This "
                "description appears on the "
                "estimate document to "
                "explain why the adjustment "
                "was applied. Common "
                'examples include "Rounding '
                'adjustment", "Handling '
                'fee", "Early payment '
                'discount", or "Late payment '
                'fee". This helps customers '
                "understand the purpose of "
                "the adjustment.",
                "example": " ",
                "type": "string",
            },
            "avatax_exempt_no": {
                "description": "Exemption certificate number of the customer.",
                "type": "string",
                "x-node_available_in": ["Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "avatax_use_code": {
                "description": "Used to group like customers for "
                "exemption purposes. It is a custom "
                "value that links customers to a "
                "tax rule. Select from Avalara "
                "[standard codes][1] or enter a "
                "custom code.",
                "type": "string",
                "x-node_available_in": ["Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "contact_persons_associated": {
                "description": "Contact Persons associated with the estimate.",
                "items": {
                    "properties": {
                        "communication_preference": {
                            "description": "Preferred "
                            "modes "
                            "of "
                            "communication "
                            "for "
                            "the "
                            "contact "
                            "person "
                            "at "
                            "transaction "
                            "level.",
                            "properties": {
                                "is_email_enabled": {
                                    "description": "Used "
                                    "to "
                                    "check "
                                    "if "
                                    "Email "
                                    "communication "
                                    "preference "
                                    "is "
                                    "enabled "
                                    "for "
                                    "the "
                                    "contact "
                                    "person "
                                    "at "
                                    "transaction "
                                    "level.",
                                    "example": True,
                                    "type": "boolean",
                                },
                                "is_whatsapp_enabled": {
                                    "description": "Used "
                                    "to "
                                    "check "
                                    "if "
                                    "WhatsApp "
                                    "communication "
                                    "preference "
                                    "is "
                                    "enabled "
                                    "for "
                                    "the "
                                    "contact "
                                    "person "
                                    "at "
                                    "transaction "
                                    "level.",
                                    "example": True,
                                    "type": "boolean",
                                    "x-node_available_in": ["WhatsApp integration"],
                                },
                            },
                            "type": "object",
                        },
                        "contact_person_id": {
                            "description": "Unique ID of the Contact Person.",
                            "example": 982000000567003,
                            "format": "int64",
                            "type": "integer",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "currency_id": {
                "description": "The ID of the currency in which the "
                "estimate will be created. Use this to "
                "specify the customer's preferred "
                "currency for transactions. Fetch valid "
                "currency IDs using the Currency API "
                "(GET /currencies).",
                "example": 982000000000190,
                "type": "string",
            },
            "custom_body": {"example": " ", "type": "string"},
            "custom_fields": {
                "description": "Custom fields for an estimate.",
                "items": {
                    "properties": {
                        "index": {"example": 1, "type": "integer"},
                        "value": {"example": "15 Dec 2013", "type": "string"},
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "custom_subject": {"example": " ", "type": "string"},
            "customer_id": {
                "description": "The ID of the customer (contact) for "
                "whom the estimate is created. This "
                "must be a valid contact ID from your "
                "organization; obtain it using the "
                "Contacts API (GET /contacts) or the "
                "Create Contact response.",
                "example": 982000000567001,
                "type": "string",
            },
            "date": {
                "description": "Search estimates by estimate date.Variants "
                "<code>date_start</code>, "
                "<code>date_end</code>, "
                "<code>date_before</code> and "
                "<code>date_after</code>",
                "example": "2013-11-18",
                "type": "string",
            },
            "description": {
                "description": "Detailed description of the product or "
                "service in this line item. Use this "
                "field to provide specifications, "
                "features, or any other relevant "
                "information that helps the customer "
                "understand about the line item.",
                "example": "500GB, USB 2.0 interface 1400 rpm, protective hard case.",
                "type": "string",
            },
            "discount": {
                "description": "Discount applied to the estimate. It can "
                "be either in % or in amount. e.g. 12.5% "
                "or 190.",
                "example": 0,
                "format": "double",
                "type": "number",
            },
            "discount_type": {
                "description": "How the discount is specified. "
                "Allowed values are entity_level or "
                "item_level.Allowed Values: "
                "<code>entity_level</code> and "
                "<code>item_level</code>",
                "example": "item_level",
                "type": "string",
            },
            "estimate_number": {
                "description": "Search estimates by estimate "
                "number.Variants<code>estimate_number_startswith</code> "
                "and "
                "<code>estimate_number_contains</code>",
                "example": "EST-00002",
                "type": "string",
            },
            "exchange_rate": {
                "description": "Exchange rate of the currency.",
                "example": 1,
                "format": "double",
                "type": "number",
            },
            "expiry_date": {
                "description": "The date of expiration of the estimates",
                "example": "2013-11-30",
                "type": "string",
            },
            "gst_no": {
                "description": "15 digit GST identification number of the customer.",
                "example": "22AAAAA0000A1Z5",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "gst_treatment": {
                "description": "Choose whether the contact is GST "
                "registered/unregistered/consumer/overseas. "
                "Allowed values are <code> "
                "business_gst </code> , <code> "
                "business_none </code> , <code> "
                "overseas </code> , <code> consumer "
                "</code>.",
                "example": "business_gst",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "is_discount_before_tax": {
                "description": "Used to specify how the "
                "discount has to applied. "
                "Either before or after the "
                "calculation of tax.",
                "example": True,
                "type": "boolean",
            },
            "is_inclusive_tax": {
                "description": "Used to specify whether the line "
                "item rates are inclusive or "
                "exclusive of tax.",
                "example": False,
                "type": "boolean",
                "x-node_available_in": [],
                "x-node_unavailable_in": ["us", "ca"],
            },
            "is_reverse_charge_applied": {
                "description": "(Required if customer "
                "tax treatment is "
                "<code>vat_registered</code>)<br/>Used "
                "to specify whether the "
                "transaction is "
                "applicable for Domestic "
                "Reverse Charge (DRC) or "
                "not.",
                "example": True,
                "type": "boolean",
                "x-node_available_in": ["za"],
                "x-node_unavailable_in": [],
            },
            "item_id": {
                "description": "Unique identifier of the item (product or "
                "service) being quoted in this line item. "
                "Use the `item_id` returned by the Items "
                "API for the same organization. This links "
                "the line item to a specific product or "
                "service in your catalog.",
                "example": " ",
                "type": "string",
            },
            "line_item_id": {
                "description": "Unique identifier of the line item "
                "within the estimate. Required when "
                "updating or referencing a specific "
                "line item. If omitted during "
                "creation, a new line item will be "
                "added.",
                "example": 982000000567021,
                "type": "string",
            },
            "line_items": {
                "description": "Line items of an estimate.",
                "items": {
                    "properties": {
                        "bcy_rate": {
                            "description": "Exchange "
                            "rate "
                            "between "
                            "the "
                            "base "
                            "currency "
                            "and "
                            "the "
                            "transaction "
                            "currency "
                            "for "
                            "this "
                            "line "
                            "item. "
                            "Used "
                            "for "
                            "currency "
                            "conversion "
                            "and "
                            "reporting.",
                            "example": 120,
                            "format": "float",
                            "type": "number",
                        },
                        "description": {
                            "description": "Detailed "
                            "description "
                            "of "
                            "the "
                            "product "
                            "or "
                            "service "
                            "in "
                            "this "
                            "line "
                            "item. "
                            "Use "
                            "this "
                            "field "
                            "to "
                            "provide "
                            "specifications, "
                            "features, "
                            "or "
                            "any "
                            "other "
                            "relevant "
                            "information "
                            "that "
                            "helps "
                            "the "
                            "customer "
                            "understand "
                            "about "
                            "the "
                            "line "
                            "item.",
                            "example": "500GB, USB 2.0 interface 1400 rpm, protective hard case.",
                            "type": "string",
                        },
                        "discount": {
                            "description": "Discount "
                            "applied "
                            "to "
                            "the "
                            "estimate. "
                            "It "
                            "can "
                            "be "
                            "either "
                            "in "
                            "% "
                            "or "
                            "in "
                            "amount. "
                            "e.g. "
                            "12.5% "
                            "or "
                            "190.",
                            "example": 0,
                            "format": "double",
                            "type": "number",
                        },
                        "discount_amount": {
                            "description": "Discount "
                            "amount "
                            "applied "
                            "to "
                            "this "
                            "line "
                            "item. "
                            "This "
                            "value "
                            "reduces "
                            "the "
                            "line "
                            "item "
                            "total "
                            "before "
                            "tax "
                            "calculation.",
                            "example": 0,
                            "format": "float",
                            "type": "number",
                        },
                        "hsn_or_sac": {
                            "description": "Add HSN/SAC code for your goods/services",
                            "example": 80540,
                            "type": "string",
                            "x-node_available_in": ["in", "ke", "za"],
                            "x-node_unavailable_in": [],
                        },
                        "item_id": {
                            "description": "Unique "
                            "identifier "
                            "of "
                            "the "
                            "item "
                            "(product "
                            "or "
                            "service) "
                            "being "
                            "quoted "
                            "in "
                            "this "
                            "line "
                            "item. "
                            "Use "
                            "the "
                            "`item_id` "
                            "returned "
                            "by "
                            "the "
                            "Items "
                            "API "
                            "for "
                            "the "
                            "same "
                            "organization. "
                            "This "
                            "links "
                            "the "
                            "line "
                            "item "
                            "to "
                            "a "
                            "specific "
                            "product "
                            "or "
                            "service "
                            "in "
                            "your "
                            "catalog.",
                            "example": " ",
                            "type": "string",
                        },
                        "item_order": {
                            "description": "Sequential "
                            "order "
                            "number "
                            "for "
                            "this "
                            "line "
                            "item "
                            "on "
                            "the "
                            "estimate. "
                            "Determines "
                            "the "
                            "display "
                            "order "
                            "of "
                            "line "
                            "items "
                            "in "
                            "the "
                            "estimate "
                            "document "
                            "— "
                            "lower "
                            "values "
                            "appear "
                            "first. "
                            "Use "
                            "this "
                            "field "
                            "to "
                            "organize "
                            "line "
                            "items "
                            "in "
                            "a "
                            "specific "
                            "sequence.",
                            "example": 1,
                            "type": "integer",
                        },
                        "item_total": {
                            "description": "Total "
                            "amount "
                            "for "
                            "this "
                            "line "
                            "item "
                            "after "
                            "applying "
                            "quantity, "
                            "rate, "
                            "discounts, "
                            "and "
                            "taxes. "
                            "This "
                            "value "
                            "contributes "
                            "to "
                            "the "
                            "overall "
                            "estimate "
                            "total.",
                            "example": 120,
                            "format": "float",
                            "type": "number",
                        },
                        "line_item_id": {
                            "description": "Unique "
                            "identifier "
                            "of "
                            "the "
                            "line "
                            "item "
                            "within "
                            "the "
                            "estimate. "
                            "Required "
                            "when "
                            "updating "
                            "or "
                            "referencing "
                            "a "
                            "specific "
                            "line "
                            "item. "
                            "If "
                            "omitted "
                            "during "
                            "creation, "
                            "a "
                            "new "
                            "line "
                            "item "
                            "will "
                            "be "
                            "added.",
                            "example": 982000000567021,
                            "type": "string",
                        },
                        "location_id": {
                            "description": "Unique "
                            "identifier "
                            "of "
                            "the "
                            "business "
                            "location "
                            "associated "
                            "with "
                            "the "
                            "estimate. "
                            "Use "
                            "the "
                            "`location_id` "
                            "returned "
                            "by "
                            "the "
                            "Locations "
                            "API "
                            "for "
                            "the "
                            "same "
                            "organization. "
                            "This "
                            "links "
                            "the "
                            "estimate "
                            "to "
                            "a "
                            "specific "
                            "business "
                            "location, "
                            "which "
                            "may "
                            "affect "
                            "tax "
                            "calculations, "
                            "reporting, "
                            "and "
                            "business "
                            "operations. "
                            "Required "
                            "if "
                            "your "
                            "organization "
                            "has "
                            "multiple "
                            "locations "
                            "configured.",
                            "example": "460000000038080",
                            "type": "string",
                        },
                        "name": {
                            "description": "Name "
                            "of "
                            "the "
                            "product "
                            "or "
                            "service "
                            "for "
                            "this "
                            "line "
                            "item. "
                            "This "
                            "is "
                            "displayed "
                            "on "
                            "the "
                            "estimate "
                            "document "
                            "and "
                            "helps "
                            "the "
                            "customer "
                            "identify "
                            "what "
                            "is "
                            "being "
                            "quoted.",
                            "example": "Hard Drive",
                            "type": "string",
                        },
                        "product_type": {
                            "description": "Type "
                            "of "
                            "product "
                            "or "
                            "service "
                            "for "
                            "this "
                            "line "
                            "item. "
                            "Allowed "
                            "values: "
                            "<code>goods</code> "
                            "or "
                            "<code>services</code>. "
                            "For "
                            "South "
                            "Africa "
                            "Edition, "
                            "additional "
                            "values "
                            "include "
                            "<code>capital_service</code> "
                            "and "
                            "<code>capital_goods</code>. "
                            "This "
                            "classification "
                            "affects "
                            "tax "
                            "calculations, "
                            "reporting, "
                            "and "
                            "compliance "
                            "requirements "
                            "based "
                            "on "
                            "your "
                            "organization's "
                            "location "
                            "and "
                            "tax "
                            "regulations.",
                            "example": "goods",
                            "type": "string",
                        },
                        "quantity": {
                            "description": "Number "
                            "of "
                            "units "
                            "of "
                            "the "
                            "product "
                            "or "
                            "service "
                            "being "
                            "quoted "
                            "in "
                            "this "
                            "line "
                            "item. "
                            "This "
                            "value "
                            "is "
                            "multiplied "
                            "by "
                            "the "
                            "rate "
                            "to "
                            "calculate "
                            "the "
                            "line "
                            "item "
                            "total.",
                            "example": 1,
                            "format": "double",
                            "type": "number",
                        },
                        "rate": {
                            "description": "Unit "
                            "price "
                            "or "
                            "rate "
                            "for "
                            "the "
                            "product "
                            "or "
                            "service "
                            "in "
                            "this "
                            "line "
                            "item. "
                            "This "
                            "value "
                            "is "
                            "multiplied "
                            "by "
                            "the "
                            "quantity "
                            "to "
                            "determine "
                            "the "
                            "line "
                            "item "
                            "total "
                            "before "
                            "taxes "
                            "and "
                            "discounts.",
                            "example": 120,
                            "format": "double",
                            "type": "number",
                        },
                        "sat_item_key_code": {
                            "description": "Add "
                            "SAT "
                            "Item "
                            "Key "
                            "Code "
                            "for "
                            "your "
                            "goods/services. "
                            "Download "
                            "the "
                            "<a "
                            "href= "
                            "http://omawww.sat.gob.mx/tramitesyservicios/Paginas/documentos/catCFDI_V_4_07122022.xls  "
                            ">CFDI "
                            "Catalogs.</a>",
                            "example": 71121206,
                            "type": "string",
                            "x-node_available_in": ["mx"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_id": {
                            "description": "Unique "
                            "identifier "
                            "of "
                            "the "
                            "tax "
                            "to "
                            "be "
                            "applied "
                            "to "
                            "this "
                            "line "
                            "item. "
                            "Use "
                            "the "
                            "`tax_id` "
                            "returned "
                            "by "
                            "the "
                            "Taxes "
                            "API "
                            "for "
                            "the "
                            "same "
                            "organization. "
                            "This "
                            "determines "
                            "which "
                            "tax "
                            "rate "
                            "and "
                            "rules "
                            "are "
                            "applied "
                            "to "
                            "the "
                            "line "
                            "item, "
                            "affecting "
                            "the "
                            "final "
                            "tax "
                            "calculation "
                            "and "
                            "compliance "
                            "reporting.",
                            "example": 982000000557028,
                            "type": "string",
                        },
                        "tax_name": {
                            "description": "The name of the tax",
                            "example": "VAT",
                            "type": "string",
                        },
                        "tax_percentage": {
                            "description": "The  percentage of tax levied",
                            "example": 12.5,
                            "format": "float",
                            "type": "number",
                        },
                        "tax_treatment_code": {
                            "description": "Specify "
                            "reason "
                            "for "
                            "using "
                            "out "
                            "of "
                            "scope.</br>Supported "
                            "values "
                            "for "
                            "<b>UAE</b> "
                            "are "
                            "<code>uae_same_tax_group</code>, "
                            "<code>uae_reimbursed_expense</code> "
                            "and "
                            "<code>uae_others</code>.</br> "
                            "Supported "
                            "values "
                            "for "
                            "<b>Bahrain</b> "
                            "are "
                            "<code>bahrain_same_tax_group</code>, "
                            "<code>bahrain_transfer_of_concern</code>, "
                            "<code>bahrain_disbursement</code>, "
                            "<code>bahrain_head_to_branch_transaction</code>, "
                            "<code>bahrain_warranty_repair_services</code> "
                            "and "
                            "<code>bahrain_others</code>.</br>Supported "
                            "values "
                            "for "
                            "<b>Saudi "
                            "Arabia</b> "
                            "are "
                            "<code>ksa_pvt_health</code>, "
                            "<code>ksa_pvt_edu</code>, "
                            "<code>ksa_reimbursed_expense</code> "
                            "and "
                            "<code>ksa_house_sales</code>.",
                            "example": "uae_others",
                            "type": "string",
                            "x-node_available_in": ["gcc"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_type": {
                            "description": "The type of the tax",
                            "example": "tax",
                            "type": "string",
                        },
                        "tds_tax_id": {
                            "description": "ID of the TDS tax.",
                            "example": "982000000557012",
                            "type": "string",
                            "x-node_available_in": ["mx"],
                            "x-node_unavailable_in": [],
                        },
                        "unit": {
                            "description": "Unit "
                            "of "
                            "measurement "
                            "for "
                            "the "
                            "product "
                            "or "
                            "service "
                            "in "
                            "this "
                            "line "
                            "item "
                            "(e.g., "
                            "kgs, "
                            "Nos., "
                            "hours). "
                            "Helps "
                            "clarify "
                            "the "
                            "quantity "
                            "being "
                            "quoted.",
                            "example": " ",
                            "type": "string",
                        },
                        "unitkey_code": {
                            "description": "Add "
                            "SAT "
                            "Unit "
                            "Key "
                            "Code "
                            "for "
                            "your "
                            "goods/services. "
                            "Download "
                            "the "
                            "<a "
                            "href= "
                            "http://omawww.sat.gob.mx/tramitesyservicios/Paginas/documentos/catCFDI_V_4_07122022.xls  "
                            ">CFDI "
                            "Catalogs.</a>",
                            "example": "E48",
                            "type": "string",
                            "x-node_available_in": ["mx"],
                            "x-node_unavailable_in": [],
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "location_id": {
                "description": "Unique identifier of the business "
                "location associated with the estimate. "
                "Use the `location_id` returned by the "
                "Locations API for the same "
                "organization. This links the estimate "
                "to a specific business location, which "
                "may affect tax calculations, "
                "reporting, and business operations. "
                "Required if your organization has "
                "multiple locations configured.",
                "example": "460000000038080",
                "type": "string",
            },
            "name": {
                "description": "Name of the product or service for this line "
                "item. This is displayed on the estimate "
                "document and helps the customer identify what "
                "is being quoted.",
                "example": "Hard Drive",
                "type": "string",
            },
            "notes": {
                "description": "Additional information or comments to be "
                "displayed on the estimate document. This "
                "field is typically used for thank you "
                "messages, special instructions, or any other "
                "information you want to communicate to the "
                "customer. The notes appear on the estimate "
                "PDF and are visible to customers.",
                "example": "Looking forward for your business.",
                "type": "string",
            },
            "place_of_supply": {
                "description": "Place where the goods/services are "
                "supplied to. (If not given, "
                "<code>place of contact</code> "
                "given for the contact will be "
                "taken)<br/>Supported codes for UAE "
                "emirates are : </br>Abu Dhabi - "
                "<code>AB</code>,</br>Ajman - "
                "<code>AJ</code>,</br>Dubai - "
                "<code>DU</code>,</br>Fujairah - "
                "<code>FU</code>,</br>Ras "
                "al-Khaimah - "
                "<code>RA</code>,</br>Sharjah - "
                "<code>SH</code>,</br>Umm al-Quwain "
                "- <code>UM</code><br/>Supported "
                "codes for the GCC countries are : "
                "</br>United Arab Emirates - "
                "<code>AE</code>,</br>Saudi Arabia "
                "- <code>SA</code>,</br>Bahrain - "
                "<code>BH</code>,</br>Kuwait - "
                "<code>KW</code>,</br>Oman - "
                "<code>OM</code>,</br>Qatar - "
                "<code>QA</code>.",
                "example": "TN",
                "type": "string",
                "x-node_available_in": ["in", "gcc"],
                "x-node_unavailable_in": [],
            },
            "project_id": {
                "description": "Unique identifier of the project "
                "associated with this estimate. Use the "
                "<code>project_id</code> returned by the "
                "Projects API for the same organization. "
                "Linking an estimate to a project helps "
                "with project-based billing, tracking, "
                "and reporting.",
                "example": 90300000087378,
                "type": "string",
            },
            "quantity": {
                "description": "Number of units of the product or service "
                "being quoted in this line item. This "
                "value is multiplied by the rate to "
                "calculate the line item total.",
                "example": 1,
                "format": "double",
                "type": "number",
            },
            "rate": {
                "description": "Unit price or rate for the product or service "
                "in this line item. This value is multiplied "
                "by the quantity to determine the line item "
                "total before taxes and discounts.",
                "example": 120,
                "format": "double",
                "type": "number",
            },
            "reference_number": {
                "description": "Optional external identifier used "
                "to associate the estimate with "
                "other systems or workflows. Helps "
                "improve traceability and "
                "integration during estimate "
                "creation.",
                "example": "QRT-12346",
                "type": "string",
            },
            "retainer_percentage": {
                "description": "Percentage of the estimate "
                "amount to be collected as a "
                "retainer (upfront payment) "
                "when the estimate is accepted. "
                "Specify a value between 0 and "
                "100. This determines the "
                "portion of the total estimate "
                "that will be invoiced as a "
                "retainer.",
                "example": 10,
                "type": "integer",
            },
            "salesperson_name": {
                "description": "Name of the sales person.",
                "example": "Will smith",
                "type": "string",
            },
            "shipping_charge": {
                "description": "Additional shipping or delivery "
                "charges applied to the estimate. "
                "Must be specified as a fixed "
                'amount (e.g., "25.00"). This '
                "amount is added to the estimate "
                "total and is subject to tax "
                "calculation.",
                "example": 0,
                "type": "string",
            },
            "tax_authority_id": {
                "description": "ID of the tax authority. Tax "
                "authority depends on the location "
                "of the customer. For example, if "
                "the customer is located in NY, "
                "then the tax authority is NY tax "
                "authority.",
                "example": 11149000000061052,
                "type": "string",
                "x-node_available_in": ["us"],
                "x-node_unavailable_in": [],
            },
            "tax_exemption_id": {
                "description": "ID of the tax exemption.",
                "example": 11149000000061054,
                "type": "string",
                "x-node_available_in": ["in", "us"],
                "x-node_unavailable_in": [],
            },
            "tax_id": {
                "description": "Unique identifier of the tax to be applied "
                "to this line item. Use the `tax_id` "
                "returned by the Taxes API for the same "
                "organization. This determines which tax "
                "rate and rules are applied to the line "
                "item, affecting the final tax calculation "
                "and compliance reporting.",
                "example": 982000000557028,
                "type": "string",
            },
            "tax_treatment": {
                "description": "VAT treatment for the Estimate. "
                "Allowed Values: "
                "<code>vat_registered</code>,<code>vat_not_registered</code>,<code>gcc_vat_not_registered</code>,<code>gcc_vat_registered</code>,<code>non_gcc</code>.</br><code>dz_vat_registered</code> "
                "and "
                "<code>dz_vat_not_registered</code> "
                "supported only for "
                "<b>UAE.</b></br><code>home_country_mexico</code>,<code>border_region_mexico</code>,<code>non_mexico</code> "
                "supported only for <b>MX</b>. "
                "<br/><b>For Kenya Edition:</b> "
                "<code>vat_registered</code> "
                ",<code>vat_not_registered</code> "
                ",<code>non_kenya</code>(A business "
                "that is located outside "
                "Kenya).<br/><b>For SouthAfrica "
                "Edition:</b> "
                "<code>vat_registered</code>, "
                "<code>vat_not_registered</code>, "
                "<code>overseas</code>(A business "
                "that is located outside "
                "SouthAfrica).",
                "example": "vat_registered",
                "type": "string",
                "x-node_available_in": ["gcc", "mx", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "template_id": {
                "description": "The ID of the template used for "
                "generating the estimate PDF. Use this "
                "to apply custom branding or formats. "
                "Fetch template IDs using the Templates "
                "API (GET /estimates/templates).",
                "example": 982000000000143,
                "type": "string",
            },
            "terms": {
                "description": "Defines the terms and conditions to be "
                "included in the estimate document. This "
                "field can be used to specify payment terms, "
                "delivery schedules, return policies, or "
                "other transactional details. The terms "
                "appear on the estimate PDF and helps "
                "communicate key conditions related to the "
                "estimate.",
                "example": "Terms & Conditions apply",
                "type": "string",
            },
            "unit": {
                "description": "Unit of measurement for the product or "
                "service in this line item (e.g., kgs, Nos., "
                "hours). Helps clarify the quantity being "
                "quoted.",
                "example": " ",
                "type": "string",
            },
            "vat_treatment": {
                "description": "(Optional) VAT treatment for the "
                "estimates. VAT treatment denotes the "
                "location of the customer, if the "
                "customer resides in UK then the VAT "
                "treatment is <code>uk</code>. If the "
                "customer is in an EU country & VAT "
                "registered, you are resides in "
                "Northen Ireland and selling Goods "
                "then his VAT treatment is "
                "<code>eu_vat_registered</code>, if "
                "he resides outside of the UK then "
                "his VAT treatment is "
                "<code>overseas</code> (For Pre "
                "Brexit, this can be split as "
                "<code>eu_vat_registered</code>, "
                "<code>eu_vat_not_registered</code> "
                "and <code>non_eu</code>).",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
        },
        "required": ["customer_id", "line_items"],
        "type": "object",
    },
    "UPDATEESTIMATEWITHCUSTOMFIELD_REQUEST_BODY_SCHEMA": {
        "properties": {
            "accept_retainer": {
                "description": "Boolean flag indicating whether a "
                "retainer invoice should be "
                "automatically created if the "
                "customer accepts this estimate. "
                "When set to <code>true</code>, a "
                "retainer invoice is generated upon "
                "acceptance, streamlining the "
                "process for upfront payments or "
                "deposits. Allowed values: "
                "<code>true</code> and "
                "<code>false</code>.",
                "example": True,
                "type": "boolean",
            },
            "adjustment": {
                "description": "Additional charge or credit amount "
                "applied to the estimate total. This can "
                "be used for rounding adjustments, "
                "handling fees, or any other one-time "
                "charges/credits. Positive values add to "
                "the total, negative values reduce the "
                "total. This amount is applied after tax "
                "calculation and affects the final "
                "estimate total.",
                "example": 0,
                "format": "double",
                "type": "number",
            },
            "adjustment_description": {
                "description": "Text description explaining "
                "the reason for the "
                "adjustment amount. This "
                "description appears on the "
                "estimate document to "
                "explain why the adjustment "
                "was applied. Common "
                'examples include "Rounding '
                'adjustment", "Handling '
                'fee", "Early payment '
                'discount", or "Late payment '
                'fee". This helps customers '
                "understand the purpose of "
                "the adjustment.",
                "example": " ",
                "type": "string",
            },
            "avatax_exempt_no": {
                "description": "Exemption certificate number of the customer.",
                "type": "string",
                "x-node_available_in": ["Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "avatax_use_code": {
                "description": "Used to group like customers for "
                "exemption purposes. It is a custom "
                "value that links customers to a "
                "tax rule. Select from Avalara "
                "[standard codes][1] or enter a "
                "custom code.",
                "type": "string",
                "x-node_available_in": ["Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "contact_persons_associated": {
                "description": "Contact Persons associated with the estimate.",
                "items": {
                    "properties": {
                        "communication_preference": {
                            "description": "Preferred "
                            "modes "
                            "of "
                            "communication "
                            "for "
                            "the "
                            "contact "
                            "person "
                            "at "
                            "transaction "
                            "level.",
                            "properties": {
                                "is_email_enabled": {
                                    "description": "Used "
                                    "to "
                                    "check "
                                    "if "
                                    "Email "
                                    "communication "
                                    "preference "
                                    "is "
                                    "enabled "
                                    "for "
                                    "the "
                                    "contact "
                                    "person "
                                    "at "
                                    "transaction "
                                    "level.",
                                    "example": True,
                                    "type": "boolean",
                                },
                                "is_whatsapp_enabled": {
                                    "description": "Used "
                                    "to "
                                    "check "
                                    "if "
                                    "WhatsApp "
                                    "communication "
                                    "preference "
                                    "is "
                                    "enabled "
                                    "for "
                                    "the "
                                    "contact "
                                    "person "
                                    "at "
                                    "transaction "
                                    "level.",
                                    "example": True,
                                    "type": "boolean",
                                    "x-node_available_in": ["WhatsApp integration"],
                                },
                            },
                            "type": "object",
                        },
                        "contact_person_id": {
                            "description": "Unique ID of the Contact Person.",
                            "example": 982000000567003,
                            "format": "int64",
                            "type": "integer",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "currency_id": {
                "description": "The ID of the currency in which the "
                "estimate will be created. Use this to "
                "specify the customer's preferred "
                "currency for transactions. Fetch valid "
                "currency IDs using the Currency API "
                "(GET /currencies).",
                "example": 982000000000190,
                "type": "string",
            },
            "custom_body": {"example": " ", "type": "string"},
            "custom_fields": {
                "description": "Custom fields for an estimate.",
                "items": {
                    "properties": {
                        "index": {"example": 1, "type": "integer"},
                        "value": {"example": "15 Dec 2013", "type": "string"},
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "custom_subject": {"example": " ", "type": "string"},
            "customer_id": {
                "description": "The ID of the customer (contact) for "
                "whom the estimate is created. This "
                "must be a valid contact ID from your "
                "organization; obtain it using the "
                "Contacts API (GET /contacts) or the "
                "Create Contact response.",
                "example": 982000000567001,
                "type": "string",
            },
            "date": {
                "description": "Search estimates by estimate date.Variants "
                "<code>date_start</code>, "
                "<code>date_end</code>, "
                "<code>date_before</code> and "
                "<code>date_after</code>",
                "example": "2013-11-18",
                "type": "string",
            },
            "description": {
                "description": "Detailed description of the product or "
                "service in this line item. Use this "
                "field to provide specifications, "
                "features, or any other relevant "
                "information that helps the customer "
                "understand about the line item.",
                "example": "500GB, USB 2.0 interface 1400 rpm, protective hard case.",
                "type": "string",
            },
            "discount": {
                "description": "Discount applied to the estimate. It can "
                "be either in % or in amount. e.g. 12.5% "
                "or 190.",
                "example": 0,
                "format": "double",
                "type": "number",
            },
            "discount_type": {
                "description": "How the discount is specified. "
                "Allowed values are entity_level or "
                "item_level.Allowed Values: "
                "<code>entity_level</code> and "
                "<code>item_level</code>",
                "example": "item_level",
                "type": "string",
            },
            "estimate_number": {
                "description": "Search estimates by estimate "
                "number.Variants<code>estimate_number_startswith</code> "
                "and "
                "<code>estimate_number_contains</code>",
                "example": "EST-00002",
                "type": "string",
            },
            "exchange_rate": {
                "description": "Exchange rate of the currency.",
                "example": 1,
                "format": "double",
                "type": "number",
            },
            "expiry_date": {
                "description": "The date of expiration of the estimates",
                "example": "2013-11-30",
                "type": "string",
            },
            "gst_no": {
                "description": "15 digit GST identification number of the customer.",
                "example": "22AAAAA0000A1Z5",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "gst_treatment": {
                "description": "Choose whether the contact is GST "
                "registered/unregistered/consumer/overseas. "
                "Allowed values are <code> "
                "business_gst </code> , <code> "
                "business_none </code> , <code> "
                "overseas </code> , <code> consumer "
                "</code>.",
                "example": "business_gst",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "is_discount_before_tax": {
                "description": "Used to specify how the "
                "discount has to applied. "
                "Either before or after the "
                "calculation of tax.",
                "example": True,
                "type": "boolean",
            },
            "is_inclusive_tax": {
                "description": "Used to specify whether the line "
                "item rates are inclusive or "
                "exclusive of tax.",
                "example": False,
                "type": "boolean",
                "x-node_available_in": [],
                "x-node_unavailable_in": ["us", "ca"],
            },
            "is_reverse_charge_applied": {
                "description": "(Required if customer "
                "tax treatment is "
                "<code>vat_registered</code>)<br/>Used "
                "to specify whether the "
                "transaction is "
                "applicable for Domestic "
                "Reverse Charge (DRC) or "
                "not.",
                "example": True,
                "type": "boolean",
                "x-node_available_in": ["za"],
                "x-node_unavailable_in": [],
            },
            "item_id": {
                "description": "Unique identifier of the item (product or "
                "service) being quoted in this line item. "
                "Use the `item_id` returned by the Items "
                "API for the same organization. This links "
                "the line item to a specific product or "
                "service in your catalog.",
                "example": " ",
                "type": "string",
            },
            "line_item_id": {
                "description": "Unique identifier of the line item "
                "within the estimate. Required when "
                "updating or referencing a specific "
                "line item. If omitted during "
                "creation, a new line item will be "
                "added.",
                "example": 982000000567021,
                "type": "string",
            },
            "line_items": {
                "description": "Line items of an estimate.",
                "items": {
                    "properties": {
                        "bcy_rate": {
                            "description": "Exchange "
                            "rate "
                            "between "
                            "the "
                            "base "
                            "currency "
                            "and "
                            "the "
                            "transaction "
                            "currency "
                            "for "
                            "this "
                            "line "
                            "item. "
                            "Used "
                            "for "
                            "currency "
                            "conversion "
                            "and "
                            "reporting.",
                            "example": 120,
                            "format": "float",
                            "type": "number",
                        },
                        "description": {
                            "description": "Detailed "
                            "description "
                            "of "
                            "the "
                            "product "
                            "or "
                            "service "
                            "in "
                            "this "
                            "line "
                            "item. "
                            "Use "
                            "this "
                            "field "
                            "to "
                            "provide "
                            "specifications, "
                            "features, "
                            "or "
                            "any "
                            "other "
                            "relevant "
                            "information "
                            "that "
                            "helps "
                            "the "
                            "customer "
                            "understand "
                            "about "
                            "the "
                            "line "
                            "item.",
                            "example": "500GB, USB 2.0 interface 1400 rpm, protective hard case.",
                            "type": "string",
                        },
                        "discount": {
                            "description": "Discount "
                            "applied "
                            "to "
                            "the "
                            "estimate. "
                            "It "
                            "can "
                            "be "
                            "either "
                            "in "
                            "% "
                            "or "
                            "in "
                            "amount. "
                            "e.g. "
                            "12.5% "
                            "or "
                            "190.",
                            "example": 0,
                            "format": "double",
                            "type": "number",
                        },
                        "discount_amount": {
                            "description": "Discount "
                            "amount "
                            "applied "
                            "to "
                            "this "
                            "line "
                            "item. "
                            "This "
                            "value "
                            "reduces "
                            "the "
                            "line "
                            "item "
                            "total "
                            "before "
                            "tax "
                            "calculation.",
                            "example": 0,
                            "format": "float",
                            "type": "number",
                        },
                        "hsn_or_sac": {
                            "description": "Add HSN/SAC code for your goods/services",
                            "example": 80540,
                            "type": "string",
                            "x-node_available_in": ["in", "ke", "za"],
                            "x-node_unavailable_in": [],
                        },
                        "item_id": {
                            "description": "Unique "
                            "identifier "
                            "of "
                            "the "
                            "item "
                            "(product "
                            "or "
                            "service) "
                            "being "
                            "quoted "
                            "in "
                            "this "
                            "line "
                            "item. "
                            "Use "
                            "the "
                            "`item_id` "
                            "returned "
                            "by "
                            "the "
                            "Items "
                            "API "
                            "for "
                            "the "
                            "same "
                            "organization. "
                            "This "
                            "links "
                            "the "
                            "line "
                            "item "
                            "to "
                            "a "
                            "specific "
                            "product "
                            "or "
                            "service "
                            "in "
                            "your "
                            "catalog.",
                            "example": " ",
                            "type": "string",
                        },
                        "item_order": {
                            "description": "Sequential "
                            "order "
                            "number "
                            "for "
                            "this "
                            "line "
                            "item "
                            "on "
                            "the "
                            "estimate. "
                            "Determines "
                            "the "
                            "display "
                            "order "
                            "of "
                            "line "
                            "items "
                            "in "
                            "the "
                            "estimate "
                            "document "
                            "— "
                            "lower "
                            "values "
                            "appear "
                            "first. "
                            "Use "
                            "this "
                            "field "
                            "to "
                            "organize "
                            "line "
                            "items "
                            "in "
                            "a "
                            "specific "
                            "sequence.",
                            "example": 1,
                            "type": "integer",
                        },
                        "item_total": {
                            "description": "Total "
                            "amount "
                            "for "
                            "this "
                            "line "
                            "item "
                            "after "
                            "applying "
                            "quantity, "
                            "rate, "
                            "discounts, "
                            "and "
                            "taxes. "
                            "This "
                            "value "
                            "contributes "
                            "to "
                            "the "
                            "overall "
                            "estimate "
                            "total.",
                            "example": 120,
                            "format": "float",
                            "type": "number",
                        },
                        "line_item_id": {
                            "description": "Unique "
                            "identifier "
                            "of "
                            "the "
                            "line "
                            "item "
                            "within "
                            "the "
                            "estimate. "
                            "Required "
                            "when "
                            "updating "
                            "or "
                            "referencing "
                            "a "
                            "specific "
                            "line "
                            "item. "
                            "If "
                            "omitted "
                            "during "
                            "creation, "
                            "a "
                            "new "
                            "line "
                            "item "
                            "will "
                            "be "
                            "added.",
                            "example": 982000000567021,
                            "type": "string",
                        },
                        "location_id": {
                            "description": "Unique "
                            "identifier "
                            "of "
                            "the "
                            "business "
                            "location "
                            "associated "
                            "with "
                            "the "
                            "estimate. "
                            "Use "
                            "the "
                            "`location_id` "
                            "returned "
                            "by "
                            "the "
                            "Locations "
                            "API "
                            "for "
                            "the "
                            "same "
                            "organization. "
                            "This "
                            "links "
                            "the "
                            "estimate "
                            "to "
                            "a "
                            "specific "
                            "business "
                            "location, "
                            "which "
                            "may "
                            "affect "
                            "tax "
                            "calculations, "
                            "reporting, "
                            "and "
                            "business "
                            "operations. "
                            "Required "
                            "if "
                            "your "
                            "organization "
                            "has "
                            "multiple "
                            "locations "
                            "configured.",
                            "example": "460000000038080",
                            "type": "string",
                        },
                        "name": {
                            "description": "Name "
                            "of "
                            "the "
                            "product "
                            "or "
                            "service "
                            "for "
                            "this "
                            "line "
                            "item. "
                            "This "
                            "is "
                            "displayed "
                            "on "
                            "the "
                            "estimate "
                            "document "
                            "and "
                            "helps "
                            "the "
                            "customer "
                            "identify "
                            "what "
                            "is "
                            "being "
                            "quoted.",
                            "example": "Hard Drive",
                            "type": "string",
                        },
                        "product_type": {
                            "description": "Type "
                            "of "
                            "product "
                            "or "
                            "service "
                            "for "
                            "this "
                            "line "
                            "item. "
                            "Allowed "
                            "values: "
                            "<code>goods</code> "
                            "or "
                            "<code>services</code>. "
                            "For "
                            "South "
                            "Africa "
                            "Edition, "
                            "additional "
                            "values "
                            "include "
                            "<code>capital_service</code> "
                            "and "
                            "<code>capital_goods</code>. "
                            "This "
                            "classification "
                            "affects "
                            "tax "
                            "calculations, "
                            "reporting, "
                            "and "
                            "compliance "
                            "requirements "
                            "based "
                            "on "
                            "your "
                            "organization's "
                            "location "
                            "and "
                            "tax "
                            "regulations.",
                            "example": "goods",
                            "type": "string",
                        },
                        "quantity": {
                            "description": "Number "
                            "of "
                            "units "
                            "of "
                            "the "
                            "product "
                            "or "
                            "service "
                            "being "
                            "quoted "
                            "in "
                            "this "
                            "line "
                            "item. "
                            "This "
                            "value "
                            "is "
                            "multiplied "
                            "by "
                            "the "
                            "rate "
                            "to "
                            "calculate "
                            "the "
                            "line "
                            "item "
                            "total.",
                            "example": 1,
                            "format": "double",
                            "type": "number",
                        },
                        "rate": {
                            "description": "Unit "
                            "price "
                            "or "
                            "rate "
                            "for "
                            "the "
                            "product "
                            "or "
                            "service "
                            "in "
                            "this "
                            "line "
                            "item. "
                            "This "
                            "value "
                            "is "
                            "multiplied "
                            "by "
                            "the "
                            "quantity "
                            "to "
                            "determine "
                            "the "
                            "line "
                            "item "
                            "total "
                            "before "
                            "taxes "
                            "and "
                            "discounts.",
                            "example": 120,
                            "format": "double",
                            "type": "number",
                        },
                        "sat_item_key_code": {
                            "description": "Add "
                            "SAT "
                            "Item "
                            "Key "
                            "Code "
                            "for "
                            "your "
                            "goods/services. "
                            "Download "
                            "the "
                            "<a "
                            "href= "
                            "http://omawww.sat.gob.mx/tramitesyservicios/Paginas/documentos/catCFDI_V_4_07122022.xls  "
                            ">CFDI "
                            "Catalogs.</a>",
                            "example": 71121206,
                            "type": "string",
                            "x-node_available_in": ["mx"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_id": {
                            "description": "Unique "
                            "identifier "
                            "of "
                            "the "
                            "tax "
                            "to "
                            "be "
                            "applied "
                            "to "
                            "this "
                            "line "
                            "item. "
                            "Use "
                            "the "
                            "`tax_id` "
                            "returned "
                            "by "
                            "the "
                            "Taxes "
                            "API "
                            "for "
                            "the "
                            "same "
                            "organization. "
                            "This "
                            "determines "
                            "which "
                            "tax "
                            "rate "
                            "and "
                            "rules "
                            "are "
                            "applied "
                            "to "
                            "the "
                            "line "
                            "item, "
                            "affecting "
                            "the "
                            "final "
                            "tax "
                            "calculation "
                            "and "
                            "compliance "
                            "reporting.",
                            "example": 982000000557028,
                            "type": "string",
                        },
                        "tax_name": {
                            "description": "The name of the tax",
                            "example": "VAT",
                            "type": "string",
                        },
                        "tax_percentage": {
                            "description": "The  percentage of tax levied",
                            "example": 12.5,
                            "format": "float",
                            "type": "number",
                        },
                        "tax_treatment_code": {
                            "description": "Specify "
                            "reason "
                            "for "
                            "using "
                            "out "
                            "of "
                            "scope.</br>Supported "
                            "values "
                            "for "
                            "<b>UAE</b> "
                            "are "
                            "<code>uae_same_tax_group</code>, "
                            "<code>uae_reimbursed_expense</code> "
                            "and "
                            "<code>uae_others</code>.</br> "
                            "Supported "
                            "values "
                            "for "
                            "<b>Bahrain</b> "
                            "are "
                            "<code>bahrain_same_tax_group</code>, "
                            "<code>bahrain_transfer_of_concern</code>, "
                            "<code>bahrain_disbursement</code>, "
                            "<code>bahrain_head_to_branch_transaction</code>, "
                            "<code>bahrain_warranty_repair_services</code> "
                            "and "
                            "<code>bahrain_others</code>.</br>Supported "
                            "values "
                            "for "
                            "<b>Saudi "
                            "Arabia</b> "
                            "are "
                            "<code>ksa_pvt_health</code>, "
                            "<code>ksa_pvt_edu</code>, "
                            "<code>ksa_reimbursed_expense</code> "
                            "and "
                            "<code>ksa_house_sales</code>.",
                            "example": "uae_others",
                            "type": "string",
                            "x-node_available_in": ["gcc"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_type": {
                            "description": "The type of the tax",
                            "example": "tax",
                            "type": "string",
                        },
                        "tds_tax_id": {
                            "description": "ID of the TDS tax.",
                            "example": "982000000557012",
                            "type": "string",
                            "x-node_available_in": ["mx"],
                            "x-node_unavailable_in": [],
                        },
                        "unit": {
                            "description": "Unit "
                            "of "
                            "measurement "
                            "for "
                            "the "
                            "product "
                            "or "
                            "service "
                            "in "
                            "this "
                            "line "
                            "item "
                            "(e.g., "
                            "kgs, "
                            "Nos., "
                            "hours). "
                            "Helps "
                            "clarify "
                            "the "
                            "quantity "
                            "being "
                            "quoted.",
                            "example": " ",
                            "type": "string",
                        },
                        "unitkey_code": {
                            "description": "Add "
                            "SAT "
                            "Unit "
                            "Key "
                            "Code "
                            "for "
                            "your "
                            "goods/services. "
                            "Download "
                            "the "
                            "<a "
                            "href= "
                            "http://omawww.sat.gob.mx/tramitesyservicios/Paginas/documentos/catCFDI_V_4_07122022.xls  "
                            ">CFDI "
                            "Catalogs.</a>",
                            "example": "E48",
                            "type": "string",
                            "x-node_available_in": ["mx"],
                            "x-node_unavailable_in": [],
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "location_id": {
                "description": "Unique identifier of the business "
                "location associated with the estimate. "
                "Use the `location_id` returned by the "
                "Locations API for the same "
                "organization. This links the estimate "
                "to a specific business location, which "
                "may affect tax calculations, "
                "reporting, and business operations. "
                "Required if your organization has "
                "multiple locations configured.",
                "example": "460000000038080",
                "type": "string",
            },
            "name": {
                "description": "Name of the product or service for this line "
                "item. This is displayed on the estimate "
                "document and helps the customer identify what "
                "is being quoted.",
                "example": "Hard Drive",
                "type": "string",
            },
            "notes": {
                "description": "Additional information or comments to be "
                "displayed on the estimate document. This "
                "field is typically used for thank you "
                "messages, special instructions, or any other "
                "information you want to communicate to the "
                "customer. The notes appear on the estimate "
                "PDF and are visible to customers.",
                "example": "Looking forward for your business.",
                "type": "string",
            },
            "place_of_supply": {
                "description": "Place where the goods/services are "
                "supplied to. (If not given, "
                "<code>place of contact</code> "
                "given for the contact will be "
                "taken)<br/>Supported codes for UAE "
                "emirates are : </br>Abu Dhabi - "
                "<code>AB</code>,</br>Ajman - "
                "<code>AJ</code>,</br>Dubai - "
                "<code>DU</code>,</br>Fujairah - "
                "<code>FU</code>,</br>Ras "
                "al-Khaimah - "
                "<code>RA</code>,</br>Sharjah - "
                "<code>SH</code>,</br>Umm al-Quwain "
                "- <code>UM</code><br/>Supported "
                "codes for the GCC countries are : "
                "</br>United Arab Emirates - "
                "<code>AE</code>,</br>Saudi Arabia "
                "- <code>SA</code>,</br>Bahrain - "
                "<code>BH</code>,</br>Kuwait - "
                "<code>KW</code>,</br>Oman - "
                "<code>OM</code>,</br>Qatar - "
                "<code>QA</code>.",
                "example": "TN",
                "type": "string",
                "x-node_available_in": ["in", "gcc"],
                "x-node_unavailable_in": [],
            },
            "project_id": {
                "description": "Unique identifier of the project "
                "associated with this estimate. Use the "
                "<code>project_id</code> returned by the "
                "Projects API for the same organization. "
                "Linking an estimate to a project helps "
                "with project-based billing, tracking, "
                "and reporting.",
                "example": 90300000087378,
                "type": "string",
            },
            "quantity": {
                "description": "Number of units of the product or service "
                "being quoted in this line item. This "
                "value is multiplied by the rate to "
                "calculate the line item total.",
                "example": 1,
                "format": "double",
                "type": "number",
            },
            "rate": {
                "description": "Unit price or rate for the product or service "
                "in this line item. This value is multiplied "
                "by the quantity to determine the line item "
                "total before taxes and discounts.",
                "example": 120,
                "format": "double",
                "type": "number",
            },
            "reference_number": {
                "description": "Optional external identifier used "
                "to associate the estimate with "
                "other systems or workflows. Helps "
                "improve traceability and "
                "integration during estimate "
                "creation.",
                "example": "QRT-12346",
                "type": "string",
            },
            "retainer_percentage": {
                "description": "Percentage of the estimate "
                "amount to be collected as a "
                "retainer (upfront payment) "
                "when the estimate is accepted. "
                "Specify a value between 0 and "
                "100. This determines the "
                "portion of the total estimate "
                "that will be invoiced as a "
                "retainer.",
                "example": 10,
                "type": "integer",
            },
            "salesperson_name": {
                "description": "Name of the sales person.",
                "example": "Will smith",
                "type": "string",
            },
            "shipping_charge": {
                "description": "Additional shipping or delivery "
                "charges applied to the estimate. "
                "Must be specified as a fixed "
                'amount (e.g., "25.00"). This '
                "amount is added to the estimate "
                "total and is subject to tax "
                "calculation.",
                "example": 0,
                "type": "string",
            },
            "tax_authority_id": {
                "description": "ID of the tax authority. Tax "
                "authority depends on the location "
                "of the customer. For example, if "
                "the customer is located in NY, "
                "then the tax authority is NY tax "
                "authority.",
                "example": 11149000000061052,
                "type": "string",
                "x-node_available_in": ["us"],
                "x-node_unavailable_in": [],
            },
            "tax_exemption_id": {
                "description": "ID of the tax exemption.",
                "example": 11149000000061054,
                "type": "string",
                "x-node_available_in": ["in", "us"],
                "x-node_unavailable_in": [],
            },
            "tax_id": {
                "description": "Unique identifier of the tax to be applied "
                "to this line item. Use the `tax_id` "
                "returned by the Taxes API for the same "
                "organization. This determines which tax "
                "rate and rules are applied to the line "
                "item, affecting the final tax calculation "
                "and compliance reporting.",
                "example": 982000000557028,
                "type": "string",
            },
            "tax_treatment": {
                "description": "VAT treatment for the Estimate. "
                "Allowed Values: "
                "<code>vat_registered</code>,<code>vat_not_registered</code>,<code>gcc_vat_not_registered</code>,<code>gcc_vat_registered</code>,<code>non_gcc</code>.</br><code>dz_vat_registered</code> "
                "and "
                "<code>dz_vat_not_registered</code> "
                "supported only for "
                "<b>UAE.</b></br><code>home_country_mexico</code>,<code>border_region_mexico</code>,<code>non_mexico</code> "
                "supported only for <b>MX</b>. "
                "<br/><b>For Kenya Edition:</b> "
                "<code>vat_registered</code> "
                ",<code>vat_not_registered</code> "
                ",<code>non_kenya</code>(A business "
                "that is located outside "
                "Kenya).<br/><b>For SouthAfrica "
                "Edition:</b> "
                "<code>vat_registered</code>, "
                "<code>vat_not_registered</code>, "
                "<code>overseas</code>(A business "
                "that is located outside "
                "SouthAfrica).",
                "example": "vat_registered",
                "type": "string",
                "x-node_available_in": ["gcc", "mx", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "template_id": {
                "description": "The ID of the template used for "
                "generating the estimate PDF. Use this "
                "to apply custom branding or formats. "
                "Fetch template IDs using the Templates "
                "API (GET /estimates/templates).",
                "example": 982000000000143,
                "type": "string",
            },
            "terms": {
                "description": "Defines the terms and conditions to be "
                "included in the estimate document. This "
                "field can be used to specify payment terms, "
                "delivery schedules, return policies, or "
                "other transactional details. The terms "
                "appear on the estimate PDF and helps "
                "communicate key conditions related to the "
                "estimate.",
                "example": "Terms & Conditions apply",
                "type": "string",
            },
            "unit": {
                "description": "Unit of measurement for the product or "
                "service in this line item (e.g., kgs, Nos., "
                "hours). Helps clarify the quantity being "
                "quoted.",
                "example": " ",
                "type": "string",
            },
            "vat_treatment": {
                "description": "(Optional) VAT treatment for the "
                "estimates. VAT treatment denotes the "
                "location of the customer, if the "
                "customer resides in UK then the VAT "
                "treatment is <code>uk</code>. If the "
                "customer is in an EU country & VAT "
                "registered, you are resides in "
                "Northen Ireland and selling Goods "
                "then his VAT treatment is "
                "<code>eu_vat_registered</code>, if "
                "he resides outside of the UK then "
                "his VAT treatment is "
                "<code>overseas</code> (For Pre "
                "Brexit, this can be split as "
                "<code>eu_vat_registered</code>, "
                "<code>eu_vat_not_registered</code> "
                "and <code>non_eu</code>).",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
        },
        "required": ["customer_id", "custom_fields"],
        "type": "object",
    },
    "UPDATEESTIMATE_REQUEST_BODY_SCHEMA": {
        "properties": {
            "accept_retainer": {
                "description": "Boolean flag indicating whether a "
                "retainer invoice should be "
                "automatically created if the "
                "customer accepts this estimate. "
                "When set to <code>true</code>, a "
                "retainer invoice is generated upon "
                "acceptance, streamlining the "
                "process for upfront payments or "
                "deposits. Allowed values: "
                "<code>true</code> and "
                "<code>false</code>.",
                "example": True,
                "type": "boolean",
            },
            "adjustment": {
                "description": "Additional charge or credit amount "
                "applied to the estimate total. This can "
                "be used for rounding adjustments, "
                "handling fees, or any other one-time "
                "charges/credits. Positive values add to "
                "the total, negative values reduce the "
                "total. This amount is applied after tax "
                "calculation and affects the final "
                "estimate total.",
                "example": 0,
                "format": "double",
                "type": "number",
            },
            "adjustment_description": {
                "description": "Text description explaining "
                "the reason for the "
                "adjustment amount. This "
                "description appears on the "
                "estimate document to "
                "explain why the adjustment "
                "was applied. Common "
                'examples include "Rounding '
                'adjustment", "Handling '
                'fee", "Early payment '
                'discount", or "Late payment '
                'fee". This helps customers '
                "understand the purpose of "
                "the adjustment.",
                "example": " ",
                "type": "string",
            },
            "avatax_exempt_no": {
                "description": "Exemption certificate number of the customer.",
                "type": "string",
                "x-node_available_in": ["Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "avatax_use_code": {
                "description": "Used to group like customers for "
                "exemption purposes. It is a custom "
                "value that links customers to a "
                "tax rule. Select from Avalara "
                "[standard codes][1] or enter a "
                "custom code.",
                "type": "string",
                "x-node_available_in": ["Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "contact_persons_associated": {
                "description": "Contact Persons associated with the estimate.",
                "items": {
                    "properties": {
                        "communication_preference": {
                            "description": "Preferred "
                            "modes "
                            "of "
                            "communication "
                            "for "
                            "the "
                            "contact "
                            "person "
                            "at "
                            "transaction "
                            "level.",
                            "properties": {
                                "is_email_enabled": {
                                    "description": "Used "
                                    "to "
                                    "check "
                                    "if "
                                    "Email "
                                    "communication "
                                    "preference "
                                    "is "
                                    "enabled "
                                    "for "
                                    "the "
                                    "contact "
                                    "person "
                                    "at "
                                    "transaction "
                                    "level.",
                                    "example": True,
                                    "type": "boolean",
                                },
                                "is_whatsapp_enabled": {
                                    "description": "Used "
                                    "to "
                                    "check "
                                    "if "
                                    "WhatsApp "
                                    "communication "
                                    "preference "
                                    "is "
                                    "enabled "
                                    "for "
                                    "the "
                                    "contact "
                                    "person "
                                    "at "
                                    "transaction "
                                    "level.",
                                    "example": True,
                                    "type": "boolean",
                                    "x-node_available_in": ["WhatsApp integration"],
                                },
                            },
                            "type": "object",
                        },
                        "contact_person_id": {
                            "description": "Unique ID of the Contact Person.",
                            "example": 982000000567003,
                            "format": "int64",
                            "type": "integer",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "currency_id": {
                "description": "The ID of the currency in which the "
                "estimate will be created. Use this to "
                "specify the customer's preferred "
                "currency for transactions. Fetch valid "
                "currency IDs using the Currency API "
                "(GET /currencies).",
                "example": 982000000000190,
                "type": "string",
            },
            "custom_body": {"example": " ", "type": "string"},
            "custom_fields": {
                "description": "Custom fields for an estimate.",
                "items": {
                    "properties": {
                        "index": {"example": 1, "type": "integer"},
                        "value": {"example": "15 Dec 2013", "type": "string"},
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "custom_subject": {"example": " ", "type": "string"},
            "customer_id": {
                "description": "The ID of the customer (contact) for "
                "whom the estimate is created. This "
                "must be a valid contact ID from your "
                "organization; obtain it using the "
                "Contacts API (GET /contacts) or the "
                "Create Contact response.",
                "example": 982000000567001,
                "type": "string",
            },
            "date": {
                "description": "Search estimates by estimate date.Variants "
                "<code>date_start</code>, "
                "<code>date_end</code>, "
                "<code>date_before</code> and "
                "<code>date_after</code>",
                "example": "2013-11-18",
                "type": "string",
            },
            "description": {
                "description": "Detailed description of the product or "
                "service in this line item. Use this "
                "field to provide specifications, "
                "features, or any other relevant "
                "information that helps the customer "
                "understand about the line item.",
                "example": "500GB, USB 2.0 interface 1400 rpm, protective hard case.",
                "type": "string",
            },
            "discount": {
                "description": "Discount applied to the estimate. It can "
                "be either in % or in amount. e.g. 12.5% "
                "or 190.",
                "example": 0,
                "format": "double",
                "type": "number",
            },
            "discount_type": {
                "description": "How the discount is specified. "
                "Allowed values are entity_level or "
                "item_level.Allowed Values: "
                "<code>entity_level</code> and "
                "<code>item_level</code>",
                "example": "item_level",
                "type": "string",
            },
            "estimate_number": {
                "description": "Search estimates by estimate "
                "number.Variants<code>estimate_number_startswith</code> "
                "and "
                "<code>estimate_number_contains</code>",
                "example": "EST-00002",
                "type": "string",
            },
            "exchange_rate": {
                "description": "Exchange rate of the currency.",
                "example": 1,
                "format": "double",
                "type": "number",
            },
            "expiry_date": {
                "description": "The date of expiration of the estimates",
                "example": "2013-11-30",
                "type": "string",
            },
            "gst_no": {
                "description": "15 digit GST identification number of the customer.",
                "example": "22AAAAA0000A1Z5",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "gst_treatment": {
                "description": "Choose whether the contact is GST "
                "registered/unregistered/consumer/overseas. "
                "Allowed values are <code> "
                "business_gst </code> , <code> "
                "business_none </code> , <code> "
                "overseas </code> , <code> consumer "
                "</code>.",
                "example": "business_gst",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "is_discount_before_tax": {
                "description": "Used to specify how the "
                "discount has to applied. "
                "Either before or after the "
                "calculation of tax.",
                "example": True,
                "type": "boolean",
            },
            "is_inclusive_tax": {
                "description": "Used to specify whether the line "
                "item rates are inclusive or "
                "exclusive of tax.",
                "example": False,
                "type": "boolean",
                "x-node_available_in": [],
                "x-node_unavailable_in": ["us", "ca"],
            },
            "is_reverse_charge_applied": {
                "description": "(Required if customer "
                "tax treatment is "
                "<code>vat_registered</code>)<br/>Used "
                "to specify whether the "
                "transaction is "
                "applicable for Domestic "
                "Reverse Charge (DRC) or "
                "not.",
                "example": True,
                "type": "boolean",
                "x-node_available_in": ["za"],
                "x-node_unavailable_in": [],
            },
            "item_id": {
                "description": "Unique identifier of the item (product or "
                "service) being quoted in this line item. "
                "Use the `item_id` returned by the Items "
                "API for the same organization. This links "
                "the line item to a specific product or "
                "service in your catalog.",
                "example": " ",
                "type": "string",
            },
            "line_item_id": {
                "description": "Unique identifier of the line item "
                "within the estimate. Required when "
                "updating or referencing a specific "
                "line item. If omitted during "
                "creation, a new line item will be "
                "added.",
                "example": 982000000567021,
                "type": "string",
            },
            "line_items": {
                "description": "Line items of an estimate.",
                "items": {
                    "properties": {
                        "bcy_rate": {
                            "description": "Exchange "
                            "rate "
                            "between "
                            "the "
                            "base "
                            "currency "
                            "and "
                            "the "
                            "transaction "
                            "currency "
                            "for "
                            "this "
                            "line "
                            "item. "
                            "Used "
                            "for "
                            "currency "
                            "conversion "
                            "and "
                            "reporting.",
                            "example": 120,
                            "format": "float",
                            "type": "number",
                        },
                        "description": {
                            "description": "Detailed "
                            "description "
                            "of "
                            "the "
                            "product "
                            "or "
                            "service "
                            "in "
                            "this "
                            "line "
                            "item. "
                            "Use "
                            "this "
                            "field "
                            "to "
                            "provide "
                            "specifications, "
                            "features, "
                            "or "
                            "any "
                            "other "
                            "relevant "
                            "information "
                            "that "
                            "helps "
                            "the "
                            "customer "
                            "understand "
                            "about "
                            "the "
                            "line "
                            "item.",
                            "example": "500GB, USB 2.0 interface 1400 rpm, protective hard case.",
                            "type": "string",
                        },
                        "discount": {
                            "description": "Discount "
                            "applied "
                            "to "
                            "the "
                            "estimate. "
                            "It "
                            "can "
                            "be "
                            "either "
                            "in "
                            "% "
                            "or "
                            "in "
                            "amount. "
                            "e.g. "
                            "12.5% "
                            "or "
                            "190.",
                            "example": 0,
                            "format": "double",
                            "type": "number",
                        },
                        "discount_amount": {
                            "description": "Discount "
                            "amount "
                            "applied "
                            "to "
                            "this "
                            "line "
                            "item. "
                            "This "
                            "value "
                            "reduces "
                            "the "
                            "line "
                            "item "
                            "total "
                            "before "
                            "tax "
                            "calculation.",
                            "example": 0,
                            "format": "float",
                            "type": "number",
                        },
                        "hsn_or_sac": {
                            "description": "Add HSN/SAC code for your goods/services",
                            "example": 80540,
                            "type": "string",
                            "x-node_available_in": ["in", "ke", "za"],
                            "x-node_unavailable_in": [],
                        },
                        "item_id": {
                            "description": "Unique "
                            "identifier "
                            "of "
                            "the "
                            "item "
                            "(product "
                            "or "
                            "service) "
                            "being "
                            "quoted "
                            "in "
                            "this "
                            "line "
                            "item. "
                            "Use "
                            "the "
                            "`item_id` "
                            "returned "
                            "by "
                            "the "
                            "Items "
                            "API "
                            "for "
                            "the "
                            "same "
                            "organization. "
                            "This "
                            "links "
                            "the "
                            "line "
                            "item "
                            "to "
                            "a "
                            "specific "
                            "product "
                            "or "
                            "service "
                            "in "
                            "your "
                            "catalog.",
                            "example": " ",
                            "type": "string",
                        },
                        "item_order": {
                            "description": "Sequential "
                            "order "
                            "number "
                            "for "
                            "this "
                            "line "
                            "item "
                            "on "
                            "the "
                            "estimate. "
                            "Determines "
                            "the "
                            "display "
                            "order "
                            "of "
                            "line "
                            "items "
                            "in "
                            "the "
                            "estimate "
                            "document "
                            "— "
                            "lower "
                            "values "
                            "appear "
                            "first. "
                            "Use "
                            "this "
                            "field "
                            "to "
                            "organize "
                            "line "
                            "items "
                            "in "
                            "a "
                            "specific "
                            "sequence.",
                            "example": 1,
                            "type": "integer",
                        },
                        "item_total": {
                            "description": "Total "
                            "amount "
                            "for "
                            "this "
                            "line "
                            "item "
                            "after "
                            "applying "
                            "quantity, "
                            "rate, "
                            "discounts, "
                            "and "
                            "taxes. "
                            "This "
                            "value "
                            "contributes "
                            "to "
                            "the "
                            "overall "
                            "estimate "
                            "total.",
                            "example": 120,
                            "format": "float",
                            "type": "number",
                        },
                        "line_item_id": {
                            "description": "Unique "
                            "identifier "
                            "of "
                            "the "
                            "line "
                            "item "
                            "within "
                            "the "
                            "estimate. "
                            "Required "
                            "when "
                            "updating "
                            "or "
                            "referencing "
                            "a "
                            "specific "
                            "line "
                            "item. "
                            "If "
                            "omitted "
                            "during "
                            "creation, "
                            "a "
                            "new "
                            "line "
                            "item "
                            "will "
                            "be "
                            "added.",
                            "example": 982000000567021,
                            "type": "string",
                        },
                        "location_id": {
                            "description": "Unique "
                            "identifier "
                            "of "
                            "the "
                            "business "
                            "location "
                            "associated "
                            "with "
                            "the "
                            "estimate. "
                            "Use "
                            "the "
                            "`location_id` "
                            "returned "
                            "by "
                            "the "
                            "Locations "
                            "API "
                            "for "
                            "the "
                            "same "
                            "organization. "
                            "This "
                            "links "
                            "the "
                            "estimate "
                            "to "
                            "a "
                            "specific "
                            "business "
                            "location, "
                            "which "
                            "may "
                            "affect "
                            "tax "
                            "calculations, "
                            "reporting, "
                            "and "
                            "business "
                            "operations. "
                            "Required "
                            "if "
                            "your "
                            "organization "
                            "has "
                            "multiple "
                            "locations "
                            "configured.",
                            "example": "460000000038080",
                            "type": "string",
                        },
                        "name": {
                            "description": "Name "
                            "of "
                            "the "
                            "product "
                            "or "
                            "service "
                            "for "
                            "this "
                            "line "
                            "item. "
                            "This "
                            "is "
                            "displayed "
                            "on "
                            "the "
                            "estimate "
                            "document "
                            "and "
                            "helps "
                            "the "
                            "customer "
                            "identify "
                            "what "
                            "is "
                            "being "
                            "quoted.",
                            "example": "Hard Drive",
                            "type": "string",
                        },
                        "product_type": {
                            "description": "Type "
                            "of "
                            "product "
                            "or "
                            "service "
                            "for "
                            "this "
                            "line "
                            "item. "
                            "Allowed "
                            "values: "
                            "<code>goods</code> "
                            "or "
                            "<code>services</code>. "
                            "For "
                            "South "
                            "Africa "
                            "Edition, "
                            "additional "
                            "values "
                            "include "
                            "<code>capital_service</code> "
                            "and "
                            "<code>capital_goods</code>. "
                            "This "
                            "classification "
                            "affects "
                            "tax "
                            "calculations, "
                            "reporting, "
                            "and "
                            "compliance "
                            "requirements "
                            "based "
                            "on "
                            "your "
                            "organization's "
                            "location "
                            "and "
                            "tax "
                            "regulations.",
                            "example": "goods",
                            "type": "string",
                        },
                        "quantity": {
                            "description": "Number "
                            "of "
                            "units "
                            "of "
                            "the "
                            "product "
                            "or "
                            "service "
                            "being "
                            "quoted "
                            "in "
                            "this "
                            "line "
                            "item. "
                            "This "
                            "value "
                            "is "
                            "multiplied "
                            "by "
                            "the "
                            "rate "
                            "to "
                            "calculate "
                            "the "
                            "line "
                            "item "
                            "total.",
                            "example": 1,
                            "format": "double",
                            "type": "number",
                        },
                        "rate": {
                            "description": "Unit "
                            "price "
                            "or "
                            "rate "
                            "for "
                            "the "
                            "product "
                            "or "
                            "service "
                            "in "
                            "this "
                            "line "
                            "item. "
                            "This "
                            "value "
                            "is "
                            "multiplied "
                            "by "
                            "the "
                            "quantity "
                            "to "
                            "determine "
                            "the "
                            "line "
                            "item "
                            "total "
                            "before "
                            "taxes "
                            "and "
                            "discounts.",
                            "example": 120,
                            "format": "double",
                            "type": "number",
                        },
                        "sat_item_key_code": {
                            "description": "Add "
                            "SAT "
                            "Item "
                            "Key "
                            "Code "
                            "for "
                            "your "
                            "goods/services. "
                            "Download "
                            "the "
                            "<a "
                            "href= "
                            "http://omawww.sat.gob.mx/tramitesyservicios/Paginas/documentos/catCFDI_V_4_07122022.xls  "
                            ">CFDI "
                            "Catalogs.</a>",
                            "example": 71121206,
                            "type": "string",
                            "x-node_available_in": ["mx"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_id": {
                            "description": "Unique "
                            "identifier "
                            "of "
                            "the "
                            "tax "
                            "to "
                            "be "
                            "applied "
                            "to "
                            "this "
                            "line "
                            "item. "
                            "Use "
                            "the "
                            "`tax_id` "
                            "returned "
                            "by "
                            "the "
                            "Taxes "
                            "API "
                            "for "
                            "the "
                            "same "
                            "organization. "
                            "This "
                            "determines "
                            "which "
                            "tax "
                            "rate "
                            "and "
                            "rules "
                            "are "
                            "applied "
                            "to "
                            "the "
                            "line "
                            "item, "
                            "affecting "
                            "the "
                            "final "
                            "tax "
                            "calculation "
                            "and "
                            "compliance "
                            "reporting.",
                            "example": 982000000557028,
                            "type": "string",
                        },
                        "tax_name": {
                            "description": "The name of the tax",
                            "example": "VAT",
                            "type": "string",
                        },
                        "tax_percentage": {
                            "description": "The  percentage of tax levied",
                            "example": 12.5,
                            "format": "float",
                            "type": "number",
                        },
                        "tax_treatment_code": {
                            "description": "Specify "
                            "reason "
                            "for "
                            "using "
                            "out "
                            "of "
                            "scope.</br>Supported "
                            "values "
                            "for "
                            "<b>UAE</b> "
                            "are "
                            "<code>uae_same_tax_group</code>, "
                            "<code>uae_reimbursed_expense</code> "
                            "and "
                            "<code>uae_others</code>.</br> "
                            "Supported "
                            "values "
                            "for "
                            "<b>Bahrain</b> "
                            "are "
                            "<code>bahrain_same_tax_group</code>, "
                            "<code>bahrain_transfer_of_concern</code>, "
                            "<code>bahrain_disbursement</code>, "
                            "<code>bahrain_head_to_branch_transaction</code>, "
                            "<code>bahrain_warranty_repair_services</code> "
                            "and "
                            "<code>bahrain_others</code>.</br>Supported "
                            "values "
                            "for "
                            "<b>Saudi "
                            "Arabia</b> "
                            "are "
                            "<code>ksa_pvt_health</code>, "
                            "<code>ksa_pvt_edu</code>, "
                            "<code>ksa_reimbursed_expense</code> "
                            "and "
                            "<code>ksa_house_sales</code>.",
                            "example": "uae_others",
                            "type": "string",
                            "x-node_available_in": ["gcc"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_type": {
                            "description": "The type of the tax",
                            "example": "tax",
                            "type": "string",
                        },
                        "tds_tax_id": {
                            "description": "ID of the TDS tax.",
                            "example": "982000000557012",
                            "type": "string",
                            "x-node_available_in": ["mx"],
                            "x-node_unavailable_in": [],
                        },
                        "unit": {
                            "description": "Unit "
                            "of "
                            "measurement "
                            "for "
                            "the "
                            "product "
                            "or "
                            "service "
                            "in "
                            "this "
                            "line "
                            "item "
                            "(e.g., "
                            "kgs, "
                            "Nos., "
                            "hours). "
                            "Helps "
                            "clarify "
                            "the "
                            "quantity "
                            "being "
                            "quoted.",
                            "example": " ",
                            "type": "string",
                        },
                        "unitkey_code": {
                            "description": "Add "
                            "SAT "
                            "Unit "
                            "Key "
                            "Code "
                            "for "
                            "your "
                            "goods/services. "
                            "Download "
                            "the "
                            "<a "
                            "href= "
                            "http://omawww.sat.gob.mx/tramitesyservicios/Paginas/documentos/catCFDI_V_4_07122022.xls  "
                            ">CFDI "
                            "Catalogs.</a>",
                            "example": "E48",
                            "type": "string",
                            "x-node_available_in": ["mx"],
                            "x-node_unavailable_in": [],
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "location_id": {
                "description": "Unique identifier of the business "
                "location associated with the estimate. "
                "Use the `location_id` returned by the "
                "Locations API for the same "
                "organization. This links the estimate "
                "to a specific business location, which "
                "may affect tax calculations, "
                "reporting, and business operations. "
                "Required if your organization has "
                "multiple locations configured.",
                "example": "460000000038080",
                "type": "string",
            },
            "name": {
                "description": "Name of the product or service for this line "
                "item. This is displayed on the estimate "
                "document and helps the customer identify what "
                "is being quoted.",
                "example": "Hard Drive",
                "type": "string",
            },
            "notes": {
                "description": "Additional information or comments to be "
                "displayed on the estimate document. This "
                "field is typically used for thank you "
                "messages, special instructions, or any other "
                "information you want to communicate to the "
                "customer. The notes appear on the estimate "
                "PDF and are visible to customers.",
                "example": "Looking forward for your business.",
                "type": "string",
            },
            "place_of_supply": {
                "description": "Place where the goods/services are "
                "supplied to. (If not given, "
                "<code>place of contact</code> "
                "given for the contact will be "
                "taken)<br/>Supported codes for UAE "
                "emirates are : </br>Abu Dhabi - "
                "<code>AB</code>,</br>Ajman - "
                "<code>AJ</code>,</br>Dubai - "
                "<code>DU</code>,</br>Fujairah - "
                "<code>FU</code>,</br>Ras "
                "al-Khaimah - "
                "<code>RA</code>,</br>Sharjah - "
                "<code>SH</code>,</br>Umm al-Quwain "
                "- <code>UM</code><br/>Supported "
                "codes for the GCC countries are : "
                "</br>United Arab Emirates - "
                "<code>AE</code>,</br>Saudi Arabia "
                "- <code>SA</code>,</br>Bahrain - "
                "<code>BH</code>,</br>Kuwait - "
                "<code>KW</code>,</br>Oman - "
                "<code>OM</code>,</br>Qatar - "
                "<code>QA</code>.",
                "example": "TN",
                "type": "string",
                "x-node_available_in": ["in", "gcc"],
                "x-node_unavailable_in": [],
            },
            "project_id": {
                "description": "Unique identifier of the project "
                "associated with this estimate. Use the "
                "<code>project_id</code> returned by the "
                "Projects API for the same organization. "
                "Linking an estimate to a project helps "
                "with project-based billing, tracking, "
                "and reporting.",
                "example": 90300000087378,
                "type": "string",
            },
            "quantity": {
                "description": "Number of units of the product or service "
                "being quoted in this line item. This "
                "value is multiplied by the rate to "
                "calculate the line item total.",
                "example": 1,
                "format": "double",
                "type": "number",
            },
            "rate": {
                "description": "Unit price or rate for the product or service "
                "in this line item. This value is multiplied "
                "by the quantity to determine the line item "
                "total before taxes and discounts.",
                "example": 120,
                "format": "double",
                "type": "number",
            },
            "reference_number": {
                "description": "Optional external identifier used "
                "to associate the estimate with "
                "other systems or workflows. Helps "
                "improve traceability and "
                "integration during estimate "
                "creation.",
                "example": "QRT-12346",
                "type": "string",
            },
            "retainer_percentage": {
                "description": "Percentage of the estimate "
                "amount to be collected as a "
                "retainer (upfront payment) "
                "when the estimate is accepted. "
                "Specify a value between 0 and "
                "100. This determines the "
                "portion of the total estimate "
                "that will be invoiced as a "
                "retainer.",
                "example": 10,
                "type": "integer",
            },
            "salesperson_name": {
                "description": "Name of the sales person.",
                "example": "Will smith",
                "type": "string",
            },
            "shipping_charge": {
                "description": "Additional shipping or delivery "
                "charges applied to the estimate. "
                "Must be specified as a fixed "
                'amount (e.g., "25.00"). This '
                "amount is added to the estimate "
                "total and is subject to tax "
                "calculation.",
                "example": 0,
                "type": "string",
            },
            "tax_authority_id": {
                "description": "ID of the tax authority. Tax "
                "authority depends on the location "
                "of the customer. For example, if "
                "the customer is located in NY, "
                "then the tax authority is NY tax "
                "authority.",
                "example": 11149000000061052,
                "type": "string",
                "x-node_available_in": ["us"],
                "x-node_unavailable_in": [],
            },
            "tax_exemption_id": {
                "description": "ID of the tax exemption.",
                "example": 11149000000061054,
                "type": "string",
                "x-node_available_in": ["in", "us"],
                "x-node_unavailable_in": [],
            },
            "tax_id": {
                "description": "Unique identifier of the tax to be applied "
                "to this line item. Use the `tax_id` "
                "returned by the Taxes API for the same "
                "organization. This determines which tax "
                "rate and rules are applied to the line "
                "item, affecting the final tax calculation "
                "and compliance reporting.",
                "example": 982000000557028,
                "type": "string",
            },
            "tax_treatment": {
                "description": "VAT treatment for the Estimate. "
                "Allowed Values: "
                "<code>vat_registered</code>,<code>vat_not_registered</code>,<code>gcc_vat_not_registered</code>,<code>gcc_vat_registered</code>,<code>non_gcc</code>.</br><code>dz_vat_registered</code> "
                "and "
                "<code>dz_vat_not_registered</code> "
                "supported only for "
                "<b>UAE.</b></br><code>home_country_mexico</code>,<code>border_region_mexico</code>,<code>non_mexico</code> "
                "supported only for <b>MX</b>. "
                "<br/><b>For Kenya Edition:</b> "
                "<code>vat_registered</code> "
                ",<code>vat_not_registered</code> "
                ",<code>non_kenya</code>(A business "
                "that is located outside "
                "Kenya).<br/><b>For SouthAfrica "
                "Edition:</b> "
                "<code>vat_registered</code>, "
                "<code>vat_not_registered</code>, "
                "<code>overseas</code>(A business "
                "that is located outside "
                "SouthAfrica).",
                "example": "vat_registered",
                "type": "string",
                "x-node_available_in": ["gcc", "mx", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "template_id": {
                "description": "The ID of the template used for "
                "generating the estimate PDF. Use this "
                "to apply custom branding or formats. "
                "Fetch template IDs using the Templates "
                "API (GET /estimates/templates).",
                "example": 982000000000143,
                "type": "string",
            },
            "terms": {
                "description": "Defines the terms and conditions to be "
                "included in the estimate document. This "
                "field can be used to specify payment terms, "
                "delivery schedules, return policies, or "
                "other transactional details. The terms "
                "appear on the estimate PDF and helps "
                "communicate key conditions related to the "
                "estimate.",
                "example": "Terms & Conditions apply",
                "type": "string",
            },
            "unit": {
                "description": "Unit of measurement for the product or "
                "service in this line item (e.g., kgs, Nos., "
                "hours). Helps clarify the quantity being "
                "quoted.",
                "example": " ",
                "type": "string",
            },
            "vat_treatment": {
                "description": "(Optional) VAT treatment for the "
                "estimates. VAT treatment denotes the "
                "location of the customer, if the "
                "customer resides in UK then the VAT "
                "treatment is <code>uk</code>. If the "
                "customer is in an EU country & VAT "
                "registered, you are resides in "
                "Northen Ireland and selling Goods "
                "then his VAT treatment is "
                "<code>eu_vat_registered</code>, if "
                "he resides outside of the UK then "
                "his VAT treatment is "
                "<code>overseas</code> (For Pre "
                "Brexit, this can be split as "
                "<code>eu_vat_registered</code>, "
                "<code>eu_vat_not_registered</code> "
                "and <code>non_eu</code>).",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
        },
        "required": ["customer_id", "custom_fields"],
        "type": "object",
    },
    "UPDATEESTIMATECUSTOMFIELDS_REQUEST_BODY_SCHEMA": {
        "description": "Custom fields for an invoice.",
        "items": {
            "properties": {
                "customfield_id": {
                    "example": "46000000012845",
                    "format": "int64",
                    "type": "integer",
                },
                "value": {"example": "15 Dec 2013", "type": "string"},
            },
            "type": "object",
        },
        "type": "array",
    },
    "SENDESTIMATEEMAIL_REQUEST_BODY_SCHEMA": {
        "properties": {
            "body": {
                "description": "Body of an email has to be sent.",
                "example": "Dear Customer,   Thanks for your business "
                "enquiry.         The estimate EST-000002 is "
                "attached with this email.        We can get "
                "started if you send us your consent. For any "
                "assistance you can reach us via email or "
                "phone.         Looking forward to hearing back "
                "from you. Here's an overview of the estimate for "
                "your reference.        Estimate Overview:        "
                "Estimate  : EST-000002         Date : 03 Oct "
                "2013        Amount : $36.47 Regards<br>\\nZillium "
                'Inc<br>\\n""',
                "type": "string",
            },
            "cc_mail_ids": {
                "description": "Array of email address of the recipients to be cced.",
                "example": ["peterparker@bowmanfurniture.com"],
                "items": {"type": "string"},
                "type": "array",
            },
            "mail_documents": {
                "description": "Array of Documents ids, which is attached into email",
                "example": ["982000000000121"],
                "items": {"type": "string"},
                "type": "array",
            },
            "send_from_org_email_id": {
                "description": "Boolean to trigger the email from the organization's email address",
                "example": False,
                "type": "boolean",
            },
            "subject": {
                "description": "Subject of an email has to be sent.",
                "example": "Statement of transactions with Zillium Inc",
                "type": "string",
            },
            "to_mail_ids": {
                "description": "Array of email address of the recipients.",
                "example": ["willsmith@bowmanfurniture.com"],
                "items": {"type": "string"},
                "type": "array",
            },
        },
        "required": ["to_mail_ids"],
        "type": "object",
    },
    "UPDATEESTIMATEBILLINGADDRESS_REQUEST_BODY_SCHEMA": {
        "properties": {
            "address": {
                "description": "Billing address for the estimate",
                "example": "B-1104, 11F, \n"
                "Horizon International Tower, \n"
                "No. 6, ZhiChun Road, HaiDian District,",
                "type": "string",
            },
            "city": {
                "description": "City of the customer's billing address.",
                "example": "Beijing",
                "type": "string",
            },
            "country": {
                "description": "Country of the customer's billing address.",
                "example": "China",
                "type": "string",
            },
            "fax": {
                "description": "Customer's fax number.",
                "example": "+86-10-82637827",
                "type": "string",
            },
            "state": {
                "description": "State of the customer's billing address.",
                "example": "Beijing",
                "type": "string",
            },
            "zip": {
                "description": "Zip code of the customer's billing address.",
                "example": 1000881,
                "type": "string",
            },
        },
        "type": "object",
    },
    "UPDATEESTIMATESHIPPINGADDRESS_REQUEST_BODY_SCHEMA": {
        "properties": {
            "address": {
                "description": "Billing address for the estimate",
                "example": "4900 Hopyard Rd, Suite 310",
                "type": "string",
            },
            "city": {
                "description": "City of the customer's billing address.",
                "example": "Pleasanton",
                "type": "string",
            },
            "country": {
                "description": "Country of the customer's billing address.",
                "example": "U.S.A",
                "type": "string",
            },
            "fax": {
                "description": "Customer's fax number.",
                "example": "+1-925-924-9600",
                "type": "string",
            },
            "state": {
                "description": "State of the customer's billing address.",
                "example": "CA",
                "type": "string",
            },
            "zip": {
                "description": "Zip code of the customer's billing address.",
                "example": 94588,
                "type": "string",
            },
        },
        "type": "object",
    },
    "ADDESTIMATECOMMENT_REQUEST_BODY_SCHEMA": {
        "properties": {
            "description": {
                "description": "The description of the line items",
                "example": "Estimate marked as sent",
                "type": "string",
            },
            "show_comment_to_clients": {
                "description": "Boolean to show the comments to contacts in portal.",
                "example": True,
                "type": "boolean",
            },
        },
        "type": "object",
    },
    "UPDATEESTIMATECOMMENT_REQUEST_BODY_SCHEMA": {
        "properties": {
            "description": {
                "description": "The description of the line items",
                "example": "Estimate created",
                "type": "string",
            },
            "show_comment_to_clients": {
                "description": "Boolean to show the comments to contacts in portal.",
                "example": " ",
                "type": "boolean",
            },
        },
        "type": "object",
    },
    "CREATEEXPENSE_REQUEST_BODY_SCHEMA": {
        "properties": {
            "account_id": {
                "description": "ID of the expense account.",
                "example": 982000000561057,
                "type": "string",
            },
            "acquisition_vat_id": {
                "description": "This is the ID of the tax "
                "applied in case this is an EU - "
                "goods expense and acquisition "
                "VAT needs to be reported.",
                "example": " ",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
            "amount": {
                "description": "Amount of the Expense.",
                "example": 112.5,
                "format": "double",
                "type": "number",
            },
            "can_reclaim_vat_on_mileage": {
                "description": "To specify if tax can be reclaimed for this mileage expense.",
                "example": " ",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
            "currency_id": {"example": 982000000567001, "type": "string"},
            "custom_fields": {
                "description": "Custom fields for an expense.",
                "example": [],
                "items": {"type": "string"},
                "type": "array",
            },
            "customer_id": {
                "description": "ID of the expense account.",
                "example": 982000000567001,
                "type": "string",
            },
            "date": {
                "description": "Date of the expense",
                "example": "2013-11-18",
                "type": "string",
            },
            "description": {
                "description": "Description of the expense. Max-length [100]",
                "example": "Marketing",
                "type": "string",
            },
            "destination_of_supply": {
                "description": "Place where the "
                "goods/services are supplied "
                "to. (If not given, "
                "organisation's home state "
                "will be taken)",
                "example": "TN",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "distance": {
                "description": "Distance travelled for a particular "
                "mileage expense where "
                "<code>mileage_type</code> is "
                "<code>manual</code>",
                "example": " ",
                "type": "string",
            },
            "employee_id": {
                "description": "ID of the employee who has submitted this mileage expense.",
                "example": "982000000030040",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
            "end_reading": {
                "description": "End reading of odometer when creating "
                "a mileage expense where "
                "<code>mileage_type</code> is "
                "<code>odometer</code>.",
                "example": " ",
                "format": "double",
                "type": "number",
            },
            "engine_capacity_range": {
                "description": "Engine capacity range for a "
                "particular mileage expense. "
                "Allowed Values: "
                "<code>less_than_1400cc</code>, "
                "<code>between_1400cc_and_1600cc</code>, "
                "<code>between_1600cc_and_2000cc</code> "
                "and "
                "<code>more_than_2000cc</code>",
                "example": " ",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
            "exchange_rate": {"example": 1, "format": "double", "type": "number"},
            "fuel_type": {
                "description": "Fuel type for a particular mileage "
                "expense. Allowed Values: "
                "<code>petrol</code>, <code>lpg</code> "
                "and <code>diesel</code>",
                "example": " ",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
            "gst_no": {
                "description": "15 digit GST identification number of the vendor.",
                "example": "22AAAAA0000A1Z5",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "hsn_or_sac": {
                "description": "Add HSN/SAC code for your goods/services",
                "example": 80540,
                "type": "string",
                "x-node_available_in": ["in", "ke"],
                "x-node_unavailable_in": [],
            },
            "is_billable": {"example": True, "type": "boolean"},
            "is_inclusive_tax": {"example": False, "type": "boolean"},
            "line_items": {
                "items": {
                    "properties": {
                        "account_id": {
                            "description": "ID of the expense account.",
                            "example": 982000000561057,
                            "type": "string",
                        },
                        "acquisition_vat_id": {
                            "description": "This "
                            "is "
                            "the "
                            "ID "
                            "of "
                            "the "
                            "tax "
                            "applied "
                            "in "
                            "case "
                            "this "
                            "is "
                            "an "
                            "EU "
                            "- "
                            "goods "
                            "expense "
                            "and "
                            "acquisition "
                            "VAT "
                            "needs "
                            "to "
                            "be "
                            "reported.",
                            "example": " ",
                            "type": "string",
                            "x-node_available_in": ["uk"],
                            "x-node_unavailable_in": [],
                        },
                        "amount": {
                            "description": "Amount of the Expense.",
                            "example": 112.5,
                            "format": "double",
                            "type": "number",
                        },
                        "description": {
                            "description": "Description of the expense. Max-length [100]",
                            "example": "Marketing",
                            "type": "string",
                        },
                        "item_order": {"example": 1, "type": "string"},
                        "line_item_id": {"example": 10763000000140068, "type": "string"},
                        "location_id": {
                            "description": "Location ID",
                            "example": "460000000038080",
                            "type": "string",
                        },
                        "product_type": {
                            "description": "Type "
                            "of "
                            "the "
                            "expense. "
                            "This "
                            "denotes "
                            "whether "
                            "the "
                            "expense "
                            "is "
                            "to "
                            "be "
                            "treated "
                            "as "
                            "a "
                            "goods "
                            "or "
                            "service "
                            "or "
                            "capital "
                            "asset "
                            "purchase. "
                            "Allowed "
                            "Values:<br/> "
                            "<b>For "
                            "UK: "
                            "</b><code>digital_service</code>, "
                            "<code>goods</code> "
                            "and "
                            "<code>service</code>.<br/><b>For "
                            "SouthAfrica "
                            "Edition:</b> "
                            "<code>service</code>, "
                            "<code>goods</code>, "
                            "<code>capital_service</code> "
                            "and "
                            "<code>capital_goods</code>",
                            "example": "goods",
                            "type": "string",
                            "x-node_available_in": ["uk", "za"],
                            "x-node_unavailable_in": [],
                        },
                        "reverse_charge_tax_id": {
                            "description": "ID of the reverse charge tax",
                            "example": 982000000561063,
                            "type": "string",
                        },
                        "reverse_charge_vat_id": {
                            "description": "This "
                            "is "
                            "the "
                            "ID "
                            "of "
                            "the "
                            "tax "
                            "applied "
                            "in "
                            "case "
                            "this "
                            "is "
                            "a "
                            "non "
                            "UK "
                            "- "
                            "service "
                            "expense "
                            "and "
                            "reverse "
                            "charge "
                            "VAT "
                            "needs "
                            "to "
                            "be "
                            "reported.",
                            "example": " ",
                            "type": "string",
                            "x-node_available_in": ["uk"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_exemption_code": {
                            "description": "Enter tax exemption code",
                            "type": "string",
                            "x-node_available_in": ["in"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_exemption_id": {
                            "description": "Enter tax exemption ID",
                            "example": 982000000561067,
                            "type": "string",
                            "x-node_available_in": ["in"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_id": {"example": 982000000566007, "type": "string"},
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "location_id": {
                "description": "Location ID",
                "example": "460000000038080",
                "type": "string",
            },
            "mileage_rate": {
                "description": "Mileage rate for a particular mileage expense.",
                "example": " ",
                "format": "double",
                "type": "number",
            },
            "mileage_type": {"example": "non_mileage", "type": "string"},
            "mileage_unit": {
                "description": "Unit of the distance travelled. "
                "Allowed Values: <code>km</code> and "
                "<code>mile</code>",
                "example": " ",
                "type": "string",
            },
            "paid_through_account_id": {
                "description": "Search expenses by paid through account id.",
                "example": 982000000567250,
                "type": "string",
            },
            "place_of_supply": {
                "description": "The place of supply is where a "
                "transaction is considered to have "
                "occurred for VAT purposes. For the "
                "supply of goods, the place of "
                "supply is the location of the "
                "goods when the supply occurs. For "
                "the supply of services, the place "
                "of supply should be where the "
                "supplier is established. (If not "
                "given, <code>place of "
                "contact</code> given for the "
                "contact will be "
                "taken)<br/>Supported codes for UAE "
                "emirates are : </br>Abu Dhabi - "
                "<code>AB</code>,</br>Ajman - "
                "<code>AJ</code>,</br>Dubai - "
                "<code>DU</code>,</br>Fujairah - "
                "<code>FU</code>,</br>Ras "
                "al-Khaimah - "
                "<code>RA</code>,</br>Sharjah - "
                "<code>SH</code>,</br>Umm al-Quwain "
                "- <code>UM</code>.<br/>Supported "
                "codes for the GCC countries are : "
                "</br>United Arab Emirates - "
                "<code>AE</code>,</br>Saudi Arabia "
                "- <code>SA</code>,</br>Bahrain - "
                "<code>BH</code>,</br>Kuwait - "
                "<code>KW</code>,</br>Oman - "
                "<code>OM</code>,</br>Qatar - "
                "<code>QA</code>.",
                "example": "DU",
                "type": "string",
                "x-node_available_in": ["gcc"],
                "x-node_unavailable_in": [],
            },
            "product_type": {
                "description": "Type of the expense. This denotes "
                "whether the expense is to be treated "
                "as a goods or service or capital "
                "asset purchase. Allowed Values:<br/> "
                "<b>For UK: "
                "</b><code>digital_service</code>, "
                "<code>goods</code> and "
                "<code>service</code>.<br/><b>For "
                "SouthAfrica Edition:</b> "
                "<code>service</code>, "
                "<code>goods</code>, "
                "<code>capital_service</code> and "
                "<code>capital_goods</code>",
                "example": "goods",
                "type": "string",
                "x-node_available_in": ["uk", "za"],
                "x-node_unavailable_in": [],
            },
            "project_id": {
                "description": "ID of the project associated with the customer.",
                "example": 982000000567226,
                "type": "string",
            },
            "reference_number": {
                "description": "Reference number of the expense. Max-length [100]",
                "example": None,
                "type": "string",
            },
            "reverse_charge_tax_id": {
                "description": "ID of the reverse charge tax",
                "example": 982000000561063,
                "type": "string",
            },
            "reverse_charge_vat_id": {
                "description": "This is the ID of the tax "
                "applied in case this is a "
                "non UK - service expense and "
                "reverse charge VAT needs to "
                "be reported.",
                "example": " ",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
            "source_of_supply": {
                "description": "Place from where the "
                "goods/services are supplied. (If "
                "not given, <code>place of "
                "contact</code> given for the "
                "contact will be taken)",
                "example": "AP",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "start_reading": {
                "description": "Start reading of odometer when "
                "creating a mileage expense where "
                "<code>mileage_type</code> is "
                "<code>odometer</code>.",
                "example": " ",
                "format": "double",
                "type": "number",
            },
            "tax_id": {"example": 982000000566007, "type": "string"},
            "tax_treatment": {
                "description": "VAT treatment for the expense "
                ".Choose whether the contact falls "
                "under: "
                "<code>vat_registered</code>,<code>vat_not_registered</code>,<code>gcc_vat_not_registered</code>,<code>gcc_vat_registered</code>,<code>non_gcc</code>.</br><code>dz_vat_registered</code> "
                "and "
                "<code>dz_vat_not_registered</code> "
                "are supported only for <b>UAE</b>. "
                "<br/><b>For Kenya Edition:</b> "
                "<code>vat_registered</code> "
                ",<code>vat_not_registered</code> "
                ",<code>non_kenya</code>(A business "
                "that is located outside "
                "Kenya).<br/><b>For SouthAfrica "
                "Edition:</b> "
                "<code>vat_registered</code>, "
                "<code>vat_not_registered</code>, "
                "<code>overseas</code>(A business "
                "that is located outside "
                "SouthAfrica).",
                "example": "vat_registered",
                "type": "string",
                "x-node_available_in": ["gcc", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "taxes": {
                "items": {
                    "properties": {
                        "tax_amount": {"example": 11.85, "format": "double", "type": "number"},
                        "tax_id": {"example": 982000000566007, "type": "string"},
                    },
                    "type": "object",
                },
                "type": "array",
                "x-node_available_in": ["mx"],
                "x-node_unavailable_in": [],
            },
            "vat_treatment": {
                "description": "VAT treatment for the expense. VAT "
                "treatment denotes the location of "
                "the vendor, if the vendor resides in "
                "UK then the VAT treatment is "
                "<code>uk</code>. If the vendor is in "
                "an EU country & VAT registered, you "
                "are resides in Northen Ireland and "
                "purchasing Goods then his VAT "
                "treatment is "
                "<code>eu_vat_registered</code> and "
                "if he resides outside the UK then "
                "his VAT treatment is "
                "<code>overseas</code> (For Pre "
                "Brexit, this can be split as "
                "<code>eu_vat_registered</code>, "
                "<code>eu_vat_not_registered</code> "
                "and <code>non_eu</code>).",
                "example": "eu_vat_not_registered",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
            "vehicle_type": {
                "description": "Vehicle type for a particular mileage "
                "expense. Allowed Values: "
                "<code>car</code>, <code>van</code>, "
                "<code>motorcycle</code> and "
                "<code>bike</code>",
                "example": " ",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
            "vendor_id": {
                "description": "ID of the vendor the expense is made.",
                "example": " ",
                "type": "string",
            },
        },
        "required": ["date", "account_id", "amount", "paid_through_account_id"],
        "type": "object",
    },
    "UPDATEEXPENSEWITHCUSTOMFIELD_REQUEST_BODY_SCHEMA": {
        "properties": {
            "account_id": {
                "description": "ID of the expense account.",
                "example": 982000000561057,
                "type": "string",
            },
            "acquisition_vat_id": {
                "description": "This is the ID of the tax "
                "applied in case this is an EU - "
                "goods expense and acquisition "
                "VAT needs to be reported.",
                "example": " ",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
            "amount": {
                "description": "Amount of the Expense.",
                "example": 120.5,
                "format": "double",
                "type": "number",
            },
            "can_reclaim_vat_on_mileage": {
                "description": "To specify if tax can be reclaimed for this mileage expense.",
                "example": " ",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
            "currency_id": {"example": 982000000567001, "type": "string"},
            "custom_fields": {
                "description": "Custom fields for an expense.",
                "example": [],
                "items": {"type": "string"},
                "type": "array",
            },
            "customer_id": {
                "description": "ID of the expense account.",
                "example": 982000000567001,
                "type": "string",
            },
            "date": {
                "description": "Date of the expense",
                "example": "2013-11-18",
                "type": "string",
            },
            "description": {
                "description": "Description of the expense. Max-length [100]",
                "example": "Marketing",
                "type": "string",
            },
            "destination_of_supply": {
                "description": "Place where the "
                "goods/services are supplied "
                "to. (If not given, "
                "organisation's home state "
                "will be taken)",
                "example": "TN",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "distance": {
                "description": "Distance travelled for a particular "
                "mileage expense where "
                "<code>mileage_type</code> is "
                "<code>manual</code>",
                "example": " ",
                "type": "string",
            },
            "employee_id": {
                "description": "ID of the employee who has submitted this mileage expense.",
                "example": "982000000030040",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
            "end_reading": {
                "description": "End reading of odometer when creating "
                "a mileage expense where "
                "<code>mileage_type</code> is "
                "<code>odometer</code>.",
                "example": " ",
                "format": "double",
                "type": "number",
            },
            "engine_capacity_range": {
                "description": "Engine capacity range for a "
                "particular mileage expense. "
                "Allowed Values: "
                "<code>less_than_1400cc</code>, "
                "<code>between_1400cc_and_1600cc</code>, "
                "<code>between_1600cc_and_2000cc</code> "
                "and "
                "<code>more_than_2000cc</code>",
                "example": " ",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
            "exchange_rate": {"example": 1, "format": "double", "type": "number"},
            "fuel_type": {
                "description": "Fuel type for a particular mileage "
                "expense. Allowed Values: "
                "<code>petrol</code>, <code>lpg</code> "
                "and <code>diesel</code>",
                "example": " ",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
            "gst_no": {
                "description": "15 digit GST identification number of the vendor.",
                "example": "22AAAAA0000A1Z5",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "hsn_or_sac": {
                "description": "Add HSN/SAC code for your goods/services",
                "example": 80540,
                "type": "string",
                "x-node_available_in": ["in", "ke"],
                "x-node_unavailable_in": [],
            },
            "is_billable": {"example": True, "type": "boolean"},
            "is_inclusive_tax": {"example": False, "type": "boolean"},
            "line_items": {
                "items": {
                    "properties": {
                        "account_id": {
                            "description": "ID of the expense account.",
                            "example": 982000000561057,
                            "type": "string",
                        },
                        "acquisition_vat_id": {
                            "description": "This "
                            "is "
                            "the "
                            "ID "
                            "of "
                            "the "
                            "tax "
                            "applied "
                            "in "
                            "case "
                            "this "
                            "is "
                            "an "
                            "EU "
                            "- "
                            "goods "
                            "expense "
                            "and "
                            "acquisition "
                            "VAT "
                            "needs "
                            "to "
                            "be "
                            "reported.",
                            "example": " ",
                            "type": "string",
                            "x-node_available_in": ["uk"],
                            "x-node_unavailable_in": [],
                        },
                        "amount": {
                            "description": "Amount of the Expense.",
                            "example": 112.5,
                            "format": "double",
                            "type": "number",
                        },
                        "description": {
                            "description": "Description of the expense. Max-length [100]",
                            "example": "Marketing",
                            "type": "string",
                        },
                        "item_order": {"example": 1, "type": "string"},
                        "line_item_id": {"example": 10763000000140068, "type": "string"},
                        "location_id": {
                            "description": "Location ID",
                            "example": "460000000038080",
                            "type": "string",
                        },
                        "product_type": {
                            "description": "Type "
                            "of "
                            "the "
                            "expense. "
                            "This "
                            "denotes "
                            "whether "
                            "the "
                            "expense "
                            "is "
                            "to "
                            "be "
                            "treated "
                            "as "
                            "a "
                            "goods "
                            "or "
                            "service "
                            "or "
                            "capital "
                            "asset "
                            "purchase. "
                            "Allowed "
                            "Values:<br/> "
                            "<b>For "
                            "UK: "
                            "</b><code>digital_service</code>, "
                            "<code>goods</code> "
                            "and "
                            "<code>service</code>.<br/><b>For "
                            "SouthAfrica "
                            "Edition:</b> "
                            "<code>service</code>, "
                            "<code>goods</code>, "
                            "<code>capital_service</code> "
                            "and "
                            "<code>capital_goods</code>",
                            "example": "goods",
                            "type": "string",
                            "x-node_available_in": ["uk", "za"],
                            "x-node_unavailable_in": [],
                        },
                        "reverse_charge_tax_id": {
                            "description": "ID of the reverse charge tax",
                            "example": 982000000561063,
                            "type": "string",
                        },
                        "reverse_charge_vat_id": {
                            "description": "This "
                            "is "
                            "the "
                            "ID "
                            "of "
                            "the "
                            "tax "
                            "applied "
                            "in "
                            "case "
                            "this "
                            "is "
                            "a "
                            "non "
                            "UK "
                            "- "
                            "service "
                            "expense "
                            "and "
                            "reverse "
                            "charge "
                            "VAT "
                            "needs "
                            "to "
                            "be "
                            "reported.",
                            "example": " ",
                            "type": "string",
                            "x-node_available_in": ["uk"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_exemption_code": {
                            "description": "Enter tax exemption code",
                            "type": "string",
                            "x-node_available_in": ["in"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_exemption_id": {
                            "description": "Enter tax exemption ID",
                            "example": 982000000561067,
                            "type": "string",
                            "x-node_available_in": ["in"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_id": {"example": 982000000566007, "type": "string"},
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "location_id": {
                "description": "Location ID",
                "example": "460000000038080",
                "type": "string",
            },
            "mileage_rate": {
                "description": "Mileage rate for a particular mileage expense.",
                "example": " ",
                "format": "double",
                "type": "number",
            },
            "mileage_type": {"example": "non_mileage", "type": "string"},
            "mileage_unit": {
                "description": "Unit of the distance travelled. "
                "Allowed Values: <code>km</code> and "
                "<code>mile</code>",
                "example": " ",
                "type": "string",
            },
            "paid_through_account_id": {
                "description": "Search expenses by paid through account id.",
                "example": 982000000567250,
                "type": "string",
            },
            "place_of_supply": {
                "description": "The place of supply is where a "
                "transaction is considered to have "
                "occurred for VAT purposes. For the "
                "supply of goods, the place of "
                "supply is the location of the "
                "goods when the supply occurs. For "
                "the supply of services, the place "
                "of supply should be where the "
                "supplier is established. (If not "
                "given, <code>place of "
                "contact</code> given for the "
                "contact will be "
                "taken)<br/>Supported codes for UAE "
                "emirates are : </br>Abu Dhabi - "
                "<code>AB</code>,</br>Ajman - "
                "<code>AJ</code>,</br>Dubai - "
                "<code>DU</code>,</br>Fujairah - "
                "<code>FU</code>,</br>Ras "
                "al-Khaimah - "
                "<code>RA</code>,</br>Sharjah - "
                "<code>SH</code>,</br>Umm al-Quwain "
                "- <code>UM</code>.<br/>Supported "
                "codes for the GCC countries are : "
                "</br>United Arab Emirates - "
                "<code>AE</code>,</br>Saudi Arabia "
                "- <code>SA</code>,</br>Bahrain - "
                "<code>BH</code>,</br>Kuwait - "
                "<code>KW</code>,</br>Oman - "
                "<code>OM</code>,</br>Qatar - "
                "<code>QA</code>.",
                "example": "DU",
                "type": "string",
                "x-node_available_in": ["gcc"],
                "x-node_unavailable_in": [],
            },
            "product_type": {
                "description": "Type of the expense. This denotes "
                "whether the expense is to be treated "
                "as a goods or service or capital "
                "asset purchase. Allowed Values:<br/> "
                "<b>For UK: "
                "</b><code>digital_service</code>, "
                "<code>goods</code> and "
                "<code>service</code>.<br/><b>For "
                "SouthAfrica Edition:</b> "
                "<code>service</code>, "
                "<code>goods</code>, "
                "<code>capital_service</code> and "
                "<code>capital_goods</code>",
                "example": "goods",
                "type": "string",
                "x-node_available_in": ["uk", "za"],
                "x-node_unavailable_in": [],
            },
            "project_id": {
                "description": "ID of the project associated with the customer.",
                "example": 982000000567226,
                "type": "string",
            },
            "reference_number": {
                "description": "Reference number of the expense. Max-length [100]",
                "example": None,
                "type": "string",
            },
            "reverse_charge_tax_id": {
                "description": "ID of the reverse charge tax",
                "example": 982000000561063,
                "type": "string",
            },
            "reverse_charge_vat_id": {
                "description": "This is the ID of the tax "
                "applied in case this is a "
                "non UK - service expense and "
                "reverse charge VAT needs to "
                "be reported.",
                "example": " ",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
            "source_of_supply": {
                "description": "Place from where the "
                "goods/services are supplied. (If "
                "not given, <code>place of "
                "contact</code> given for the "
                "contact will be taken)",
                "example": "AP",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "start_reading": {
                "description": "Start reading of odometer when "
                "creating a mileage expense where "
                "<code>mileage_type</code> is "
                "<code>odometer</code>.",
                "example": " ",
                "format": "double",
                "type": "number",
            },
            "tax_id": {"example": 982000000566007, "type": "string"},
            "tax_treatment": {
                "description": "VAT treatment for the expense "
                ".Choose whether the contact falls "
                "under: "
                "<code>vat_registered</code>,<code>vat_not_registered</code>,<code>gcc_vat_not_registered</code>,<code>gcc_vat_registered</code>,<code>non_gcc</code>.</br><code>dz_vat_registered</code> "
                "and "
                "<code>dz_vat_not_registered</code> "
                "are supported only for <b>UAE</b>. "
                "<br/><b>For Kenya Edition:</b> "
                "<code>vat_registered</code> "
                ",<code>vat_not_registered</code> "
                ",<code>non_kenya</code>(A business "
                "that is located outside "
                "Kenya).<br/><b>For SouthAfrica "
                "Edition:</b> "
                "<code>vat_registered</code>, "
                "<code>vat_not_registered</code>, "
                "<code>overseas</code>(A business "
                "that is located outside "
                "SouthAfrica).",
                "example": "vat_registered",
                "type": "string",
                "x-node_available_in": ["gcc", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "taxes": {
                "items": {
                    "properties": {
                        "tax_amount": {"example": 11.85, "format": "double", "type": "number"},
                        "tax_id": {"example": 982000000566007, "type": "string"},
                    },
                    "type": "object",
                },
                "type": "array",
                "x-node_available_in": ["mx"],
                "x-node_unavailable_in": [],
            },
            "vat_treatment": {
                "description": "VAT treatment for the expense. VAT "
                "treatment denotes the location of "
                "the vendor, if the vendor resides in "
                "UK then the VAT treatment is "
                "<code>uk</code>. If the vendor is in "
                "an EU country & VAT registered, you "
                "are resides in Northen Ireland and "
                "purchasing Goods then his VAT "
                "treatment is "
                "<code>eu_vat_registered</code> and "
                "if he resides outside the UK then "
                "his VAT treatment is "
                "<code>overseas</code> (For Pre "
                "Brexit, this can be split as "
                "<code>eu_vat_registered</code>, "
                "<code>eu_vat_not_registered</code> "
                "and <code>non_eu</code>).",
                "example": "eu_vat_not_registered",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
            "vehicle_type": {
                "description": "Vehicle type for a particular mileage "
                "expense. Allowed Values: "
                "<code>car</code>, <code>van</code>, "
                "<code>motorcycle</code> and "
                "<code>bike</code>",
                "example": " ",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
            "vendor_id": {
                "description": "ID of the vendor the expense is made.",
                "example": " ",
                "type": "string",
            },
        },
        "required": ["date", "account_id", "amount", "paid_through_account_id"],
        "type": "object",
    },
    "UPDATEEXISTINGEXPENSE_REQUEST_BODY_SCHEMA": {
        "properties": {
            "account_id": {
                "description": "ID of the expense account.",
                "example": 982000000561057,
                "type": "string",
            },
            "acquisition_vat_id": {
                "description": "This is the ID of the tax "
                "applied in case this is an EU - "
                "goods expense and acquisition "
                "VAT needs to be reported.",
                "example": " ",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
            "amount": {
                "description": "Amount of the Expense.",
                "example": 120.5,
                "format": "double",
                "type": "number",
            },
            "can_reclaim_vat_on_mileage": {
                "description": "To specify if tax can be reclaimed for this mileage expense.",
                "example": " ",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
            "currency_id": {"example": 982000000567001, "type": "string"},
            "custom_fields": {
                "description": "Custom fields for an expense.",
                "example": [],
                "items": {"type": "string"},
                "type": "array",
            },
            "customer_id": {
                "description": "ID of the expense account.",
                "example": 982000000567001,
                "type": "string",
            },
            "date": {
                "description": "Date of the expense",
                "example": "2013-11-18",
                "type": "string",
            },
            "description": {
                "description": "Description of the expense. Max-length [100]",
                "example": "Marketing",
                "type": "string",
            },
            "destination_of_supply": {
                "description": "Place where the "
                "goods/services are supplied "
                "to. (If not given, "
                "organisation's home state "
                "will be taken)",
                "example": "TN",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "distance": {
                "description": "Distance travelled for a particular "
                "mileage expense where "
                "<code>mileage_type</code> is "
                "<code>manual</code>",
                "example": " ",
                "type": "string",
            },
            "employee_id": {
                "description": "ID of the employee who has submitted this mileage expense.",
                "example": "982000000030040",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
            "end_reading": {
                "description": "End reading of odometer when creating "
                "a mileage expense where "
                "<code>mileage_type</code> is "
                "<code>odometer</code>.",
                "example": " ",
                "format": "double",
                "type": "number",
            },
            "engine_capacity_range": {
                "description": "Engine capacity range for a "
                "particular mileage expense. "
                "Allowed Values: "
                "<code>less_than_1400cc</code>, "
                "<code>between_1400cc_and_1600cc</code>, "
                "<code>between_1600cc_and_2000cc</code> "
                "and "
                "<code>more_than_2000cc</code>",
                "example": " ",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
            "exchange_rate": {"example": 1, "format": "double", "type": "number"},
            "fuel_type": {
                "description": "Fuel type for a particular mileage "
                "expense. Allowed Values: "
                "<code>petrol</code>, <code>lpg</code> "
                "and <code>diesel</code>",
                "example": " ",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
            "gst_no": {
                "description": "15 digit GST identification number of the vendor.",
                "example": "22AAAAA0000A1Z5",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "hsn_or_sac": {
                "description": "Add HSN/SAC code for your goods/services",
                "example": 80540,
                "type": "string",
                "x-node_available_in": ["in", "ke"],
                "x-node_unavailable_in": [],
            },
            "is_billable": {"example": True, "type": "boolean"},
            "is_inclusive_tax": {"example": False, "type": "boolean"},
            "line_items": {
                "items": {
                    "properties": {
                        "account_id": {
                            "description": "ID of the expense account.",
                            "example": 982000000561057,
                            "type": "string",
                        },
                        "acquisition_vat_id": {
                            "description": "This "
                            "is "
                            "the "
                            "ID "
                            "of "
                            "the "
                            "tax "
                            "applied "
                            "in "
                            "case "
                            "this "
                            "is "
                            "an "
                            "EU "
                            "- "
                            "goods "
                            "expense "
                            "and "
                            "acquisition "
                            "VAT "
                            "needs "
                            "to "
                            "be "
                            "reported.",
                            "example": " ",
                            "type": "string",
                            "x-node_available_in": ["uk"],
                            "x-node_unavailable_in": [],
                        },
                        "amount": {
                            "description": "Amount of the Expense.",
                            "example": 112.5,
                            "format": "double",
                            "type": "number",
                        },
                        "description": {
                            "description": "Description of the expense. Max-length [100]",
                            "example": "Marketing",
                            "type": "string",
                        },
                        "item_order": {"example": 1, "type": "string"},
                        "line_item_id": {"example": 10763000000140068, "type": "string"},
                        "location_id": {
                            "description": "Location ID",
                            "example": "460000000038080",
                            "type": "string",
                        },
                        "product_type": {
                            "description": "Type "
                            "of "
                            "the "
                            "expense. "
                            "This "
                            "denotes "
                            "whether "
                            "the "
                            "expense "
                            "is "
                            "to "
                            "be "
                            "treated "
                            "as "
                            "a "
                            "goods "
                            "or "
                            "service "
                            "or "
                            "capital "
                            "asset "
                            "purchase. "
                            "Allowed "
                            "Values:<br/> "
                            "<b>For "
                            "UK: "
                            "</b><code>digital_service</code>, "
                            "<code>goods</code> "
                            "and "
                            "<code>service</code>.<br/><b>For "
                            "SouthAfrica "
                            "Edition:</b> "
                            "<code>service</code>, "
                            "<code>goods</code>, "
                            "<code>capital_service</code> "
                            "and "
                            "<code>capital_goods</code>",
                            "example": "goods",
                            "type": "string",
                            "x-node_available_in": ["uk", "za"],
                            "x-node_unavailable_in": [],
                        },
                        "reverse_charge_tax_id": {
                            "description": "ID of the reverse charge tax",
                            "example": 982000000561063,
                            "type": "string",
                        },
                        "reverse_charge_vat_id": {
                            "description": "This "
                            "is "
                            "the "
                            "ID "
                            "of "
                            "the "
                            "tax "
                            "applied "
                            "in "
                            "case "
                            "this "
                            "is "
                            "a "
                            "non "
                            "UK "
                            "- "
                            "service "
                            "expense "
                            "and "
                            "reverse "
                            "charge "
                            "VAT "
                            "needs "
                            "to "
                            "be "
                            "reported.",
                            "example": " ",
                            "type": "string",
                            "x-node_available_in": ["uk"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_exemption_code": {
                            "description": "Enter tax exemption code",
                            "type": "string",
                            "x-node_available_in": ["in"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_exemption_id": {
                            "description": "Enter tax exemption ID",
                            "example": 982000000561067,
                            "type": "string",
                            "x-node_available_in": ["in"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_id": {"example": 982000000566007, "type": "string"},
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "location_id": {
                "description": "Location ID",
                "example": "460000000038080",
                "type": "string",
            },
            "mileage_rate": {
                "description": "Mileage rate for a particular mileage expense.",
                "example": " ",
                "format": "double",
                "type": "number",
            },
            "mileage_type": {"example": "non_mileage", "type": "string"},
            "mileage_unit": {
                "description": "Unit of the distance travelled. "
                "Allowed Values: <code>km</code> and "
                "<code>mile</code>",
                "example": " ",
                "type": "string",
            },
            "paid_through_account_id": {
                "description": "Search expenses by paid through account id.",
                "example": 982000000567250,
                "type": "string",
            },
            "place_of_supply": {
                "description": "The place of supply is where a "
                "transaction is considered to have "
                "occurred for VAT purposes. For the "
                "supply of goods, the place of "
                "supply is the location of the "
                "goods when the supply occurs. For "
                "the supply of services, the place "
                "of supply should be where the "
                "supplier is established. (If not "
                "given, <code>place of "
                "contact</code> given for the "
                "contact will be "
                "taken)<br/>Supported codes for UAE "
                "emirates are : </br>Abu Dhabi - "
                "<code>AB</code>,</br>Ajman - "
                "<code>AJ</code>,</br>Dubai - "
                "<code>DU</code>,</br>Fujairah - "
                "<code>FU</code>,</br>Ras "
                "al-Khaimah - "
                "<code>RA</code>,</br>Sharjah - "
                "<code>SH</code>,</br>Umm al-Quwain "
                "- <code>UM</code>.<br/>Supported "
                "codes for the GCC countries are : "
                "</br>United Arab Emirates - "
                "<code>AE</code>,</br>Saudi Arabia "
                "- <code>SA</code>,</br>Bahrain - "
                "<code>BH</code>,</br>Kuwait - "
                "<code>KW</code>,</br>Oman - "
                "<code>OM</code>,</br>Qatar - "
                "<code>QA</code>.",
                "example": "DU",
                "type": "string",
                "x-node_available_in": ["gcc"],
                "x-node_unavailable_in": [],
            },
            "product_type": {
                "description": "Type of the expense. This denotes "
                "whether the expense is to be treated "
                "as a goods or service or capital "
                "asset purchase. Allowed Values:<br/> "
                "<b>For UK: "
                "</b><code>digital_service</code>, "
                "<code>goods</code> and "
                "<code>service</code>.<br/><b>For "
                "SouthAfrica Edition:</b> "
                "<code>service</code>, "
                "<code>goods</code>, "
                "<code>capital_service</code> and "
                "<code>capital_goods</code>",
                "example": "goods",
                "type": "string",
                "x-node_available_in": ["uk", "za"],
                "x-node_unavailable_in": [],
            },
            "project_id": {
                "description": "ID of the project associated with the customer.",
                "example": 982000000567226,
                "type": "string",
            },
            "reference_number": {
                "description": "Reference number of the expense. Max-length [100]",
                "example": None,
                "type": "string",
            },
            "reverse_charge_tax_id": {
                "description": "ID of the reverse charge tax",
                "example": 982000000561063,
                "type": "string",
            },
            "reverse_charge_vat_id": {
                "description": "This is the ID of the tax "
                "applied in case this is a "
                "non UK - service expense and "
                "reverse charge VAT needs to "
                "be reported.",
                "example": " ",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
            "source_of_supply": {
                "description": "Place from where the "
                "goods/services are supplied. (If "
                "not given, <code>place of "
                "contact</code> given for the "
                "contact will be taken)",
                "example": "AP",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "start_reading": {
                "description": "Start reading of odometer when "
                "creating a mileage expense where "
                "<code>mileage_type</code> is "
                "<code>odometer</code>.",
                "example": " ",
                "format": "double",
                "type": "number",
            },
            "tax_id": {"example": 982000000566007, "type": "string"},
            "tax_treatment": {
                "description": "VAT treatment for the expense "
                ".Choose whether the contact falls "
                "under: "
                "<code>vat_registered</code>,<code>vat_not_registered</code>,<code>gcc_vat_not_registered</code>,<code>gcc_vat_registered</code>,<code>non_gcc</code>.</br><code>dz_vat_registered</code> "
                "and "
                "<code>dz_vat_not_registered</code> "
                "are supported only for <b>UAE</b>. "
                "<br/><b>For Kenya Edition:</b> "
                "<code>vat_registered</code> "
                ",<code>vat_not_registered</code> "
                ",<code>non_kenya</code>(A business "
                "that is located outside "
                "Kenya).<br/><b>For SouthAfrica "
                "Edition:</b> "
                "<code>vat_registered</code>, "
                "<code>vat_not_registered</code>, "
                "<code>overseas</code>(A business "
                "that is located outside "
                "SouthAfrica).",
                "example": "vat_registered",
                "type": "string",
                "x-node_available_in": ["gcc", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "taxes": {
                "items": {
                    "properties": {
                        "tax_amount": {"example": 11.85, "format": "double", "type": "number"},
                        "tax_id": {"example": 982000000566007, "type": "string"},
                    },
                    "type": "object",
                },
                "type": "array",
                "x-node_available_in": ["mx"],
                "x-node_unavailable_in": [],
            },
            "vat_treatment": {
                "description": "VAT treatment for the expense. VAT "
                "treatment denotes the location of "
                "the vendor, if the vendor resides in "
                "UK then the VAT treatment is "
                "<code>uk</code>. If the vendor is in "
                "an EU country & VAT registered, you "
                "are resides in Northen Ireland and "
                "purchasing Goods then his VAT "
                "treatment is "
                "<code>eu_vat_registered</code> and "
                "if he resides outside the UK then "
                "his VAT treatment is "
                "<code>overseas</code> (For Pre "
                "Brexit, this can be split as "
                "<code>eu_vat_registered</code>, "
                "<code>eu_vat_not_registered</code> "
                "and <code>non_eu</code>).",
                "example": "eu_vat_not_registered",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
            "vehicle_type": {
                "description": "Vehicle type for a particular mileage "
                "expense. Allowed Values: "
                "<code>car</code>, <code>van</code>, "
                "<code>motorcycle</code> and "
                "<code>bike</code>",
                "example": " ",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
            "vendor_id": {
                "description": "ID of the vendor the expense is made.",
                "example": " ",
                "type": "string",
            },
        },
        "required": ["date", "account_id", "amount", "paid_through_account_id"],
        "type": "object",
    },
    "CREATEEMPLOYEEFOREXPENSE_REQUEST_BODY_SCHEMA": {
        "properties": {
            "email": {"example": "johnsmith@zilliuminc.com", "type": "string"},
            "name": {"example": "John David", "type": "string"},
        },
        "required": ["name", "email"],
        "type": "object",
    },
    "CREATEFIXEDASSET_REQUEST_BODY_SCHEMA": {
        "properties": {
            "asset_account_id": {
                "description": "Enter the account id to track the fixed asset.",
                "example": "3640355000000000367",
                "type": "string",
            },
            "asset_cost": {
                "description": "Enter the purchase cost of the asset",
                "example": 1000,
                "format": "double",
                "type": "number",
            },
            "asset_name": {
                "description": "Enter the name of the fixed asset.",
                "example": "Laptop",
                "type": "string",
            },
            "asset_purchase_date": {
                "description": "Enter the Purchase date of the asset",
                "example": "2024-12-17",
                "type": "string",
            },
            "computation_type": {
                "description": "Enter the computation types of "
                "assets. The available types are: "
                "<code>prorata_basis</code> and "
                "<code>no_prorata</code>",
                "example": "prorata_basis",
                "type": "string",
            },
            "custom_fields": {
                "items": {
                    "properties": {
                        "customfield_id": {
                            "description": "ID of the Custom Field",
                            "example": "460000000098001",
                            "type": "string",
                        },
                        "value": {
                            "description": "Value of the Custom Field",
                            "example": "Normal",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "dep_start_value": {
                "description": "Enter the value from which depreciation will be calculated.",
                "example": 1000,
                "format": "double",
                "type": "number",
            },
            "depreciation_account_id": {
                "description": "Enter the account id to track the asset's depreciation over time.",
                "example": "3640355000000000367",
                "type": "string",
            },
            "depreciation_frequency": {
                "description": "Enter the frequency of "
                "depreciation. The available "
                "frequencies are: "
                "<code>yearly</code> and "
                "<code>monthly</code>",
                "example": "yearly",
                "type": "string",
            },
            "depreciation_method": {
                "description": "Enter the depreciation method "
                "for your asset.The available "
                "methods are: "
                "<code>declining_method</code> "
                "and "
                "<code>straight_line</code>. "
                "<br/><b>For US and GLobal "
                "Edition:</b> "
                "<code>declining_method</code>, "
                "<code>straight_line</code>, "
                "<code>200_declining_method</code> "
                "and "
                "<code>150_declining_method</code>",
                "example": "declining_method",
                "type": "string",
            },
            "depreciation_percentage": {
                "description": "Enter the depreciation "
                "percentage only if the "
                "entered depreciation "
                "method is a declining "
                "method. The entered "
                "percentage should be "
                "within the range of 0 to "
                "100",
                "example": 12,
                "format": "double",
                "type": "number",
            },
            "depreciation_start_date": {
                "description": "Enter the depreciation start date of the asset",
                "example": "2024-12-17",
                "type": "string",
            },
            "description": {"description": "Description of the asset", "type": "string"},
            "expense_account_id": {
                "description": "Enter the account id to track "
                "the expenses associated with "
                "the asset's depreciation.The "
                "available account types are "
                "<b>Expense</b>  and <b>Other "
                "Expense</b>",
                "example": "3640355000000000421",
                "type": "string",
            },
            "fixed_asset_type_id": {
                "description": "Associate the fixed asset with "
                "a fixed asset type by "
                "specifying fixed asset type "
                "id.",
                "example": "3640355000000319008",
                "type": "string",
            },
            "notes": {
                "description": "Provide notes for the asset, if required",
                "example": "This is a laptop Model 2024",
                "type": "string",
            },
            "salvage_value": {
                "description": "Enter the remaining amount of the "
                "asset after its useful life or the "
                "value after it's fully depreciated",
                "example": 100,
                "format": "double",
                "type": "string",
            },
            "serial_no": {
                "description": "serial number of the asset",
                "example": "SN-0001",
                "type": "string",
            },
            "tags": {
                "items": {
                    "properties": {
                        "tag_id": {
                            "description": "ID of the tag",
                            "example": "460000000094001",
                            "type": "string",
                        },
                        "tag_option_id": {
                            "description": "Option ID of the tag",
                            "example": "460000000048001",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "total_life": {
                "description": "Enter the total life of the asset (in months)",
                "example": 60,
                "type": "number",
            },
            "warranty_expiry_date": {
                "description": "Enter the warranty expiration date of the asset",
                "example": "2027-12-17",
                "type": "string",
            },
        },
        "required": [
            "asset_name",
            "fixed_asset_type_id",
            "asset_account_id",
            "asset_cost",
            "asset_purchase_date",
        ],
        "type": "object",
    },
    "UPDATEFIXEDASSETINFO_REQUEST_BODY_SCHEMA": {
        "properties": {
            "asset_account_id": {
                "description": "Enter the account id to track the fixed asset.",
                "example": "3640355000000000367",
                "type": "string",
            },
            "asset_cost": {
                "description": "Enter the purchase cost of the asset",
                "example": 1000,
                "format": "double",
                "type": "number",
            },
            "asset_name": {
                "description": "Enter the name of the fixed asset.",
                "example": "Laptop",
                "type": "string",
            },
            "asset_purchase_date": {
                "description": "Enter the Purchase date of the asset",
                "example": "2024-12-17",
                "type": "string",
            },
            "computation_type": {
                "description": "Enter the computation types of "
                "assets. The available types are: "
                "<code>prorata_basis</code> and "
                "<code>no_prorata</code>",
                "example": "prorata_basis",
                "type": "string",
            },
            "custom_fields": {
                "items": {
                    "properties": {
                        "customfield_id": {
                            "description": "ID of the Custom Field",
                            "example": "460000000098001",
                            "type": "string",
                        },
                        "value": {
                            "description": "Value of the Custom Field",
                            "example": "Normal",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "dep_start_value": {
                "description": "Enter the value from which depreciation will be calculated.",
                "example": 1000,
                "format": "double",
                "type": "number",
            },
            "depreciation_account_id": {
                "description": "Enter the account id to track the asset's depreciation over time.",
                "example": "3640355000000000367",
                "type": "string",
            },
            "depreciation_frequency": {
                "description": "Enter the frequency of "
                "depreciation. The available "
                "frequencies are: "
                "<code>yearly</code> and "
                "<code>monthly</code>",
                "example": "yearly",
                "type": "string",
            },
            "depreciation_method": {
                "description": "Enter the depreciation method "
                "for your asset.The available "
                "methods are: "
                "<code>declining_method</code> "
                "and "
                "<code>straight_line</code>. "
                "<br/><b>For US and GLobal "
                "Edition:</b> "
                "<code>declining_method</code>, "
                "<code>straight_line</code>, "
                "<code>200_declining_method</code> "
                "and "
                "<code>150_declining_method</code>",
                "example": "declining_method",
                "type": "string",
            },
            "depreciation_percentage": {
                "description": "Enter the depreciation "
                "percentage only if the "
                "entered depreciation "
                "method is a declining "
                "method. The entered "
                "percentage should be "
                "within the range of 0 to "
                "100",
                "example": 12,
                "format": "double",
                "type": "number",
            },
            "depreciation_start_date": {
                "description": "Enter the depreciation start date of the asset",
                "example": "2024-12-17",
                "type": "string",
            },
            "description": {"description": "Description of the asset", "type": "string"},
            "expense_account_id": {
                "description": "Enter the account id to track "
                "the expenses associated with "
                "the asset's depreciation.The "
                "available account types are "
                "<b>Expense</b>  and <b>Other "
                "Expense</b>",
                "example": "3640355000000000421",
                "type": "string",
            },
            "fixed_asset_type_id": {
                "description": "Associate the fixed asset with "
                "a fixed asset type by "
                "specifying fixed asset type "
                "id.",
                "example": "3640355000000319008",
                "type": "string",
            },
            "notes": {
                "description": "Provide notes for the asset, if required",
                "example": "This is a laptop Model 2024",
                "type": "string",
            },
            "salvage_value": {
                "description": "Enter the remaining amount of the "
                "asset after its useful life or the "
                "value after it's fully depreciated",
                "example": 100,
                "format": "double",
                "type": "string",
            },
            "serial_no": {
                "description": "serial number of the asset",
                "example": "SN-0001",
                "type": "string",
            },
            "tags": {
                "items": {
                    "properties": {
                        "tag_id": {
                            "description": "ID of the tag",
                            "example": "460000000094001",
                            "type": "string",
                        },
                        "tag_option_id": {
                            "description": "Option ID of the tag",
                            "example": "460000000048001",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "total_life": {
                "description": "Enter the total life of the asset (in months)",
                "example": 60,
                "type": "number",
            },
            "warranty_expiry_date": {
                "description": "Enter the warranty expiration date of the asset",
                "example": "2027-12-17",
                "type": "string",
            },
        },
        "required": [
            "asset_name",
            "fixed_asset_type_id",
            "asset_account_id",
            "asset_cost",
            "asset_purchase_date",
        ],
        "type": "object",
    },
    "WRITEOFFFIXEDASSET_REQUEST_BODY_SCHEMA": {
        "properties": {
            "date": {
                "description": "Enter the date on which the fixed asset is written off",
                "example": "2024-12-17",
                "type": "string",
            },
            "expense_account_id": {
                "description": "Enter an account id to track "
                "the expenses associated with "
                "the written-off fixed asset",
                "example": "3640355000000000421",
                "type": "string",
            },
            "reason": {
                "description": "Enter the reason for writing off the fixed asset",
                "example": "Asset is damaged",
                "type": "string",
            },
        },
        "required": ["date", "expense_account_id", "reason"],
        "type": "object",
    },
    "SELLFIXEDASSET_REQUEST_BODY_SCHEMA": {
        "properties": {
            "expense_account_id": {
                "description": "Enter the account id to track "
                "the expenses associated with "
                "the asset's depreciation.The "
                "available account types are "
                "<b>Expense</b>  and <b>Other "
                "Expense</b>",
                "example": "3640355000000000421",
                "type": "string",
            },
            "invoice_id": {
                "description": "Enter the invoice id associated with selling the fixed asset.",
                "example": "3640355000000319008",
                "type": "string",
            },
            "line_item_id": {
                "description": "Enter the line item id that is "
                "associated with the fixed asset "
                "account.",
                "example": "3640355000000319008",
                "type": "string",
            },
            "reason": {
                "description": "Enter the reason for selling the fixed asset",
                "example": "Asset is no longer required",
                "type": "string",
            },
        },
        "required": ["invoice_id", "line_item_id", "reason", "expense_account_id"],
        "type": "object",
    },
    "ADDFIXEDASSETCOMMENT_REQUEST_BODY_SCHEMA": {
        "properties": {
            "description": {
                "description": "It displays the description of the "
                "comment added for the fixed asset",
                "example": "Fixed asset is in good condition",
                "type": "string",
            }
        },
        "type": "object",
    },
    "CREATEFIXEDASSETTYPE_REQUEST_BODY_SCHEMA": {
        "properties": {
            "computation_type": {
                "description": "Enter the computation types of "
                "assets. The available types are: "
                "<code>prorata_basis</code> and "
                "<code>no_prorata</code>",
                "example": "prorata_basis",
                "type": "string",
            },
            "depreciation_account_id": {
                "description": "Enter the account id to track the asset's depreciation over time.",
                "example": "3640355000000000367",
                "type": "string",
            },
            "depreciation_frequency": {
                "description": "Enter the frequency of "
                "depreciation. The available "
                "frequencies are: "
                "<code>yearly</code> and "
                "<code>monthly</code>",
                "example": "yearly",
                "type": "string",
            },
            "depreciation_method": {
                "description": "Enter the depreciation method "
                "for your asset.The available "
                "methods are: "
                "<code>declining_method</code> "
                "and "
                "<code>straight_line</code>. "
                "<br/><b>For US and GLobal "
                "Edition:</b> "
                "<code>declining_method</code>, "
                "<code>straight_line</code>, "
                "<code>200_declining_method</code> "
                "and "
                "<code>150_declining_method</code>",
                "example": "declining_method",
                "type": "string",
            },
            "depreciation_percentage": {
                "description": "Enter the depreciation "
                "percentage only if the "
                "entered depreciation "
                "method is a declining "
                "method. The entered "
                "percentage should be "
                "within the range of 0 to "
                "100",
                "example": 12,
                "format": "double",
                "type": "number",
            },
            "expense_account_id": {
                "description": "Enter the account id to track "
                "the expenses associated with "
                "the asset's depreciation.The "
                "available account types are "
                "<b>Expense</b>  and <b>Other "
                "Expense</b>",
                "example": "3640355000000000421",
                "type": "string",
            },
            "fixed_asset_type_name": {
                "description": "Enter the name of fixed asset type",
                "example": "Machines",
                "type": "string",
            },
            "salvage_value": {
                "description": "Enter the remaining amount of the "
                "asset after its useful life or the "
                "value after it's fully depreciated",
                "example": 100,
                "format": "double",
                "type": "string",
            },
            "total_life": {
                "description": "Enter the total life of the asset (in months)",
                "example": 60,
                "type": "number",
            },
        },
        "required": [
            "fixed_asset_type_name",
            "expense_account_id",
            "depreciation_account_id",
            "depreciation_method",
            "depreciation_frequency",
            "depreciation_percentage",
            "total_life",
            "salvage_value",
            "computation_type",
        ],
        "type": "object",
    },
    "UPDATEFIXEDASSETTYPE_REQUEST_BODY_SCHEMA": {
        "properties": {
            "computation_type": {
                "description": "Enter the computation types of "
                "assets. The available types are: "
                "<code>prorata_basis</code> and "
                "<code>no_prorata</code>",
                "example": "prorata_basis",
                "type": "string",
            },
            "depreciation_account_id": {
                "description": "Enter the account id to track the asset's depreciation over time.",
                "example": "3640355000000000367",
                "type": "string",
            },
            "depreciation_frequency": {
                "description": "Enter the frequency of "
                "depreciation. The available "
                "frequencies are: "
                "<code>yearly</code> and "
                "<code>monthly</code>",
                "example": "yearly",
                "type": "string",
            },
            "depreciation_method": {
                "description": "Enter the depreciation method "
                "for your asset.The available "
                "methods are: "
                "<code>declining_method</code> "
                "and "
                "<code>straight_line</code>. "
                "<br/><b>For US and GLobal "
                "Edition:</b> "
                "<code>declining_method</code>, "
                "<code>straight_line</code>, "
                "<code>200_declining_method</code> "
                "and "
                "<code>150_declining_method</code>",
                "example": "declining_method",
                "type": "string",
            },
            "depreciation_percentage": {
                "description": "Enter the depreciation "
                "percentage only if the "
                "entered depreciation "
                "method is a declining "
                "method. The entered "
                "percentage should be "
                "within the range of 0 to "
                "100",
                "example": 12,
                "format": "double",
                "type": "number",
            },
            "expense_account_id": {
                "description": "Enter the account id to track "
                "the expenses associated with "
                "the asset's depreciation.The "
                "available account types are "
                "<b>Expense</b>  and <b>Other "
                "Expense</b>",
                "example": "3640355000000000421",
                "type": "string",
            },
            "fixed_asset_type_name": {
                "description": "Enter the name of fixed asset type",
                "example": "Machines",
                "type": "string",
            },
            "salvage_value": {
                "description": "Enter the remaining amount of the "
                "asset after its useful life or the "
                "value after it's fully depreciated",
                "example": 100,
                "format": "double",
                "type": "string",
            },
            "total_life": {
                "description": "Enter the total life of the asset (in months)",
                "example": 60,
                "type": "number",
            },
        },
        "required": [
            "fixed_asset_type_name",
            "expense_account_id",
            "depreciation_account_id",
            "depreciation_method",
            "depreciation_frequency",
            "depreciation_percentage",
            "total_life",
            "salvage_value",
            "computation_type",
        ],
        "type": "object",
    },
    "CREATECUSTOMERINVOICE_REQUEST_BODY_SCHEMA": {
        "properties": {
            "adjustment": {
                "description": "Additional charge or credit amount "
                "applied to the invoice total. This can "
                "be used for rounding adjustments, "
                "handling fees, or any other one-time "
                "charges/credits. Positive values add to "
                "the total, negative values reduce the "
                "total. This amount is applied after tax "
                "calculation and affects the final "
                "invoice total.",
                "example": 0,
                "format": "double",
                "type": "number",
            },
            "adjustment_description": {
                "description": "Text description explaining "
                "the reason for the "
                "adjustment amount. This "
                "description appears on the "
                "invoice document to explain "
                "why the adjustment was "
                "applied. Common examples "
                'include "Rounding '
                'adjustment", "Handling '
                'fee", "Early payment '
                'discount", or "Late payment '
                'fee". This helps customers '
                "understand the purpose of "
                "the adjustment.",
                "example": " ",
                "type": "string",
            },
            "allow_partial_payments": {
                "description": "Boolean flag that "
                "determines whether "
                "customers can make partial "
                "payments against this "
                "invoice. When "
                "<code>true</code>, "
                "customers can pay less than "
                "the full invoice amount, "
                "and the invoice will remain "
                "open with a remaining "
                "balance. When "
                "<code>false</code>, "
                "customers must pay the full "
                "amount to complete the "
                "invoice. This setting "
                "affects payment processing "
                "and invoice status "
                "tracking.",
                "example": True,
                "type": "boolean",
            },
            "avatax_exempt_no": {
                "description": "Exemption certificate number of the customer. Max-length [25]",
                "type": "string",
                "x-node_available_in": ["Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "avatax_tax_code": {
                "description": "A tax code is a unique label used "
                "to group Items (products, "
                "services, or charges) together. "
                "Refer the [link][2] for more "
                "deails. Max-length [25]",
                "type": "string",
                "x-node_available_in": ["Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "avatax_use_code": {
                "description": "Used to group like customers for "
                "exemption purposes. It is a custom "
                "value that links customers to a "
                "tax rule. Select from Avalara "
                "[standard codes][1] or enter a "
                "custom code. Max-length [25]",
                "type": "string",
                "x-node_available_in": ["Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "batch_payments": {
                "description": "Array of batch payment details to "
                "be processed with the invoice. Each "
                "payment includes payment mode, "
                "amount, and account information for "
                "automated payment processing.",
                "example": [
                    {"account_id": "1000000095342", "amount": "100.00", "payment_mode": "Cash"}
                ],
                "items": {
                    "properties": {
                        "account_id": {
                            "description": "Account ID where the payment will be recorded.",
                            "example": "1000000095342",
                            "type": "string",
                        },
                        "amount": {
                            "description": "Payment amount for this batch payment entry.",
                            "example": "100.00",
                            "type": "string",
                        },
                        "payment_mode": {
                            "description": "Mode of payment for this batch payment entry.",
                            "example": "Cash",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "billing_address_id": {
                "description": "Unique identifier of the "
                "billing address to be used for "
                "this invoice. Use the "
                "`billing_address_id` returned "
                "by the Addresses API for the "
                "same customer and organization. "
                "This address appears on the "
                "invoice document and is used "
                "for billing purposes. If "
                "omitted, the customer's default "
                "billing address will be used.",
                "example": "218500000000142012",
                "type": "string",
            },
            "cfdi_usage": {
                "description": "Choose CFDI Usage. Allowed "
                "values:</br><code>acquisition_of_merchandise</code>, "
                "<code>return_discount_bonus</code>, "
                "<code>general_expense</code>, "
                "<code>buildings</code>, "
                "<code>furniture_office_equipment</code>, "
                "<code>transport_equipment</code>, "
                "<code>computer_equipmentdye_molds_tools</code>, "
                "<code>telephone_communication</code>, "
                "<code>satellite_communication</code>, "
                "<code>other_machinery_equipment</code>, "
                "<code>hospital_expense</code>, "
                "<code>medical_expense_disability</code>, "
                "<code>funeral_expense</code>, "
                "<code>donation</code>, "
                "<code>interest_mortage_loans</code>, "
                "<code>contribution_sar</code>, "
                "<code>medical_expense_insurance_pormium</code>, "
                "<code>school_transportation_expense</code>, "
                "<code>deposit_saving_account</code>, "
                "<code>payment_educational_service</code>, "
                "<code>no_tax_effect</code>, "
                "<code>payment</code>, "
                "<code>payroll</code>.",
                "example": "acquisition_of_merchandise",
                "type": "string",
                "x-node_available_in": ["mx"],
                "x-node_unavailable_in": [],
            },
            "contact_persons": {
                "description": "Array of contact person IDs "
                "associated with the specified "
                "customer. Provide the IDs of "
                "contact persons (from the "
                "Contacts/Contact Persons API) who "
                "should receive invoice "
                "communications (e.g., emails) for "
                "this invoice. Each ID must belong "
                "to the same customer and "
                "organization as the invoice. If "
                "omitted, the customer's primary "
                "contact may be used.",
                "example": ["982000000870911", "982000000870915"],
                "items": {"type": "string"},
                "type": "array",
            },
            "contact_persons_associated": {
                "description": "Contact Persons associated with the transaction.",
                "items": {
                    "properties": {
                        "communication_preference": {
                            "description": "Preferred "
                            "modes "
                            "of "
                            "communication "
                            "for "
                            "the "
                            "contact "
                            "person "
                            "at "
                            "transaction "
                            "level.",
                            "properties": {
                                "is_email_enabled": {
                                    "description": "Used "
                                    "to "
                                    "check "
                                    "if "
                                    "Email "
                                    "communication "
                                    "preference "
                                    "is "
                                    "enabled "
                                    "for "
                                    "the "
                                    "contact "
                                    "person "
                                    "at "
                                    "transaction "
                                    "level.",
                                    "example": True,
                                    "type": "boolean",
                                },
                                "is_whatsapp_enabled": {
                                    "description": "Used "
                                    "to "
                                    "check "
                                    "if "
                                    "WhatsApp "
                                    "communication "
                                    "preference "
                                    "is "
                                    "enabled "
                                    "for "
                                    "the "
                                    "contact "
                                    "person "
                                    "at "
                                    "transaction "
                                    "level.",
                                    "example": True,
                                    "type": "boolean",
                                    "x-node_available_in": ["WhatsApp integration"],
                                },
                            },
                            "type": "object",
                        },
                        "contact_person_id": {
                            "description": "Unique ID of the Contact Person.",
                            "example": 982000000567003,
                            "format": "int64",
                            "type": "integer",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "currency_id": {
                "description": "Unique identifier of the currency in "
                "which the invoice will be created for "
                "the customer. Use the `currency_id` "
                "returned by the Currencies API for the "
                "same organization. This sets the "
                "currency for all monetary amounts on "
                "the invoice; if it differs from the "
                "organization's base currency, an "
                "appropriate `exchange_rate` may be "
                "required.",
                "example": 982000000000190,
                "type": "string",
            },
            "custom_body": {"example": " ", "type": "string"},
            "custom_fields": {
                "description": "Custom fields for an invoice.",
                "items": {
                    "properties": {
                        "customfield_id": {
                            "example": "46000000012845",
                            "format": "int64",
                            "type": "integer",
                        },
                        "value": {
                            "description": "Value of the Custom Field",
                            "example": "Normal",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "custom_subject": {"example": " ", "type": "string"},
            "customer_id": {
                "description": "Unique identifier of the customer in "
                "the current organization for whom this "
                "invoice is created. Required when "
                "creating an invoice. Use the "
                "`customer_id` returned by the get "
                "Customers API. Must belong to the "
                "organization specified by the "
                "`organization_id` parameter.",
                "example": 982000000567001,
                "type": "string",
            },
            "date": {
                "description": "The date on which the invoice is created. Use "
                "the format yyyy-mm-dd (e.g., 2013-11-17). "
                "This date appears on the invoice document and "
                "is used for accounting purposes. When "
                "searching invoices, supports variants: "
                "<code>date_start</code>, "
                "<code>date_end</code>, "
                "<code>date_before</code> and "
                "<code>date_after</code>.",
                "example": "2013-11-17",
                "type": "string",
            },
            "discount": {
                "description": "Discount amount applied to the invoice. "
                "Can be specified as a percentage (e.g., "
                "12.5 for 12.5%) — up to a maximum of 100% "
                "— or as a fixed amount (e.g., 190 for "
                "$190). The discount is applied based on "
                "the `is_discount_before_tax` setting and "
                "`discount_type` (entity_level or "
                "item_level).",
                "example": 0,
                "format": "float",
                "type": "number",
            },
            "discount_type": {
                "description": "Specifies the scope of discount "
                "application. "
                "<code>entity_level</code> applies "
                "the discount to the entire invoice "
                "total. <code>item_level</code> "
                "applies the discount to individual "
                "line items. This determines how the "
                "discount amount is distributed "
                "across the invoice items.",
                "example": "item_level",
                "type": "string",
            },
            "due_date": {
                "description": "The date by which payment is due for the "
                "invoice. Use the format yyyy-mm-dd (e.g., "
                "2013-12-03). This date is typically "
                "calculated as invoice date + "
                "payment_terms days, but can be overridden "
                "with a custom date. When searching "
                "invoices, supports variants: "
                "<code>due_date_start</code>, "
                "<code>due_date_end</code>, "
                "<code>due_date_before</code> and "
                "<code>due_date_after</code>.",
                "example": "2013-12-03",
                "type": "string",
            },
            "exchange_rate": {
                "description": "Exchange rate used to convert "
                "amounts from the invoice currency to "
                "the organization's base currency. "
                "Required when the invoice currency "
                "differs from the organization's base "
                "currency. For example, if base "
                "currency is USD and invoice currency "
                "is EUR, set the EUR to USD exchange "
                "rate (e.g., 1.18). Default value is "
                "1.0 when invoice currency matches "
                "base currency.",
                "example": 1,
                "format": "float",
                "type": "number",
            },
            "expense_id": {
                "description": "Unique identifier of the billable "
                "expense to be converted to an invoice "
                "line item. This converts a previously "
                "recorded expense into a billable line "
                "item on the invoice, enabling "
                "expense-to-invoice conversion.",
                "example": "460000000028080",
                "type": "string",
            },
            "gst_no": {
                "description": "15 digit GST identification number of the customer.",
                "example": "22AAAAA0000A1Z5",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "gst_treatment": {
                "description": "Choose whether the contact is GST "
                "registered/unregistered/consumer/overseas. "
                "Allowed values are <code> "
                "business_gst </code> , <code> "
                "business_none </code> , <code> "
                "overseas </code> , <code> consumer "
                "</code>.",
                "example": "business_gst",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "invoice_number": {
                "description": "Unique identifier or reference "
                "number for the invoice. When "
                "creating an invoice, this can be a "
                "custom number (requires "
                "`ignore_auto_number_generation=true` "
                "query parameter) or left empty for "
                "auto-generation. When searching "
                "invoices, supports variants: "
                "<code>invoice_number_startswith</code> "
                "and "
                "<code>invoice_number_contains</code>. "
                "Maximum length is 100 characters. "
                "Must be unique within the "
                "organization.",
                "example": "INV-00003",
                "type": "string",
            },
            "invoiced_estimate_id": {
                "description": "Unique identifier of the "
                "estimate that was converted "
                "to create this invoice. Use "
                "this field when creating an "
                "invoice from an existing "
                "estimate. The "
                "`invoiced_estimate_id` links "
                "this invoice back to its "
                "source estimate, enabling "
                "tracking of the conversion "
                "process and maintaining the "
                "relationship between "
                "estimates and invoices.",
                "example": " ",
                "type": "string",
            },
            "is_discount_before_tax": {
                "description": "Boolean flag that "
                "determines when the "
                "discount is applied in "
                "relation to tax "
                "calculation. When "
                "<code>true</code>, discount "
                "is applied before tax "
                "calculation (discount "
                "reduces the taxable "
                "amount). When "
                "<code>false</code>, "
                "discount is applied after "
                "tax calculation (discount "
                "reduces the final total "
                "including tax). This "
                "affects the final invoice "
                "total and tax amounts.",
                "example": True,
                "type": "boolean",
            },
            "is_inclusive_tax": {
                "description": "Boolean flag that indicates "
                "whether line item rates include "
                "tax. When <code>true</code>, the "
                "specified rates are inclusive of "
                "tax (tax is already included in "
                "the rate). When "
                "<code>false</code>, the rates are "
                "exclusive of tax (tax will be "
                "added to the rate). This affects "
                "how tax calculations are "
                "performed on line items.",
                "example": False,
                "type": "boolean",
            },
            "is_reverse_charge_applied": {
                "description": "(Required if customer "
                "tax treatment is "
                "<code>vat_registered</code>)<br/>Used "
                "to specify whether the "
                "transaction is "
                "applicable for Domestic "
                "Reverse Charge (DRC) or "
                "not.",
                "example": True,
                "type": "boolean",
                "x-node_available_in": ["za"],
                "x-node_unavailable_in": [],
            },
            "line_items": {
                "items": {
                    "properties": {
                        "bcy_rate": {
                            "description": "Base "
                            "currency "
                            "rate "
                            "for "
                            "the "
                            "line "
                            "item. "
                            "This "
                            "is "
                            "the "
                            "rate "
                            "in "
                            "the "
                            "organization's "
                            "base "
                            "currency "
                            "before "
                            "any "
                            "currency "
                            "conversion. "
                            "Used "
                            "for "
                            "multi-currency "
                            "scenarios "
                            "where "
                            "the "
                            "invoice "
                            "currency "
                            "differs "
                            "from "
                            "the "
                            "base "
                            "currency.",
                            "example": 120,
                            "format": "float",
                            "type": "number",
                        },
                        "bill_id": {
                            "description": "Unique "
                            "identifier "
                            "of "
                            "the "
                            "specific "
                            "bill "
                            "line "
                            "item "
                            "to "
                            "be "
                            "converted "
                            "to "
                            "an "
                            "invoice "
                            "line "
                            "item. "
                            "This "
                            "allows "
                            "you "
                            "to "
                            "convert "
                            "individual "
                            "line "
                            "items "
                            "from "
                            "a "
                            "bill "
                            "rather "
                            "than "
                            "the "
                            "entire "
                            "bill, "
                            "providing "
                            "granular "
                            "control "
                            "over "
                            "bill-to-invoice "
                            "conversion.",
                            "example": " ",
                            "type": "string",
                        },
                        "bill_item_id": {
                            "description": "Unique "
                            "identifier "
                            "of "
                            "the "
                            "specific "
                            "bill "
                            "line "
                            "item "
                            "to "
                            "be "
                            "converted "
                            "to "
                            "an "
                            "invoice "
                            "line "
                            "item. "
                            "This "
                            "allows "
                            "you "
                            "to "
                            "convert "
                            "individual "
                            "line "
                            "items "
                            "from "
                            "a "
                            "bill "
                            "rather "
                            "than "
                            "the "
                            "entire "
                            "bill, "
                            "providing "
                            "granular "
                            "control "
                            "over "
                            "bill-to-invoice "
                            "conversion.",
                            "example": " ",
                            "type": "string",
                        },
                        "description": {
                            "description": "Detailed "
                            "description "
                            "of "
                            "the "
                            "line "
                            "item "
                            "providing "
                            "additional "
                            "information "
                            "about "
                            "the "
                            "product "
                            "or "
                            "service. "
                            "This "
                            "description "
                            "appears "
                            "on "
                            "the "
                            "invoice "
                            "document "
                            "and "
                            "helps "
                            "customers "
                            "understand "
                            "what "
                            "they "
                            "are "
                            "being "
                            "charged "
                            "for. "
                            "Maximum "
                            "length "
                            "is "
                            "2000 "
                            "characters.",
                            "example": "500GB, USB 2.0 interface 1400 rpm, protective hard case.",
                            "type": "string",
                        },
                        "discount": {
                            "description": "Discount "
                            "amount "
                            "applied "
                            "to "
                            "the "
                            "invoice. "
                            "Can "
                            "be "
                            "specified "
                            "as "
                            "a "
                            "percentage "
                            "(e.g., "
                            "12.5 "
                            "for "
                            "12.5%) "
                            "— "
                            "up "
                            "to "
                            "a "
                            "maximum "
                            "of "
                            "100% "
                            "— "
                            "or "
                            "as "
                            "a "
                            "fixed "
                            "amount "
                            "(e.g., "
                            "190 "
                            "for "
                            "$190). "
                            "The "
                            "discount "
                            "is "
                            "applied "
                            "based "
                            "on "
                            "the "
                            "`is_discount_before_tax` "
                            "setting "
                            "and "
                            "`discount_type` "
                            "(entity_level "
                            "or "
                            "item_level).",
                            "example": 0,
                            "format": "float",
                            "type": "number",
                        },
                        "discount_amount": {
                            "description": "Fixed "
                            "discount "
                            "amount "
                            "applied "
                            "to "
                            "this "
                            "specific "
                            "line "
                            "item. "
                            "This "
                            "is "
                            "a "
                            "monetary "
                            "value "
                            "that "
                            "reduces "
                            "the "
                            "line "
                            "item "
                            "total. "
                            "The "
                            "discount "
                            "is "
                            "applied "
                            "after "
                            "the "
                            "rate "
                            "x "
                            "quantity "
                            "calculation "
                            "but "
                            "before "
                            "tax "
                            "calculation. "
                            "Can "
                            "be "
                            "used "
                            "for "
                            "line-item "
                            "specific "
                            "discounts "
                            "or "
                            "promotions.",
                            "example": 0,
                            "format": "float",
                            "type": "number",
                        },
                        "expense_id": {
                            "description": "Unique "
                            "identifier "
                            "of "
                            "the "
                            "billable "
                            "expense "
                            "to "
                            "be "
                            "converted "
                            "to "
                            "an "
                            "invoice "
                            "line "
                            "item. "
                            "This "
                            "converts "
                            "a "
                            "previously "
                            "recorded "
                            "expense "
                            "into "
                            "a "
                            "billable "
                            "line "
                            "item "
                            "on "
                            "the "
                            "invoice, "
                            "enabling "
                            "expense-to-invoice "
                            "conversion.",
                            "example": "460000000028080",
                            "type": "string",
                        },
                        "expense_receipt_name": {"type": "string"},
                        "header_name": {
                            "description": "Name "
                            "of "
                            "the "
                            "item "
                            "header "
                            "or "
                            "category "
                            "that "
                            "groups "
                            "related "
                            "line "
                            "items "
                            "together. "
                            "This "
                            "is "
                            "used "
                            "for "
                            "organizational "
                            "purposes "
                            "to "
                            "categorize "
                            "and "
                            "group "
                            "similar "
                            "items "
                            "on "
                            "the "
                            "invoice. "
                            "For "
                            "example, "
                            '"Electronic '
                            'devices", '
                            '"Office '
                            'supplies", '
                            "or "
                            '"Professional '
                            'services". '
                            "This "
                            "helps "
                            "in "
                            "organizing "
                            "and "
                            "presenting "
                            "line "
                            "items "
                            "in "
                            "a "
                            "structured "
                            "manner "
                            "on "
                            "the "
                            "invoice "
                            "document.",
                            "example": "Electronic devices",
                            "type": "string",
                        },
                        "hsn_or_sac": {
                            "description": "Add HSN/SAC code for your goods/services",
                            "example": 80540,
                            "type": "string",
                            "x-node_available_in": ["in", "ke", "za"],
                            "x-node_unavailable_in": [],
                        },
                        "item_id": {
                            "description": "Unique "
                            "identifier "
                            "of "
                            "the "
                            "item "
                            "(product "
                            "or "
                            "service) "
                            "to "
                            "be "
                            "included "
                            "in "
                            "the "
                            "invoice "
                            "line "
                            "item. "
                            "Use "
                            "the "
                            "`item_id` "
                            "returned "
                            "by "
                            "the "
                            "Items "
                            "API "
                            "for "
                            "the "
                            "same "
                            "organization. "
                            "This "
                            "field "
                            "is "
                            "required "
                            "for "
                            "each "
                            "line "
                            "item "
                            "and "
                            "determines "
                            "the "
                            "item "
                            "details, "
                            "pricing, "
                            "and "
                            "tax "
                            "settings "
                            "that "
                            "will "
                            "be "
                            "applied "
                            "to "
                            "this "
                            "line "
                            "item.",
                            "example": 982000000030049,
                            "type": "string",
                        },
                        "item_order": {
                            "description": "Sequential "
                            "order "
                            "number "
                            "for "
                            "this "
                            "line "
                            "item "
                            "on "
                            "the "
                            "invoice. "
                            "Determines "
                            "the "
                            "display "
                            "order "
                            "of "
                            "line "
                            "items "
                            "on "
                            "the "
                            "invoice "
                            "document. "
                            "Lower "
                            "numbers "
                            "appear "
                            "first. "
                            "Used "
                            "for "
                            "organizing "
                            "line "
                            "items "
                            "in "
                            "a "
                            "specific "
                            "sequence.",
                            "example": 1,
                            "type": "integer",
                        },
                        "location_id": {
                            "description": "Unique "
                            "identifier "
                            "of "
                            "the "
                            "business "
                            "location "
                            "associated "
                            "with "
                            "the "
                            "invoice. "
                            "Use "
                            "the "
                            "`location_id` "
                            "returned "
                            "by "
                            "the "
                            "Locations "
                            "API "
                            "for "
                            "the "
                            "same "
                            "organization. "
                            "This "
                            "links "
                            "the "
                            "invoice "
                            "to "
                            "a "
                            "specific "
                            "business "
                            "location, "
                            "which "
                            "may "
                            "affect "
                            "tax "
                            "calculations, "
                            "reporting, "
                            "and "
                            "business "
                            "operations. "
                            "Required "
                            "if "
                            "your "
                            "organization "
                            "has "
                            "multiple "
                            "locations "
                            "configured.",
                            "example": "460000000038080",
                            "type": "string",
                        },
                        "name": {
                            "description": "Name "
                            "or "
                            "title "
                            "of "
                            "the "
                            "line "
                            "item "
                            "as it "
                            "appears "
                            "on "
                            "the "
                            "invoice. "
                            "Maximum "
                            "length "
                            "is "
                            "100 "
                            "characters. "
                            "Can "
                            "be "
                            "customized "
                            "to "
                            "override "
                            "the "
                            "default "
                            "item "
                            "name "
                            "from "
                            "the "
                            "item "
                            "catalog.",
                            "example": "Hard Drive",
                            "type": "string",
                        },
                        "product_type": {
                            "description": "Type "
                            "of "
                            "product "
                            "or "
                            "service "
                            "for "
                            "this "
                            "line "
                            "item. "
                            "Allowed "
                            "values: "
                            "<code>goods</code> "
                            "or "
                            "<code>services</code>. "
                            "For "
                            "South "
                            "Africa "
                            "Edition, "
                            "additional "
                            "values "
                            "include "
                            "<code>capital_service</code> "
                            "and "
                            "<code>capital_goods</code>. "
                            "This "
                            "classification "
                            "affects "
                            "tax "
                            "calculations, "
                            "reporting, "
                            "and "
                            "compliance "
                            "requirements "
                            "based "
                            "on "
                            "your "
                            "organization's "
                            "location "
                            "and "
                            "tax "
                            "regulations.",
                            "example": "goods",
                            "type": "string",
                        },
                        "project_id": {
                            "description": "Unique "
                            "identifier "
                            "of "
                            "the "
                            "project "
                            "associated "
                            "with "
                            "this "
                            "line "
                            "item. "
                            "Use "
                            "the "
                            "`project_id` "
                            "returned "
                            "by "
                            "the "
                            "Projects "
                            "API "
                            "for "
                            "the "
                            "same "
                            "organization. "
                            "This "
                            "links "
                            "the "
                            "line "
                            "item "
                            "to "
                            "a "
                            "specific "
                            "project "
                            "for "
                            "project-based "
                            "billing, "
                            "time "
                            "tracking, "
                            "and "
                            "cost "
                            "allocation. "
                            "Optional "
                            "field "
                            "that "
                            "enables "
                            "project-specific "
                            "invoicing "
                            "and "
                            "reporting.",
                            "example": 90300000087378,
                            "type": "string",
                        },
                        "quantity": {
                            "description": "Number "
                            "of "
                            "units "
                            "of "
                            "the "
                            "item "
                            "being "
                            "invoiced. "
                            "This "
                            "value "
                            "is "
                            "multiplied "
                            "by "
                            "the "
                            "rate "
                            "to "
                            "calculate "
                            "the "
                            "line "
                            "item "
                            "total. "
                            "Must "
                            "be "
                            "a "
                            "positive "
                            "number "
                            "greater "
                            "than "
                            "zero.",
                            "example": 1,
                            "format": "float",
                            "type": "number",
                        },
                        "rate": {
                            "description": "Unit "
                            "rate "
                            "or "
                            "price "
                            "for "
                            "the "
                            "line "
                            "item "
                            "in "
                            "the "
                            "invoice "
                            "currency. "
                            "This "
                            "is "
                            "the "
                            "amount "
                            "charged "
                            "per "
                            "unit "
                            "of "
                            "the "
                            "item. "
                            "The "
                            "rate "
                            "is "
                            "used "
                            "to "
                            "calculate "
                            "the "
                            "line "
                            "item "
                            "total "
                            "(rate "
                            "x "
                            "quantity) "
                            "and "
                            "affects "
                            "the "
                            "final "
                            "invoice "
                            "amount.",
                            "example": 120,
                            "format": "double",
                            "type": "number",
                        },
                        "salesorder_item_id": {
                            "description": "Unique "
                            "identifier "
                            "of "
                            "the "
                            "sales "
                            "order "
                            "line "
                            "item "
                            "that "
                            "is "
                            "being "
                            "converted "
                            "to "
                            "this "
                            "invoice "
                            "line "
                            "item. "
                            "Use "
                            "this "
                            "field "
                            "when "
                            "creating "
                            "an "
                            "invoice "
                            "from "
                            "an "
                            "existing "
                            "sales "
                            "order. "
                            "The "
                            "`salesorder_item_id` "
                            "links "
                            "this "
                            "invoice "
                            "line "
                            "item "
                            "back "
                            "to "
                            "its "
                            "source "
                            "sales "
                            "order "
                            "line "
                            "item, "
                            "enabling "
                            "tracking "
                            "of "
                            "the "
                            "conversion "
                            "process "
                            "and "
                            "maintaining "
                            "the "
                            "relationship "
                            "between "
                            "sales "
                            "orders "
                            "and "
                            "invoices.",
                            "example": " ",
                            "type": "string",
                        },
                        "sat_item_key_code": {
                            "description": "Add "
                            "SAT "
                            "Item "
                            "Key "
                            "Code "
                            "for "
                            "your "
                            "goods/services. "
                            "Download "
                            "the "
                            "<a "
                            "href= "
                            "http://omawww.sat.gob.mx/tramitesyservicios/Paginas/documentos/catCFDI_V_4_07122022.xls  "
                            ">CFDI "
                            "Catalogs.</a>",
                            "example": 71121206,
                            "type": "string",
                            "x-node_available_in": ["mx"],
                            "x-node_unavailable_in": [],
                        },
                        "tags": {
                            "description": "Array "
                            "of "
                            "reporting "
                            "tags "
                            "associated "
                            "with "
                            "this "
                            "line "
                            "item. "
                            "Each "
                            "tag "
                            "consists "
                            "of a "
                            "`tag_id` "
                            "and "
                            "`tag_option_id` "
                            "that "
                            "categorize "
                            "the "
                            "line "
                            "item "
                            "for "
                            "reporting "
                            "and "
                            "analytics "
                            "purposes. "
                            "Tags "
                            "help "
                            "organize "
                            "and "
                            "filter "
                            "data "
                            "across "
                            "reports "
                            "and "
                            "enable "
                            "detailed "
                            "business "
                            "intelligence "
                            "analysis.",
                            "items": {
                                "properties": {
                                    "tag_id": {
                                        "description": "ID of the reporting tag",
                                        "example": 982000000009070,
                                        "type": "string",
                                    },
                                    "tag_option_id": {
                                        "description": "ID of the reporting tag's option",
                                        "example": 982000000002670,
                                        "type": "string",
                                    },
                                },
                                "type": "object",
                            },
                            "type": "array",
                        },
                        "tax_id": {
                            "description": "Unique "
                            "identifier "
                            "of "
                            "the "
                            "tax "
                            "to "
                            "be "
                            "applied "
                            "to "
                            "this "
                            "line "
                            "item. "
                            "Use "
                            "the "
                            "`tax_id` "
                            "returned "
                            "by "
                            "the "
                            "Taxes "
                            "API "
                            "for "
                            "the "
                            "same "
                            "organization. "
                            "This "
                            "determines "
                            "which "
                            "tax "
                            "rate "
                            "and "
                            "rules "
                            "are "
                            "applied "
                            "to "
                            "the "
                            "line "
                            "item, "
                            "affecting "
                            "the "
                            "final "
                            "tax "
                            "calculation "
                            "and "
                            "compliance "
                            "reporting.",
                            "example": 982000000557028,
                            "type": "string",
                        },
                        "tax_name": {
                            "description": "The name of the tax",
                            "example": "VAT",
                            "type": "string",
                        },
                        "tax_percentage": {
                            "description": "The  percentage of tax levied",
                            "example": 12.5,
                            "format": "float",
                            "type": "number",
                        },
                        "tax_treatment_code": {
                            "description": "Specify "
                            "reason "
                            "for "
                            "using "
                            "out "
                            "of "
                            "scope.</br>Supported "
                            "values "
                            "for "
                            "UAE "
                            "are "
                            "<code>uae_same_tax_group</code>, "
                            "<code>uae_reimbursed_expense</code> "
                            "and "
                            "<code>uae_others</code>.</br> "
                            "Supported "
                            "values "
                            "for "
                            "Bahrain "
                            "are "
                            "<code>bahrain_same_tax_group</code>, "
                            "<code>bahrain_transfer_of_concern</code>, "
                            "<code>bahrain_disbursement</code>, "
                            "<code>bahrain_head_to_branch_transaction</code>, "
                            "<code>bahrain_warranty_repair_services</code> "
                            "and "
                            "<code>bahrain_others</code>.</br>Supported "
                            "values "
                            "for "
                            "Saudi "
                            "Arabia "
                            "are "
                            "<code>ksa_pvt_health</code>, "
                            "<code>ksa_pvt_edu</code>, "
                            "<code>ksa_reimbursed_expense</code> "
                            "and "
                            "<code>ksa_house_sales</code>.",
                            "example": "uae_others",
                            "type": "string",
                            "x-node_available_in": ["gcc"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_type": {
                            "description": "The type of the tax",
                            "example": "tax",
                            "type": "string",
                        },
                        "tds_tax_id": {
                            "description": "ID of the TDS tax.",
                            "example": "982000000557012",
                            "type": "string",
                            "x-node_available_in": ["mx"],
                            "x-node_unavailable_in": [],
                        },
                        "time_entry_ids": {
                            "description": "Array "
                            "of "
                            "time "
                            "entry "
                            "IDs "
                            "to "
                            "be "
                            "billed "
                            "on "
                            "this "
                            "line "
                            "item. "
                            "This "
                            "allows "
                            "you "
                            "to "
                            "bill "
                            "specific "
                            "time "
                            "entries "
                            "against "
                            "this "
                            "line "
                            "item, "
                            "enabling "
                            "detailed "
                            "time-based "
                            "invoicing "
                            "and "
                            "project "
                            "cost "
                            "tracking.",
                            "example": [],
                            "items": {"type": "string"},
                            "type": "array",
                        },
                        "unit": {
                            "description": "Unit "
                            "of "
                            "measurement "
                            "for "
                            "the "
                            "line "
                            "item "
                            "quantity. "
                            "Examples "
                            "include "
                            '"Nos" '
                            "(Numbers), "
                            '"kgs" '
                            "(Kilograms), "
                            '"hrs" '
                            "(Hours), "
                            '"pcs" '
                            "(Pieces), "
                            "etc. "
                            "This "
                            "helps "
                            "clarify "
                            "what "
                            "the "
                            "quantity "
                            "represents. "
                            "Maximum "
                            "length "
                            "is "
                            "100 "
                            "characters.",
                            "example": " ",
                            "type": "string",
                        },
                        "unitkey_code": {
                            "description": "Add "
                            "SAT "
                            "Unit "
                            "Key "
                            "Code "
                            "for "
                            "your "
                            "goods/services. "
                            "Download "
                            "the "
                            "<a "
                            "href= "
                            "http://omawww.sat.gob.mx/tramitesyservicios/Paginas/documentos/catCFDI_V_4_07122022.xls  "
                            ">CFDI "
                            "Catalogs.</a>",
                            "example": "E48",
                            "type": "string",
                            "x-node_available_in": ["mx"],
                            "x-node_unavailable_in": [],
                        },
                    },
                    "required": ["item_id"],
                    "type": "object",
                },
                "type": "array",
            },
            "location_id": {
                "description": "Unique identifier of the business "
                "location associated with the invoice. "
                "Use the `location_id` returned by the "
                "Locations API for the same "
                "organization. This links the invoice "
                "to a specific business location, which "
                "may affect tax calculations, "
                "reporting, and business operations. "
                "Required if your organization has "
                "multiple locations configured.",
                "example": "460000000038080",
                "type": "string",
            },
            "notes": {
                "description": "Additional information or comments to be "
                "displayed on the invoice document. This "
                "field is typically used for thank you "
                "messages, special instructions, or any other "
                "information you want to communicate to the "
                "customer. The notes appear on the invoice "
                "PDF and are visible to customers",
                "example": "Looking forward for your business.",
                "type": "string",
            },
            "payment_options": {
                "description": "Payment options for the invoice, "
                "online payment gateways and bank "
                "accounts. Will be displayed in the "
                "pdf.",
                "properties": {
                    "payment_gateways": {
                        "description": "Online payment gateways through which payment can be made.",
                        "items": {
                            "properties": {
                                "additional_field1": {
                                    "description": "Paypal "
                                    "payment "
                                    "method. "
                                    "Allowed "
                                    "Values: "
                                    "<code>standard</code> "
                                    "and "
                                    "<code>adaptive</code>",
                                    "example": "standard",
                                    "type": "string",
                                },
                                "configured": {
                                    "description": "Boolean "
                                    "check "
                                    "to "
                                    "see "
                                    "if "
                                    "a "
                                    "payment "
                                    "gateway "
                                    "has "
                                    "been "
                                    "configured",
                                    "example": True,
                                    "type": "boolean",
                                },
                                "gateway_name": {
                                    "description": "Name "
                                    "of "
                                    "the "
                                    "payment "
                                    "gateway "
                                    "associated "
                                    "with "
                                    "the "
                                    "invoice. "
                                    "E.g. "
                                    "paypal, "
                                    "stripe.Allowed "
                                    "Values: "
                                    "<code>paypal</code>, "
                                    "<code>authorize_net</code>, "
                                    "<code>payflow_pro</code>, "
                                    "<code>stripe</code>, "
                                    "<code>2checkout</code> "
                                    "and "
                                    "<code>braintree</code>",
                                    "example": "paypal",
                                    "type": "string",
                                },
                            },
                            "type": "object",
                        },
                        "type": "array",
                    }
                },
                "type": "object",
            },
            "payment_terms": {
                "description": "Number of days allowed for payment "
                "(e.g., 15, 30, 60). This value "
                "determines the invoice due date by "
                "adding the specified number of days "
                "to the invoice date. For example, if "
                "invoice date is 2023-11-17 and "
                "payment_terms is 15, the due_date "
                "will be 2023-12-02. Maximum value is "
                "100 days.",
                "example": 15,
                "type": "integer",
            },
            "payment_terms_label": {
                "description": "Custom label for payment terms "
                "that appears on the invoice "
                "document. Used to override the "
                "default system-generated "
                "label. For example, instead of "
                'the default "Net 15 Days", you '
                'can set this to "Net 15", "Due '
                'in 15 days", or any custom '
                "text. This label is displayed "
                "to customers on the invoice. "
                "Maximum length is 100 "
                "characters.",
                "example": "Net 15",
                "type": "string",
            },
            "place_of_supply": {
                "description": "Place where the goods/services are "
                "supplied to. (If not given, "
                "<code>place of contact</code> "
                "given for the contact will be "
                "taken)<br/>Supported codes for UAE "
                "emirates are : </br>Abu Dhabi - "
                "<code>AB</code>,</br>Ajman - "
                "<code>AJ</code>,</br>Dubai - "
                "<code>DU</code>,</br>Fujairah - "
                "<code>FU</code>,</br>Ras "
                "al-Khaimah - "
                "<code>RA</code>,</br>Sharjah - "
                "<code>SH</code>,</br>Umm al-Quwain "
                "- <code>UM</code><br/>Supported "
                "codes for the GCC countries are : "
                "</br>United Arab Emirates - "
                "<code>AE</code>,</br>Saudi Arabia "
                "- <code>SA</code>,</br>Bahrain - "
                "<code>BH</code>,</br>Kuwait - "
                "<code>KW</code>,</br>Oman - "
                "<code>OM</code>,</br>Qatar - "
                "<code>QA</code>.",
                "example": "TN",
                "type": "string",
                "x-node_available_in": ["in", "gcc"],
                "x-node_unavailable_in": [],
            },
            "reason": {"example": " ", "type": "string"},
            "recurring_invoice_id": {
                "description": "Unique identifier of the "
                "recurring invoice template "
                "that generated this invoice. "
                "Use this field when creating "
                "an invoice from a recurring "
                "invoice template. The "
                "`recurring_invoice_id` links "
                "this invoice back to its "
                "source recurring invoice, "
                "enabling tracking of which "
                "template generated it and "
                "maintaining the recurring "
                "invoice relationship.",
                "example": " ",
                "type": "string",
            },
            "reference_number": {
                "description": "External reference number or "
                "identifier for the invoice, such "
                "as a purchase order number, "
                "contract number, or any other "
                "business reference. When "
                "converting from an estimate or "
                "sales order, this field can be "
                "used to reference the original "
                "document number.",
                "example": " ",
                "type": "string",
            },
            "salesorder_item_id": {
                "description": "Unique identifier of the sales "
                "order line item that is being "
                "converted to this invoice line "
                "item. Use this field when "
                "creating an invoice from an "
                "existing sales order. The "
                "`salesorder_item_id` links this "
                "invoice line item back to its "
                "source sales order line item, "
                "enabling tracking of the "
                "conversion process and "
                "maintaining the relationship "
                "between sales orders and "
                "invoices.",
                "example": " ",
                "type": "string",
            },
            "salesperson_name": {
                "description": "Name of the salesperson. Max-length [200]",
                "example": " ",
                "type": "string",
            },
            "send": {
                "description": "Send the invoice to the contact person(s) "
                "associated with the invoice. Allowed values "
                "<code>true</code> and <code>false</code>.",
                "type": "boolean",
            },
            "shipping_address_id": {
                "description": "Unique identifier of the "
                "shipping address to be used "
                "for this invoice. Use the "
                "`shipping_address_id` returned "
                "by the Addresses API for the "
                "same customer and "
                "organization. This address "
                "appears on the invoice "
                "document and is used for "
                "delivery purposes. If omitted, "
                "the customer's default "
                "shipping address will be used.",
                "example": "218500000000142014",
                "type": "string",
            },
            "shipping_charge": {
                "description": "Additional shipping or delivery "
                "charges applied to the invoice. "
                "Must be specified as a fixed "
                'amount (e.g., "25.00"). This '
                "amount is added to the invoice "
                "total and is subject to tax "
                "calculation.",
                "example": 0,
                "type": "string",
            },
            "tax_authority_id": {
                "description": "ID of the tax authority. Tax "
                "authority depends on the location "
                "of the customer. For example, if "
                "the customer is located in NY, "
                "then the tax authority is NY tax "
                "authority.",
                "example": 11149000000061052,
                "type": "string",
                "x-node_available_in": ["us"],
                "x-node_unavailable_in": [],
            },
            "tax_exemption_id": {
                "description": "ID of the tax exemption.",
                "example": 11149000000061054,
                "type": "string",
                "x-node_available_in": ["in", "us"],
                "x-node_unavailable_in": [],
            },
            "tax_id": {
                "description": "Unique identifier of the tax to be applied "
                "to this line item. Use the `tax_id` "
                "returned by the Taxes API for the same "
                "organization. This determines which tax "
                "rate and rules are applied to the line "
                "item, affecting the final tax calculation "
                "and compliance reporting.",
                "example": 982000000557028,
                "type": "string",
            },
            "tax_treatment": {
                "description": "VAT treatment for the invoice "
                ".Choose whether the contact falls "
                "under: "
                "<code>vat_registered</code>,<code>vat_not_registered</code>,<code>gcc_vat_not_registered</code>,<code>gcc_vat_registered</code>,<code>non_gcc</code>.</br><code>dz_vat_registered</code> "
                "and "
                "<code>dz_vat_not_registered</code> "
                "supported only for "
                "<b>UAE</b>.</b></br><code>home_country_mexico</code>,<code>border_region_mexico</code>,<code>non_mexico</code> "
                "supported only for "
                "<b>MX</b>.<br/><b>For Kenya "
                "Edition:</b> "
                "<code>vat_registered</code> "
                ",<code>vat_not_registered</code> "
                ",<code>non_kenya</code>(A business "
                "that is located outside "
                "Kenya).<br/><b>For SouthAfrica "
                "Edition:</b> "
                "<code>vat_registered</code>, "
                "<code>vat_not_registered</code>, "
                "<code>overseas</code>(A business "
                "that is located outside "
                "SouthAfrica).",
                "example": "vat_registered",
                "type": "string",
                "x-node_available_in": ["gcc", "mx", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "template_id": {
                "description": "Unique identifier of the PDF template "
                "linked to the invoice. Obtain this "
                "value from the `template_id` field in "
                "the response of the GET "
                "`/invoices/templates` API for your "
                "organization. Determines which "
                "template is used for the invoice PDF.",
                "example": 982000000000143,
                "type": "string",
            },
            "terms": {
                "description": "Terms and conditions text to be displayed on "
                "the invoice document. This field is used to "
                "specify payment terms, delivery conditions, "
                "return policies, or any other legal or "
                "business terms that apply to this "
                "transaction. The terms appear on the invoice "
                "PDF and are legally binding.",
                "example": "Terms & Conditions apply",
                "type": "string",
            },
            "time_entry_ids": {
                "description": "Array of time entry IDs to be "
                "billed on this line item. This "
                "allows you to bill specific time "
                "entries against this line item, "
                "enabling detailed time-based "
                "invoicing and project cost "
                "tracking.",
                "example": [],
                "items": {"type": "string"},
                "type": "array",
            },
            "vat_treatment": {
                "description": "(Optional) VAT treatment for the "
                "invoices. VAT treatment denotes the "
                "location of the customer, if the "
                "customer resides in UK then the VAT "
                "treatment is <code>uk</code>. If the "
                "customer is in an EU country & VAT "
                "registered, you are resides in "
                "Northen Ireland and selling Goods "
                "then his VAT treatment is "
                "<code>eu_vat_registered</code>, if "
                "he resides outside of the UK then "
                "his VAT treatment is "
                "<code>overseas</code> (For Pre "
                "Brexit, this can be split as "
                "<code>eu_vat_registered</code>, "
                "<code>eu_vat_not_registered</code> "
                "and <code>non_eu</code>).",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
        },
        "required": ["customer_id", "line_items"],
        "type": "object",
    },
    "UPDATEINVOICEBYCUSTOMFIELD_REQUEST_BODY_SCHEMA": {
        "properties": {
            "adjustment": {
                "description": "Additional charge or credit amount "
                "applied to the invoice total. This can "
                "be used for rounding adjustments, "
                "handling fees, or any other one-time "
                "charges/credits. Positive values add to "
                "the total, negative values reduce the "
                "total. This amount is applied after tax "
                "calculation and affects the final "
                "invoice total.",
                "example": 0,
                "format": "double",
                "type": "number",
            },
            "adjustment_description": {
                "description": "Text description explaining "
                "the reason for the "
                "adjustment amount. This "
                "description appears on the "
                "invoice document to explain "
                "why the adjustment was "
                "applied. Common examples "
                'include "Rounding '
                'adjustment", "Handling '
                'fee", "Early payment '
                'discount", or "Late payment '
                'fee". This helps customers '
                "understand the purpose of "
                "the adjustment.",
                "example": " ",
                "type": "string",
            },
            "allow_partial_payments": {
                "description": "Boolean flag that "
                "determines whether "
                "customers can make partial "
                "payments against this "
                "invoice. When "
                "<code>true</code>, "
                "customers can pay less than "
                "the full invoice amount, "
                "and the invoice will remain "
                "open with a remaining "
                "balance. When "
                "<code>false</code>, "
                "customers must pay the full "
                "amount to complete the "
                "invoice. This setting "
                "affects payment processing "
                "and invoice status "
                "tracking.",
                "example": True,
                "type": "boolean",
            },
            "avatax_exempt_no": {
                "description": "Exemption certificate number of the customer. Max-length [25]",
                "type": "string",
                "x-node_available_in": ["Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "avatax_tax_code": {
                "description": "A tax code is a unique label used "
                "to group Items (products, "
                "services, or charges) together. "
                "Refer the [link][2] for more "
                "deails. Max-length [25]",
                "type": "string",
                "x-node_available_in": ["Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "avatax_use_code": {
                "description": "Used to group like customers for "
                "exemption purposes. It is a custom "
                "value that links customers to a "
                "tax rule. Select from Avalara "
                "[standard codes][1] or enter a "
                "custom code. Max-length [25]",
                "type": "string",
                "x-node_available_in": ["Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "cfdi_reference_type": {
                "description": "Choose CFDI Reference Type. "
                "Allowed "
                "values:</br><code>return_of_merchandise</code>, "
                "<code>substitution_previous_cfdi</code>, "
                "<code>transfer_of_goods</code>, "
                "<code>invoice_generated_from_order</code>, "
                "<code>cfdi_for_advance</code>.",
                "example": "return_of_merchandise",
                "type": "string",
                "x-node_available_in": ["mx"],
                "x-node_unavailable_in": [],
            },
            "cfdi_usage": {
                "description": "Choose CFDI Usage. Allowed "
                "values:</br><code>acquisition_of_merchandise</code>, "
                "<code>return_discount_bonus</code>, "
                "<code>general_expense</code>, "
                "<code>buildings</code>, "
                "<code>furniture_office_equipment</code>, "
                "<code>transport_equipment</code>, "
                "<code>computer_equipmentdye_molds_tools</code>, "
                "<code>telephone_communication</code>, "
                "<code>satellite_communication</code>, "
                "<code>other_machinery_equipment</code>, "
                "<code>hospital_expense</code>, "
                "<code>medical_expense_disability</code>, "
                "<code>funeral_expense</code>, "
                "<code>donation</code>, "
                "<code>interest_mortage_loans</code>, "
                "<code>contribution_sar</code>, "
                "<code>medical_expense_insurance_pormium</code>, "
                "<code>school_transportation_expense</code>, "
                "<code>deposit_saving_account</code>, "
                "<code>payment_educational_service</code>, "
                "<code>no_tax_effect</code>, "
                "<code>payment</code>, "
                "<code>payroll</code>.",
                "example": "acquisition_of_merchandise",
                "type": "string",
                "x-node_available_in": ["mx"],
                "x-node_unavailable_in": [],
            },
            "contact_persons_associated": {
                "description": "Contact Persons associated with the transaction.",
                "items": {
                    "properties": {
                        "communication_preference": {
                            "description": "Preferred "
                            "modes "
                            "of "
                            "communication "
                            "for "
                            "the "
                            "contact "
                            "person "
                            "at "
                            "transaction "
                            "level.",
                            "properties": {
                                "is_email_enabled": {
                                    "description": "Used "
                                    "to "
                                    "check "
                                    "if "
                                    "Email "
                                    "communication "
                                    "preference "
                                    "is "
                                    "enabled "
                                    "for "
                                    "the "
                                    "contact "
                                    "person "
                                    "at "
                                    "transaction "
                                    "level.",
                                    "example": True,
                                    "type": "boolean",
                                },
                                "is_whatsapp_enabled": {
                                    "description": "Used "
                                    "to "
                                    "check "
                                    "if "
                                    "WhatsApp "
                                    "communication "
                                    "preference "
                                    "is "
                                    "enabled "
                                    "for "
                                    "the "
                                    "contact "
                                    "person "
                                    "at "
                                    "transaction "
                                    "level.",
                                    "example": True,
                                    "type": "boolean",
                                    "x-node_available_in": ["WhatsApp integration"],
                                },
                            },
                            "type": "object",
                        },
                        "contact_person_id": {
                            "description": "Unique ID of the Contact Person.",
                            "example": 982000000567003,
                            "format": "int64",
                            "type": "integer",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "currency_id": {
                "description": "Unique identifier of the currency in "
                "which the invoice will be created for "
                "the customer. Use the `currency_id` "
                "returned by the Currencies API for the "
                "same organization. This sets the "
                "currency for all monetary amounts on "
                "the invoice; if it differs from the "
                "organization's base currency, an "
                "appropriate `exchange_rate` may be "
                "required.",
                "example": 982000000000190,
                "type": "string",
            },
            "custom_body": {"example": " ", "type": "string"},
            "custom_fields": {
                "description": "Custom fields for an invoice.",
                "items": {
                    "properties": {
                        "customfield_id": {
                            "example": "46000000012845",
                            "format": "int64",
                            "type": "integer",
                        },
                        "value": {
                            "description": "Value of the Custom Field",
                            "example": "Normal",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "custom_subject": {"example": " ", "type": "string"},
            "customer_id": {
                "description": "Unique identifier of the customer in "
                "the current organization for whom this "
                "invoice is created. Required when "
                "creating an invoice. Use the "
                "`customer_id` returned by the get "
                "Customers API. Must belong to the "
                "organization specified by the "
                "`organization_id` parameter.",
                "example": 982000000567001,
                "type": "string",
            },
            "date": {
                "description": "The date on which the invoice is created. Use "
                "the format yyyy-mm-dd (e.g., 2013-11-17). "
                "This date appears on the invoice document and "
                "is used for accounting purposes. When "
                "searching invoices, supports variants: "
                "<code>date_start</code>, "
                "<code>date_end</code>, "
                "<code>date_before</code> and "
                "<code>date_after</code>.",
                "example": "2013-11-17",
                "type": "string",
            },
            "discount": {
                "description": "Discount amount applied to the invoice. "
                "Can be specified as a percentage (e.g., "
                "12.5 for 12.5%) — up to a maximum of 100% "
                "— or as a fixed amount (e.g., 190 for "
                "$190). The discount is applied based on "
                "the `is_discount_before_tax` setting and "
                "`discount_type` (entity_level or "
                "item_level).",
                "example": 0,
                "format": "float",
                "type": "number",
            },
            "discount_type": {
                "description": "Specifies the scope of discount "
                "application. "
                "<code>entity_level</code> applies "
                "the discount to the entire invoice "
                "total. <code>item_level</code> "
                "applies the discount to individual "
                "line items. This determines how the "
                "discount amount is distributed "
                "across the invoice items.",
                "example": "item_level",
                "type": "string",
            },
            "due_date": {
                "description": "The date by which payment is due for the "
                "invoice. Use the format yyyy-mm-dd (e.g., "
                "2013-12-03). This date is typically "
                "calculated as invoice date + "
                "payment_terms days, but can be overridden "
                "with a custom date. When searching "
                "invoices, supports variants: "
                "<code>due_date_start</code>, "
                "<code>due_date_end</code>, "
                "<code>due_date_before</code> and "
                "<code>due_date_after</code>.",
                "example": "2013-12-03",
                "type": "string",
            },
            "exchange_rate": {
                "description": "Exchange rate used to convert "
                "amounts from the invoice currency to "
                "the organization's base currency. "
                "Required when the invoice currency "
                "differs from the organization's base "
                "currency. For example, if base "
                "currency is USD and invoice currency "
                "is EUR, set the EUR to USD exchange "
                "rate (e.g., 1.18). Default value is "
                "1.0 when invoice currency matches "
                "base currency.",
                "example": 1,
                "format": "float",
                "type": "number",
            },
            "expense_id": {
                "description": "Unique identifier of the billable "
                "expense to be converted to an invoice "
                "line item. This converts a previously "
                "recorded expense into a billable line "
                "item on the invoice, enabling "
                "expense-to-invoice conversion.",
                "example": "460000000028080",
                "type": "string",
            },
            "gst_no": {
                "description": "15 digit GST identification number of the customer.",
                "example": "22AAAAA0000A1Z5",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "gst_treatment": {
                "description": "Choose whether the contact is GST "
                "registered/unregistered/consumer/overseas. "
                "Allowed values are <code> "
                "business_gst </code> , <code> "
                "business_none </code> , <code> "
                "overseas </code> , <code> consumer "
                "</code>.",
                "example": "business_gst",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "invoice_number": {
                "description": "Unique identifier or reference "
                "number for the invoice. When "
                "creating an invoice, this can be a "
                "custom number (requires "
                "`ignore_auto_number_generation=true` "
                "query parameter) or left empty for "
                "auto-generation. When searching "
                "invoices, supports variants: "
                "<code>invoice_number_startswith</code> "
                "and "
                "<code>invoice_number_contains</code>. "
                "Maximum length is 100 characters. "
                "Must be unique within the "
                "organization.",
                "example": "INV-00003",
                "type": "string",
            },
            "invoiced_estimate_id": {
                "description": "Unique identifier of the "
                "estimate that was converted "
                "to create this invoice. Use "
                "this field when creating an "
                "invoice from an existing "
                "estimate. The "
                "`invoiced_estimate_id` links "
                "this invoice back to its "
                "source estimate, enabling "
                "tracking of the conversion "
                "process and maintaining the "
                "relationship between "
                "estimates and invoices.",
                "example": " ",
                "type": "string",
            },
            "is_discount_before_tax": {
                "description": "Boolean flag that "
                "determines when the "
                "discount is applied in "
                "relation to tax "
                "calculation. When "
                "<code>true</code>, discount "
                "is applied before tax "
                "calculation (discount "
                "reduces the taxable "
                "amount). When "
                "<code>false</code>, "
                "discount is applied after "
                "tax calculation (discount "
                "reduces the final total "
                "including tax). This "
                "affects the final invoice "
                "total and tax amounts.",
                "example": True,
                "type": "boolean",
            },
            "is_inclusive_tax": {
                "description": "Boolean flag that indicates "
                "whether line item rates include "
                "tax. When <code>true</code>, the "
                "specified rates are inclusive of "
                "tax (tax is already included in "
                "the rate). When "
                "<code>false</code>, the rates are "
                "exclusive of tax (tax will be "
                "added to the rate). This affects "
                "how tax calculations are "
                "performed on line items.",
                "example": False,
                "type": "boolean",
            },
            "is_reverse_charge_applied": {
                "description": "(Required if customer "
                "tax treatment is "
                "<code>vat_registered</code>)<br/>Used "
                "to specify whether the "
                "transaction is "
                "applicable for Domestic "
                "Reverse Charge (DRC) or "
                "not.",
                "example": True,
                "type": "boolean",
                "x-node_available_in": ["za"],
                "x-node_unavailable_in": [],
            },
            "line_item_id": {
                "description": "The line item id",
                "example": 982000000567021,
                "type": "string",
            },
            "line_items": {
                "items": {
                    "properties": {
                        "bcy_rate": {
                            "description": "Base "
                            "currency "
                            "rate "
                            "for "
                            "the "
                            "line "
                            "item. "
                            "This "
                            "is "
                            "the "
                            "rate "
                            "in "
                            "the "
                            "organization's "
                            "base "
                            "currency "
                            "before "
                            "any "
                            "currency "
                            "conversion. "
                            "Used "
                            "for "
                            "multi-currency "
                            "scenarios "
                            "where "
                            "the "
                            "invoice "
                            "currency "
                            "differs "
                            "from "
                            "the "
                            "base "
                            "currency.",
                            "example": 120,
                            "format": "float",
                            "type": "number",
                        },
                        "description": {
                            "description": "Detailed "
                            "description "
                            "of "
                            "the "
                            "line "
                            "item "
                            "providing "
                            "additional "
                            "information "
                            "about "
                            "the "
                            "product "
                            "or "
                            "service. "
                            "This "
                            "description "
                            "appears "
                            "on "
                            "the "
                            "invoice "
                            "document "
                            "and "
                            "helps "
                            "customers "
                            "understand "
                            "what "
                            "they "
                            "are "
                            "being "
                            "charged "
                            "for. "
                            "Maximum "
                            "length "
                            "is "
                            "2000 "
                            "characters.",
                            "example": "500GB, USB 2.0 interface 1400 rpm, protective hard case.",
                            "type": "string",
                        },
                        "discount": {
                            "description": "Discount "
                            "amount "
                            "applied "
                            "to "
                            "the "
                            "invoice. "
                            "Can "
                            "be "
                            "specified "
                            "as "
                            "a "
                            "percentage "
                            "(e.g., "
                            "12.5 "
                            "for "
                            "12.5%) "
                            "— "
                            "up "
                            "to "
                            "a "
                            "maximum "
                            "of "
                            "100% "
                            "— "
                            "or "
                            "as "
                            "a "
                            "fixed "
                            "amount "
                            "(e.g., "
                            "190 "
                            "for "
                            "$190). "
                            "The "
                            "discount "
                            "is "
                            "applied "
                            "based "
                            "on "
                            "the "
                            "`is_discount_before_tax` "
                            "setting "
                            "and "
                            "`discount_type` "
                            "(entity_level "
                            "or "
                            "item_level).",
                            "example": 0,
                            "format": "float",
                            "type": "number",
                        },
                        "discount_amount": {
                            "description": "Fixed "
                            "discount "
                            "amount "
                            "applied "
                            "to "
                            "this "
                            "specific "
                            "line "
                            "item. "
                            "This "
                            "is "
                            "a "
                            "monetary "
                            "value "
                            "that "
                            "reduces "
                            "the "
                            "line "
                            "item "
                            "total. "
                            "The "
                            "discount "
                            "is "
                            "applied "
                            "after "
                            "the "
                            "rate "
                            "x "
                            "quantity "
                            "calculation "
                            "but "
                            "before "
                            "tax "
                            "calculation. "
                            "Can "
                            "be "
                            "used "
                            "for "
                            "line-item "
                            "specific "
                            "discounts "
                            "or "
                            "promotions.",
                            "example": 0,
                            "format": "float",
                            "type": "number",
                        },
                        "expense_id": {
                            "description": "Unique "
                            "identifier "
                            "of "
                            "the "
                            "billable "
                            "expense "
                            "to "
                            "be "
                            "converted "
                            "to "
                            "an "
                            "invoice "
                            "line "
                            "item. "
                            "This "
                            "converts "
                            "a "
                            "previously "
                            "recorded "
                            "expense "
                            "into "
                            "a "
                            "billable "
                            "line "
                            "item "
                            "on "
                            "the "
                            "invoice, "
                            "enabling "
                            "expense-to-invoice "
                            "conversion.",
                            "example": "460000000028080",
                            "type": "string",
                        },
                        "expense_receipt_name": {"type": "string"},
                        "header_id": {
                            "description": "ID of the item header",
                            "example": 982000000000670,
                            "type": "string",
                        },
                        "header_name": {
                            "description": "Name "
                            "of "
                            "the "
                            "item "
                            "header "
                            "or "
                            "category "
                            "that "
                            "groups "
                            "related "
                            "line "
                            "items "
                            "together. "
                            "This "
                            "is "
                            "used "
                            "for "
                            "organizational "
                            "purposes "
                            "to "
                            "categorize "
                            "and "
                            "group "
                            "similar "
                            "items "
                            "on "
                            "the "
                            "invoice. "
                            "For "
                            "example, "
                            '"Electronic '
                            'devices", '
                            '"Office '
                            'supplies", '
                            "or "
                            '"Professional '
                            'services". '
                            "This "
                            "helps "
                            "in "
                            "organizing "
                            "and "
                            "presenting "
                            "line "
                            "items "
                            "in "
                            "a "
                            "structured "
                            "manner "
                            "on "
                            "the "
                            "invoice "
                            "document.",
                            "example": "Electronic devices",
                            "type": "string",
                        },
                        "hsn_or_sac": {
                            "description": "Add HSN/SAC code for your goods/services",
                            "example": 80540,
                            "type": "string",
                            "x-node_available_in": ["in", "ke", "za"],
                            "x-node_unavailable_in": [],
                        },
                        "item_id": {
                            "description": "Unique "
                            "identifier "
                            "of "
                            "the "
                            "item "
                            "(product "
                            "or "
                            "service) "
                            "to "
                            "be "
                            "included "
                            "in "
                            "the "
                            "invoice "
                            "line "
                            "item. "
                            "Use "
                            "the "
                            "`item_id` "
                            "returned "
                            "by "
                            "the "
                            "Items "
                            "API "
                            "for "
                            "the "
                            "same "
                            "organization. "
                            "This "
                            "field "
                            "is "
                            "required "
                            "for "
                            "each "
                            "line "
                            "item "
                            "and "
                            "determines "
                            "the "
                            "item "
                            "details, "
                            "pricing, "
                            "and "
                            "tax "
                            "settings "
                            "that "
                            "will "
                            "be "
                            "applied "
                            "to "
                            "this "
                            "line "
                            "item.",
                            "example": 982000000030049,
                            "type": "string",
                        },
                        "item_order": {
                            "description": "Sequential "
                            "order "
                            "number "
                            "for "
                            "this "
                            "line "
                            "item "
                            "on "
                            "the "
                            "invoice. "
                            "Determines "
                            "the "
                            "display "
                            "order "
                            "of "
                            "line "
                            "items "
                            "on "
                            "the "
                            "invoice "
                            "document. "
                            "Lower "
                            "numbers "
                            "appear "
                            "first. "
                            "Used "
                            "for "
                            "organizing "
                            "line "
                            "items "
                            "in "
                            "a "
                            "specific "
                            "sequence.",
                            "example": 1,
                            "type": "integer",
                        },
                        "location_id": {
                            "description": "Unique "
                            "identifier "
                            "of "
                            "the "
                            "business "
                            "location "
                            "associated "
                            "with "
                            "the "
                            "invoice. "
                            "Use "
                            "the "
                            "`location_id` "
                            "returned "
                            "by "
                            "the "
                            "Locations "
                            "API "
                            "for "
                            "the "
                            "same "
                            "organization. "
                            "This "
                            "links "
                            "the "
                            "invoice "
                            "to "
                            "a "
                            "specific "
                            "business "
                            "location, "
                            "which "
                            "may "
                            "affect "
                            "tax "
                            "calculations, "
                            "reporting, "
                            "and "
                            "business "
                            "operations. "
                            "Required "
                            "if "
                            "your "
                            "organization "
                            "has "
                            "multiple "
                            "locations "
                            "configured.",
                            "example": "460000000038080",
                            "type": "string",
                        },
                        "name": {
                            "description": "Name "
                            "or "
                            "title "
                            "of "
                            "the "
                            "line "
                            "item "
                            "as it "
                            "appears "
                            "on "
                            "the "
                            "invoice. "
                            "Maximum "
                            "length "
                            "is "
                            "100 "
                            "characters. "
                            "Can "
                            "be "
                            "customized "
                            "to "
                            "override "
                            "the "
                            "default "
                            "item "
                            "name "
                            "from "
                            "the "
                            "item "
                            "catalog.",
                            "example": "Hard Drive",
                            "type": "string",
                        },
                        "product_type": {
                            "description": "Type "
                            "of "
                            "product "
                            "or "
                            "service "
                            "for "
                            "this "
                            "line "
                            "item. "
                            "Allowed "
                            "values: "
                            "<code>goods</code> "
                            "or "
                            "<code>services</code>. "
                            "For "
                            "South "
                            "Africa "
                            "Edition, "
                            "additional "
                            "values "
                            "include "
                            "<code>capital_service</code> "
                            "and "
                            "<code>capital_goods</code>. "
                            "This "
                            "classification "
                            "affects "
                            "tax "
                            "calculations, "
                            "reporting, "
                            "and "
                            "compliance "
                            "requirements "
                            "based "
                            "on "
                            "your "
                            "organization's "
                            "location "
                            "and "
                            "tax "
                            "regulations.",
                            "example": "goods",
                            "type": "string",
                        },
                        "project_id": {
                            "description": "Unique "
                            "identifier "
                            "of "
                            "the "
                            "project "
                            "associated "
                            "with "
                            "this "
                            "line "
                            "item. "
                            "Use "
                            "the "
                            "`project_id` "
                            "returned "
                            "by "
                            "the "
                            "Projects "
                            "API "
                            "for "
                            "the "
                            "same "
                            "organization. "
                            "This "
                            "links "
                            "the "
                            "line "
                            "item "
                            "to "
                            "a "
                            "specific "
                            "project "
                            "for "
                            "project-based "
                            "billing, "
                            "time "
                            "tracking, "
                            "and "
                            "cost "
                            "allocation. "
                            "Optional "
                            "field "
                            "that "
                            "enables "
                            "project-specific "
                            "invoicing "
                            "and "
                            "reporting.",
                            "example": 90300000087378,
                            "type": "string",
                        },
                        "quantity": {
                            "description": "Number "
                            "of "
                            "units "
                            "of "
                            "the "
                            "item "
                            "being "
                            "invoiced. "
                            "This "
                            "value "
                            "is "
                            "multiplied "
                            "by "
                            "the "
                            "rate "
                            "to "
                            "calculate "
                            "the "
                            "line "
                            "item "
                            "total. "
                            "Must "
                            "be "
                            "a "
                            "positive "
                            "number "
                            "greater "
                            "than "
                            "zero.",
                            "example": 1,
                            "format": "float",
                            "type": "number",
                        },
                        "rate": {
                            "description": "Unit "
                            "rate "
                            "or "
                            "price "
                            "for "
                            "the "
                            "line "
                            "item "
                            "in "
                            "the "
                            "invoice "
                            "currency. "
                            "This "
                            "is "
                            "the "
                            "amount "
                            "charged "
                            "per "
                            "unit "
                            "of "
                            "the "
                            "item. "
                            "The "
                            "rate "
                            "is "
                            "used "
                            "to "
                            "calculate "
                            "the "
                            "line "
                            "item "
                            "total "
                            "(rate "
                            "x "
                            "quantity) "
                            "and "
                            "affects "
                            "the "
                            "final "
                            "invoice "
                            "amount.",
                            "example": 120,
                            "format": "double",
                            "type": "number",
                        },
                        "sat_item_key_code": {
                            "description": "Add "
                            "SAT "
                            "Item "
                            "Key "
                            "Code "
                            "for "
                            "your "
                            "goods/services. "
                            "Download "
                            "the "
                            "<a "
                            "href= "
                            "http://omawww.sat.gob.mx/tramitesyservicios/Paginas/documentos/catCFDI_V_4_07122022.xls  "
                            ">CFDI "
                            "Catalogs.</a>",
                            "example": 71121206,
                            "type": "string",
                            "x-node_available_in": ["mx"],
                            "x-node_unavailable_in": [],
                        },
                        "tags": {
                            "description": "Array "
                            "of "
                            "reporting "
                            "tags "
                            "associated "
                            "with "
                            "this "
                            "line "
                            "item. "
                            "Each "
                            "tag "
                            "consists "
                            "of a "
                            "`tag_id` "
                            "and "
                            "`tag_option_id` "
                            "that "
                            "categorize "
                            "the "
                            "line "
                            "item "
                            "for "
                            "reporting "
                            "and "
                            "analytics "
                            "purposes. "
                            "Tags "
                            "help "
                            "organize "
                            "and "
                            "filter "
                            "data "
                            "across "
                            "reports "
                            "and "
                            "enable "
                            "detailed "
                            "business "
                            "intelligence "
                            "analysis.",
                            "items": {
                                "properties": {
                                    "tag_id": {
                                        "description": "ID of the reporting tag",
                                        "example": 982000000009070,
                                        "type": "string",
                                    },
                                    "tag_option_id": {
                                        "description": "ID of the reporting tag's option",
                                        "example": 982000000002670,
                                        "type": "string",
                                    },
                                },
                                "type": "object",
                            },
                            "type": "array",
                        },
                        "tax_id": {
                            "description": "Unique "
                            "identifier "
                            "of "
                            "the "
                            "tax "
                            "to "
                            "be "
                            "applied "
                            "to "
                            "this "
                            "line "
                            "item. "
                            "Use "
                            "the "
                            "`tax_id` "
                            "returned "
                            "by "
                            "the "
                            "Taxes "
                            "API "
                            "for "
                            "the "
                            "same "
                            "organization. "
                            "This "
                            "determines "
                            "which "
                            "tax "
                            "rate "
                            "and "
                            "rules "
                            "are "
                            "applied "
                            "to "
                            "the "
                            "line "
                            "item, "
                            "affecting "
                            "the "
                            "final "
                            "tax "
                            "calculation "
                            "and "
                            "compliance "
                            "reporting.",
                            "example": 982000000557028,
                            "type": "string",
                        },
                        "tax_name": {
                            "description": "The name of the tax",
                            "example": "VAT",
                            "type": "string",
                        },
                        "tax_percentage": {
                            "description": "The  percentage of tax levied",
                            "example": 12.5,
                            "format": "float",
                            "type": "number",
                        },
                        "tax_treatment_code": {
                            "description": "Specify "
                            "reason "
                            "for "
                            "using "
                            "out "
                            "of "
                            "scope.</br>Supported "
                            "values "
                            "for "
                            "UAE "
                            "are "
                            "<code>uae_same_tax_group</code>, "
                            "<code>uae_reimbursed_expense</code> "
                            "and "
                            "<code>uae_others</code>.</br> "
                            "Supported "
                            "values "
                            "for "
                            "Bahrain "
                            "are "
                            "<code>bahrain_same_tax_group</code>, "
                            "<code>bahrain_transfer_of_concern</code>, "
                            "<code>bahrain_disbursement</code>, "
                            "<code>bahrain_head_to_branch_transaction</code>, "
                            "<code>bahrain_warranty_repair_services</code> "
                            "and "
                            "<code>bahrain_others</code>.</br>Supported "
                            "values "
                            "for "
                            "Saudi "
                            "Arabia "
                            "are "
                            "<code>ksa_pvt_health</code>, "
                            "<code>ksa_pvt_edu</code>, "
                            "<code>ksa_reimbursed_expense</code> "
                            "and "
                            "<code>ksa_house_sales</code>.",
                            "example": "uae_others",
                            "type": "string",
                            "x-node_available_in": ["gcc"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_type": {
                            "description": "The type of the tax",
                            "example": "tax",
                            "type": "string",
                        },
                        "tds_tax_id": {
                            "description": "ID of the TDS tax.",
                            "example": "982000000557012",
                            "type": "string",
                            "x-node_available_in": ["mx"],
                            "x-node_unavailable_in": [],
                        },
                        "time_entry_ids": {
                            "description": "Array "
                            "of "
                            "time "
                            "entry "
                            "IDs "
                            "to "
                            "be "
                            "billed "
                            "on "
                            "this "
                            "line "
                            "item. "
                            "This "
                            "allows "
                            "you "
                            "to "
                            "bill "
                            "specific "
                            "time "
                            "entries "
                            "against "
                            "this "
                            "line "
                            "item, "
                            "enabling "
                            "detailed "
                            "time-based "
                            "invoicing "
                            "and "
                            "project "
                            "cost "
                            "tracking.",
                            "example": [],
                            "items": {"type": "string"},
                            "type": "array",
                        },
                        "unit": {
                            "description": "Unit "
                            "of "
                            "measurement "
                            "for "
                            "the "
                            "line "
                            "item "
                            "quantity. "
                            "Examples "
                            "include "
                            '"Nos" '
                            "(Numbers), "
                            '"kgs" '
                            "(Kilograms), "
                            '"hrs" '
                            "(Hours), "
                            '"pcs" '
                            "(Pieces), "
                            "etc. "
                            "This "
                            "helps "
                            "clarify "
                            "what "
                            "the "
                            "quantity "
                            "represents. "
                            "Maximum "
                            "length "
                            "is "
                            "100 "
                            "characters.",
                            "example": " ",
                            "type": "string",
                        },
                        "unitkey_code": {
                            "description": "Add "
                            "SAT "
                            "Unit "
                            "Key "
                            "Code "
                            "for "
                            "your "
                            "goods/services. "
                            "Download "
                            "the "
                            "<a "
                            "href= "
                            "http://omawww.sat.gob.mx/tramitesyservicios/Paginas/documentos/catCFDI_V_4_07122022.xls  "
                            ">CFDI "
                            "Catalogs.</a>",
                            "example": "E48",
                            "type": "string",
                            "x-node_available_in": ["mx"],
                            "x-node_unavailable_in": [],
                        },
                    },
                    "required": ["item_id"],
                    "type": "object",
                },
                "type": "array",
            },
            "location_id": {
                "description": "Unique identifier of the business "
                "location associated with the invoice. "
                "Use the `location_id` returned by the "
                "Locations API for the same "
                "organization. This links the invoice "
                "to a specific business location, which "
                "may affect tax calculations, "
                "reporting, and business operations. "
                "Required if your organization has "
                "multiple locations configured.",
                "example": "460000000038080",
                "type": "string",
            },
            "notes": {
                "description": "Additional information or comments to be "
                "displayed on the invoice document. This "
                "field is typically used for thank you "
                "messages, special instructions, or any other "
                "information you want to communicate to the "
                "customer. The notes appear on the invoice "
                "PDF and are visible to customers",
                "example": "Looking forward for your business.",
                "type": "string",
            },
            "payment_options": {
                "description": "Payment options for the invoice, "
                "online payment gateways and bank "
                "accounts. Will be displayed in the "
                "pdf.",
                "properties": {
                    "payment_gateways": {
                        "description": "Online payment gateways through which payment can be made.",
                        "items": {
                            "properties": {
                                "additional_field1": {
                                    "description": "Paypal "
                                    "payment "
                                    "method. "
                                    "Allowed "
                                    "Values: "
                                    "<code>standard</code> "
                                    "and "
                                    "<code>adaptive</code>",
                                    "example": "standard",
                                    "type": "string",
                                },
                                "configured": {
                                    "description": "Boolean "
                                    "check "
                                    "to "
                                    "see "
                                    "if "
                                    "a "
                                    "payment "
                                    "gateway "
                                    "has "
                                    "been "
                                    "configured",
                                    "example": True,
                                    "type": "boolean",
                                },
                                "gateway_name": {
                                    "description": "Name "
                                    "of "
                                    "the "
                                    "payment "
                                    "gateway "
                                    "associated "
                                    "with "
                                    "the "
                                    "invoice. "
                                    "E.g. "
                                    "paypal, "
                                    "stripe.Allowed "
                                    "Values: "
                                    "<code>paypal</code>, "
                                    "<code>authorize_net</code>, "
                                    "<code>payflow_pro</code>, "
                                    "<code>stripe</code>, "
                                    "<code>2checkout</code> "
                                    "and "
                                    "<code>braintree</code>",
                                    "example": "paypal",
                                    "type": "string",
                                },
                            },
                            "type": "object",
                        },
                        "type": "array",
                    }
                },
                "type": "object",
            },
            "payment_terms": {
                "description": "Number of days allowed for payment "
                "(e.g., 15, 30, 60). This value "
                "determines the invoice due date by "
                "adding the specified number of days "
                "to the invoice date. For example, if "
                "invoice date is 2023-11-17 and "
                "payment_terms is 15, the due_date "
                "will be 2023-12-02. Maximum value is "
                "100 days.",
                "example": 15,
                "type": "integer",
            },
            "payment_terms_label": {
                "description": "Custom label for payment terms "
                "that appears on the invoice "
                "document. Used to override the "
                "default system-generated "
                "label. For example, instead of "
                'the default "Net 15 Days", you '
                'can set this to "Net 15", "Due '
                'in 15 days", or any custom '
                "text. This label is displayed "
                "to customers on the invoice. "
                "Maximum length is 100 "
                "characters.",
                "example": "Net 15",
                "type": "string",
            },
            "place_of_supply": {
                "description": "Place where the goods/services are "
                "supplied to. (If not given, "
                "<code>place of contact</code> "
                "given for the contact will be "
                "taken)<br/>Supported codes for UAE "
                "emirates are : </br>Abu Dhabi - "
                "<code>AB</code>,</br>Ajman - "
                "<code>AJ</code>,</br>Dubai - "
                "<code>DU</code>,</br>Fujairah - "
                "<code>FU</code>,</br>Ras "
                "al-Khaimah - "
                "<code>RA</code>,</br>Sharjah - "
                "<code>SH</code>,</br>Umm al-Quwain "
                "- <code>UM</code><br/>Supported "
                "codes for the GCC countries are : "
                "</br>United Arab Emirates - "
                "<code>AE</code>,</br>Saudi Arabia "
                "- <code>SA</code>,</br>Bahrain - "
                "<code>BH</code>,</br>Kuwait - "
                "<code>KW</code>,</br>Oman - "
                "<code>OM</code>,</br>Qatar - "
                "<code>QA</code>.",
                "example": "TN",
                "type": "string",
                "x-node_available_in": ["in", "gcc"],
                "x-node_unavailable_in": [],
            },
            "reason": {"example": " ", "type": "string"},
            "recurring_invoice_id": {
                "description": "Unique identifier of the "
                "recurring invoice template "
                "that generated this invoice. "
                "Use this field when creating "
                "an invoice from a recurring "
                "invoice template. The "
                "`recurring_invoice_id` links "
                "this invoice back to its "
                "source recurring invoice, "
                "enabling tracking of which "
                "template generated it and "
                "maintaining the recurring "
                "invoice relationship.",
                "example": " ",
                "type": "string",
            },
            "reference_invoice_id": {
                "description": "Associate the reference invoice.",
                "example": "132738000000126013",
                "type": "string",
                "x-node_available_in": ["mx"],
                "x-node_unavailable_in": [],
            },
            "reference_number": {
                "description": "External reference number or "
                "identifier for the invoice, such "
                "as a purchase order number, "
                "contract number, or any other "
                "business reference. When "
                "converting from an estimate or "
                "sales order, this field can be "
                "used to reference the original "
                "document number.",
                "example": " ",
                "type": "string",
            },
            "salesorder_item_id": {
                "description": "Unique identifier of the sales "
                "order line item that is being "
                "converted to this invoice line "
                "item. Use this field when "
                "creating an invoice from an "
                "existing sales order. The "
                "`salesorder_item_id` links this "
                "invoice line item back to its "
                "source sales order line item, "
                "enabling tracking of the "
                "conversion process and "
                "maintaining the relationship "
                "between sales orders and "
                "invoices.",
                "example": " ",
                "type": "string",
            },
            "salesperson_name": {
                "description": "Name of the salesperson. Max-length [200]",
                "example": " ",
                "type": "string",
            },
            "shipping_charge": {
                "description": "Additional shipping or delivery "
                "charges applied to the invoice. "
                "Must be specified as a fixed "
                'amount (e.g., "25.00"). This '
                "amount is added to the invoice "
                "total and is subject to tax "
                "calculation.",
                "example": 0,
                "type": "string",
            },
            "tax_authority_id": {
                "description": "ID of the tax authority. Tax "
                "authority depends on the location "
                "of the customer. For example, if "
                "the customer is located in NY, "
                "then the tax authority is NY tax "
                "authority.",
                "example": 11149000000061052,
                "type": "string",
                "x-node_available_in": ["us"],
                "x-node_unavailable_in": [],
            },
            "tax_exemption_id": {
                "description": "ID of the tax exemption.",
                "example": 11149000000061054,
                "type": "string",
                "x-node_available_in": ["in", "us"],
                "x-node_unavailable_in": [],
            },
            "tax_id": {
                "description": "Unique identifier of the tax to be applied "
                "to this line item. Use the `tax_id` "
                "returned by the Taxes API for the same "
                "organization. This determines which tax "
                "rate and rules are applied to the line "
                "item, affecting the final tax calculation "
                "and compliance reporting.",
                "example": 982000000557028,
                "type": "string",
            },
            "tax_treatment": {
                "description": "VAT treatment for the invoice "
                ".Choose whether the contact falls "
                "under: "
                "<code>vat_registered</code>,<code>vat_not_registered</code>,<code>gcc_vat_not_registered</code>,<code>gcc_vat_registered</code>,<code>non_gcc</code>.</br><code>dz_vat_registered</code> "
                "and "
                "<code>dz_vat_not_registered</code> "
                "supported only for "
                "<b>UAE</b>.</b></br><code>home_country_mexico</code>,<code>border_region_mexico</code>,<code>non_mexico</code> "
                "supported only for "
                "<b>MX</b>.<br/><b>For Kenya "
                "Edition:</b> "
                "<code>vat_registered</code> "
                ",<code>vat_not_registered</code> "
                ",<code>non_kenya</code>(A business "
                "that is located outside "
                "Kenya).<br/><b>For SouthAfrica "
                "Edition:</b> "
                "<code>vat_registered</code>, "
                "<code>vat_not_registered</code>, "
                "<code>overseas</code>(A business "
                "that is located outside "
                "SouthAfrica).",
                "example": "vat_registered",
                "type": "string",
                "x-node_available_in": ["gcc", "mx", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "template_id": {
                "description": "Unique identifier of the PDF template "
                "linked to the invoice. Obtain this "
                "value from the `template_id` field in "
                "the response of the GET "
                "`/invoices/templates` API for your "
                "organization. Determines which "
                "template is used for the invoice PDF.",
                "example": 982000000000143,
                "type": "string",
            },
            "terms": {
                "description": "Terms and conditions text to be displayed on "
                "the invoice document. This field is used to "
                "specify payment terms, delivery conditions, "
                "return policies, or any other legal or "
                "business terms that apply to this "
                "transaction. The terms appear on the invoice "
                "PDF and are legally binding.",
                "example": "Terms & Conditions apply",
                "type": "string",
            },
            "vat_treatment": {
                "description": "(Optional) VAT treatment for the "
                "invoices. VAT treatment denotes the "
                "location of the customer, if the "
                "customer resides in UK then the VAT "
                "treatment is <code>uk</code>. If the "
                "customer is in an EU country & VAT "
                "registered, you are resides in "
                "Northen Ireland and selling Goods "
                "then his VAT treatment is "
                "<code>eu_vat_registered</code>, if "
                "he resides outside of the UK then "
                "his VAT treatment is "
                "<code>overseas</code> (For Pre "
                "Brexit, this can be split as "
                "<code>eu_vat_registered</code>, "
                "<code>eu_vat_not_registered</code> "
                "and <code>non_eu</code>).",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
        },
        "required": ["customer_id", "line_items"],
        "type": "object",
    },
    "UPDATEINVOICE_REQUEST_BODY_SCHEMA": {
        "properties": {
            "adjustment": {
                "description": "Additional charge or credit amount "
                "applied to the invoice total. This can "
                "be used for rounding adjustments, "
                "handling fees, or any other one-time "
                "charges/credits. Positive values add to "
                "the total, negative values reduce the "
                "total. This amount is applied after tax "
                "calculation and affects the final "
                "invoice total.",
                "example": 0,
                "format": "double",
                "type": "number",
            },
            "adjustment_description": {
                "description": "Text description explaining "
                "the reason for the "
                "adjustment amount. This "
                "description appears on the "
                "invoice document to explain "
                "why the adjustment was "
                "applied. Common examples "
                'include "Rounding '
                'adjustment", "Handling '
                'fee", "Early payment '
                'discount", or "Late payment '
                'fee". This helps customers '
                "understand the purpose of "
                "the adjustment.",
                "example": " ",
                "type": "string",
            },
            "allow_partial_payments": {
                "description": "Boolean flag that "
                "determines whether "
                "customers can make partial "
                "payments against this "
                "invoice. When "
                "<code>true</code>, "
                "customers can pay less than "
                "the full invoice amount, "
                "and the invoice will remain "
                "open with a remaining "
                "balance. When "
                "<code>false</code>, "
                "customers must pay the full "
                "amount to complete the "
                "invoice. This setting "
                "affects payment processing "
                "and invoice status "
                "tracking.",
                "example": True,
                "type": "boolean",
            },
            "avatax_exempt_no": {
                "description": "Exemption certificate number of the customer. Max-length [25]",
                "type": "string",
                "x-node_available_in": ["Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "avatax_tax_code": {
                "description": "A tax code is a unique label used "
                "to group Items (products, "
                "services, or charges) together. "
                "Refer the [link][2] for more "
                "deails. Max-length [25]",
                "type": "string",
                "x-node_available_in": ["Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "avatax_use_code": {
                "description": "Used to group like customers for "
                "exemption purposes. It is a custom "
                "value that links customers to a "
                "tax rule. Select from Avalara "
                "[standard codes][1] or enter a "
                "custom code. Max-length [25]",
                "type": "string",
                "x-node_available_in": ["Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "cfdi_reference_type": {
                "description": "Choose CFDI Reference Type. "
                "Allowed "
                "values:</br><code>return_of_merchandise</code>, "
                "<code>substitution_previous_cfdi</code>, "
                "<code>transfer_of_goods</code>, "
                "<code>invoice_generated_from_order</code>, "
                "<code>cfdi_for_advance</code>.",
                "example": "return_of_merchandise",
                "type": "string",
                "x-node_available_in": ["mx"],
                "x-node_unavailable_in": [],
            },
            "cfdi_usage": {
                "description": "Choose CFDI Usage. Allowed "
                "values:</br><code>acquisition_of_merchandise</code>, "
                "<code>return_discount_bonus</code>, "
                "<code>general_expense</code>, "
                "<code>buildings</code>, "
                "<code>furniture_office_equipment</code>, "
                "<code>transport_equipment</code>, "
                "<code>computer_equipmentdye_molds_tools</code>, "
                "<code>telephone_communication</code>, "
                "<code>satellite_communication</code>, "
                "<code>other_machinery_equipment</code>, "
                "<code>hospital_expense</code>, "
                "<code>medical_expense_disability</code>, "
                "<code>funeral_expense</code>, "
                "<code>donation</code>, "
                "<code>interest_mortage_loans</code>, "
                "<code>contribution_sar</code>, "
                "<code>medical_expense_insurance_pormium</code>, "
                "<code>school_transportation_expense</code>, "
                "<code>deposit_saving_account</code>, "
                "<code>payment_educational_service</code>, "
                "<code>no_tax_effect</code>, "
                "<code>payment</code>, "
                "<code>payroll</code>.",
                "example": "acquisition_of_merchandise",
                "type": "string",
                "x-node_available_in": ["mx"],
                "x-node_unavailable_in": [],
            },
            "contact_persons_associated": {
                "description": "Contact Persons associated with the transaction.",
                "items": {
                    "properties": {
                        "communication_preference": {
                            "description": "Preferred "
                            "modes "
                            "of "
                            "communication "
                            "for "
                            "the "
                            "contact "
                            "person "
                            "at "
                            "transaction "
                            "level.",
                            "properties": {
                                "is_email_enabled": {
                                    "description": "Used "
                                    "to "
                                    "check "
                                    "if "
                                    "Email "
                                    "communication "
                                    "preference "
                                    "is "
                                    "enabled "
                                    "for "
                                    "the "
                                    "contact "
                                    "person "
                                    "at "
                                    "transaction "
                                    "level.",
                                    "example": True,
                                    "type": "boolean",
                                },
                                "is_whatsapp_enabled": {
                                    "description": "Used "
                                    "to "
                                    "check "
                                    "if "
                                    "WhatsApp "
                                    "communication "
                                    "preference "
                                    "is "
                                    "enabled "
                                    "for "
                                    "the "
                                    "contact "
                                    "person "
                                    "at "
                                    "transaction "
                                    "level.",
                                    "example": True,
                                    "type": "boolean",
                                    "x-node_available_in": ["WhatsApp integration"],
                                },
                            },
                            "type": "object",
                        },
                        "contact_person_id": {
                            "description": "Unique ID of the Contact Person.",
                            "example": 982000000567003,
                            "format": "int64",
                            "type": "integer",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "currency_id": {
                "description": "Unique identifier of the currency in "
                "which the invoice will be created for "
                "the customer. Use the `currency_id` "
                "returned by the Currencies API for the "
                "same organization. This sets the "
                "currency for all monetary amounts on "
                "the invoice; if it differs from the "
                "organization's base currency, an "
                "appropriate `exchange_rate` may be "
                "required.",
                "example": 982000000000190,
                "type": "string",
            },
            "custom_body": {"example": " ", "type": "string"},
            "custom_fields": {
                "description": "Custom fields for an invoice.",
                "items": {
                    "properties": {
                        "customfield_id": {
                            "example": "46000000012845",
                            "format": "int64",
                            "type": "integer",
                        },
                        "value": {
                            "description": "Value of the Custom Field",
                            "example": "Normal",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "custom_subject": {"example": " ", "type": "string"},
            "customer_id": {
                "description": "Unique identifier of the customer in "
                "the current organization for whom this "
                "invoice is created. Required when "
                "creating an invoice. Use the "
                "`customer_id` returned by the get "
                "Customers API. Must belong to the "
                "organization specified by the "
                "`organization_id` parameter.",
                "example": 982000000567001,
                "type": "string",
            },
            "date": {
                "description": "The date on which the invoice is created. Use "
                "the format yyyy-mm-dd (e.g., 2013-11-17). "
                "This date appears on the invoice document and "
                "is used for accounting purposes. When "
                "searching invoices, supports variants: "
                "<code>date_start</code>, "
                "<code>date_end</code>, "
                "<code>date_before</code> and "
                "<code>date_after</code>.",
                "example": "2013-11-17",
                "type": "string",
            },
            "discount": {
                "description": "Discount amount applied to the invoice. "
                "Can be specified as a percentage (e.g., "
                "12.5 for 12.5%) — up to a maximum of 100% "
                "— or as a fixed amount (e.g., 190 for "
                "$190). The discount is applied based on "
                "the `is_discount_before_tax` setting and "
                "`discount_type` (entity_level or "
                "item_level).",
                "example": 0,
                "format": "float",
                "type": "number",
            },
            "discount_type": {
                "description": "Specifies the scope of discount "
                "application. "
                "<code>entity_level</code> applies "
                "the discount to the entire invoice "
                "total. <code>item_level</code> "
                "applies the discount to individual "
                "line items. This determines how the "
                "discount amount is distributed "
                "across the invoice items.",
                "example": "item_level",
                "type": "string",
            },
            "due_date": {
                "description": "The date by which payment is due for the "
                "invoice. Use the format yyyy-mm-dd (e.g., "
                "2013-12-03). This date is typically "
                "calculated as invoice date + "
                "payment_terms days, but can be overridden "
                "with a custom date. When searching "
                "invoices, supports variants: "
                "<code>due_date_start</code>, "
                "<code>due_date_end</code>, "
                "<code>due_date_before</code> and "
                "<code>due_date_after</code>.",
                "example": "2013-12-03",
                "type": "string",
            },
            "exchange_rate": {
                "description": "Exchange rate used to convert "
                "amounts from the invoice currency to "
                "the organization's base currency. "
                "Required when the invoice currency "
                "differs from the organization's base "
                "currency. For example, if base "
                "currency is USD and invoice currency "
                "is EUR, set the EUR to USD exchange "
                "rate (e.g., 1.18). Default value is "
                "1.0 when invoice currency matches "
                "base currency.",
                "example": 1,
                "format": "float",
                "type": "number",
            },
            "expense_id": {
                "description": "Unique identifier of the billable "
                "expense to be converted to an invoice "
                "line item. This converts a previously "
                "recorded expense into a billable line "
                "item on the invoice, enabling "
                "expense-to-invoice conversion.",
                "example": "460000000028080",
                "type": "string",
            },
            "gst_no": {
                "description": "15 digit GST identification number of the customer.",
                "example": "22AAAAA0000A1Z5",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "gst_treatment": {
                "description": "Choose whether the contact is GST "
                "registered/unregistered/consumer/overseas. "
                "Allowed values are <code> "
                "business_gst </code> , <code> "
                "business_none </code> , <code> "
                "overseas </code> , <code> consumer "
                "</code>.",
                "example": "business_gst",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "invoice_number": {
                "description": "Unique identifier or reference "
                "number for the invoice. When "
                "creating an invoice, this can be a "
                "custom number (requires "
                "`ignore_auto_number_generation=true` "
                "query parameter) or left empty for "
                "auto-generation. When searching "
                "invoices, supports variants: "
                "<code>invoice_number_startswith</code> "
                "and "
                "<code>invoice_number_contains</code>. "
                "Maximum length is 100 characters. "
                "Must be unique within the "
                "organization.",
                "example": "INV-00003",
                "type": "string",
            },
            "invoiced_estimate_id": {
                "description": "Unique identifier of the "
                "estimate that was converted "
                "to create this invoice. Use "
                "this field when creating an "
                "invoice from an existing "
                "estimate. The "
                "`invoiced_estimate_id` links "
                "this invoice back to its "
                "source estimate, enabling "
                "tracking of the conversion "
                "process and maintaining the "
                "relationship between "
                "estimates and invoices.",
                "example": " ",
                "type": "string",
            },
            "is_discount_before_tax": {
                "description": "Boolean flag that "
                "determines when the "
                "discount is applied in "
                "relation to tax "
                "calculation. When "
                "<code>true</code>, discount "
                "is applied before tax "
                "calculation (discount "
                "reduces the taxable "
                "amount). When "
                "<code>false</code>, "
                "discount is applied after "
                "tax calculation (discount "
                "reduces the final total "
                "including tax). This "
                "affects the final invoice "
                "total and tax amounts.",
                "example": True,
                "type": "boolean",
            },
            "is_inclusive_tax": {
                "description": "Boolean flag that indicates "
                "whether line item rates include "
                "tax. When <code>true</code>, the "
                "specified rates are inclusive of "
                "tax (tax is already included in "
                "the rate). When "
                "<code>false</code>, the rates are "
                "exclusive of tax (tax will be "
                "added to the rate). This affects "
                "how tax calculations are "
                "performed on line items.",
                "example": False,
                "type": "boolean",
            },
            "is_reverse_charge_applied": {
                "description": "(Required if customer "
                "tax treatment is "
                "<code>vat_registered</code>)<br/>Used "
                "to specify whether the "
                "transaction is "
                "applicable for Domestic "
                "Reverse Charge (DRC) or "
                "not.",
                "example": True,
                "type": "boolean",
                "x-node_available_in": ["za"],
                "x-node_unavailable_in": [],
            },
            "line_item_id": {
                "description": "The line item id",
                "example": 982000000567021,
                "type": "string",
            },
            "line_items": {
                "items": {
                    "properties": {
                        "bcy_rate": {
                            "description": "Base "
                            "currency "
                            "rate "
                            "for "
                            "the "
                            "line "
                            "item. "
                            "This "
                            "is "
                            "the "
                            "rate "
                            "in "
                            "the "
                            "organization's "
                            "base "
                            "currency "
                            "before "
                            "any "
                            "currency "
                            "conversion. "
                            "Used "
                            "for "
                            "multi-currency "
                            "scenarios "
                            "where "
                            "the "
                            "invoice "
                            "currency "
                            "differs "
                            "from "
                            "the "
                            "base "
                            "currency.",
                            "example": 120,
                            "format": "float",
                            "type": "number",
                        },
                        "description": {
                            "description": "Detailed "
                            "description "
                            "of "
                            "the "
                            "line "
                            "item "
                            "providing "
                            "additional "
                            "information "
                            "about "
                            "the "
                            "product "
                            "or "
                            "service. "
                            "This "
                            "description "
                            "appears "
                            "on "
                            "the "
                            "invoice "
                            "document "
                            "and "
                            "helps "
                            "customers "
                            "understand "
                            "what "
                            "they "
                            "are "
                            "being "
                            "charged "
                            "for. "
                            "Maximum "
                            "length "
                            "is "
                            "2000 "
                            "characters.",
                            "example": "500GB, USB 2.0 interface 1400 rpm, protective hard case.",
                            "type": "string",
                        },
                        "discount": {
                            "description": "Discount "
                            "amount "
                            "applied "
                            "to "
                            "the "
                            "invoice. "
                            "Can "
                            "be "
                            "specified "
                            "as "
                            "a "
                            "percentage "
                            "(e.g., "
                            "12.5 "
                            "for "
                            "12.5%) "
                            "— "
                            "up "
                            "to "
                            "a "
                            "maximum "
                            "of "
                            "100% "
                            "— "
                            "or "
                            "as "
                            "a "
                            "fixed "
                            "amount "
                            "(e.g., "
                            "190 "
                            "for "
                            "$190). "
                            "The "
                            "discount "
                            "is "
                            "applied "
                            "based "
                            "on "
                            "the "
                            "`is_discount_before_tax` "
                            "setting "
                            "and "
                            "`discount_type` "
                            "(entity_level "
                            "or "
                            "item_level).",
                            "example": 0,
                            "format": "float",
                            "type": "number",
                        },
                        "discount_amount": {
                            "description": "Fixed "
                            "discount "
                            "amount "
                            "applied "
                            "to "
                            "this "
                            "specific "
                            "line "
                            "item. "
                            "This "
                            "is "
                            "a "
                            "monetary "
                            "value "
                            "that "
                            "reduces "
                            "the "
                            "line "
                            "item "
                            "total. "
                            "The "
                            "discount "
                            "is "
                            "applied "
                            "after "
                            "the "
                            "rate "
                            "x "
                            "quantity "
                            "calculation "
                            "but "
                            "before "
                            "tax "
                            "calculation. "
                            "Can "
                            "be "
                            "used "
                            "for "
                            "line-item "
                            "specific "
                            "discounts "
                            "or "
                            "promotions.",
                            "example": 0,
                            "format": "float",
                            "type": "number",
                        },
                        "expense_id": {
                            "description": "Unique "
                            "identifier "
                            "of "
                            "the "
                            "billable "
                            "expense "
                            "to "
                            "be "
                            "converted "
                            "to "
                            "an "
                            "invoice "
                            "line "
                            "item. "
                            "This "
                            "converts "
                            "a "
                            "previously "
                            "recorded "
                            "expense "
                            "into "
                            "a "
                            "billable "
                            "line "
                            "item "
                            "on "
                            "the "
                            "invoice, "
                            "enabling "
                            "expense-to-invoice "
                            "conversion.",
                            "example": "460000000028080",
                            "type": "string",
                        },
                        "expense_receipt_name": {"type": "string"},
                        "header_id": {
                            "description": "ID of the item header",
                            "example": 982000000000670,
                            "type": "string",
                        },
                        "header_name": {
                            "description": "Name "
                            "of "
                            "the "
                            "item "
                            "header "
                            "or "
                            "category "
                            "that "
                            "groups "
                            "related "
                            "line "
                            "items "
                            "together. "
                            "This "
                            "is "
                            "used "
                            "for "
                            "organizational "
                            "purposes "
                            "to "
                            "categorize "
                            "and "
                            "group "
                            "similar "
                            "items "
                            "on "
                            "the "
                            "invoice. "
                            "For "
                            "example, "
                            '"Electronic '
                            'devices", '
                            '"Office '
                            'supplies", '
                            "or "
                            '"Professional '
                            'services". '
                            "This "
                            "helps "
                            "in "
                            "organizing "
                            "and "
                            "presenting "
                            "line "
                            "items "
                            "in "
                            "a "
                            "structured "
                            "manner "
                            "on "
                            "the "
                            "invoice "
                            "document.",
                            "example": "Electronic devices",
                            "type": "string",
                        },
                        "hsn_or_sac": {
                            "description": "Add HSN/SAC code for your goods/services",
                            "example": 80540,
                            "type": "string",
                            "x-node_available_in": ["in", "ke", "za"],
                            "x-node_unavailable_in": [],
                        },
                        "item_id": {
                            "description": "Unique "
                            "identifier "
                            "of "
                            "the "
                            "item "
                            "(product "
                            "or "
                            "service) "
                            "to "
                            "be "
                            "included "
                            "in "
                            "the "
                            "invoice "
                            "line "
                            "item. "
                            "Use "
                            "the "
                            "`item_id` "
                            "returned "
                            "by "
                            "the "
                            "Items "
                            "API "
                            "for "
                            "the "
                            "same "
                            "organization. "
                            "This "
                            "field "
                            "is "
                            "required "
                            "for "
                            "each "
                            "line "
                            "item "
                            "and "
                            "determines "
                            "the "
                            "item "
                            "details, "
                            "pricing, "
                            "and "
                            "tax "
                            "settings "
                            "that "
                            "will "
                            "be "
                            "applied "
                            "to "
                            "this "
                            "line "
                            "item.",
                            "example": 982000000030049,
                            "type": "string",
                        },
                        "item_order": {
                            "description": "Sequential "
                            "order "
                            "number "
                            "for "
                            "this "
                            "line "
                            "item "
                            "on "
                            "the "
                            "invoice. "
                            "Determines "
                            "the "
                            "display "
                            "order "
                            "of "
                            "line "
                            "items "
                            "on "
                            "the "
                            "invoice "
                            "document. "
                            "Lower "
                            "numbers "
                            "appear "
                            "first. "
                            "Used "
                            "for "
                            "organizing "
                            "line "
                            "items "
                            "in "
                            "a "
                            "specific "
                            "sequence.",
                            "example": 1,
                            "type": "integer",
                        },
                        "location_id": {
                            "description": "Unique "
                            "identifier "
                            "of "
                            "the "
                            "business "
                            "location "
                            "associated "
                            "with "
                            "the "
                            "invoice. "
                            "Use "
                            "the "
                            "`location_id` "
                            "returned "
                            "by "
                            "the "
                            "Locations "
                            "API "
                            "for "
                            "the "
                            "same "
                            "organization. "
                            "This "
                            "links "
                            "the "
                            "invoice "
                            "to "
                            "a "
                            "specific "
                            "business "
                            "location, "
                            "which "
                            "may "
                            "affect "
                            "tax "
                            "calculations, "
                            "reporting, "
                            "and "
                            "business "
                            "operations. "
                            "Required "
                            "if "
                            "your "
                            "organization "
                            "has "
                            "multiple "
                            "locations "
                            "configured.",
                            "example": "460000000038080",
                            "type": "string",
                        },
                        "name": {
                            "description": "Name "
                            "or "
                            "title "
                            "of "
                            "the "
                            "line "
                            "item "
                            "as it "
                            "appears "
                            "on "
                            "the "
                            "invoice. "
                            "Maximum "
                            "length "
                            "is "
                            "100 "
                            "characters. "
                            "Can "
                            "be "
                            "customized "
                            "to "
                            "override "
                            "the "
                            "default "
                            "item "
                            "name "
                            "from "
                            "the "
                            "item "
                            "catalog.",
                            "example": "Hard Drive",
                            "type": "string",
                        },
                        "product_type": {
                            "description": "Type "
                            "of "
                            "product "
                            "or "
                            "service "
                            "for "
                            "this "
                            "line "
                            "item. "
                            "Allowed "
                            "values: "
                            "<code>goods</code> "
                            "or "
                            "<code>services</code>. "
                            "For "
                            "South "
                            "Africa "
                            "Edition, "
                            "additional "
                            "values "
                            "include "
                            "<code>capital_service</code> "
                            "and "
                            "<code>capital_goods</code>. "
                            "This "
                            "classification "
                            "affects "
                            "tax "
                            "calculations, "
                            "reporting, "
                            "and "
                            "compliance "
                            "requirements "
                            "based "
                            "on "
                            "your "
                            "organization's "
                            "location "
                            "and "
                            "tax "
                            "regulations.",
                            "example": "goods",
                            "type": "string",
                        },
                        "project_id": {
                            "description": "Unique "
                            "identifier "
                            "of "
                            "the "
                            "project "
                            "associated "
                            "with "
                            "this "
                            "line "
                            "item. "
                            "Use "
                            "the "
                            "`project_id` "
                            "returned "
                            "by "
                            "the "
                            "Projects "
                            "API "
                            "for "
                            "the "
                            "same "
                            "organization. "
                            "This "
                            "links "
                            "the "
                            "line "
                            "item "
                            "to "
                            "a "
                            "specific "
                            "project "
                            "for "
                            "project-based "
                            "billing, "
                            "time "
                            "tracking, "
                            "and "
                            "cost "
                            "allocation. "
                            "Optional "
                            "field "
                            "that "
                            "enables "
                            "project-specific "
                            "invoicing "
                            "and "
                            "reporting.",
                            "example": 90300000087378,
                            "type": "string",
                        },
                        "quantity": {
                            "description": "Number "
                            "of "
                            "units "
                            "of "
                            "the "
                            "item "
                            "being "
                            "invoiced. "
                            "This "
                            "value "
                            "is "
                            "multiplied "
                            "by "
                            "the "
                            "rate "
                            "to "
                            "calculate "
                            "the "
                            "line "
                            "item "
                            "total. "
                            "Must "
                            "be "
                            "a "
                            "positive "
                            "number "
                            "greater "
                            "than "
                            "zero.",
                            "example": 1,
                            "format": "float",
                            "type": "number",
                        },
                        "rate": {
                            "description": "Unit "
                            "rate "
                            "or "
                            "price "
                            "for "
                            "the "
                            "line "
                            "item "
                            "in "
                            "the "
                            "invoice "
                            "currency. "
                            "This "
                            "is "
                            "the "
                            "amount "
                            "charged "
                            "per "
                            "unit "
                            "of "
                            "the "
                            "item. "
                            "The "
                            "rate "
                            "is "
                            "used "
                            "to "
                            "calculate "
                            "the "
                            "line "
                            "item "
                            "total "
                            "(rate "
                            "x "
                            "quantity) "
                            "and "
                            "affects "
                            "the "
                            "final "
                            "invoice "
                            "amount.",
                            "example": 120,
                            "format": "double",
                            "type": "number",
                        },
                        "sat_item_key_code": {
                            "description": "Add "
                            "SAT "
                            "Item "
                            "Key "
                            "Code "
                            "for "
                            "your "
                            "goods/services. "
                            "Download "
                            "the "
                            "<a "
                            "href= "
                            "http://omawww.sat.gob.mx/tramitesyservicios/Paginas/documentos/catCFDI_V_4_07122022.xls  "
                            ">CFDI "
                            "Catalogs.</a>",
                            "example": 71121206,
                            "type": "string",
                            "x-node_available_in": ["mx"],
                            "x-node_unavailable_in": [],
                        },
                        "tags": {
                            "description": "Array "
                            "of "
                            "reporting "
                            "tags "
                            "associated "
                            "with "
                            "this "
                            "line "
                            "item. "
                            "Each "
                            "tag "
                            "consists "
                            "of a "
                            "`tag_id` "
                            "and "
                            "`tag_option_id` "
                            "that "
                            "categorize "
                            "the "
                            "line "
                            "item "
                            "for "
                            "reporting "
                            "and "
                            "analytics "
                            "purposes. "
                            "Tags "
                            "help "
                            "organize "
                            "and "
                            "filter "
                            "data "
                            "across "
                            "reports "
                            "and "
                            "enable "
                            "detailed "
                            "business "
                            "intelligence "
                            "analysis.",
                            "items": {
                                "properties": {
                                    "tag_id": {
                                        "description": "ID of the reporting tag",
                                        "example": 982000000009070,
                                        "type": "string",
                                    },
                                    "tag_option_id": {
                                        "description": "ID of the reporting tag's option",
                                        "example": 982000000002670,
                                        "type": "string",
                                    },
                                },
                                "type": "object",
                            },
                            "type": "array",
                        },
                        "tax_id": {
                            "description": "Unique "
                            "identifier "
                            "of "
                            "the "
                            "tax "
                            "to "
                            "be "
                            "applied "
                            "to "
                            "this "
                            "line "
                            "item. "
                            "Use "
                            "the "
                            "`tax_id` "
                            "returned "
                            "by "
                            "the "
                            "Taxes "
                            "API "
                            "for "
                            "the "
                            "same "
                            "organization. "
                            "This "
                            "determines "
                            "which "
                            "tax "
                            "rate "
                            "and "
                            "rules "
                            "are "
                            "applied "
                            "to "
                            "the "
                            "line "
                            "item, "
                            "affecting "
                            "the "
                            "final "
                            "tax "
                            "calculation "
                            "and "
                            "compliance "
                            "reporting.",
                            "example": 982000000557028,
                            "type": "string",
                        },
                        "tax_name": {
                            "description": "The name of the tax",
                            "example": "VAT",
                            "type": "string",
                        },
                        "tax_percentage": {
                            "description": "The  percentage of tax levied",
                            "example": 12.5,
                            "format": "float",
                            "type": "number",
                        },
                        "tax_treatment_code": {
                            "description": "Specify "
                            "reason "
                            "for "
                            "using "
                            "out "
                            "of "
                            "scope.</br>Supported "
                            "values "
                            "for "
                            "UAE "
                            "are "
                            "<code>uae_same_tax_group</code>, "
                            "<code>uae_reimbursed_expense</code> "
                            "and "
                            "<code>uae_others</code>.</br> "
                            "Supported "
                            "values "
                            "for "
                            "Bahrain "
                            "are "
                            "<code>bahrain_same_tax_group</code>, "
                            "<code>bahrain_transfer_of_concern</code>, "
                            "<code>bahrain_disbursement</code>, "
                            "<code>bahrain_head_to_branch_transaction</code>, "
                            "<code>bahrain_warranty_repair_services</code> "
                            "and "
                            "<code>bahrain_others</code>.</br>Supported "
                            "values "
                            "for "
                            "Saudi "
                            "Arabia "
                            "are "
                            "<code>ksa_pvt_health</code>, "
                            "<code>ksa_pvt_edu</code>, "
                            "<code>ksa_reimbursed_expense</code> "
                            "and "
                            "<code>ksa_house_sales</code>.",
                            "example": "uae_others",
                            "type": "string",
                            "x-node_available_in": ["gcc"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_type": {
                            "description": "The type of the tax",
                            "example": "tax",
                            "type": "string",
                        },
                        "tds_tax_id": {
                            "description": "ID of the TDS tax.",
                            "example": "982000000557012",
                            "type": "string",
                            "x-node_available_in": ["mx"],
                            "x-node_unavailable_in": [],
                        },
                        "time_entry_ids": {
                            "description": "Array "
                            "of "
                            "time "
                            "entry "
                            "IDs "
                            "to "
                            "be "
                            "billed "
                            "on "
                            "this "
                            "line "
                            "item. "
                            "This "
                            "allows "
                            "you "
                            "to "
                            "bill "
                            "specific "
                            "time "
                            "entries "
                            "against "
                            "this "
                            "line "
                            "item, "
                            "enabling "
                            "detailed "
                            "time-based "
                            "invoicing "
                            "and "
                            "project "
                            "cost "
                            "tracking.",
                            "example": [],
                            "items": {"type": "string"},
                            "type": "array",
                        },
                        "unit": {
                            "description": "Unit "
                            "of "
                            "measurement "
                            "for "
                            "the "
                            "line "
                            "item "
                            "quantity. "
                            "Examples "
                            "include "
                            '"Nos" '
                            "(Numbers), "
                            '"kgs" '
                            "(Kilograms), "
                            '"hrs" '
                            "(Hours), "
                            '"pcs" '
                            "(Pieces), "
                            "etc. "
                            "This "
                            "helps "
                            "clarify "
                            "what "
                            "the "
                            "quantity "
                            "represents. "
                            "Maximum "
                            "length "
                            "is "
                            "100 "
                            "characters.",
                            "example": " ",
                            "type": "string",
                        },
                        "unitkey_code": {
                            "description": "Add "
                            "SAT "
                            "Unit "
                            "Key "
                            "Code "
                            "for "
                            "your "
                            "goods/services. "
                            "Download "
                            "the "
                            "<a "
                            "href= "
                            "http://omawww.sat.gob.mx/tramitesyservicios/Paginas/documentos/catCFDI_V_4_07122022.xls  "
                            ">CFDI "
                            "Catalogs.</a>",
                            "example": "E48",
                            "type": "string",
                            "x-node_available_in": ["mx"],
                            "x-node_unavailable_in": [],
                        },
                    },
                    "required": ["item_id"],
                    "type": "object",
                },
                "type": "array",
            },
            "location_id": {
                "description": "Unique identifier of the business "
                "location associated with the invoice. "
                "Use the `location_id` returned by the "
                "Locations API for the same "
                "organization. This links the invoice "
                "to a specific business location, which "
                "may affect tax calculations, "
                "reporting, and business operations. "
                "Required if your organization has "
                "multiple locations configured.",
                "example": "460000000038080",
                "type": "string",
            },
            "notes": {
                "description": "Additional information or comments to be "
                "displayed on the invoice document. This "
                "field is typically used for thank you "
                "messages, special instructions, or any other "
                "information you want to communicate to the "
                "customer. The notes appear on the invoice "
                "PDF and are visible to customers",
                "example": "Looking forward for your business.",
                "type": "string",
            },
            "payment_options": {
                "description": "Payment options for the invoice, "
                "online payment gateways and bank "
                "accounts. Will be displayed in the "
                "pdf.",
                "properties": {
                    "payment_gateways": {
                        "description": "Online payment gateways through which payment can be made.",
                        "items": {
                            "properties": {
                                "additional_field1": {
                                    "description": "Paypal "
                                    "payment "
                                    "method. "
                                    "Allowed "
                                    "Values: "
                                    "<code>standard</code> "
                                    "and "
                                    "<code>adaptive</code>",
                                    "example": "standard",
                                    "type": "string",
                                },
                                "configured": {
                                    "description": "Boolean "
                                    "check "
                                    "to "
                                    "see "
                                    "if "
                                    "a "
                                    "payment "
                                    "gateway "
                                    "has "
                                    "been "
                                    "configured",
                                    "example": True,
                                    "type": "boolean",
                                },
                                "gateway_name": {
                                    "description": "Name "
                                    "of "
                                    "the "
                                    "payment "
                                    "gateway "
                                    "associated "
                                    "with "
                                    "the "
                                    "invoice. "
                                    "E.g. "
                                    "paypal, "
                                    "stripe.Allowed "
                                    "Values: "
                                    "<code>paypal</code>, "
                                    "<code>authorize_net</code>, "
                                    "<code>payflow_pro</code>, "
                                    "<code>stripe</code>, "
                                    "<code>2checkout</code> "
                                    "and "
                                    "<code>braintree</code>",
                                    "example": "paypal",
                                    "type": "string",
                                },
                            },
                            "type": "object",
                        },
                        "type": "array",
                    }
                },
                "type": "object",
            },
            "payment_terms": {
                "description": "Number of days allowed for payment "
                "(e.g., 15, 30, 60). This value "
                "determines the invoice due date by "
                "adding the specified number of days "
                "to the invoice date. For example, if "
                "invoice date is 2023-11-17 and "
                "payment_terms is 15, the due_date "
                "will be 2023-12-02. Maximum value is "
                "100 days.",
                "example": 15,
                "type": "integer",
            },
            "payment_terms_label": {
                "description": "Custom label for payment terms "
                "that appears on the invoice "
                "document. Used to override the "
                "default system-generated "
                "label. For example, instead of "
                'the default "Net 15 Days", you '
                'can set this to "Net 15", "Due '
                'in 15 days", or any custom '
                "text. This label is displayed "
                "to customers on the invoice. "
                "Maximum length is 100 "
                "characters.",
                "example": "Net 15",
                "type": "string",
            },
            "place_of_supply": {
                "description": "Place where the goods/services are "
                "supplied to. (If not given, "
                "<code>place of contact</code> "
                "given for the contact will be "
                "taken)<br/>Supported codes for UAE "
                "emirates are : </br>Abu Dhabi - "
                "<code>AB</code>,</br>Ajman - "
                "<code>AJ</code>,</br>Dubai - "
                "<code>DU</code>,</br>Fujairah - "
                "<code>FU</code>,</br>Ras "
                "al-Khaimah - "
                "<code>RA</code>,</br>Sharjah - "
                "<code>SH</code>,</br>Umm al-Quwain "
                "- <code>UM</code><br/>Supported "
                "codes for the GCC countries are : "
                "</br>United Arab Emirates - "
                "<code>AE</code>,</br>Saudi Arabia "
                "- <code>SA</code>,</br>Bahrain - "
                "<code>BH</code>,</br>Kuwait - "
                "<code>KW</code>,</br>Oman - "
                "<code>OM</code>,</br>Qatar - "
                "<code>QA</code>.",
                "example": "TN",
                "type": "string",
                "x-node_available_in": ["in", "gcc"],
                "x-node_unavailable_in": [],
            },
            "reason": {"example": " ", "type": "string"},
            "recurring_invoice_id": {
                "description": "Unique identifier of the "
                "recurring invoice template "
                "that generated this invoice. "
                "Use this field when creating "
                "an invoice from a recurring "
                "invoice template. The "
                "`recurring_invoice_id` links "
                "this invoice back to its "
                "source recurring invoice, "
                "enabling tracking of which "
                "template generated it and "
                "maintaining the recurring "
                "invoice relationship.",
                "example": " ",
                "type": "string",
            },
            "reference_invoice_id": {
                "description": "Associate the reference invoice.",
                "example": "132738000000126013",
                "type": "string",
                "x-node_available_in": ["mx"],
                "x-node_unavailable_in": [],
            },
            "reference_number": {
                "description": "External reference number or "
                "identifier for the invoice, such "
                "as a purchase order number, "
                "contract number, or any other "
                "business reference. When "
                "converting from an estimate or "
                "sales order, this field can be "
                "used to reference the original "
                "document number.",
                "example": " ",
                "type": "string",
            },
            "salesorder_item_id": {
                "description": "Unique identifier of the sales "
                "order line item that is being "
                "converted to this invoice line "
                "item. Use this field when "
                "creating an invoice from an "
                "existing sales order. The "
                "`salesorder_item_id` links this "
                "invoice line item back to its "
                "source sales order line item, "
                "enabling tracking of the "
                "conversion process and "
                "maintaining the relationship "
                "between sales orders and "
                "invoices.",
                "example": " ",
                "type": "string",
            },
            "salesperson_name": {
                "description": "Name of the salesperson. Max-length [200]",
                "example": " ",
                "type": "string",
            },
            "shipping_charge": {
                "description": "Additional shipping or delivery "
                "charges applied to the invoice. "
                "Must be specified as a fixed "
                'amount (e.g., "25.00"). This '
                "amount is added to the invoice "
                "total and is subject to tax "
                "calculation.",
                "example": 0,
                "type": "string",
            },
            "tax_authority_id": {
                "description": "ID of the tax authority. Tax "
                "authority depends on the location "
                "of the customer. For example, if "
                "the customer is located in NY, "
                "then the tax authority is NY tax "
                "authority.",
                "example": 11149000000061052,
                "type": "string",
                "x-node_available_in": ["us"],
                "x-node_unavailable_in": [],
            },
            "tax_exemption_id": {
                "description": "ID of the tax exemption.",
                "example": 11149000000061054,
                "type": "string",
                "x-node_available_in": ["in", "us"],
                "x-node_unavailable_in": [],
            },
            "tax_id": {
                "description": "Unique identifier of the tax to be applied "
                "to this line item. Use the `tax_id` "
                "returned by the Taxes API for the same "
                "organization. This determines which tax "
                "rate and rules are applied to the line "
                "item, affecting the final tax calculation "
                "and compliance reporting.",
                "example": 982000000557028,
                "type": "string",
            },
            "tax_treatment": {
                "description": "VAT treatment for the invoice "
                ".Choose whether the contact falls "
                "under: "
                "<code>vat_registered</code>,<code>vat_not_registered</code>,<code>gcc_vat_not_registered</code>,<code>gcc_vat_registered</code>,<code>non_gcc</code>.</br><code>dz_vat_registered</code> "
                "and "
                "<code>dz_vat_not_registered</code> "
                "supported only for "
                "<b>UAE</b>.</b></br><code>home_country_mexico</code>,<code>border_region_mexico</code>,<code>non_mexico</code> "
                "supported only for "
                "<b>MX</b>.<br/><b>For Kenya "
                "Edition:</b> "
                "<code>vat_registered</code> "
                ",<code>vat_not_registered</code> "
                ",<code>non_kenya</code>(A business "
                "that is located outside "
                "Kenya).<br/><b>For SouthAfrica "
                "Edition:</b> "
                "<code>vat_registered</code>, "
                "<code>vat_not_registered</code>, "
                "<code>overseas</code>(A business "
                "that is located outside "
                "SouthAfrica).",
                "example": "vat_registered",
                "type": "string",
                "x-node_available_in": ["gcc", "mx", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "template_id": {
                "description": "Unique identifier of the PDF template "
                "linked to the invoice. Obtain this "
                "value from the `template_id` field in "
                "the response of the GET "
                "`/invoices/templates` API for your "
                "organization. Determines which "
                "template is used for the invoice PDF.",
                "example": 982000000000143,
                "type": "string",
            },
            "terms": {
                "description": "Terms and conditions text to be displayed on "
                "the invoice document. This field is used to "
                "specify payment terms, delivery conditions, "
                "return policies, or any other legal or "
                "business terms that apply to this "
                "transaction. The terms appear on the invoice "
                "PDF and are legally binding.",
                "example": "Terms & Conditions apply",
                "type": "string",
            },
            "vat_treatment": {
                "description": "(Optional) VAT treatment for the "
                "invoices. VAT treatment denotes the "
                "location of the customer, if the "
                "customer resides in UK then the VAT "
                "treatment is <code>uk</code>. If the "
                "customer is in an EU country & VAT "
                "registered, you are resides in "
                "Northen Ireland and selling Goods "
                "then his VAT treatment is "
                "<code>eu_vat_registered</code>, if "
                "he resides outside of the UK then "
                "his VAT treatment is "
                "<code>overseas</code> (For Pre "
                "Brexit, this can be split as "
                "<code>eu_vat_registered</code>, "
                "<code>eu_vat_not_registered</code> "
                "and <code>non_eu</code>).",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
        },
        "required": ["customer_id", "line_items"],
        "type": "object",
    },
    "SENDINVOICESEMAIL_REQUEST_BODY_SCHEMA": {
        "properties": {
            "contacts": {
                "description": "Contacts for whom email or snail mail has to be sent.",
                "items": {
                    "properties": {
                        "contact_id": {
                            "description": "ID "
                            "of "
                            "the "
                            "Customer "
                            "and "
                            "mail "
                            "will "
                            "be "
                            "sent "
                            "to "
                            "invoice "
                            "associated "
                            "contact "
                            "persons",
                            "example": 460000000026049,
                            "type": "string",
                        },
                        "email": {
                            "description": "the boolean check for Email",
                            "example": True,
                            "type": "boolean",
                        },
                        "snail_mail": {
                            "description": "the boolean check for snail mail",
                            "example": False,
                            "type": "boolean",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            }
        },
        "required": ["contact_id", "email", "snail_mail"],
        "type": "object",
    },
    "ASSOCIATEINVOICEWITHSALESORDER_REQUEST_BODY_SCHEMA": {
        "properties": {
            "invoice_ids": {
                "description": "Array of invoice IDs to be associated with a sales order.",
                "example": ["982000000567114", "982000000567115", "982000000567116"],
                "items": {"type": "string"},
                "type": "array",
            }
        },
        "required": ["invoice_ids"],
        "type": "object",
    },
    "SENDINVOICEEMAIL_REQUEST_BODY_SCHEMA": {
        "properties": {
            "body": {
                "description": "The body of the mail",
                "example": "Dear Customer,         <br><br><br><br>Thanks for "
                "your business.         <br><br><br><br>The "
                "invoice INV-00001 is attached with this email. "
                "You can choose the easy way out and <a href= "
                "https://invoice.zoho.com/SecurePayment?CInvoiceID=b9800228e011ae86abe71227bdacb3c68e1af685f647dcaed747812e0b9314635e55ac6223925675b371fcbd2d5ae3dc  "
                ">pay online for this invoice.</a>         "
                "<br><br>Here's an overview of the invoice for "
                "your reference.         <br><br><br><br>Invoice "
                "Overview:         <br><br>Invoice  : "
                "INV-00001         <br><br>Date : 05 Aug "
                "2013         <br><br>Amount : $541.82         "
                "<br><br><br><br>It was great working with you. "
                "Looking forward to working with you "
                "again.<br><br><br>\\nRegards<br>\\nZillium "
                'Inc<br>\\n",',
                "type": "string",
            },
            "cc_mail_ids": {
                "description": "Array of email address of the recipients to be cced.",
                "example": ["peterparker@bowmanfurniture.com"],
                "items": {"type": "string"},
                "type": "array",
            },
            "from_address_id": {
                "description": "From email address id",
                "example": 2000000011993,
                "type": "string",
            },
            "send_from_org_email_id": {
                "description": "Boolean to trigger the email from the organization's email address",
                "example": False,
                "type": "boolean",
            },
            "subject": {
                "description": "The subject of the mail",
                "example": "Invoice from Zillium Inc (Invoice#: INV-00001)",
                "type": "string",
            },
            "to_mail_ids": {
                "description": "Array of email address of the recipients.",
                "example": ["willsmith@bowmanfurniture.com"],
                "items": {"type": "string"},
                "type": "array",
            },
        },
        "required": ["to_mail_ids"],
        "type": "object",
    },
    "REMINDCUSTOMERINVOICEPAYMENT_REQUEST_BODY_SCHEMA": {
        "properties": {
            "body": {
                "description": "The body of the mail",
                "example": "<br>Dear Mr. Sujin,&nbsp;<br><br>You might have "
                "missed the payment date and the invoice is now "
                "overdue "
                "by&nbsp;1&nbsp;days.<br><br>----------------------------------------------------------------------------------------<br><h2>Invoice# "
                ": INV-000004 </h2>Dated : 23 Dec "
                "2016<br>----------------------------------------------------------------------------------------<br><b>&nbsp;Due "
                "Date &nbsp; &nbsp; &nbsp; &nbsp; : &nbsp;&nbsp;23 "
                "Dec 2016</b><br><b>&nbsp;Amount &nbsp; &nbsp; "
                "&nbsp; &nbsp; &nbsp; : "
                "&nbsp;&nbsp;$139.65</b><br>----------------------------------------------------------------------------------------<br><br><span>Not "
                "to worry at all !&nbsp;</span>View your invoice "
                "and take the easy way out by making an&nbsp;<a "
                'href="https://books.zoho.com/portal/zilliuminc/index#/invoices/invoice/2000000007037 '
                '">online payment</a>.<br><br>If you have already '
                "paid, please accept our apologies and kindly "
                "ignore this payment "
                "reminder.<br><br><br>Regards,<br><br>David "
                "Sujin<br>Zillium Inc<br><br><br>",
                "type": "string",
            },
            "cc_mail_ids": {
                "description": "Array of email address of the recipients to be cced.",
                "example": ["peterparker@bowmanfurniture.com"],
                "items": {"type": "string"},
                "type": "array",
            },
            "send_from_org_email_id": {
                "description": "Boolean to trigger the email from the organization's email address",
                "example": False,
                "type": "boolean",
            },
            "subject": {
                "description": "The subject of the mail",
                "example": "Invoice from Zillium Inc (Invoice#: INV-00001)",
                "type": "string",
            },
            "to_mail_ids": {
                "description": "Array of email address of the recipients.",
                "example": ["willsmith@bowmanfurniture.com"],
                "items": {"type": "string"},
                "type": "array",
            },
        },
        "required": ["cc_mail_ids"],
        "type": "object",
    },
    "MODIFYINVOICEADDRESS_REQUEST_BODY_SCHEMA": {
        "properties": {
            "address": {
                "description": "Billing address for the invoice",
                "example": "B-1104, 11F, \n"
                "Horizon International Tower, \n"
                "No. 6, ZhiChun Road, HaiDian District",
                "type": "string",
            },
            "city": {
                "description": "City of the customer's billing address.",
                "example": "Beijing",
                "type": "string",
            },
            "country": {
                "description": "Country of the customer's billing address.",
                "type": "string",
            },
            "fax": {
                "description": "Customer's fax number.",
                "example": "+86-10-82637827",
                "type": "string",
            },
            "state": {
                "description": "State of the customer's billing address.",
                "example": "Beijing",
                "type": "string",
            },
            "zip": {
                "description": "Zip code of the customer's billing address.",
                "example": 1000881,
                "type": "string",
            },
        },
        "type": "object",
    },
    "UPDATEINVOICESHIPPINGADDRESS_REQUEST_BODY_SCHEMA": {
        "properties": {
            "address": {
                "description": "Shipping address for the invoice",
                "example": "4900 Hopyard Rd, Suit 310",
                "type": "string",
            },
            "city": {
                "description": "City of the customer's Shipping address.",
                "example": "Pleasanton",
                "type": "string",
            },
            "country": {
                "description": "Country of the customer's Shipping address.",
                "example": "USA",
                "type": "string",
            },
            "fax": {
                "description": "Customer's fax number.",
                "example": "+1-925-924-9600",
                "type": "string",
            },
            "state": {
                "description": "State of the customer's Shipping address.",
                "example": "CA",
                "type": "string",
            },
            "street2": {"example": "McMillan Avenue", "type": "string"},
            "zip": {
                "description": "Zip code of the customer's Shipping address.",
                "example": 945881,
                "type": "string",
            },
        },
        "type": "object",
    },
    "APPLYCREDITSTOINVOICE_REQUEST_BODY_SCHEMA": {
        "properties": {
            "apply_creditnotes": {
                "items": {
                    "properties": {
                        "amount_applied": {
                            "description": "The applied amount to the creditnote",
                            "example": 12.2,
                            "format": "float",
                            "type": "number",
                        },
                        "creditnote_id": {
                            "description": "ID of the creditnote",
                            "example": 982000000567134,
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "invoice_payments": {
                "items": {
                    "properties": {
                        "amount_applied": {
                            "description": "The applied amount to the creditnote",
                            "example": 12.2,
                            "format": "float",
                            "type": "number",
                        },
                        "payment_id": {
                            "description": "ID of the payment",
                            "example": 982000000567190,
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
        },
        "required": ["invoice_payments", "apply_creditnotes"],
        "type": "object",
    },
    "UPDATEINVOICECUSTOMFIELDS_REQUEST_BODY_SCHEMA": {
        "description": "Custom fields for an invoice.",
        "items": {
            "properties": {
                "customfield_id": {
                    "example": "46000000012845",
                    "format": "int64",
                    "type": "integer",
                },
                "value": {
                    "description": "Value of the Custom Field",
                    "example": "Normal",
                    "type": "string",
                },
            },
            "type": "object",
        },
        "type": "array",
    },
    "ADDINVOICECOMMENT_REQUEST_BODY_SCHEMA": {
        "properties": {
            "description": {
                "description": "The description of the comment.",
                "example": "This is a comment.",
                "type": "string",
            },
            "payment_expected_date": {
                "description": "The expected date of payment",
                "example": " ",
                "type": "string",
            },
            "show_comment_to_clients": {
                "description": "Boolean to check if the comment to be shown to the clients",
                "example": True,
                "type": "boolean",
            },
        },
        "type": "object",
    },
    "UPDATEINVOICECOMMENT_REQUEST_BODY_SCHEMA": {
        "properties": {
            "description": {
                "description": "The description of the comment.",
                "example": "This is a comment.",
                "type": "string",
            },
            "show_comment_to_clients": {
                "description": "Boolean to check if the comment to be shown to the clients",
                "example": True,
                "type": "boolean",
            },
        },
        "type": "object",
    },
    "CREATENEWZOHOITEM_REQUEST_BODY_SCHEMA": {
        "properties": {
            "account_id": {
                "description": "ID of the account to which the item has to be associated with.",
                "example": " ",
                "type": "string",
            },
            "avatax_tax_code": {
                "description": "A tax code is a unique label used "
                "to group Items (products, "
                "services, or charges) together. "
                "Max-length [25]",
                "example": 982000000037049,
                "type": "string",
                "x-node_available_in": ["Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "avatax_use_code": {
                "description": "Used to group like customers for "
                "exemption purposes. It is a custom "
                "value that links customers to a "
                "tax rule. Select from Avalara "
                "[standard codes][1] or enter a "
                "custom code. Max-length [25]",
                "example": 982000000037049,
                "type": "string",
                "x-node_available_in": ["Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "custom_fields": {
                "description": "Custom fields for an item.",
                "items": {
                    "properties": {
                        "customfield_id": {
                            "example": "46000000012845",
                            "format": "int64",
                            "type": "integer",
                        },
                        "value": {
                            "description": "Value of the Custom Field",
                            "example": "Normal",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "description": {
                "description": "Description for the item. Max-length [2000]",
                "example": "500GB",
                "type": "string",
            },
            "hsn_or_sac": {
                "description": "HSN Code",
                "type": "string",
                "x-node_available_in": ["in", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "inventory_account_id": {
                "description": "ID of the stock account to "
                "which the item has to be "
                "associated with. Mandatory, "
                "if item_type is inventory.",
                "example": " ",
                "type": "string",
            },
            "is_taxable": {
                "description": "Boolean to track the taxability of the item.",
                "type": "boolean",
                "x-node_available_in": ["in", "us", "mx", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "item_tax_preferences": {
                "items": {
                    "properties": {
                        "tax_id": {
                            "description": "ID of the tax to be associated to the item.",
                            "example": 982000000037049,
                            "type": "string",
                            "x-node_available_in": ["in"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_specification": {
                            "description": "Set whether the tax type is intra/interstate",
                            "example": "intra",
                            "type": "string",
                            "x-node_available_in": ["in"],
                            "x-node_unavailable_in": [],
                        },
                    },
                    "type": "object",
                },
                "type": "array",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "item_type": {
                "description": "Type of the item. Allowed values: "
                "<code>sales</code>,<code>purchases</code>,<code>sales_and_purchases</code> "
                "and <code>inventory</code>. Default "
                "value will be <code>sales</code>.",
                "example": " ",
                "type": "string",
            },
            "locations": {
                "items": {
                    "properties": {
                        "initial_stock": {
                            "description": "Opening stock of the item.",
                            "example": " ",
                            "type": "string",
                        },
                        "initial_stock_rate": {
                            "description": "Unit price of the opening stock.",
                            "example": " ",
                            "type": "string",
                        },
                        "location_id": {
                            "description": "Location ID",
                            "example": "460000000038080",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "name": {
                "description": "Name of the item. Max-length [100]",
                "example": "Hard Drive",
                "type": "string",
            },
            "product_type": {
                "description": "Specify the type of an item. Allowed "
                "values:<br/><code> goods</code> or "
                "<code> service</code> or <code> "
                "digital_service</code>. <br/><b>For "
                "SouthAfrica Edition:</b> "
                "<code>service</code>, "
                "<code>goods</code>, "
                "<code>capital_service</code> and "
                "<code>capital_goods</code>",
                "example": "goods",
                "type": "string",
            },
            "purchase_account_id": {
                "description": "ID of the COGS account to "
                "which the item has to be "
                "associated with. Mandatory, if "
                "item_type is purchase / sales "
                "and purchase / inventory.",
                "example": " ",
                "type": "string",
            },
            "purchase_description": {
                "description": "Purchase description for the item.",
                "example": " ",
                "type": "string",
            },
            "purchase_rate": {
                "description": "Purchase price of the item.",
                "example": " ",
                "type": "string",
            },
            "purchase_tax_exemption_id": {
                "description": "ID of the purchase tax "
                "exemption. Mandatory, if "
                "<code>is_taxable</code> "
                "is false.",
                "type": "string",
                "x-node_available_in": ["ke", "za"],
                "x-node_unavailable_in": [],
            },
            "purchase_tax_rule_id": {
                "description": "Id of the purchase tax rule",
                "example": 127919000000106780,
                "type": "string",
                "x-node_available_in": ["mx", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "rate": {
                "description": "Price of the item.",
                "example": 120,
                "format": "double",
                "type": "number",
            },
            "reorder_level": {
                "description": "Reorder level of the item.",
                "example": " ",
                "type": "string",
            },
            "sales_tax_rule_id": {
                "description": "Id of the sales tax rule",
                "example": 127919000000106780,
                "type": "string",
                "x-node_available_in": ["mx", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "sat_item_key_code": {
                "description": "Add SAT Item Key Code for your "
                "goods/services. Download the <a "
                "href= "
                "http://omawww.sat.gob.mx/tramitesyservicios/Paginas/documentos/catCFDI_V_4_07122022.xls  "
                ">CFDI Catalogs.</a>",
                "type": "string",
                "x-node_available_in": ["mx"],
                "x-node_unavailable_in": [],
            },
            "sku": {
                "description": "SKU value of item,should be unique throughout the product",
                "example": "s12345",
                "type": "string",
            },
            "tax_exemption_id": {
                "description": "ID of the tax exemption. "
                "Mandatory, if "
                "<code>is_taxable</code> is false.",
                "type": "string",
                "x-node_available_in": ["in", "us", "mx", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "tax_id": {
                "description": "ID of the tax to be associated to the item.",
                "example": 982000000037049,
                "type": "string",
                "x-node_available_in": [],
                "x-node_unavailable_in": ["us", "in"],
            },
            "tax_percentage": {
                "description": "Percent of the tax.",
                "example": "70%",
                "type": "string",
            },
            "unitkey_code": {
                "description": "Add Unit Key Code for your "
                "goods/services. Download the <a href= "
                "http://omawww.sat.gob.mx/tramitesyservicios/Paginas/documentos/catCFDI_V_4_07122022.xls  "
                ">CFDI Catalogs.</a>",
                "type": "string",
                "x-node_available_in": ["mx"],
                "x-node_unavailable_in": [],
            },
            "vendor_id": {"description": "Preferred vendor ID.", "example": " ", "type": "string"},
        },
        "required": ["name", "rate"],
        "type": "object",
    },
    "UPDATEITEMVIACUSTOMFIELD_REQUEST_BODY_SCHEMA": {
        "properties": {
            "account_id": {
                "description": "ID of the account to which the item has to be associated with.",
                "example": " ",
                "type": "string",
            },
            "avatax_tax_code": {
                "description": "A tax code is a unique label used "
                "to group Items (products, "
                "services, or charges) together. "
                "Max-length [25]",
                "example": 982000000037049,
                "type": "string",
                "x-node_available_in": ["Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "avatax_use_code": {
                "description": "Used to group like customers for "
                "exemption purposes. It is a custom "
                "value that links customers to a "
                "tax rule. Select from Avalara "
                "[standard codes][1] or enter a "
                "custom code. Max-length [25]",
                "example": 982000000037049,
                "type": "string",
                "x-node_available_in": ["Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "custom_fields": {
                "description": "Custom fields for an item.",
                "items": {
                    "properties": {
                        "customfield_id": {
                            "example": "46000000012845",
                            "format": "int64",
                            "type": "integer",
                        },
                        "value": {
                            "description": "Value of the Custom Field",
                            "example": "Normal",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "description": {
                "description": "Description for the item. Max-length [2000]",
                "example": "500GB",
                "type": "string",
            },
            "hsn_or_sac": {
                "description": "HSN Code",
                "type": "string",
                "x-node_available_in": ["in", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "inventory_account_id": {
                "description": "ID of the stock account to "
                "which the item has to be "
                "associated with. Mandatory, "
                "if item_type is inventory.",
                "example": " ",
                "type": "string",
            },
            "is_taxable": {
                "description": "Boolean to track the taxability of the item.",
                "type": "boolean",
                "x-node_available_in": ["in", "us", "mx", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "item_tax_preferences": {
                "items": {
                    "properties": {
                        "tax_id": {
                            "description": "ID of the tax to be associated to the item.",
                            "example": 982000000037049,
                            "type": "string",
                            "x-node_available_in": ["in"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_specification": {
                            "description": "Set whether the tax type is intra/interstate",
                            "example": "intra",
                            "type": "string",
                            "x-node_available_in": ["in"],
                            "x-node_unavailable_in": [],
                        },
                    },
                    "type": "object",
                },
                "type": "array",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "item_type": {
                "description": "Type of the item. Allowed values: "
                "<code>sales</code>,<code>purchases</code>,<code>sales_and_purchases</code> "
                "and <code>inventory</code>. Default "
                "value will be <code>sales</code>.",
                "example": " ",
                "type": "string",
            },
            "locations": {
                "items": {
                    "properties": {
                        "initial_stock": {
                            "description": "Opening stock of the item.",
                            "example": " ",
                            "type": "string",
                        },
                        "initial_stock_rate": {
                            "description": "Unit price of the opening stock.",
                            "example": " ",
                            "type": "string",
                        },
                        "location_id": {
                            "description": "Location ID",
                            "example": "460000000038080",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "name": {
                "description": "Name of the item. Max-length [100]",
                "example": "Hard Drive",
                "type": "string",
            },
            "product_type": {
                "description": "Specify the type of an item. Allowed "
                "values:<br/><code> goods</code> or "
                "<code> service</code> or <code> "
                "digital_service</code>. <br/><b>For "
                "SouthAfrica Edition:</b> "
                "<code>service</code>, "
                "<code>goods</code>, "
                "<code>capital_service</code> and "
                "<code>capital_goods</code>",
                "example": "goods",
                "type": "string",
            },
            "purchase_account_id": {
                "description": "ID of the COGS account to "
                "which the item has to be "
                "associated with. Mandatory, if "
                "item_type is purchase / sales "
                "and purchase / inventory.",
                "example": " ",
                "type": "string",
            },
            "purchase_description": {
                "description": "Purchase description for the item.",
                "example": " ",
                "type": "string",
            },
            "purchase_rate": {
                "description": "Purchase price of the item.",
                "example": " ",
                "type": "string",
            },
            "purchase_tax_exemption_id": {
                "description": "ID of the purchase tax "
                "exemption. Mandatory, if "
                "<code>is_taxable</code> "
                "is false.",
                "type": "string",
                "x-node_available_in": ["ke", "za"],
                "x-node_unavailable_in": [],
            },
            "purchase_tax_rule_id": {
                "description": "Id of the purchase tax rule",
                "example": 127919000000106780,
                "type": "string",
                "x-node_available_in": ["mx", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "rate": {
                "description": "Price of the item.",
                "example": 120,
                "format": "double",
                "type": "number",
            },
            "reorder_level": {
                "description": "Reorder level of the item.",
                "example": " ",
                "type": "string",
            },
            "sales_tax_rule_id": {
                "description": "Id of the sales tax rule",
                "example": 127919000000106780,
                "type": "string",
                "x-node_available_in": ["mx", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "sat_item_key_code": {
                "description": "Add SAT Item Key Code for your "
                "goods/services. Download the <a "
                "href= "
                "http://omawww.sat.gob.mx/tramitesyservicios/Paginas/documentos/catCFDI_V_4_07122022.xls  "
                ">CFDI Catalogs.</a>",
                "type": "string",
                "x-node_available_in": ["mx"],
                "x-node_unavailable_in": [],
            },
            "sku": {
                "description": "SKU value of item,should be unique throughout the product",
                "example": "s12345",
                "type": "string",
            },
            "tax_exemption_id": {
                "description": "ID of the tax exemption. "
                "Mandatory, if "
                "<code>is_taxable</code> is false.",
                "type": "string",
                "x-node_available_in": ["in", "us", "mx", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "tax_id": {
                "description": "ID of the tax to be associated to the item.",
                "example": 982000000037049,
                "type": "string",
                "x-node_available_in": [],
                "x-node_unavailable_in": ["us", "in"],
            },
            "tax_percentage": {
                "description": "Percent of the tax.",
                "example": "70%",
                "type": "string",
            },
            "unitkey_code": {
                "description": "Add Unit Key Code for your "
                "goods/services. Download the <a href= "
                "http://omawww.sat.gob.mx/tramitesyservicios/Paginas/documentos/catCFDI_V_4_07122022.xls  "
                ">CFDI Catalogs.</a>",
                "type": "string",
                "x-node_available_in": ["mx"],
                "x-node_unavailable_in": [],
            },
            "vendor_id": {"description": "Preferred vendor ID.", "example": " ", "type": "string"},
        },
        "required": ["name", "rate"],
        "type": "object",
    },
    "UPDATEZOHOITEMDETAILS_REQUEST_BODY_SCHEMA": {
        "properties": {
            "account_id": {
                "description": "ID of the account to which the item has to be associated with.",
                "example": " ",
                "type": "string",
            },
            "avatax_tax_code": {
                "description": "A tax code is a unique label used "
                "to group Items (products, "
                "services, or charges) together. "
                "Max-length [25]",
                "example": 982000000037049,
                "type": "string",
                "x-node_available_in": ["Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "avatax_use_code": {
                "description": "Used to group like customers for "
                "exemption purposes. It is a custom "
                "value that links customers to a "
                "tax rule. Select from Avalara "
                "[standard codes][1] or enter a "
                "custom code. Max-length [25]",
                "example": 982000000037049,
                "type": "string",
                "x-node_available_in": ["Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "custom_fields": {
                "description": "Custom fields for an item.",
                "items": {
                    "properties": {
                        "customfield_id": {
                            "example": "46000000012845",
                            "format": "int64",
                            "type": "integer",
                        },
                        "value": {
                            "description": "Value of the Custom Field",
                            "example": "Normal",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "description": {
                "description": "Description for the item. Max-length [2000]",
                "example": "500GB",
                "type": "string",
            },
            "hsn_or_sac": {
                "description": "HSN Code",
                "type": "string",
                "x-node_available_in": ["in", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "inventory_account_id": {
                "description": "ID of the stock account to "
                "which the item has to be "
                "associated with. Mandatory, "
                "if item_type is inventory.",
                "example": " ",
                "type": "string",
            },
            "is_taxable": {
                "description": "Boolean to track the taxability of the item.",
                "type": "boolean",
                "x-node_available_in": ["in", "us", "mx", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "item_tax_preferences": {
                "items": {
                    "properties": {
                        "tax_id": {
                            "description": "ID of the tax to be associated to the item.",
                            "example": 982000000037049,
                            "type": "string",
                            "x-node_available_in": ["in"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_specification": {
                            "description": "Set whether the tax type is intra/interstate",
                            "example": "intra",
                            "type": "string",
                            "x-node_available_in": ["in"],
                            "x-node_unavailable_in": [],
                        },
                    },
                    "type": "object",
                },
                "type": "array",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "item_type": {
                "description": "Type of the item. Allowed values: "
                "<code>sales</code>,<code>purchases</code>,<code>sales_and_purchases</code> "
                "and <code>inventory</code>. Default "
                "value will be <code>sales</code>.",
                "example": " ",
                "type": "string",
            },
            "locations": {
                "items": {
                    "properties": {
                        "initial_stock": {
                            "description": "Opening stock of the item.",
                            "example": " ",
                            "type": "string",
                        },
                        "initial_stock_rate": {
                            "description": "Unit price of the opening stock.",
                            "example": " ",
                            "type": "string",
                        },
                        "location_id": {
                            "description": "Location ID",
                            "example": "460000000038080",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "name": {
                "description": "Name of the item. Max-length [100]",
                "example": "Hard Drive",
                "type": "string",
            },
            "product_type": {
                "description": "Specify the type of an item. Allowed "
                "values:<br/><code> goods</code> or "
                "<code> service</code> or <code> "
                "digital_service</code>. <br/><b>For "
                "SouthAfrica Edition:</b> "
                "<code>service</code>, "
                "<code>goods</code>, "
                "<code>capital_service</code> and "
                "<code>capital_goods</code>",
                "example": "goods",
                "type": "string",
            },
            "purchase_account_id": {
                "description": "ID of the COGS account to "
                "which the item has to be "
                "associated with. Mandatory, if "
                "item_type is purchase / sales "
                "and purchase / inventory.",
                "example": " ",
                "type": "string",
            },
            "purchase_description": {
                "description": "Purchase description for the item.",
                "example": " ",
                "type": "string",
            },
            "purchase_rate": {
                "description": "Purchase price of the item.",
                "example": " ",
                "type": "string",
            },
            "purchase_tax_exemption_id": {
                "description": "ID of the purchase tax "
                "exemption. Mandatory, if "
                "<code>is_taxable</code> "
                "is false.",
                "type": "string",
                "x-node_available_in": ["ke", "za"],
                "x-node_unavailable_in": [],
            },
            "purchase_tax_rule_id": {
                "description": "Id of the purchase tax rule",
                "example": 127919000000106780,
                "type": "string",
                "x-node_available_in": ["mx", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "rate": {
                "description": "Price of the item.",
                "example": 120,
                "format": "double",
                "type": "number",
            },
            "reorder_level": {
                "description": "Reorder level of the item.",
                "example": " ",
                "type": "string",
            },
            "sales_tax_rule_id": {
                "description": "Id of the sales tax rule",
                "example": 127919000000106780,
                "type": "string",
                "x-node_available_in": ["mx", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "sat_item_key_code": {
                "description": "Add SAT Item Key Code for your "
                "goods/services. Download the <a "
                "href= "
                "http://omawww.sat.gob.mx/tramitesyservicios/Paginas/documentos/catCFDI_V_4_07122022.xls  "
                ">CFDI Catalogs.</a>",
                "type": "string",
                "x-node_available_in": ["mx"],
                "x-node_unavailable_in": [],
            },
            "sku": {
                "description": "SKU value of item,should be unique throughout the product",
                "example": "s12345",
                "type": "string",
            },
            "tax_exemption_id": {
                "description": "ID of the tax exemption. "
                "Mandatory, if "
                "<code>is_taxable</code> is false.",
                "type": "string",
                "x-node_available_in": ["in", "us", "mx", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "tax_id": {
                "description": "ID of the tax to be associated to the item.",
                "example": 982000000037049,
                "type": "string",
                "x-node_available_in": [],
                "x-node_unavailable_in": ["us", "in"],
            },
            "tax_percentage": {
                "description": "Percent of the tax.",
                "example": "70%",
                "type": "string",
            },
            "unitkey_code": {
                "description": "Add Unit Key Code for your "
                "goods/services. Download the <a href= "
                "http://omawww.sat.gob.mx/tramitesyservicios/Paginas/documentos/catCFDI_V_4_07122022.xls  "
                ">CFDI Catalogs.</a>",
                "type": "string",
                "x-node_available_in": ["mx"],
                "x-node_unavailable_in": [],
            },
            "vendor_id": {"description": "Preferred vendor ID.", "example": " ", "type": "string"},
        },
        "required": ["name", "rate"],
        "type": "object",
    },
    "UPDATEITEMCUSTOMFIELDS_REQUEST_BODY_SCHEMA": {
        "description": "Custom fields for an item.",
        "items": {
            "properties": {
                "customfield_id": {
                    "example": "46000000012845",
                    "format": "int64",
                    "type": "integer",
                },
                "value": {
                    "description": "Value of the Custom Field",
                    "example": "Normal",
                    "type": "string",
                },
            },
            "type": "object",
        },
        "type": "array",
    },
    "CREATEJOURNALENTRY_REQUEST_BODY_SCHEMA": {
        "properties": {
            "currency_id": {
                "description": "ID of the Currency Associated with the Journal",
                "example": "460000000000097",
                "type": "string",
            },
            "custom_fields": {
                "items": {
                    "properties": {
                        "customfield_id": {
                            "description": "ID of the Custom Field",
                            "example": "460000000098001",
                            "type": "string",
                        },
                        "value": {
                            "description": "Value of the Custom Field",
                            "example": "Normal",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "exchange_rate": {
                "description": "Exchange Rate between the Currencies",
                "example": 1,
                "format": "double",
                "type": "number",
            },
            "include_in_vat_return": {
                "description": "Check if Journal should be included in VAT Return",
                "type": "boolean",
                "x-node_available_in": ["eu", "uk"],
                "x-node_unavailable_in": [],
            },
            "is_bas_adjustment": {
                "description": "Check if Journal is created for BAS Adjustment",
                "type": "boolean",
                "x-node_available_in": ["au"],
                "x-node_unavailable_in": [],
            },
            "journal_date": {
                "description": "Date on which the journal to be recorded.",
                "example": "2013-09-04",
                "type": "string",
            },
            "journal_type": {
                "description": "Type of the Journal. Allowed values: "
                "<code> Cash </code> and  <code> Both "
                "</code>.",
                "example": "both",
                "type": "string",
            },
            "line_items": {
                "items": {
                    "properties": {
                        "account_id": {
                            "description": "ID of account for which journals to be recorded.",
                            "example": "460000000000361",
                            "type": "string",
                        },
                        "acquisition_vat_id": {
                            "description": "(Optional) "
                            "This "
                            "is "
                            "the "
                            "ID "
                            "of "
                            "the "
                            "tax "
                            "applied "
                            "in "
                            "case "
                            "this "
                            "is "
                            "an "
                            "EU "
                            "- "
                            "goods "
                            "journal "
                            "and "
                            "acquisition "
                            "VAT "
                            "needs "
                            "to "
                            "be "
                            "reported.",
                            "type": "string",
                            "x-node_available_in": ["uk"],
                            "x-node_unavailable_in": [],
                        },
                        "amount": {
                            "description": "Amount to be recorded for the journal.",
                            "example": 5000,
                            "format": "double",
                            "type": "number",
                        },
                        "customer_id": {
                            "description": "ID of the Customer/Vendor",
                            "type": "string",
                        },
                        "debit_or_credit": {
                            "description": "Whether "
                            "the "
                            "accounts "
                            "needs "
                            "to "
                            "be "
                            "debited "
                            "or "
                            "credited. "
                            "Allowed "
                            "Values: "
                            "<code>debit</code> "
                            "and "
                            "<code>credit</code>.",
                            "example": "credit",
                            "type": "string",
                        },
                        "description": {
                            "description": "Description that can be given at the line item level.",
                            "type": "string",
                        },
                        "line_id": {
                            "description": "ID of the Line",
                            "example": "460000000038005",
                            "type": "string",
                        },
                        "location_id": {
                            "description": "Location ID",
                            "example": "460000000038080",
                            "type": "string",
                        },
                        "project_id": {
                            "description": "ID of the Project",
                            "example": "460000000898001",
                            "type": "string",
                        },
                        "reverse_charge_vat_id": {
                            "description": "(Optional) "
                            "This "
                            "is "
                            "the "
                            "ID "
                            "of "
                            "the "
                            "tax "
                            "applied "
                            "in "
                            "case "
                            "this "
                            "is "
                            "a "
                            "non "
                            "UK "
                            "- "
                            "service "
                            "journal "
                            "and "
                            "reverse "
                            "charge "
                            "VAT "
                            "needs "
                            "to "
                            "be "
                            "reported.",
                            "type": "string",
                            "x-node_available_in": ["uk"],
                            "x-node_unavailable_in": [],
                        },
                        "tags": {
                            "items": {
                                "properties": {
                                    "tag_id": {
                                        "description": "ID of the Tag",
                                        "example": "460000000094001",
                                        "format": "int64",
                                        "type": "integer",
                                    },
                                    "tag_option_id": {
                                        "description": "ID of the Tag Option",
                                        "example": "460000000048001",
                                        "format": "int64",
                                        "type": "integer",
                                    },
                                },
                                "type": "object",
                            },
                            "type": "array",
                        },
                        "tax_authority_id": {
                            "description": "ID of the Tax Authority",
                            "type": "string",
                            "x-node_available_in": ["us", "au", "ca", "mx"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_authority_name": {
                            "description": "Name of the Tax Authority",
                            "type": "string",
                            "x-node_available_in": ["us", "au", "ca"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_exemption_code": {
                            "description": "Code of the Tax Exemption",
                            "type": "string",
                            "x-node_available_in": ["in", "us", "au", "ca"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_exemption_id": {
                            "description": "ID of the Tax Exemption",
                            "type": "string",
                            "x-node_available_in": ["in", "us", "au", "ca", "mx"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_exemption_type": {
                            "description": "Type "
                            "of "
                            "the "
                            "Tax "
                            "Exemption. "
                            "Allowed "
                            "Values "
                            ": "
                            "<code>customer</code> "
                            "and "
                            "<code>item</code>",
                            "type": "string",
                            "x-node_available_in": ["in", "us", "au", "ca", "mx"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_id": {"description": "ID of the tax.", "type": "string"},
                    },
                    "required": ["amount", "debit_or_credit"],
                    "type": "object",
                },
                "type": "array",
            },
            "location_id": {
                "description": "Location ID",
                "example": "460000000038080",
                "type": "string",
            },
            "notes": {
                "description": "Notes for the journal.",
                "example": "Loan repayment",
                "type": "string",
            },
            "product_type": {
                "description": "Type of the journal. This denotes "
                "whether the journal is to be treated "
                "as goods or service. Allowed Values: "
                "<code> digital_service</code>, "
                "<code>goods</code> and "
                "<code>service</code>.",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
            "reference_number": {
                "description": "Reference number for the journal.",
                "example": "7355",
                "type": "string",
            },
            "status": {
                "description": "Search Journal by journal status. Allowed "
                "Values: <code>draft</code> and  "
                "<code>published</code>.",
                "example": "draft",
                "type": "string",
            },
            "tax_exemption_code": {
                "description": "Code of the Tax Exemption",
                "type": "string",
                "x-node_available_in": ["in", "us", "au", "ca"],
                "x-node_unavailable_in": [],
            },
            "tax_exemption_type": {
                "description": "Type of the Tax Exemption. "
                "Allowed Values : "
                "<code>customer</code> and "
                "<code>item</code>",
                "type": "string",
                "x-node_available_in": ["in", "us", "au", "ca", "mx"],
                "x-node_unavailable_in": [],
            },
            "vat_treatment": {
                "description": "(Optional) VAT treatment for the "
                "journals. VAT treatment denotes the "
                "location of the customer, if the "
                "customer resides in UK then the VAT "
                "treatment is <code>uk</code>. If the "
                "customer is in an EU country & VAT "
                "registered, you are resides in "
                "Northen Ireland and selling Goods "
                "then his VAT treatment is "
                "<code>eu_vat_registered</code>, if "
                "he resides outside of the UK then "
                "his VAT treatment is "
                "<code>overseas</code> (For Pre "
                "Brexit, this can be split as "
                "<code>eu_vat_registered</code>, "
                "<code>eu_vat_not_registered</code> "
                "and <code>non_eu</code>).",
                "type": "string",
                "x-node_available_in": ["uk", "eu"],
                "x-node_unavailable_in": [],
            },
        },
        "required": ["journal_date"],
        "type": "object",
    },
    "UPDATEJOURNALINZOHOBOOKS_REQUEST_BODY_SCHEMA": {
        "properties": {
            "currency_id": {
                "description": "ID of the Currency Associated with the Journal",
                "example": "460000000000097",
                "type": "string",
            },
            "custom_fields": {
                "items": {
                    "properties": {
                        "customfield_id": {
                            "description": "ID of the Custom Field",
                            "example": "460000000098001",
                            "type": "string",
                        },
                        "value": {
                            "description": "Value of the Custom Field",
                            "example": "Normal",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "exchange_rate": {
                "description": "Exchange Rate between the Currencies",
                "example": 1,
                "format": "double",
                "type": "number",
            },
            "include_in_vat_return": {
                "description": "Check if Journal should be included in VAT Return",
                "type": "boolean",
                "x-node_available_in": ["eu", "uk"],
                "x-node_unavailable_in": [],
            },
            "is_bas_adjustment": {
                "description": "Check if Journal is created for BAS Adjustment",
                "type": "boolean",
                "x-node_available_in": ["au"],
                "x-node_unavailable_in": [],
            },
            "journal_date": {
                "description": "Date on which the journal to be recorded.",
                "example": "2013-09-04",
                "type": "string",
            },
            "journal_type": {
                "description": "Type of the Journal. Allowed values: "
                "<code> Cash </code> and  <code> Both "
                "</code>.",
                "example": "both",
                "type": "string",
            },
            "line_items": {
                "items": {
                    "properties": {
                        "account_id": {
                            "description": "ID of account for which journals to be recorded.",
                            "example": "460000000000361",
                            "type": "string",
                        },
                        "acquisition_vat_id": {
                            "description": "(Optional) "
                            "This "
                            "is "
                            "the "
                            "ID "
                            "of "
                            "the "
                            "tax "
                            "applied "
                            "in "
                            "case "
                            "this "
                            "is "
                            "an "
                            "EU "
                            "- "
                            "goods "
                            "journal "
                            "and "
                            "acquisition "
                            "VAT "
                            "needs "
                            "to "
                            "be "
                            "reported.",
                            "type": "string",
                            "x-node_available_in": ["uk"],
                            "x-node_unavailable_in": [],
                        },
                        "amount": {
                            "description": "Amount to be recorded for the journal.",
                            "example": 5000,
                            "format": "double",
                            "type": "number",
                        },
                        "customer_id": {
                            "description": "ID of the Customer/Vendor",
                            "type": "string",
                        },
                        "debit_or_credit": {
                            "description": "Whether "
                            "the "
                            "accounts "
                            "needs "
                            "to "
                            "be "
                            "debited "
                            "or "
                            "credited. "
                            "Allowed "
                            "Values: "
                            "<code>debit</code> "
                            "and "
                            "<code>credit</code>.",
                            "example": "credit",
                            "type": "string",
                        },
                        "description": {
                            "description": "Description that can be given at the line item level.",
                            "type": "string",
                        },
                        "line_id": {
                            "description": "ID of the Line",
                            "example": "460000000038005",
                            "type": "string",
                        },
                        "location_id": {
                            "description": "Location ID",
                            "example": "460000000038080",
                            "type": "string",
                        },
                        "project_id": {
                            "description": "ID of the Project",
                            "example": "460000000898001",
                            "type": "string",
                        },
                        "reverse_charge_vat_id": {
                            "description": "(Optional) "
                            "This "
                            "is "
                            "the "
                            "ID "
                            "of "
                            "the "
                            "tax "
                            "applied "
                            "in "
                            "case "
                            "this "
                            "is "
                            "a "
                            "non "
                            "UK "
                            "- "
                            "service "
                            "journal "
                            "and "
                            "reverse "
                            "charge "
                            "VAT "
                            "needs "
                            "to "
                            "be "
                            "reported.",
                            "type": "string",
                            "x-node_available_in": ["uk"],
                            "x-node_unavailable_in": [],
                        },
                        "tags": {
                            "items": {
                                "properties": {
                                    "tag_id": {
                                        "description": "ID of the Tag",
                                        "example": "460000000094001",
                                        "format": "int64",
                                        "type": "integer",
                                    },
                                    "tag_option_id": {
                                        "description": "ID of the Tag Option",
                                        "example": "460000000048001",
                                        "format": "int64",
                                        "type": "integer",
                                    },
                                },
                                "type": "object",
                            },
                            "type": "array",
                        },
                        "tax_authority_id": {
                            "description": "ID of the Tax Authority",
                            "type": "string",
                            "x-node_available_in": ["us", "au", "ca", "mx"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_authority_name": {
                            "description": "Name of the Tax Authority",
                            "type": "string",
                            "x-node_available_in": ["us", "au", "ca"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_exemption_code": {
                            "description": "Code of the Tax Exemption",
                            "type": "string",
                            "x-node_available_in": ["in", "us", "au", "ca"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_exemption_id": {
                            "description": "ID of the Tax Exemption",
                            "type": "string",
                            "x-node_available_in": ["in", "us", "au", "ca", "mx"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_exemption_type": {
                            "description": "Type "
                            "of "
                            "the "
                            "Tax "
                            "Exemption. "
                            "Allowed "
                            "Values "
                            ": "
                            "<code>customer</code> "
                            "and "
                            "<code>item</code>",
                            "type": "string",
                            "x-node_available_in": ["in", "us", "au", "ca", "mx"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_id": {"description": "ID of the tax.", "type": "string"},
                    },
                    "required": ["amount", "debit_or_credit"],
                    "type": "object",
                },
                "type": "array",
            },
            "location_id": {
                "description": "Location ID",
                "example": "460000000038080",
                "type": "string",
            },
            "notes": {
                "description": "Notes for the journal.",
                "example": "Loan repayment",
                "type": "string",
            },
            "product_type": {
                "description": "Type of the journal. This denotes "
                "whether the journal is to be treated "
                "as goods or service. Allowed Values: "
                "<code> digital_service</code>, "
                "<code>goods</code> and "
                "<code>service</code>.",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
            "reference_number": {
                "description": "Reference number for the journal.",
                "example": "7355",
                "type": "string",
            },
            "tax_exemption_code": {
                "description": "Code of the Tax Exemption",
                "type": "string",
                "x-node_available_in": ["in", "us", "au", "ca"],
                "x-node_unavailable_in": [],
            },
            "tax_exemption_type": {
                "description": "Type of the Tax Exemption. "
                "Allowed Values : "
                "<code>customer</code> and "
                "<code>item</code>",
                "type": "string",
                "x-node_available_in": ["in", "us", "au", "ca", "mx"],
                "x-node_unavailable_in": [],
            },
            "vat_treatment": {
                "description": "(Optional) VAT treatment for the "
                "journals. VAT treatment denotes the "
                "location of the customer, if the "
                "customer resides in UK then the VAT "
                "treatment is <code>uk</code>. If the "
                "customer is in an EU country & VAT "
                "registered, you are resides in "
                "Northen Ireland and selling Goods "
                "then his VAT treatment is "
                "<code>eu_vat_registered</code>, if "
                "he resides outside of the UK then "
                "his VAT treatment is "
                "<code>overseas</code> (For Pre "
                "Brexit, this can be split as "
                "<code>eu_vat_registered</code>, "
                "<code>eu_vat_not_registered</code> "
                "and <code>non_eu</code>).",
                "type": "string",
                "x-node_available_in": ["uk", "eu"],
                "x-node_unavailable_in": [],
            },
        },
        "required": ["journal_date"],
        "type": "object",
    },
    "ADDJOURNALCOMMENT_REQUEST_BODY_SCHEMA": {
        "properties": {
            "description": {
                "description": "Description of a comment",
                "example": "Journal Created",
                "type": "string",
            }
        },
        "type": "object",
    },
    "CREATEZOHOBOOKLOCATION_REQUEST_BODY_SCHEMA": {
        "properties": {
            "address": {
                "properties": {
                    "attention": {"description": "Attention of the location.", "type": "string"},
                    "city": {
                        "description": "City Name of the location.",
                        "example": "New York City",
                        "type": "string",
                    },
                    "country": {
                        "description": "Country Name of the location.",
                        "example": "U.S.A",
                        "type": "string",
                    },
                    "state": {
                        "description": "State Name of the location.",
                        "example": "New York",
                        "type": "string",
                    },
                    "state_code": {
                        "description": "State code of the location.",
                        "example": "NY",
                        "type": "string",
                    },
                    "street_address1": {
                        "description": "Street Name of the location.",
                        "example": "No:234,90 Church Street",
                        "type": "string",
                    },
                    "street_address2": {
                        "description": "Street Name of the location.",
                        "example": "McMillan Avenue",
                        "type": "string",
                    },
                },
                "type": "object",
            },
            "associated_series_ids": {
                "example": ["982000000870911", "982000000870915"],
                "items": {"type": "string"},
                "type": "array",
            },
            "auto_number_generation_id": {
                "description": "Autonumber generation group ID",
                "example": "982000000870911",
                "type": "string",
            },
            "email": {
                "description": "Email id for the location",
                "example": "willsmith@bowmanfurniture.com",
                "type": "string",
            },
            "is_all_users_selected": {
                "description": "Whether all users are selected or not",
                "example": False,
                "type": "boolean",
            },
            "location_name": {
                "description": "Name of the location",
                "example": "Head Office",
                "type": "string",
            },
            "parent_location_id": {
                "description": "Parent Location ID",
                "example": "460000000041010",
                "type": "string",
            },
            "phone": {
                "description": "Mobile number for location",
                "example": "+1-925-921-9201",
                "type": "string",
            },
            "tax_settings_id": {
                "description": "Tax Settings ID",
                "example": "460000000038080",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "type": {
                "description": "Type of the location",
                "example": "general / line_item_only",
                "type": "string",
            },
            "user_ids": {
                "description": "Comma separated user ids.",
                "example": "460000000036868,460000000036869",
                "type": "string",
            },
        },
        "required": ["location_name", "country", "tax_settings_id"],
        "type": "object",
    },
    "UPDATELOCATIONINZOHOBOOKS_REQUEST_BODY_SCHEMA": {
        "properties": {
            "address": {
                "properties": {
                    "attention": {"description": "Attention of the location.", "type": "string"},
                    "city": {
                        "description": "City Name of the location.",
                        "example": "New York City",
                        "type": "string",
                    },
                    "country": {
                        "description": "Country Name of the location.",
                        "example": "U.S.A",
                        "type": "string",
                    },
                    "state": {
                        "description": "State Name of the location.",
                        "example": "New York",
                        "type": "string",
                    },
                    "state_code": {
                        "description": "State code of the location.",
                        "example": "NY",
                        "type": "string",
                    },
                    "street_address1": {
                        "description": "Street Name of the location.",
                        "example": "No:234,90 Church Street",
                        "type": "string",
                    },
                    "street_address2": {
                        "description": "Street Name of the location.",
                        "example": "McMillan Avenue",
                        "type": "string",
                    },
                },
                "type": "object",
            },
            "associated_series_ids": {
                "example": ["982000000870911", "982000000870915"],
                "items": {"type": "string"},
                "type": "array",
            },
            "auto_number_generation_id": {
                "description": "Autonumber generation group ID",
                "example": "982000000870911",
                "type": "string",
            },
            "email": {
                "description": "Email id for the location",
                "example": "willsmith@bowmanfurniture.com",
                "type": "string",
            },
            "is_all_users_selected": {
                "description": "Whether all users are selected or not",
                "example": False,
                "type": "boolean",
            },
            "location_name": {
                "description": "Name of the location",
                "example": "Head Office",
                "type": "string",
            },
            "parent_location_id": {
                "description": "Parent Location ID",
                "example": "460000000041010",
                "type": "string",
            },
            "phone": {
                "description": "Mobile number for location",
                "example": "+1-925-921-9201",
                "type": "string",
            },
            "tax_settings_id": {
                "description": "Tax Settings ID",
                "example": "460000000038080",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "type": {
                "description": "Type of the location",
                "example": "general / line_item_only",
                "type": "string",
            },
            "user_ids": {
                "description": "Comma separated user ids.",
                "example": "460000000036868,460000000036869",
                "type": "string",
            },
        },
        "required": ["location_name", "country", "tax_settings_id"],
        "type": "object",
    },
    "CREATEOPENINGBALANCE_REQUEST_BODY_SCHEMA": {
        "properties": {
            "accounts": {
                "items": {
                    "properties": {
                        "account_id": {
                            "description": "ID "
                            "of "
                            "account "
                            "for "
                            "which "
                            "you "
                            "need "
                            "to "
                            "record "
                            "opening "
                            "balance.",
                            "example": "460000000000358",
                            "type": "string",
                        },
                        "amount": {"example": 2000, "format": "double", "type": "number"},
                        "currency_id": {
                            "description": "ID of account currency.",
                            "example": "460000000000097",
                            "type": "string",
                        },
                        "debit_or_credit": {
                            "description": "Debit "
                            "or "
                            "Credit "
                            "for "
                            "which "
                            "the "
                            "amount "
                            "needs "
                            "to "
                            "be "
                            "recorded. "
                            "Allowed "
                            "Values: "
                            "<code>debit</code> "
                            "and "
                            "<code>credit</code>.",
                            "example": "debit",
                            "type": "string",
                        },
                        "exchange_rate": {
                            "description": "Exchange rate for the foreign currencies if involved.",
                            "example": 1,
                            "format": "double",
                            "type": "number",
                        },
                        "location_id": {
                            "description": "Location ID",
                            "example": "460000000038080",
                            "type": "string",
                        },
                    },
                    "required": ["debit_or_credit"],
                    "type": "object",
                },
                "type": "array",
            },
            "date": {
                "description": "Date on which the opening balance needs to be "
                "recorded. [yyyy-MM-dd]",
                "example": "2013-10-01",
                "type": "string",
            },
        },
        "required": ["date"],
        "type": "object",
    },
    "UPDATEOPENINGBALANCE_REQUEST_BODY_SCHEMA": {
        "properties": {
            "accounts": {
                "items": {
                    "properties": {
                        "account_id": {
                            "description": "ID "
                            "of "
                            "account "
                            "for "
                            "which "
                            "you "
                            "need "
                            "to "
                            "record "
                            "opening "
                            "balance.",
                            "example": "460000000000358",
                            "type": "string",
                        },
                        "account_name": {"example": "Undeposited Funds", "type": "string"},
                        "acount_split_id": {
                            "description": "ID of split account that you want to update.",
                            "example": "460000000050045",
                            "type": "string",
                        },
                        "amount": {"example": 2000, "format": "double", "type": "number"},
                        "bcy_amount": {
                            "description": "Amount in Base Currency of the Organisation",
                            "example": 2000,
                            "format": "double",
                            "type": "number",
                        },
                        "currency_code": {"example": "USD", "type": "string"},
                        "currency_id": {
                            "description": "ID of account currency.",
                            "example": "460000000000097",
                            "type": "string",
                        },
                        "debit_or_credit": {
                            "description": "Debit "
                            "or "
                            "Credit "
                            "for "
                            "which "
                            "the "
                            "amount "
                            "needs "
                            "to "
                            "be "
                            "recorded. "
                            "Allowed "
                            "Values: "
                            "<code>debit</code> "
                            "and "
                            "<code>credit</code>.",
                            "example": "debit",
                            "type": "string",
                        },
                        "exchange_rate": {
                            "description": "Exchange rate for the foreign currencies if involved.",
                            "example": 1,
                            "format": "double",
                            "type": "number",
                        },
                        "location_id": {
                            "description": "Location ID",
                            "example": "460000000038080",
                            "type": "string",
                        },
                        "location_name": {"description": "Name of the location.", "type": "string"},
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "date": {
                "description": "Date on which the opening balance needs to be "
                "recorded. [yyyy-MM-dd]",
                "example": "2013-10-01",
                "type": "string",
            },
            "opening_balance_id": {
                "description": "ID of opening balance.",
                "example": "460000000050041",
                "type": "string",
            },
        },
        "required": ["opening_balance_id"],
        "type": "object",
    },
    "CREATEORGANIZATIONINZOHOBOOKS_REQUEST_BODY_SCHEMA": {
        "properties": {
            "address": {
                "description": "Billing address of the organisation",
                "properties": {
                    "city": {
                        "description": "City of the organisation",
                        "example": " ",
                        "type": "string",
                    },
                    "country": {
                        "description": "Country of the Organisation",
                        "example": "U.S.A",
                        "type": "string",
                    },
                    "state": {
                        "description": "State where the organisation is located",
                        "example": " ",
                        "type": "string",
                    },
                    "street_address1": {
                        "description": "Street name of the Billing address of the Organisation",
                        "example": " ",
                        "type": "string",
                    },
                    "street_address2": {
                        "description": "Continyed billing address of the organisation",
                        "example": " ",
                        "type": "string",
                    },
                    "zip": {
                        "description": "ZIP/Postal code of the organisation's location",
                        "example": "U.S.A",
                        "type": "string",
                    },
                },
                "type": "object",
            },
            "currency_code": {
                "description": "Standard code for currency.",
                "example": "USD",
                "type": "string",
            },
            "date_format": {
                "description": "Format for representing the date.",
                "example": "dd MMM yyyy",
                "type": "string",
            },
            "field_separator": {
                "description": "Field separator for components in date.",
                "example": " ",
                "type": "string",
            },
            "fiscal_year_start_month": {
                "description": "Fiscal or financial "
                "starting year of your "
                "business. Allowed Values: "
                "<code>january</code>, "
                "<code>february</code>, "
                "<code>march</code>, "
                "<code>april</code>,<code> "
                "may</code>, "
                "<code>june</code>, "
                "<code>july</code>, "
                "<code>august</code>, "
                "<code>september</code>, "
                "<code>october</code>, "
                "<code>november</code> and "
                "<code>december</code>",
                "example": "january",
                "type": "string",
            },
            "industry_size": {
                "description": "The size of the industry. The "
                'possibe values could be "small '
                'scale", "medium scale", "large '
                'scale"',
                "example": " ",
                "type": "string",
            },
            "industry_type": {
                "description": "Business type",
                "example": "Services",
                "type": "string",
            },
            "language_code": {
                "description": "language code for organization.For "
                "instance <code>en</code> represents "
                "english.",
                "example": "en",
                "type": "string",
            },
            "name": {
                "description": "Name of the project.",
                "example": "Zillium Inc",
                "type": "string",
            },
            "org_address": {
                "description": "Billing address of the organisation",
                "example": " ",
                "type": "string",
            },
            "portal_name": {
                "description": "Poratal name for the organisation. "
                "Length of the portal name should be "
                "greater than 4 and less than 31. "
                "Allowed chars [a-z][A-Z][0-9]",
                "example": "zilluminc",
                "type": "string",
            },
            "remit_to_address": {
                "description": "Shipping address of the organisation",
                "example": " ",
                "type": "string",
            },
            "time_zone": {
                "description": "Time zone in with the organization is located geographically.",
                "example": "PST",
                "type": "string",
            },
        },
        "required": ["name", "currency_code", "time_zone", "portal_name"],
        "type": "object",
    },
    "UPDATEORGANIZATIONDETAILS_REQUEST_BODY_SCHEMA": {
        "properties": {
            "address": {
                "description": "Billing address of the organisation",
                "properties": {
                    "city": {
                        "description": "City of the organisation",
                        "example": " ",
                        "type": "string",
                    },
                    "country": {
                        "description": "Country of the Organisation",
                        "example": "U.S.A",
                        "type": "string",
                    },
                    "state": {
                        "description": "State where the organisation is located",
                        "example": " ",
                        "type": "string",
                    },
                    "street_address1": {
                        "description": "Street name of the Billing address of the Organisation",
                        "example": " ",
                        "type": "string",
                    },
                    "street_address2": {
                        "description": "Continyed billing address of the organisation",
                        "example": " ",
                        "type": "string",
                    },
                    "zip": {
                        "description": "ZIP/Postal code of the organisation's location",
                        "example": "U.S.A",
                        "type": "string",
                    },
                },
                "type": "object",
            },
            "companyid_label": {
                "description": 'Label " Company ID "',
                "example": " ",
                "type": "string",
            },
            "companyid_value": {
                "description": 'value in field "company ID"',
                "example": " ",
                "type": "string",
            },
            "contact_name": {
                "description": "Name of the contact person of the organisation",
                "example": "John Smith",
                "type": "string",
            },
            "currency_id": {
                "description": "ID of the organisation curreency",
                "example": "982000000000190",
                "type": "string",
            },
            "custom_fields": {
                "description": "Additional fields to describe an organisation",
                "items": {
                    "properties": {
                        "index": {
                            "description": "Index used to list",
                            "example": 1,
                            "format": "double",
                            "type": "number",
                        },
                        "label": {
                            "description": "Label of each column",
                            "example": " ",
                            "type": "string",
                        },
                        "value": {
                            "description": "Value of the list",
                            "example": " ",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "date_format": {
                "description": "Format for representing the date.",
                "example": "dd MMM yyyy",
                "type": "string",
            },
            "email": {
                "description": "email ID of the contact person of the organisation",
                "example": "johndavid@zilliuminc.com",
                "type": "string",
            },
            "fax": {
                "description": "FAX number of the organisation",
                "example": " ",
                "type": "string",
            },
            "field_separator": {
                "description": "Field separator for components in date.",
                "example": " ",
                "type": "string",
            },
            "fiscal_year_start_month": {
                "description": "Fiscal or financial "
                "starting year of your "
                "business. Allowed Values: "
                "<code>january</code>, "
                "<code>february</code>, "
                "<code>march</code>, "
                "<code>april</code>,<code> "
                "may</code>, "
                "<code>june</code>, "
                "<code>july</code>, "
                "<code>august</code>, "
                "<code>september</code>, "
                "<code>october</code>, "
                "<code>november</code> and "
                "<code>december</code>",
                "example": "january",
                "type": "string",
            },
            "is_logo_uploaded": {
                "description": "To determine whether logo is uploaded.",
                "example": True,
                "type": "boolean",
            },
            "language_code": {
                "description": "language code for organization.For "
                "instance <code>en</code> represents "
                "english.",
                "example": "en",
                "type": "string",
            },
            "name": {
                "description": "Name of the project.",
                "example": "Zillium Inc",
                "type": "string",
            },
            "org_address": {
                "description": "Billing address of the organisation",
                "example": " ",
                "type": "string",
            },
            "phone": {
                "description": "Contact number of the organisation",
                "example": " ",
                "type": "string",
            },
            "remit_to_address": {
                "description": "Shipping address of the organisation",
                "example": " ",
                "type": "string",
            },
            "taxid_label": {"description": 'Label "tax ID"', "example": " ", "type": "string"},
            "taxid_value": {"description": 'Value in "tax ID"', "example": " ", "type": "string"},
            "time_zone": {
                "description": "Time zone in with the organization is located geographically.",
                "example": "PST",
                "type": "string",
            },
            "website": {"description": "Organisation's website", "example": " ", "type": "string"},
        },
        "type": "object",
    },
    "CREATEPROJECT_REQUEST_BODY_SCHEMA": {
        "properties": {
            "billing_type": {
                "description": "The way you bill your customer. "
                "Allowed Values: "
                "<code>fixed_cost_for_project</code>, "
                "<code>based_on_project_hours</code>, "
                "<code>based_on_staff_hours</code> and "
                "<code>based_on_task_hours</code>",
                "example": "based_on_task_hours",
                "type": "string",
            },
            "budget_amount": {
                "description": "Give value, if you are estimating total project revenue budget.",
                "example": " ",
                "type": "string",
            },
            "budget_hours": {"description": "Task budget hours", "example": " ", "type": "string"},
            "budget_type": {
                "description": "The way you budget. Allowed Values: "
                "<code>total_project_cost</code>, "
                "<code>total_project_hours</code>, "
                "<code>hours_per_task</code> and "
                "<code>hours_per_staff</code>",
                "example": " ",
                "type": "string",
            },
            "cost_budget_amount": {
                "description": "Budgeted Cost to complete this project",
                "example": "1000.00",
                "format": "double",
                "type": "number",
            },
            "currency_id": {"example": "460000000098001", "type": "string"},
            "customer_id": {
                "description": "ID of the customer.",
                "example": "460000000044001",
                "type": "string",
            },
            "description": {
                "description": "Project description. <code>Max-length [500]</code>",
                "example": "Distribution for the system of "
                "intermediaries between the producer of "
                "goods and/or services and the final user",
                "type": "string",
            },
            "project_name": {
                "description": "Name of the project. <code>Max-length [100]</code>",
                "example": "Network Distribution",
                "type": "string",
            },
            "rate": {"description": "Hourly rate for a task.", "example": " ", "type": "string"},
            "tasks": {
                "items": {
                    "properties": {
                        "budget_hours": {
                            "description": "Task budgeting.",
                            "example": "INV-00003",
                            "type": "string",
                        },
                        "description": {
                            "description": "Task description. <code>Max-length [500]</code>",
                            "example": "INV-00003",
                            "type": "string",
                        },
                        "rate": {
                            "description": "Hourly rate of a task.",
                            "example": "INV-00003",
                            "type": "string",
                        },
                        "task_name": {
                            "description": "Name of the task. <code>Max-length [100]</code>",
                            "example": "INV-00003",
                            "type": "string",
                        },
                    },
                    "required": ["task_name"],
                    "type": "object",
                },
                "type": "array",
            },
            "user_id": {
                "description": "ID of the user to be added to the project.",
                "example": "INV-00003",
                "type": "string",
            },
            "users": {
                "items": {
                    "properties": {
                        "billed_hours": {"example": "12:27", "type": "string"},
                        "budget_hours": {
                            "description": "Task budget hours",
                            "example": " ",
                            "type": "string",
                        },
                        "cost_rate": {"example": "10.00", "format": "double", "type": "number"},
                        "email": {
                            "description": "Email of the user. <code>Max-length [100]</code>",
                            "example": "johndavid@zilliuminc.com",
                            "type": "string",
                        },
                        "is_current_user": {"example": True, "type": "boolean"},
                        "rate": {
                            "description": "Hourly rate for a task.",
                            "example": " ",
                            "type": "string",
                        },
                        "status": {"example": "active", "type": "string"},
                        "total_hours": {"example": "12:26", "type": "string"},
                        "un_billed_hours": {"example": "00:00", "type": "string"},
                        "user_id": {
                            "description": "ID of the user to be added to the project.",
                            "example": "INV-00003",
                            "type": "string",
                        },
                        "user_name": {
                            "description": "Name of the user. <code>Max-length [200]</code>",
                            "example": "John David",
                            "type": "string",
                        },
                        "user_role": {
                            "description": "Role "
                            "to be "
                            "assigned. "
                            "Allowed "
                            "Values: "
                            "<code>staff</code>, "
                            "<code>admin</code> "
                            "and "
                            "<code>timesheetstaff</code>",
                            "example": "admin",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
        },
        "required": ["project_name", "customer_id", "billing_type", "user_id"],
        "type": "object",
    },
    "UPDATEPROJECTWITHCUSTOMFIELD_REQUEST_BODY_SCHEMA": {
        "properties": {
            "billing_type": {
                "description": "The way you bill your customer. "
                "Allowed Values: "
                "<code>fixed_cost_for_project</code>, "
                "<code>based_on_project_hours</code>, "
                "<code>based_on_staff_hours</code> and "
                "<code>based_on_task_hours</code>",
                "example": "based_on_task_hours",
                "type": "string",
            },
            "budget_amount": {
                "description": "Give value, if you are estimating total project revenue.",
                "example": " ",
                "type": "string",
            },
            "budget_hours": {"description": "Task budget hours", "example": " ", "type": "string"},
            "budget_type": {
                "description": "The way you budget. Allowed Values: "
                "<code>total_project_cost</code>, "
                "<code>total_project_hours</code>, "
                "<code>hours_per_task</code> and "
                "<code>hours_per_staff</code>",
                "example": " ",
                "type": "string",
            },
            "cost_budget_amount": {
                "description": "Budgeted Cost to complete this project",
                "example": "1000.00",
                "format": "double",
                "type": "number",
            },
            "currency_id": {"example": "460000000098001", "type": "string"},
            "customer_id": {
                "description": "ID of the customer.",
                "example": "460000000044001",
                "type": "string",
            },
            "description": {
                "description": "Project description. <code>Max-length [500]</code>",
                "example": "Distribution for the system of "
                "intermediaries between the producer of "
                "goods and/or services and the final user",
                "type": "string",
            },
            "project_name": {
                "description": "Name of the project. <code>Max-length [100]</code>",
                "example": "Network Distribution",
                "type": "string",
            },
            "rate": {"description": "Hourly rate for a task.", "example": " ", "type": "string"},
            "tasks": {
                "items": {
                    "properties": {
                        "budget_hours": {
                            "description": "Task budgeting.",
                            "example": "INV-00003",
                            "type": "string",
                        },
                        "description": {
                            "description": "Task description. <code>Max-length [500]</code>",
                            "example": "INV-00003",
                            "type": "string",
                        },
                        "rate": {
                            "description": "Hourly rate of a task.",
                            "example": "INV-00003",
                            "type": "string",
                        },
                        "task_name": {
                            "description": "Name of the task. <code>Max-length [100]</code>",
                            "example": "INV-00003",
                            "type": "string",
                        },
                    },
                    "required": ["task_name"],
                    "type": "object",
                },
                "type": "array",
            },
            "user_id": {
                "description": "ID of the user to be added to the project.",
                "example": "INV-00003",
                "type": "string",
            },
            "users": {
                "items": {
                    "properties": {
                        "billed_hours": {"example": "12:27", "type": "string"},
                        "budget_hours": {
                            "description": "Task budget hours",
                            "example": " ",
                            "type": "string",
                        },
                        "cost_rate": {"example": "10.00", "format": "double", "type": "number"},
                        "email": {
                            "description": "Email of the user. <code>Max-length [100]</code>",
                            "example": "johndavid@zilliuminc.com",
                            "type": "string",
                        },
                        "is_current_user": {"example": True, "type": "boolean"},
                        "rate": {
                            "description": "Hourly rate for a task.",
                            "example": " ",
                            "type": "string",
                        },
                        "status": {"example": "active", "type": "string"},
                        "total_hours": {"example": "12:26", "type": "string"},
                        "un_billed_hours": {"example": "00:00", "type": "string"},
                        "user_id": {
                            "description": "ID of the user to be added to the project.",
                            "example": "INV-00003",
                            "type": "string",
                        },
                        "user_name": {
                            "description": "Name of the user. <code>Max-length [200]</code>",
                            "example": "John David",
                            "type": "string",
                        },
                        "user_role": {
                            "description": "Role "
                            "to be "
                            "assigned. "
                            "Allowed "
                            "Values: "
                            "<code>staff</code>, "
                            "<code>admin</code> "
                            "and "
                            "<code>timesheetstaff</code>",
                            "example": "admin",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
        },
        "required": ["project_name", "customer_id", "billing_type", "user_id"],
        "type": "object",
    },
    "UPDATEPROJECTDETAILS_REQUEST_BODY_SCHEMA": {
        "properties": {
            "billing_type": {
                "description": "The way you bill your customer. "
                "Allowed Values: "
                "<code>fixed_cost_for_project</code>, "
                "<code>based_on_project_hours</code>, "
                "<code>based_on_staff_hours</code> and "
                "<code>based_on_task_hours</code>",
                "example": "based_on_task_hours",
                "type": "string",
            },
            "budget_amount": {
                "description": "Give value, if you are estimating total project revenue.",
                "example": " ",
                "type": "string",
            },
            "budget_hours": {"description": "Task budget hours", "example": " ", "type": "string"},
            "budget_type": {
                "description": "The way you budget. Allowed Values: "
                "<code>total_project_cost</code>, "
                "<code>total_project_hours</code>, "
                "<code>hours_per_task</code> and "
                "<code>hours_per_staff</code>",
                "example": " ",
                "type": "string",
            },
            "cost_budget_amount": {
                "description": "Budgeted Cost to complete this project",
                "example": "1000.00",
                "format": "double",
                "type": "number",
            },
            "currency_id": {"example": "460000000098001", "type": "string"},
            "customer_id": {
                "description": "ID of the customer.",
                "example": "460000000044001",
                "type": "string",
            },
            "description": {
                "description": "Project description. <code>Max-length [500]</code>",
                "example": "Distribution for the system of "
                "intermediaries between the producer of "
                "goods and/or services and the final user",
                "type": "string",
            },
            "project_name": {
                "description": "Name of the project. <code>Max-length [100]</code>",
                "example": "Network Distribution",
                "type": "string",
            },
            "rate": {"description": "Hourly rate for a task.", "example": " ", "type": "string"},
            "tasks": {
                "items": {
                    "properties": {
                        "budget_hours": {
                            "description": "Task budgeting.",
                            "example": "INV-00003",
                            "type": "string",
                        },
                        "description": {
                            "description": "Task description. <code>Max-length [500]</code>",
                            "example": "INV-00003",
                            "type": "string",
                        },
                        "rate": {
                            "description": "Hourly rate of a task.",
                            "example": "INV-00003",
                            "type": "string",
                        },
                        "task_name": {
                            "description": "Name of the task. <code>Max-length [100]</code>",
                            "example": "INV-00003",
                            "type": "string",
                        },
                    },
                    "required": ["task_name"],
                    "type": "object",
                },
                "type": "array",
            },
            "user_id": {
                "description": "ID of the user to be added to the project.",
                "example": "INV-00003",
                "type": "string",
            },
            "users": {
                "items": {
                    "properties": {
                        "billed_hours": {"example": "12:27", "type": "string"},
                        "budget_hours": {
                            "description": "Task budget hours",
                            "example": " ",
                            "type": "string",
                        },
                        "cost_rate": {"example": "10.00", "format": "double", "type": "number"},
                        "email": {
                            "description": "Email of the user. <code>Max-length [100]</code>",
                            "example": "johndavid@zilliuminc.com",
                            "type": "string",
                        },
                        "is_current_user": {"example": True, "type": "boolean"},
                        "rate": {
                            "description": "Hourly rate for a task.",
                            "example": " ",
                            "type": "string",
                        },
                        "status": {"example": "active", "type": "string"},
                        "total_hours": {"example": "12:26", "type": "string"},
                        "un_billed_hours": {"example": "00:00", "type": "string"},
                        "user_id": {
                            "description": "ID of the user to be added to the project.",
                            "example": "INV-00003",
                            "type": "string",
                        },
                        "user_name": {
                            "description": "Name of the user. <code>Max-length [200]</code>",
                            "example": "John David",
                            "type": "string",
                        },
                        "user_role": {
                            "description": "Role "
                            "to be "
                            "assigned. "
                            "Allowed "
                            "Values: "
                            "<code>staff</code>, "
                            "<code>admin</code> "
                            "and "
                            "<code>timesheetstaff</code>",
                            "example": "admin",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
        },
        "required": ["project_name", "customer_id", "billing_type", "user_id"],
        "type": "object",
    },
    "CLONEPROJECT_REQUEST_BODY_SCHEMA": {
        "properties": {
            "description": {
                "description": "Project description. <code>Max-length [500]</code>",
                "example": "Distribution for the system of "
                "intermediaries between the producer of "
                "goods and/or services and the final user",
                "type": "string",
            },
            "project_name": {
                "description": "Name of the project. <code>Max-length [100]</code>",
                "example": "Network Distribution",
                "type": "string",
            },
        },
        "required": ["project_name"],
        "type": "object",
    },
    "ASSIGNUSERSTOPROJECT_REQUEST_BODY_SCHEMA": {
        "properties": {
            "cost_rate": {"example": "10.00", "format": "double", "type": "number"},
            "users": {
                "items": {
                    "properties": {
                        "user_id": {
                            "description": "ID of the user to be added to the project.",
                            "example": "460000000024003",
                            "type": "string",
                        }
                    },
                    "required": ["user_id"],
                    "type": "object",
                },
                "type": "array",
            },
        },
        "required": ["cost_rate"],
        "type": "object",
    },
    "INVITEUSERTOPROJECT_REQUEST_BODY_SCHEMA": {
        "properties": {
            "budget_hours": {"description": "Task budget hours.", "example": "0", "type": "string"},
            "cost_rate": {"example": "10.00", "format": "double", "type": "number"},
            "email": {
                "description": "Email of the user. <code>Max-length [100]</code>",
                "example": "johndavid@zilliuminc.com",
                "type": "string",
            },
            "rate": {"description": "Hourly rate for a task.", "example": " ", "type": "string"},
            "user_name": {
                "description": "Name of the user. <code>Max-length [200]</code>",
                "example": "John David",
                "type": "string",
            },
            "user_role": {
                "description": "Role to be assigned. Allowed Values: "
                "<code>staff</code>, <code>admin</code> "
                "and <code>timesheetstaff</code>",
                "example": "admin",
                "type": "string",
            },
        },
        "required": ["user_name", "email"],
        "type": "object",
    },
    "UPDATEPROJECTUSERDETAILS_REQUEST_BODY_SCHEMA": {
        "properties": {
            "budget_hours": {"description": "Task budget hours.", "example": "0", "type": "string"},
            "cost_rate": {"example": "10.00", "format": "double", "type": "number"},
            "rate": {"example": 5000, "format": "float", "type": "number"},
            "user_name": {
                "description": "Name of the user. <code>Max-length [200]</code>",
                "example": "John David",
                "type": "string",
            },
            "user_role": {
                "description": "Role to be assigned. Allowed Values: "
                "<code>staff</code>, <code>admin</code> "
                "and <code>timesheetstaff</code>",
                "example": "admin",
                "type": "string",
            },
        },
        "type": "object",
    },
    "POSTPROJECTCOMMENT_REQUEST_BODY_SCHEMA": {
        "properties": {
            "description": {
                "description": "Project description. <code>Max-length [500]</code>",
                "example": "Billing based on task hours",
                "type": "string",
            }
        },
        "required": ["description"],
        "type": "object",
    },
    "CREATEVENDORPURCHASEORDER_REQUEST_BODY_SCHEMA": {
        "properties": {
            "attention": {
                "description": "The name or designation of the specific "
                "person who should be contacted or "
                "notified regarding the delivery of goods "
                "or services from this purchase order. "
                "This field is typically used to specify "
                "the primary contact person at the "
                "delivery location, such as a warehouse "
                "manager, office administrator, or "
                "project coordinator who will receive and "
                "process the delivered items.",
                "type": "string",
            },
            "billing_address_id": {
                "description": "Unique identifier of the "
                "billing address to be used for "
                "this purchase order. The "
                "billing address determines "
                "where invoices and related "
                "documents will be sent. This "
                "field is optional and if not "
                "specified, the default billing "
                "address from your organization "
                "settings will be used. You can "
                "obtain the billing address ID "
                "by listing all available "
                "addresses in your organization. "
                "Ensure the address exists and "
                "contains the correct billing "
                "information before referencing "
                "its ID here.",
                "example": "460000000017491",
                "format": "int64",
                "type": "integer",
            },
            "contact_persons_associated": {
                "description": "Contact Persons associated with the transaction.",
                "items": {
                    "properties": {
                        "communication_preference": {
                            "description": "Preferred "
                            "modes "
                            "of "
                            "communication "
                            "for "
                            "the "
                            "contact "
                            "person "
                            "at "
                            "transaction "
                            "level.",
                            "properties": {
                                "is_email_enabled": {
                                    "description": "Used "
                                    "to "
                                    "check "
                                    "if "
                                    "Email "
                                    "communication "
                                    "preference "
                                    "is "
                                    "enabled "
                                    "for "
                                    "the "
                                    "contact "
                                    "person "
                                    "at "
                                    "transaction "
                                    "level.",
                                    "example": True,
                                    "type": "boolean",
                                },
                                "is_whatsapp_enabled": {
                                    "description": "Used "
                                    "to "
                                    "check "
                                    "if "
                                    "WhatsApp "
                                    "communication "
                                    "preference "
                                    "is "
                                    "enabled "
                                    "for "
                                    "the "
                                    "contact "
                                    "person "
                                    "at "
                                    "transaction "
                                    "level.",
                                    "example": True,
                                    "type": "boolean",
                                    "x-node_available_in": ["WhatsApp integration"],
                                },
                            },
                            "type": "object",
                        },
                        "contact_person_id": {
                            "description": "Unique ID of the Contact Person",
                            "example": 460000000031001,
                            "format": "int64",
                            "type": "integer",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "crm_custom_reference_id": {
                "description": "ID of CRM Custom Reference",
                "format": "int64",
                "type": "integer",
            },
            "crm_owner_id": {
                "description": "Unique identifier of the CRM owner "
                "assigned to this purchase order. This "
                "field links the purchase order to a "
                "specific CRM user who is responsible "
                "for managing the vendor relationship "
                "and overseeing the procurement "
                "process. The CRM owner can track, "
                "follow up, and manage all aspects of "
                "this purchase order within the CRM "
                "system.",
                "type": "string",
            },
            "currency_id": {
                "description": "Unique identifier of the currency for "
                "the purchase order. This value is "
                "mandatory to specify the currency in "
                "which the purchase order amounts will "
                "be displayed and processed. You can "
                "obtain the currency ID by listing all "
                "available currencies using the GET "
                "/settings/currencies API. Ensure the "
                "currency exists and is properly "
                "configured in your organization before "
                "referencing its ID here.",
                "example": "460000000000099",
                "type": "string",
            },
            "custom_fields": {
                "description": "Custom fields for purchase order.",
                "items": {
                    "properties": {
                        "customfield_id": {
                            "example": "46000000012845",
                            "format": "int64",
                            "type": "integer",
                        },
                        "value": {
                            "description": "Value of the Custom Field",
                            "example": "Normal",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "date": {
                "description": "The date when the purchase order was created "
                "or issued. This is the official date that "
                "appears on the purchase order document and is "
                "used for record-keeping, reporting, and "
                "tracking purposes. The date should be in "
                "YYYY-MM-DD format and typically represents "
                "when the purchase order was authorized and "
                "sent to the vendor.",
                "example": "2014-02-10",
                "type": "string",
            },
            "delivery_customer_id": {
                "description": "Unique identifier of the "
                "customer for whom the goods "
                "or services in this purchase "
                "order are being procured. "
                "This field is used when the "
                "purchase order is created on "
                "behalf of a customer, such as "
                "in drop-shipping scenarios or "
                "when procuring items for "
                "specific customer projects. "
                "The customer information may "
                "be displayed on the purchase "
                "order for vendor reference.",
                "type": "string",
            },
            "delivery_date": {
                "description": "The expected delivery date when the "
                "goods or services ordered in this "
                "purchase order should be received. "
                "This date is used for planning, "
                "scheduling, and tracking deliveries. "
                "It helps in managing inventory, "
                "coordinating with vendors, and "
                "ensuring timely receipt of ordered "
                "items. The date should be in "
                "YYYY-MM-DD format and is typically "
                "communicated to the vendor as part "
                "of the purchase order terms.",
                "example": "2014-02-10",
                "type": "string",
            },
            "delivery_org_address_id": {
                "description": "Unique identifier of the "
                "organization address where "
                "the goods or services from "
                "this purchase order should "
                "be delivered. This field "
                "specifies the delivery "
                "location within your "
                "organization, such as a "
                "warehouse, office, or "
                "branch location. The "
                "address details are "
                "retrieved from your "
                "organization's address "
                "book and displayed on the "
                "purchase order for vendor "
                "reference.",
                "type": "string",
            },
            "destination_of_supply": {
                "description": "Place where the "
                "goods/services are supplied "
                "to. (If not given, "
                "organisation's home state "
                "will be taken)",
                "example": "TN",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "discount": {
                "description": "The discount amount or percentage to be "
                "applied to the purchase order total. This "
                "can be specified as a fixed amount or "
                "percentage value. Discounts are typically "
                "offered by vendors for bulk purchases, "
                "early payments, or promotional purposes. "
                "The discount reduces the total amount "
                "payable and affects the final purchase "
                "order total.",
                "example": "10",
                "type": "string",
            },
            "discount_account_id": {
                "description": "Unique identifier of the "
                "accounting account where the "
                "discount amount will be "
                "recorded. This account is used "
                "to track and categorize "
                "discount expenses in your "
                "general ledger. The discount "
                "account should be configured "
                "as an expense or "
                "contra-revenue account to "
                "properly reflect the impact of "
                "discounts on your financial "
                "statements.",
                "example": "460000000011105",
                "type": "string",
            },
            "documents": {
                "description": "Array of documents attached to the purchase order.",
                "items": {
                    "properties": {
                        "document_id": {
                            "description": "ID of the Document",
                            "format": "int64",
                            "type": "integer",
                        },
                        "file_name": {
                            "description": "Name "
                            "of "
                            "the "
                            "attached "
                            "document "
                            "file. "
                            "Includes "
                            "file "
                            "extension "
                            "and "
                            "represents "
                            "the "
                            "original "
                            "filename "
                            "as "
                            "uploaded. "
                            "Used "
                            "for "
                            "display "
                            "purposes "
                            "and "
                            "file "
                            "identification "
                            "in "
                            "the "
                            "system.",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "due_date": {
                "description": "The expected delivery date when the goods "
                "or services ordered in this purchase "
                "order should be received. This date is "
                "used for planning, scheduling, and "
                "tracking deliveries. It helps in managing "
                "inventory, coordinating with vendors, and "
                "ensuring timely receipt of ordered items. "
                "The date should be in YYYY-MM-DD format.",
                "type": "string",
            },
            "exchange_rate": {
                "description": "The currency exchange rate used to "
                "convert the purchase order amounts "
                "from the vendor's currency to your "
                "organization's base currency. This "
                "rate is applied when the purchase "
                "order is created in a foreign "
                "currency. A value of 1 indicates the "
                "same currency as your base currency. "
                "This rate affects all monetary "
                "calculations and reporting for this "
                "purchase order.",
                "example": 1,
                "format": "double",
                "type": "number",
            },
            "gst_no": {
                "description": "15 digit GST identification number of the vendor.",
                "example": "22AAAAA0000A1Z5",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "gst_treatment": {
                "description": "Choose whether the contact is GST "
                "registered/unregistered/consumer/overseas. "
                "Allowed values are <code> "
                "business_gst </code> , <code> "
                "business_none </code> , <code> "
                "overseas </code> , <code> consumer "
                "</code>.",
                "example": "business_gst",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "is_discount_before_tax": {
                "description": "Boolean flag that "
                "determines whether the "
                "discount is applied before "
                "or after tax calculations. "
                "When set to true, the "
                "discount is applied to the "
                "subtotal before tax is "
                "calculated, resulting in "
                "tax being calculated on the "
                "discounted amount. When set "
                "to false, the discount is "
                "applied after tax "
                "calculations, which may "
                "affect the final total "
                "differently depending on "
                "your tax configuration.",
                "example": True,
                "type": "boolean",
            },
            "is_inclusive_tax": {
                "description": "Boolean flag that specifies "
                "whether the line item rates "
                "include or exclude tax amounts. "
                "When set to true, the specified "
                "rates are inclusive of tax, "
                "meaning the tax amount is already "
                "included in the rate. When set to "
                "false, the rates are exclusive of "
                "tax, and tax will be calculated "
                "and added separately. This "
                "setting affects how tax "
                "calculations are performed and "
                "displayed on the purchase order.",
                "example": False,
                "type": "boolean",
                "x-node_available_in": [],
                "x-node_unavailable_in": ["us"],
            },
            "is_update_customer": {
                "description": "Check if customer should be updated",
                "type": "string",
            },
            "line_items": {
                "description": "Line items of purchase order.",
                "items": {
                    "properties": {
                        "account_id": {
                            "description": "Unique "
                            "identifier "
                            "of "
                            "the "
                            "accounting "
                            "account "
                            "for "
                            "the "
                            "line "
                            "item. "
                            "Mandatory "
                            "for "
                            "non-inventory "
                            "items/services. "
                            "Determines "
                            "expense "
                            "categorization "
                            "in "
                            "general "
                            "ledger.",
                            "example": "460000000074003",
                            "type": "string",
                        },
                        "acquisition_vat_id": {
                            "description": "ID of the VAT Acquistion",
                            "type": "string",
                            "x-node_available_in": ["uk", "eu"],
                            "x-node_unavailable_in": [],
                        },
                        "description": {
                            "description": "Additional "
                            "details, "
                            "specifications, "
                            "or "
                            "notes "
                            "about "
                            "the "
                            "line "
                            "item. "
                            "Can "
                            "include "
                            "technical "
                            "specs, "
                            "requirements, "
                            "delivery "
                            "instructions. "
                            "Appears "
                            "on "
                            "purchase "
                            "order "
                            "document "
                            "for "
                            "vendor "
                            "reference.",
                            "type": "string",
                        },
                        "hsn_or_sac": {
                            "description": "HSN or SAC Code for the Item",
                            "type": "string",
                            "x-node_available_in": ["in", "ke", "za"],
                            "x-node_unavailable_in": [],
                        },
                        "item_custom_fields": {
                            "items": {
                                "properties": {
                                    "index": {
                                        "description": "Index of the Custom Field",
                                        "example": 1,
                                        "type": "integer",
                                    },
                                    "value": {
                                        "description": "Value of the Custom Field",
                                        "example": "Normal",
                                        "type": "string",
                                    },
                                },
                                "type": "object",
                            },
                            "type": "array",
                        },
                        "item_id": {
                            "description": "Unique "
                            "identifier "
                            "of "
                            "the "
                            "item "
                            "or "
                            "service "
                            "in "
                            "the "
                            "line "
                            "item. "
                            "Mandatory "
                            "field "
                            "that "
                            "links "
                            "to "
                            "the "
                            "item "
                            "catalog. "
                            "Determines "
                            "item "
                            "details, "
                            "pricing, "
                            "and "
                            "inventory "
                            "tracking. "
                            "Obtain "
                            "from "
                            "GET "
                            "/items "
                            "API.",
                            "example": "460000000027009",
                            "type": "string",
                        },
                        "item_order": {
                            "description": "Sequential "
                            "order "
                            "of "
                            "line "
                            "item "
                            "within "
                            "purchase "
                            "order. "
                            "Determines "
                            "display "
                            "order "
                            "on "
                            "documents "
                            "and "
                            "reports. "
                            "Typically "
                            "numbered "
                            "sequentially "
                            "from "
                            "0 "
                            "or "
                            "1. "
                            "Maintains "
                            "consistency "
                            "across "
                            "related "
                            "documents.",
                            "example": 0,
                            "type": "integer",
                        },
                        "location_id": {
                            "description": "Unique "
                            "identifier "
                            "of "
                            "the "
                            "business "
                            "location "
                            "or "
                            "branch "
                            "where "
                            "this "
                            "purchase "
                            "order "
                            "is "
                            "being "
                            "created "
                            "and "
                            "managed. "
                            "This "
                            "field "
                            "is "
                            "used "
                            "to "
                            "associate "
                            "the "
                            "purchase "
                            "order "
                            "with "
                            "a "
                            "specific "
                            "location "
                            "within "
                            "your "
                            "organization, "
                            "enabling "
                            "location-based "
                            "reporting, "
                            "inventory "
                            "tracking, "
                            "and "
                            "multi-location "
                            "business "
                            "operations. "
                            "The "
                            "location "
                            "information "
                            "affects "
                            "how "
                            "the "
                            "purchase "
                            "order "
                            "is "
                            "processed "
                            "and "
                            "where "
                            "inventory "
                            "is "
                            "received.",
                            "example": "460000000038080",
                            "type": "string",
                        },
                        "name": {
                            "description": "Display "
                            "name "
                            "of "
                            "the "
                            "line "
                            "item "
                            "on "
                            "the "
                            "purchase "
                            "order. "
                            "Auto-populated "
                            "from "
                            "item "
                            "catalog "
                            "when "
                            "item_id "
                            "is "
                            "specified. "
                            "Can "
                            "be "
                            "customized. "
                            "Used "
                            "for "
                            "vendor "
                            "reference "
                            "and "
                            "documentation.",
                            "example": "Hard Drive",
                            "type": "string",
                        },
                        "project_id": {
                            "description": "ID of the project",
                            "example": 90300000087378,
                            "type": "string",
                        },
                        "quantity": {
                            "description": "Number "
                            "of "
                            "units "
                            "being "
                            "ordered. "
                            "Used "
                            "with "
                            "rate "
                            "to "
                            "calculate "
                            "total "
                            "line "
                            "item "
                            "amount. "
                            "Must "
                            "match "
                            "unit "
                            "of "
                            "measurement. "
                            "Represents "
                            "actual "
                            "order "
                            "quantity "
                            "for "
                            "delivery.",
                            "example": 1,
                            "type": "string",
                        },
                        "rate": {
                            "description": "Unit "
                            "price "
                            "per "
                            "item/service. "
                            "Used "
                            "to "
                            "calculate "
                            "total "
                            "line "
                            "item "
                            "amount. "
                            "Must "
                            "be in "
                            "purchase "
                            "order "
                            "currency. "
                            "Tax "
                            "inclusion "
                            "depends "
                            "on "
                            "is_inclusive_tax "
                            "setting. "
                            "Affects "
                            "pricing "
                            "calculations "
                            "and "
                            "vendor "
                            "billing.",
                            "example": 112,
                            "format": "double",
                            "type": "number",
                        },
                        "reverse_charge_tax_id": {
                            "description": "Unique "
                            "identifier "
                            "of "
                            "the "
                            "reverse "
                            "charge "
                            "tax "
                            "for "
                            "the "
                            "line "
                            "item. "
                            "Used "
                            "when "
                            "buyer "
                            "is "
                            "responsible "
                            "for "
                            "paying "
                            "tax "
                            "instead "
                            "of "
                            "vendor. "
                            "Applicable "
                            "for "
                            "unregistered "
                            "vendors "
                            "or "
                            "specific "
                            "tax "
                            "regulations. "
                            "Must "
                            "reference "
                            "valid "
                            "reverse "
                            "charge "
                            "tax "
                            "configuration.",
                            "example": 460000000026068,
                            "type": "string",
                        },
                        "reverse_charge_vat_id": {
                            "description": "ID of the Reverse Charge",
                            "type": "string",
                            "x-node_available_in": ["uk", "eu"],
                            "x-node_unavailable_in": [],
                        },
                        "tags": {
                            "items": {
                                "properties": {
                                    "tag_id": {
                                        "description": "ID of the Tag",
                                        "format": "int64",
                                        "type": "integer",
                                    },
                                    "tag_option_id": {
                                        "description": "Id of the Tag Option",
                                        "format": "int64",
                                        "type": "integer",
                                    },
                                },
                                "type": "object",
                            },
                            "type": "array",
                        },
                        "tax_exemption_code": {
                            "description": "Code of the Tax Exemption",
                            "type": "string",
                            "x-node_available_in": ["in", "au", "ca", "mx"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_exemption_id": {
                            "description": "ID of the Tax Exemption",
                            "type": "string",
                            "x-node_available_in": ["in", "au", "ca"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_id": {
                            "description": "Unique "
                            "identifier "
                            "of "
                            "the "
                            "tax "
                            "for "
                            "the "
                            "line "
                            "item. "
                            "Determines "
                            "tax "
                            "rate, "
                            "name, "
                            "and "
                            "treatment "
                            "for "
                            "calculations. "
                            "Used "
                            "in "
                            "tax "
                            "amount "
                            "computation "
                            "and "
                            "display "
                            "on "
                            "purchase "
                            "order. "
                            "Obtain "
                            "from "
                            "taxes "
                            "API.",
                            "type": "string",
                        },
                        "tax_treatment_code": {
                            "description": "Specify "
                            "reason "
                            "for "
                            "using "
                            "out "
                            "of "
                            "scope.</br>Supported "
                            "values "
                            "for "
                            "<b>UAE</b> "
                            "are "
                            "<code>uae_same_tax_group</code>, "
                            "<code>uae_reimbursed_expense</code> "
                            "and "
                            "<code>uae_others</code>.</br> "
                            "Supported "
                            "values "
                            "for "
                            "<b>Bahrain</b> "
                            "are "
                            "<code>bahrain_same_tax_group</code>, "
                            "<code>bahrain_transfer_of_concern</code>, "
                            "<code>bahrain_disbursement</code>, "
                            "<code>bahrain_head_to_branch_transaction</code>, "
                            "<code>bahrain_warranty_repair_services</code> "
                            "and "
                            "<code>bahrain_others</code>.</br> "
                            "Supported "
                            "values "
                            "for "
                            "<b>KSA</b> "
                            "are "
                            "<code>ksa_reimbursed_expense</code>.",
                            "example": "uae_others",
                            "type": "string",
                            "x-node_available_in": ["gcc"],
                            "x-node_unavailable_in": [],
                        },
                        "tds_tax_id": {
                            "example": 90300000087370,
                            "type": "string",
                            "x-node_available_in": ["mx"],
                            "x-node_unavailable_in": [],
                        },
                        "unit": {
                            "description": "Unit "
                            "of "
                            "measurement "
                            "for "
                            "the "
                            "quantity "
                            "(e.g., "
                            "Nos, "
                            "kgs, "
                            "hours, "
                            "meters). "
                            "Should "
                            "match "
                            "vendor "
                            "pricing "
                            "structure. "
                            "Used "
                            "for "
                            "quantity "
                            "calculations "
                            "and "
                            "pricing.",
                            "example": "Nos",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "location_id": {
                "description": "Unique identifier of the business "
                "location or branch where this purchase "
                "order is being created and managed. "
                "This field is used to associate the "
                "purchase order with a specific "
                "location within your organization, "
                "enabling location-based reporting, "
                "inventory tracking, and multi-location "
                "business operations. The location "
                "information affects how the purchase "
                "order is processed and where inventory "
                "is received.",
                "example": "460000000038080",
                "type": "string",
            },
            "notes": {
                "description": "Additional information, instructions, or "
                "comments to be displayed on the purchase "
                "order document. This field is typically used "
                "for delivery instructions, special "
                "requirements, vendor communications, or any "
                "other information relevant to the purchase "
                "order. The notes appear on the purchase "
                "order PDF and are visible to the vendor.",
                "example": "Please deliver as soon as possible.",
                "type": "string",
            },
            "notes_default": {"description": "Default notes for purchase order", "type": "string"},
            "place_of_supply": {
                "description": "The place of supply is where a "
                "transaction is considered to have "
                "occurred for VAT purposes. For the "
                "supply of goods, the place of "
                "supply is the location of the "
                "goods when the supply occurs. For "
                "the supply of services, the place "
                "of supply should be where the "
                "supplier is established. (If not "
                "given, <code>place of "
                "contact</code> given for the "
                "contact will be "
                "taken)<br/>Supported codes for UAE "
                "emirates are : </br>Abu Dhabi - "
                "<code>AB</code>,</br>Ajman - "
                "<code>AJ</code>,</br>Dubai - "
                "<code>DU</code>,</br>Fujairah - "
                "<code>FU</code>,</br>Ras "
                "al-Khaimah - "
                "<code>RA</code>,</br>Sharjah - "
                "<code>SH</code>,</br>Umm al-Quwain "
                "- <code>UM</code>.<br/>Supported "
                "codes for the GCC countries are : "
                "</br>United Arab Emirates - "
                "<code>AE</code>,</br>Saudi Arabia "
                "- <code>SA</code>,</br>Bahrain - "
                "<code>BH</code>,</br>Kuwait - "
                "<code>KW</code>,</br>Oman - "
                "<code>OM</code>,</br>Qatar - "
                "<code>QA</code>.",
                "example": "DU",
                "type": "string",
                "x-node_available_in": ["gcc"],
                "x-node_unavailable_in": [],
            },
            "pricebook_id": {
                "description": "Unique identifier of the pricebook to "
                "be used for this purchase order. The "
                "pricebook contains predefined pricing "
                "information for items and services. "
                "This field is optional and if not "
                "specified, the default pricebook will "
                "be used. You can obtain the pricebook "
                "ID by listing all available "
                "pricebooks in your organization. "
                "Ensure the pricebook exists and "
                "contains the relevant pricing "
                "information before referencing its ID "
                "here.",
                "example": 460000000026089,
                "type": "string",
            },
            "purchaseorder_number": {
                "description": "Unique identifier for the "
                "purchase order. This field is "
                "mandatory when auto number "
                "generation is disabled for "
                "your organization. If auto "
                "numbering is enabled, this "
                "field can be left empty as "
                "the system will automatically "
                "generate a sequential "
                "purchase order number. When "
                "manually specifying a number, "
                "ensure it follows your "
                "organization's numbering "
                "convention and is unique "
                "across all purchase orders.",
                "example": "PO-00001",
                "type": "string",
            },
            "reference_number": {
                "description": "External reference number or "
                "identifier for the purchase "
                "order. This field is optional and "
                "can be used to store additional "
                "reference information such as "
                "vendor order numbers, internal "
                "tracking codes, or any other "
                "external system identifiers. This "
                "reference number will be "
                "displayed on the purchase order "
                "document and can be used for "
                "cross-referencing with external "
                "systems or internal tracking "
                "purposes.",
                "example": "ER/0034",
                "type": "string",
            },
            "salesorder_id": {
                "description": "Unique identifier of the sales order "
                "that is linked to this purchase "
                "order. This field establishes a "
                "connection between the sales order "
                "and purchase order, typically used "
                "in drop-shipping scenarios where you "
                "need to procure items to fulfill a "
                "customer's sales order. The linked "
                "sales order information may be "
                "displayed on the purchase order for "
                "vendor reference and internal "
                "tracking purposes.",
                "example": "460000124728314",
                "format": "int64",
                "type": "integer",
            },
            "ship_via": {"description": "Shipment Preference", "type": "string"},
            "source_of_supply": {
                "description": "Place from where the "
                "goods/services are supplied. (If "
                "not given, <code>place of "
                "contact</code> given for the "
                "contact will be taken)",
                "example": "AP",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "tax_treatment": {
                "description": "VAT treatment for the purchase "
                "order. Choose whether the vendor "
                "falls under: "
                "<code>vat_registered</code>,<code>vat_not_registered</code>,<code>gcc_vat_not_registered</code>,<code>gcc_vat_registered</code>,<code>non_gcc</code>.</br><code>dz_vat_registered</code> "
                "and "
                "<code>dz_vat_not_registered</code> "
                "are supported only for "
                "<b>UAE</b>.</b></br><code>home_country_mexico</code>,<code>border_region_mexico</code>,<code>non_mexico</code> "
                "supported only for "
                "<b>MX</b>.<br/><b>For Kenya "
                "Edition:</b> "
                "<code>vat_registered</code> "
                ",<code>vat_not_registered</code> "
                ",<code>non_kenya</code>(A business "
                "that is located outside "
                "Kenya).<br/><b>For SouthAfrica "
                "Edition:</b> "
                "<code>vat_registered</code>, "
                "<code>vat_not_registered</code>, "
                "<code>overseas</code>(A business "
                "that is located outside "
                "SouthAfrica).",
                "example": "vat_registered",
                "x-node_available_in": ["gcc", "mx", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "template_id": {
                "description": "Unique identifier of the PDF template "
                "linked to the purchase order. Obtain "
                "this value from the `template_id` "
                "field in the response of the GET "
                "`/purchaseorders/templates` API for "
                "your organization. Determines which "
                "template is used for the purchase "
                "order PDF document, controlling the "
                "layout, formatting, and visual "
                "appearance of the generated purchase "
                "order.",
                "example": "460000000011003",
                "type": "string",
            },
            "terms": {
                "description": "Terms and conditions text to be displayed on "
                "the purchase order document. This field is "
                "used to specify payment terms, delivery "
                "conditions, return policies, warranty "
                "information, or any other legal or business "
                "terms that apply to this transaction. The "
                "terms appear on the purchase order PDF and "
                "form part of the contractual agreement with "
                "the vendor.",
                "example": "Thanks for your business.",
                "type": "string",
            },
            "terms_default": {"description": "Default terms for Purchase Orders", "type": "string"},
            "vat_treatment": {
                "description": "(Optional) VAT treatment for the "
                "purchase order. VAT treatment "
                "denotes the location of the vendor, "
                "if the vendor resides in UK then the "
                "VAT treatment is <code>uk</code>. If "
                "the vendor is in an EU country & VAT "
                "registered, you are resides in "
                "Northen Ireland and purchasing Goods "
                "then his VAT treatment is "
                "<code>eu_vat_registered</code> and "
                "if he resides outside the UK then "
                "his VAT treatment is "
                "<code>overseas</code>(For Pre "
                "Brexit, this can be split as "
                "<code>eu_vat_registered</code>, "
                "<code>eu_vat_not_registered</code> "
                "and <code>non_eu</code>).",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
            "vendor_id": {
                "description": "Unique identifier of the vendor for whom "
                "the purchase order is being created. "
                "This value is mandatory to associate the "
                "purchase order with a specific vendor in "
                "your organization. You can obtain the "
                "vendor ID by listing all vendors using "
                "the contacts API. Ensure the vendor "
                "exists before referencing their ID here.",
                "example": "460000000026049",
                "type": "string",
            },
        },
        "required": ["vendor_id", "line_items"],
        "type": "object",
    },
    "UPDATEPURCHASEORDERBYCUSTOMFIELD_REQUEST_BODY_SCHEMA": {
        "properties": {
            "attention": {
                "description": "The name or designation of the specific "
                "person who should be contacted or "
                "notified regarding the delivery of goods "
                "or services from this purchase order. "
                "This field is typically used to specify "
                "the primary contact person at the "
                "delivery location, such as a warehouse "
                "manager, office administrator, or "
                "project coordinator who will receive and "
                "process the delivered items.",
                "type": "string",
            },
            "billing_address_id": {
                "description": "Unique identifier of the "
                "billing address to be used for "
                "this purchase order. The "
                "billing address determines "
                "where invoices and related "
                "documents will be sent. This "
                "field is optional and if not "
                "specified, the default billing "
                "address from your organization "
                "settings will be used. You can "
                "obtain the billing address ID "
                "by listing all available "
                "addresses in your organization. "
                "Ensure the address exists and "
                "contains the correct billing "
                "information before referencing "
                "its ID here.",
                "example": "460000000017491",
                "format": "int64",
                "type": "integer",
            },
            "contact_persons_associated": {
                "description": "Contact Persons associated with the transaction.",
                "items": {
                    "properties": {
                        "communication_preference": {
                            "description": "Preferred "
                            "modes "
                            "of "
                            "communication "
                            "for "
                            "the "
                            "contact "
                            "person "
                            "at "
                            "transaction "
                            "level.",
                            "properties": {
                                "is_email_enabled": {
                                    "description": "Used "
                                    "to "
                                    "check "
                                    "if "
                                    "Email "
                                    "communication "
                                    "preference "
                                    "is "
                                    "enabled "
                                    "for "
                                    "the "
                                    "contact "
                                    "person "
                                    "at "
                                    "transaction "
                                    "level.",
                                    "example": True,
                                    "type": "boolean",
                                },
                                "is_whatsapp_enabled": {
                                    "description": "Used "
                                    "to "
                                    "check "
                                    "if "
                                    "WhatsApp "
                                    "communication "
                                    "preference "
                                    "is "
                                    "enabled "
                                    "for "
                                    "the "
                                    "contact "
                                    "person "
                                    "at "
                                    "transaction "
                                    "level.",
                                    "example": True,
                                    "type": "boolean",
                                    "x-node_available_in": ["WhatsApp integration"],
                                },
                            },
                            "type": "object",
                        },
                        "contact_person_id": {
                            "description": "Unique ID of the Contact Person",
                            "example": 460000000031001,
                            "format": "int64",
                            "type": "integer",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "crm_custom_reference_id": {
                "description": "ID of CRM Custom Reference",
                "format": "int64",
                "type": "integer",
            },
            "crm_owner_id": {
                "description": "Unique identifier of the CRM owner "
                "assigned to this purchase order. This "
                "field links the purchase order to a "
                "specific CRM user who is responsible "
                "for managing the vendor relationship "
                "and overseeing the procurement "
                "process. The CRM owner can track, "
                "follow up, and manage all aspects of "
                "this purchase order within the CRM "
                "system.",
                "type": "string",
            },
            "currency_id": {
                "description": "Unique identifier of the currency for "
                "the purchase order. This value is "
                "mandatory to specify the currency in "
                "which the purchase order amounts will "
                "be displayed and processed. You can "
                "obtain the currency ID by listing all "
                "available currencies using the GET "
                "/settings/currencies API. Ensure the "
                "currency exists and is properly "
                "configured in your organization before "
                "referencing its ID here.",
                "example": "460000000000099",
                "type": "string",
            },
            "custom_fields": {
                "description": "Custom fields for purchase order.",
                "items": {
                    "properties": {
                        "customfield_id": {
                            "example": "46000000012845",
                            "format": "int64",
                            "type": "integer",
                        },
                        "value": {
                            "description": "Value of the Custom Field",
                            "example": "Normal",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "date": {
                "description": "The date when the purchase order was created "
                "or issued. This is the official date that "
                "appears on the purchase order document and is "
                "used for record-keeping, reporting, and "
                "tracking purposes. The date should be in "
                "YYYY-MM-DD format and typically represents "
                "when the purchase order was authorized and "
                "sent to the vendor.",
                "example": "2014-02-10",
                "type": "string",
            },
            "delivery_customer_id": {
                "description": "Unique identifier of the "
                "customer for whom the goods "
                "or services in this purchase "
                "order are being procured. "
                "This field is used when the "
                "purchase order is created on "
                "behalf of a customer, such as "
                "in drop-shipping scenarios or "
                "when procuring items for "
                "specific customer projects. "
                "The customer information may "
                "be displayed on the purchase "
                "order for vendor reference.",
                "type": "string",
            },
            "delivery_date": {
                "description": "The expected delivery date when the "
                "goods or services ordered in this "
                "purchase order should be received. "
                "This date is used for planning, "
                "scheduling, and tracking deliveries. "
                "It helps in managing inventory, "
                "coordinating with vendors, and "
                "ensuring timely receipt of ordered "
                "items. The date should be in "
                "YYYY-MM-DD format and is typically "
                "communicated to the vendor as part "
                "of the purchase order terms.",
                "example": "2014-02-10",
                "type": "string",
            },
            "delivery_org_address_id": {
                "description": "Unique identifier of the "
                "organization address where "
                "the goods or services from "
                "this purchase order should "
                "be delivered. This field "
                "specifies the delivery "
                "location within your "
                "organization, such as a "
                "warehouse, office, or "
                "branch location. The "
                "address details are "
                "retrieved from your "
                "organization's address "
                "book and displayed on the "
                "purchase order for vendor "
                "reference.",
                "type": "string",
            },
            "destination_of_supply": {
                "description": "Place where the "
                "goods/services are supplied "
                "to. (If not given, "
                "organisation's home state "
                "will be taken)",
                "example": "TN",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "discount": {
                "description": "The discount amount or percentage to be "
                "applied to the purchase order total. This "
                "can be specified as a fixed amount or "
                "percentage value. Discounts are typically "
                "offered by vendors for bulk purchases, "
                "early payments, or promotional purposes. "
                "The discount reduces the total amount "
                "payable and affects the final purchase "
                "order total.",
                "example": "10",
                "type": "string",
            },
            "discount_account_id": {
                "description": "Unique identifier of the "
                "accounting account where the "
                "discount amount will be "
                "recorded. This account is used "
                "to track and categorize "
                "discount expenses in your "
                "general ledger. The discount "
                "account should be configured "
                "as an expense or "
                "contra-revenue account to "
                "properly reflect the impact of "
                "discounts on your financial "
                "statements.",
                "example": "460000000011105",
                "type": "string",
            },
            "documents": {
                "description": "Array of documents attached to the purchase order.",
                "items": {
                    "properties": {
                        "document_id": {
                            "description": "ID of the Document",
                            "format": "int64",
                            "type": "integer",
                        },
                        "file_name": {
                            "description": "Name "
                            "of "
                            "the "
                            "attached "
                            "document "
                            "file. "
                            "Includes "
                            "file "
                            "extension "
                            "and "
                            "represents "
                            "the "
                            "original "
                            "filename "
                            "as "
                            "uploaded. "
                            "Used "
                            "for "
                            "display "
                            "purposes "
                            "and "
                            "file "
                            "identification "
                            "in "
                            "the "
                            "system.",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "due_date": {
                "description": "The expected delivery date when the goods "
                "or services ordered in this purchase "
                "order should be received. This date is "
                "used for planning, scheduling, and "
                "tracking deliveries. It helps in managing "
                "inventory, coordinating with vendors, and "
                "ensuring timely receipt of ordered items. "
                "The date should be in YYYY-MM-DD format.",
                "type": "string",
            },
            "exchange_rate": {
                "description": "The currency exchange rate used to "
                "convert the purchase order amounts "
                "from the vendor's currency to your "
                "organization's base currency. This "
                "rate is applied when the purchase "
                "order is created in a foreign "
                "currency. A value of 1 indicates the "
                "same currency as your base currency. "
                "This rate affects all monetary "
                "calculations and reporting for this "
                "purchase order.",
                "example": 1,
                "format": "double",
                "type": "number",
            },
            "gst_no": {
                "description": "15 digit GST identification number of the vendor.",
                "example": "22AAAAA0000A1Z5",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "gst_treatment": {
                "description": "Choose whether the contact is GST "
                "registered/unregistered/consumer/overseas. "
                "Allowed values are <code> "
                "business_gst </code> , <code> "
                "business_none </code> , <code> "
                "overseas </code> , <code> consumer "
                "</code>.",
                "example": "business_gst",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "is_discount_before_tax": {
                "description": "Boolean flag that "
                "determines whether the "
                "discount is applied before "
                "or after tax calculations. "
                "When set to true, the "
                "discount is applied to the "
                "subtotal before tax is "
                "calculated, resulting in "
                "tax being calculated on the "
                "discounted amount. When set "
                "to false, the discount is "
                "applied after tax "
                "calculations, which may "
                "affect the final total "
                "differently depending on "
                "your tax configuration.",
                "example": True,
                "type": "boolean",
            },
            "is_inclusive_tax": {
                "description": "Boolean flag that specifies "
                "whether the line item rates "
                "include or exclude tax amounts. "
                "When set to true, the specified "
                "rates are inclusive of tax, "
                "meaning the tax amount is already "
                "included in the rate. When set to "
                "false, the rates are exclusive of "
                "tax, and tax will be calculated "
                "and added separately. This "
                "setting affects how tax "
                "calculations are performed and "
                "displayed on the purchase order.",
                "example": False,
                "type": "boolean",
                "x-node_available_in": [],
                "x-node_unavailable_in": ["us"],
            },
            "is_update_customer": {
                "description": "Check if customer should be updated",
                "type": "string",
            },
            "line_items": {
                "description": "Line items of purchase order.",
                "items": {
                    "properties": {
                        "account_id": {
                            "description": "Unique "
                            "identifier "
                            "of "
                            "the "
                            "accounting "
                            "account "
                            "for "
                            "the "
                            "line "
                            "item. "
                            "Mandatory "
                            "for "
                            "non-inventory "
                            "items/services. "
                            "Determines "
                            "expense "
                            "categorization "
                            "in "
                            "general "
                            "ledger.",
                            "example": "460000000074003",
                            "type": "string",
                        },
                        "acquisition_vat_id": {
                            "description": "ID of the VAT Acquistion",
                            "type": "string",
                            "x-node_available_in": ["uk", "eu"],
                            "x-node_unavailable_in": [],
                        },
                        "description": {
                            "description": "Additional "
                            "details, "
                            "specifications, "
                            "or "
                            "notes "
                            "about "
                            "the "
                            "line "
                            "item. "
                            "Can "
                            "include "
                            "technical "
                            "specs, "
                            "requirements, "
                            "delivery "
                            "instructions. "
                            "Appears "
                            "on "
                            "purchase "
                            "order "
                            "document "
                            "for "
                            "vendor "
                            "reference.",
                            "type": "string",
                        },
                        "hsn_or_sac": {
                            "description": "HSN or SAC Code for the Item",
                            "type": "string",
                            "x-node_available_in": ["in", "ke", "za"],
                            "x-node_unavailable_in": [],
                        },
                        "item_custom_fields": {
                            "items": {
                                "properties": {
                                    "index": {
                                        "description": "Index of the Custom Field",
                                        "example": 1,
                                        "type": "integer",
                                    },
                                    "value": {
                                        "description": "Value of the Custom Field",
                                        "example": "Normal",
                                        "type": "string",
                                    },
                                },
                                "type": "object",
                            },
                            "type": "array",
                        },
                        "item_id": {
                            "description": "Unique "
                            "identifier "
                            "of "
                            "the "
                            "item "
                            "or "
                            "service "
                            "in "
                            "the "
                            "line "
                            "item. "
                            "Mandatory "
                            "field "
                            "that "
                            "links "
                            "to "
                            "the "
                            "item "
                            "catalog. "
                            "Determines "
                            "item "
                            "details, "
                            "pricing, "
                            "and "
                            "inventory "
                            "tracking. "
                            "Obtain "
                            "from "
                            "GET "
                            "/items "
                            "API.",
                            "example": "460000000027009",
                            "type": "string",
                        },
                        "item_order": {
                            "description": "Sequential "
                            "order "
                            "of "
                            "line "
                            "item "
                            "within "
                            "purchase "
                            "order. "
                            "Determines "
                            "display "
                            "order "
                            "on "
                            "documents "
                            "and "
                            "reports. "
                            "Typically "
                            "numbered "
                            "sequentially "
                            "from "
                            "0 "
                            "or "
                            "1. "
                            "Maintains "
                            "consistency "
                            "across "
                            "related "
                            "documents.",
                            "example": 0,
                            "type": "integer",
                        },
                        "line_item_id": {
                            "description": "ID "
                            "of "
                            "the "
                            "line "
                            "item. "
                            "Mandatory "
                            "if "
                            "the "
                            "existing "
                            "line "
                            "item "
                            "has "
                            "to "
                            "be "
                            "updated. "
                            "If "
                            "empty, "
                            "a "
                            "new "
                            "line "
                            "item "
                            "will "
                            "be "
                            "created.",
                            "example": "460000000074009",
                            "type": "string",
                        },
                        "location_id": {
                            "description": "Unique "
                            "identifier "
                            "of "
                            "the "
                            "business "
                            "location "
                            "or "
                            "branch "
                            "where "
                            "this "
                            "purchase "
                            "order "
                            "is "
                            "being "
                            "created "
                            "and "
                            "managed. "
                            "This "
                            "field "
                            "is "
                            "used "
                            "to "
                            "associate "
                            "the "
                            "purchase "
                            "order "
                            "with "
                            "a "
                            "specific "
                            "location "
                            "within "
                            "your "
                            "organization, "
                            "enabling "
                            "location-based "
                            "reporting, "
                            "inventory "
                            "tracking, "
                            "and "
                            "multi-location "
                            "business "
                            "operations. "
                            "The "
                            "location "
                            "information "
                            "affects "
                            "how "
                            "the "
                            "purchase "
                            "order "
                            "is "
                            "processed "
                            "and "
                            "where "
                            "inventory "
                            "is "
                            "received.",
                            "example": "460000000038080",
                            "type": "string",
                        },
                        "name": {
                            "description": "Display "
                            "name "
                            "of "
                            "the "
                            "line "
                            "item "
                            "on "
                            "the "
                            "purchase "
                            "order. "
                            "Auto-populated "
                            "from "
                            "item "
                            "catalog "
                            "when "
                            "item_id "
                            "is "
                            "specified. "
                            "Can "
                            "be "
                            "customized. "
                            "Used "
                            "for "
                            "vendor "
                            "reference "
                            "and "
                            "documentation.",
                            "example": "Hard Drive",
                            "type": "string",
                        },
                        "project_id": {
                            "description": "ID of the project",
                            "example": 90300000087378,
                            "type": "string",
                        },
                        "quantity": {
                            "description": "Number "
                            "of "
                            "units "
                            "being "
                            "ordered. "
                            "Used "
                            "with "
                            "rate "
                            "to "
                            "calculate "
                            "total "
                            "line "
                            "item "
                            "amount. "
                            "Must "
                            "match "
                            "unit "
                            "of "
                            "measurement. "
                            "Represents "
                            "actual "
                            "order "
                            "quantity "
                            "for "
                            "delivery.",
                            "example": 1,
                            "type": "string",
                        },
                        "rate": {
                            "description": "Unit "
                            "price "
                            "per "
                            "item/service. "
                            "Used "
                            "to "
                            "calculate "
                            "total "
                            "line "
                            "item "
                            "amount. "
                            "Must "
                            "be in "
                            "purchase "
                            "order "
                            "currency. "
                            "Tax "
                            "inclusion "
                            "depends "
                            "on "
                            "is_inclusive_tax "
                            "setting. "
                            "Affects "
                            "pricing "
                            "calculations "
                            "and "
                            "vendor "
                            "billing.",
                            "example": 112,
                            "format": "double",
                            "type": "number",
                        },
                        "reverse_charge_tax_id": {
                            "description": "Unique "
                            "identifier "
                            "of "
                            "the "
                            "reverse "
                            "charge "
                            "tax "
                            "for "
                            "the "
                            "line "
                            "item. "
                            "Used "
                            "when "
                            "buyer "
                            "is "
                            "responsible "
                            "for "
                            "paying "
                            "tax "
                            "instead "
                            "of "
                            "vendor. "
                            "Applicable "
                            "for "
                            "unregistered "
                            "vendors "
                            "or "
                            "specific "
                            "tax "
                            "regulations. "
                            "Must "
                            "reference "
                            "valid "
                            "reverse "
                            "charge "
                            "tax "
                            "configuration.",
                            "example": 460000000026068,
                            "type": "string",
                        },
                        "reverse_charge_vat_id": {
                            "description": "ID of the Reverse Charge",
                            "type": "string",
                            "x-node_available_in": ["uk", "eu"],
                            "x-node_unavailable_in": [],
                        },
                        "tags": {
                            "items": {
                                "properties": {
                                    "tag_id": {
                                        "description": "ID of the Tag",
                                        "format": "int64",
                                        "type": "integer",
                                    },
                                    "tag_option_id": {
                                        "description": "Id of the Tag Option",
                                        "format": "int64",
                                        "type": "integer",
                                    },
                                },
                                "type": "object",
                            },
                            "type": "array",
                        },
                        "tax_exemption_code": {
                            "description": "Code of the Tax Exemption",
                            "type": "string",
                            "x-node_available_in": ["in", "au", "ca", "mx"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_exemption_id": {
                            "description": "ID of the Tax Exemption",
                            "type": "string",
                            "x-node_available_in": ["in", "au", "ca"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_id": {
                            "description": "Unique "
                            "identifier "
                            "of "
                            "the "
                            "tax "
                            "for "
                            "the "
                            "line "
                            "item. "
                            "Determines "
                            "tax "
                            "rate, "
                            "name, "
                            "and "
                            "treatment "
                            "for "
                            "calculations. "
                            "Used "
                            "in "
                            "tax "
                            "amount "
                            "computation "
                            "and "
                            "display "
                            "on "
                            "purchase "
                            "order. "
                            "Obtain "
                            "from "
                            "taxes "
                            "API.",
                            "type": "string",
                        },
                        "tax_treatment_code": {
                            "description": "Specify "
                            "reason "
                            "for "
                            "using "
                            "out "
                            "of "
                            "scope.</br>Supported "
                            "values "
                            "for "
                            "<b>UAE</b> "
                            "are "
                            "<code>uae_same_tax_group</code>, "
                            "<code>uae_reimbursed_expense</code> "
                            "and "
                            "<code>uae_others</code>.</br> "
                            "Supported "
                            "values "
                            "for "
                            "<b>Bahrain</b> "
                            "are "
                            "<code>bahrain_same_tax_group</code>, "
                            "<code>bahrain_transfer_of_concern</code>, "
                            "<code>bahrain_disbursement</code>, "
                            "<code>bahrain_head_to_branch_transaction</code>, "
                            "<code>bahrain_warranty_repair_services</code> "
                            "and "
                            "<code>bahrain_others</code>.</br> "
                            "Supported "
                            "values "
                            "for "
                            "<b>KSA</b> "
                            "are "
                            "<code>ksa_reimbursed_expense</code>.",
                            "example": "uae_others",
                            "type": "string",
                            "x-node_available_in": ["gcc"],
                            "x-node_unavailable_in": [],
                        },
                        "tds_tax_id": {
                            "example": 90300000087370,
                            "type": "string",
                            "x-node_available_in": ["mx"],
                            "x-node_unavailable_in": [],
                        },
                        "unit": {
                            "description": "Unit "
                            "of "
                            "measurement "
                            "for "
                            "the "
                            "quantity "
                            "(e.g., "
                            "Nos, "
                            "kgs, "
                            "hours, "
                            "meters). "
                            "Should "
                            "match "
                            "vendor "
                            "pricing "
                            "structure. "
                            "Used "
                            "for "
                            "quantity "
                            "calculations "
                            "and "
                            "pricing.",
                            "example": "Nos",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "location_id": {
                "description": "Unique identifier of the business "
                "location or branch where this purchase "
                "order is being created and managed. "
                "This field is used to associate the "
                "purchase order with a specific "
                "location within your organization, "
                "enabling location-based reporting, "
                "inventory tracking, and multi-location "
                "business operations. The location "
                "information affects how the purchase "
                "order is processed and where inventory "
                "is received.",
                "example": "460000000038080",
                "type": "string",
            },
            "notes": {
                "description": "Additional information, instructions, or "
                "comments to be displayed on the purchase "
                "order document. This field is typically used "
                "for delivery instructions, special "
                "requirements, vendor communications, or any "
                "other information relevant to the purchase "
                "order. The notes appear on the purchase "
                "order PDF and are visible to the vendor.",
                "example": "Please deliver as soon as possible.",
                "type": "string",
            },
            "notes_default": {"description": "Default notes for purchase order", "type": "string"},
            "place_of_supply": {
                "description": "The place of supply is where a "
                "transaction is considered to have "
                "occurred for VAT purposes. For the "
                "supply of goods, the place of "
                "supply is the location of the "
                "goods when the supply occurs. For "
                "the supply of services, the place "
                "of supply should be where the "
                "supplier is established. (If not "
                "given, <code>place of "
                "contact</code> given for the "
                "contact will be "
                "taken)<br/>Supported codes for UAE "
                "emirates are : </br>Abu Dhabi - "
                "<code>AB</code>,</br>Ajman - "
                "<code>AJ</code>,</br>Dubai - "
                "<code>DU</code>,</br>Fujairah - "
                "<code>FU</code>,</br>Ras "
                "al-Khaimah - "
                "<code>RA</code>,</br>Sharjah - "
                "<code>SH</code>,</br>Umm al-Quwain "
                "- <code>UM</code>.<br/>Supported "
                "codes for the GCC countries are : "
                "</br>United Arab Emirates - "
                "<code>AE</code>,</br>Saudi Arabia "
                "- <code>SA</code>,</br>Bahrain - "
                "<code>BH</code>,</br>Kuwait - "
                "<code>KW</code>,</br>Oman - "
                "<code>OM</code>,</br>Qatar - "
                "<code>QA</code>.",
                "example": "DU",
                "type": "string",
                "x-node_available_in": ["gcc"],
                "x-node_unavailable_in": [],
            },
            "pricebook_id": {
                "description": "Unique identifier of the pricebook to "
                "be used for this purchase order. The "
                "pricebook contains predefined pricing "
                "information for items and services. "
                "This field is optional and if not "
                "specified, the default pricebook will "
                "be used. You can obtain the pricebook "
                "ID by listing all available "
                "pricebooks in your organization. "
                "Ensure the pricebook exists and "
                "contains the relevant pricing "
                "information before referencing its ID "
                "here.",
                "example": 460000000026089,
                "type": "string",
            },
            "purchaseorder_number": {
                "description": "Unique identifier for the "
                "purchase order. This field is "
                "mandatory when auto number "
                "generation is disabled for "
                "your organization. If auto "
                "numbering is enabled, this "
                "field can be left empty as "
                "the system will automatically "
                "generate a sequential "
                "purchase order number. When "
                "manually specifying a number, "
                "ensure it follows your "
                "organization's numbering "
                "convention and is unique "
                "across all purchase orders.",
                "example": "PO-00001",
                "type": "string",
            },
            "reference_number": {
                "description": "External reference number or "
                "identifier for the purchase "
                "order. This field is optional and "
                "can be used to store additional "
                "reference information such as "
                "vendor order numbers, internal "
                "tracking codes, or any other "
                "external system identifiers. This "
                "reference number will be "
                "displayed on the purchase order "
                "document and can be used for "
                "cross-referencing with external "
                "systems or internal tracking "
                "purposes.",
                "example": "ER/0034",
                "type": "string",
            },
            "salesorder_id": {
                "description": "Unique identifier of the sales order "
                "that is linked to this purchase "
                "order. This field establishes a "
                "connection between the sales order "
                "and purchase order, typically used "
                "in drop-shipping scenarios where you "
                "need to procure items to fulfill a "
                "customer's sales order. The linked "
                "sales order information may be "
                "displayed on the purchase order for "
                "vendor reference and internal "
                "tracking purposes.",
                "example": "460000124728314",
                "format": "int64",
                "type": "integer",
            },
            "ship_via": {"description": "Shipment Preference", "type": "string"},
            "source_of_supply": {
                "description": "Place from where the "
                "goods/services are supplied. (If "
                "not given, <code>place of "
                "contact</code> given for the "
                "contact will be taken)",
                "example": "AP",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "tax_treatment": {
                "description": "VAT treatment for the purchase "
                "order. Choose whether the vendor "
                "falls under: "
                "<code>vat_registered</code>,<code>vat_not_registered</code>,<code>gcc_vat_not_registered</code>,<code>gcc_vat_registered</code>,<code>non_gcc</code>.</br><code>dz_vat_registered</code> "
                "and "
                "<code>dz_vat_not_registered</code> "
                "are supported only for "
                "<b>UAE</b>.</b></br><code>home_country_mexico</code>,<code>border_region_mexico</code>,<code>non_mexico</code> "
                "supported only for "
                "<b>MX</b>.<br/><b>For Kenya "
                "Edition:</b> "
                "<code>vat_registered</code> "
                ",<code>vat_not_registered</code> "
                ",<code>non_kenya</code>(A business "
                "that is located outside "
                "Kenya).<br/><b>For SouthAfrica "
                "Edition:</b> "
                "<code>vat_registered</code>, "
                "<code>vat_not_registered</code>, "
                "<code>overseas</code>(A business "
                "that is located outside "
                "SouthAfrica).",
                "example": "vat_registered",
                "x-node_available_in": ["gcc", "mx", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "template_id": {
                "description": "Unique identifier of the PDF template "
                "linked to the purchase order. Obtain "
                "this value from the `template_id` "
                "field in the response of the GET "
                "`/purchaseorders/templates` API for "
                "your organization. Determines which "
                "template is used for the purchase "
                "order PDF document, controlling the "
                "layout, formatting, and visual "
                "appearance of the generated purchase "
                "order.",
                "example": "460000000011003",
                "type": "string",
            },
            "terms": {
                "description": "Terms and conditions text to be displayed on "
                "the purchase order document. This field is "
                "used to specify payment terms, delivery "
                "conditions, return policies, warranty "
                "information, or any other legal or business "
                "terms that apply to this transaction. The "
                "terms appear on the purchase order PDF and "
                "form part of the contractual agreement with "
                "the vendor.",
                "example": "Thanks for your business.",
                "type": "string",
            },
            "terms_default": {"description": "Default terms for Purchase Orders", "type": "string"},
            "vat_treatment": {
                "description": "(Optional) VAT treatment for the "
                "purchase order. VAT treatment "
                "denotes the location of the vendor, "
                "if the vendor resides in UK then the "
                "VAT treatment is <code>uk</code>. If "
                "the vendor is in an EU country & VAT "
                "registered, you are resides in "
                "Northen Ireland and purchasing Goods "
                "then his VAT treatment is "
                "<code>eu_vat_registered</code> and "
                "if he resides outside the UK then "
                "his VAT treatment is "
                "<code>overseas</code>(For Pre "
                "Brexit, this can be split as "
                "<code>eu_vat_registered</code>, "
                "<code>eu_vat_not_registered</code> "
                "and <code>non_eu</code>).",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
            "vendor_id": {
                "description": "Unique identifier of the vendor for whom "
                "the purchase order is being created. "
                "This value is mandatory to associate the "
                "purchase order with a specific vendor in "
                "your organization. You can obtain the "
                "vendor ID by listing all vendors using "
                "the contacts API. Ensure the vendor "
                "exists before referencing their ID here.",
                "example": "460000000026049",
                "type": "string",
            },
        },
        "required": ["vendor_id", "line_items"],
        "type": "object",
    },
    "UPDATEPURCHASEORDER_REQUEST_BODY_SCHEMA": {
        "properties": {
            "attention": {
                "description": "The name or designation of the specific "
                "person who should be contacted or "
                "notified regarding the delivery of goods "
                "or services from this purchase order. "
                "This field is typically used to specify "
                "the primary contact person at the "
                "delivery location, such as a warehouse "
                "manager, office administrator, or "
                "project coordinator who will receive and "
                "process the delivered items.",
                "type": "string",
            },
            "billing_address_id": {
                "description": "Unique identifier of the "
                "billing address to be used for "
                "this purchase order. The "
                "billing address determines "
                "where invoices and related "
                "documents will be sent. This "
                "field is optional and if not "
                "specified, the default billing "
                "address from your organization "
                "settings will be used. You can "
                "obtain the billing address ID "
                "by listing all available "
                "addresses in your organization. "
                "Ensure the address exists and "
                "contains the correct billing "
                "information before referencing "
                "its ID here.",
                "example": "460000000017491",
                "format": "int64",
                "type": "integer",
            },
            "contact_persons_associated": {
                "description": "Contact Persons associated with the transaction.",
                "items": {
                    "properties": {
                        "communication_preference": {
                            "description": "Preferred "
                            "modes "
                            "of "
                            "communication "
                            "for "
                            "the "
                            "contact "
                            "person "
                            "at "
                            "transaction "
                            "level.",
                            "properties": {
                                "is_email_enabled": {
                                    "description": "Used "
                                    "to "
                                    "check "
                                    "if "
                                    "Email "
                                    "communication "
                                    "preference "
                                    "is "
                                    "enabled "
                                    "for "
                                    "the "
                                    "contact "
                                    "person "
                                    "at "
                                    "transaction "
                                    "level.",
                                    "example": True,
                                    "type": "boolean",
                                },
                                "is_whatsapp_enabled": {
                                    "description": "Used "
                                    "to "
                                    "check "
                                    "if "
                                    "WhatsApp "
                                    "communication "
                                    "preference "
                                    "is "
                                    "enabled "
                                    "for "
                                    "the "
                                    "contact "
                                    "person "
                                    "at "
                                    "transaction "
                                    "level.",
                                    "example": True,
                                    "type": "boolean",
                                    "x-node_available_in": ["WhatsApp integration"],
                                },
                            },
                            "type": "object",
                        },
                        "contact_person_id": {
                            "description": "Unique ID of the Contact Person",
                            "example": 460000000031001,
                            "format": "int64",
                            "type": "integer",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "crm_custom_reference_id": {
                "description": "ID of CRM Custom Reference",
                "format": "int64",
                "type": "integer",
            },
            "crm_owner_id": {
                "description": "Unique identifier of the CRM owner "
                "assigned to this purchase order. This "
                "field links the purchase order to a "
                "specific CRM user who is responsible "
                "for managing the vendor relationship "
                "and overseeing the procurement "
                "process. The CRM owner can track, "
                "follow up, and manage all aspects of "
                "this purchase order within the CRM "
                "system.",
                "type": "string",
            },
            "currency_id": {
                "description": "Unique identifier of the currency for "
                "the purchase order. This value is "
                "mandatory to specify the currency in "
                "which the purchase order amounts will "
                "be displayed and processed. You can "
                "obtain the currency ID by listing all "
                "available currencies using the GET "
                "/settings/currencies API. Ensure the "
                "currency exists and is properly "
                "configured in your organization before "
                "referencing its ID here.",
                "example": "460000000000099",
                "type": "string",
            },
            "custom_fields": {
                "description": "Custom fields for purchase order.",
                "items": {
                    "properties": {
                        "customfield_id": {
                            "example": "46000000012845",
                            "format": "int64",
                            "type": "integer",
                        },
                        "value": {
                            "description": "Value of the Custom Field",
                            "example": "Normal",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "date": {
                "description": "The date when the purchase order was created "
                "or issued. This is the official date that "
                "appears on the purchase order document and is "
                "used for record-keeping, reporting, and "
                "tracking purposes. The date should be in "
                "YYYY-MM-DD format and typically represents "
                "when the purchase order was authorized and "
                "sent to the vendor.",
                "example": "2014-02-10",
                "type": "string",
            },
            "delivery_customer_id": {
                "description": "Unique identifier of the "
                "customer for whom the goods "
                "or services in this purchase "
                "order are being procured. "
                "This field is used when the "
                "purchase order is created on "
                "behalf of a customer, such as "
                "in drop-shipping scenarios or "
                "when procuring items for "
                "specific customer projects. "
                "The customer information may "
                "be displayed on the purchase "
                "order for vendor reference.",
                "type": "string",
            },
            "delivery_date": {
                "description": "The expected delivery date when the "
                "goods or services ordered in this "
                "purchase order should be received. "
                "This date is used for planning, "
                "scheduling, and tracking deliveries. "
                "It helps in managing inventory, "
                "coordinating with vendors, and "
                "ensuring timely receipt of ordered "
                "items. The date should be in "
                "YYYY-MM-DD format and is typically "
                "communicated to the vendor as part "
                "of the purchase order terms.",
                "example": "2014-02-10",
                "type": "string",
            },
            "delivery_org_address_id": {
                "description": "Unique identifier of the "
                "organization address where "
                "the goods or services from "
                "this purchase order should "
                "be delivered. This field "
                "specifies the delivery "
                "location within your "
                "organization, such as a "
                "warehouse, office, or "
                "branch location. The "
                "address details are "
                "retrieved from your "
                "organization's address "
                "book and displayed on the "
                "purchase order for vendor "
                "reference.",
                "type": "string",
            },
            "destination_of_supply": {
                "description": "Place where the "
                "goods/services are supplied "
                "to. (If not given, "
                "organisation's home state "
                "will be taken)",
                "example": "TN",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "discount": {
                "description": "The discount amount or percentage to be "
                "applied to the purchase order total. This "
                "can be specified as a fixed amount or "
                "percentage value. Discounts are typically "
                "offered by vendors for bulk purchases, "
                "early payments, or promotional purposes. "
                "The discount reduces the total amount "
                "payable and affects the final purchase "
                "order total.",
                "example": "10",
                "type": "string",
            },
            "discount_account_id": {
                "description": "Unique identifier of the "
                "accounting account where the "
                "discount amount will be "
                "recorded. This account is used "
                "to track and categorize "
                "discount expenses in your "
                "general ledger. The discount "
                "account should be configured "
                "as an expense or "
                "contra-revenue account to "
                "properly reflect the impact of "
                "discounts on your financial "
                "statements.",
                "example": "460000000011105",
                "type": "string",
            },
            "documents": {
                "description": "Array of documents attached to the purchase order.",
                "items": {
                    "properties": {
                        "document_id": {
                            "description": "ID of the Document",
                            "format": "int64",
                            "type": "integer",
                        },
                        "file_name": {
                            "description": "Name "
                            "of "
                            "the "
                            "attached "
                            "document "
                            "file. "
                            "Includes "
                            "file "
                            "extension "
                            "and "
                            "represents "
                            "the "
                            "original "
                            "filename "
                            "as "
                            "uploaded. "
                            "Used "
                            "for "
                            "display "
                            "purposes "
                            "and "
                            "file "
                            "identification "
                            "in "
                            "the "
                            "system.",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "due_date": {
                "description": "The expected delivery date when the goods "
                "or services ordered in this purchase "
                "order should be received. This date is "
                "used for planning, scheduling, and "
                "tracking deliveries. It helps in managing "
                "inventory, coordinating with vendors, and "
                "ensuring timely receipt of ordered items. "
                "The date should be in YYYY-MM-DD format.",
                "type": "string",
            },
            "exchange_rate": {
                "description": "The currency exchange rate used to "
                "convert the purchase order amounts "
                "from the vendor's currency to your "
                "organization's base currency. This "
                "rate is applied when the purchase "
                "order is created in a foreign "
                "currency. A value of 1 indicates the "
                "same currency as your base currency. "
                "This rate affects all monetary "
                "calculations and reporting for this "
                "purchase order.",
                "example": 1,
                "format": "double",
                "type": "number",
            },
            "gst_no": {
                "description": "15 digit GST identification number of the vendor.",
                "example": "22AAAAA0000A1Z5",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "gst_treatment": {
                "description": "Choose whether the contact is GST "
                "registered/unregistered/consumer/overseas. "
                "Allowed values are <code> "
                "business_gst </code> , <code> "
                "business_none </code> , <code> "
                "overseas </code> , <code> consumer "
                "</code>.",
                "example": "business_gst",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "is_discount_before_tax": {
                "description": "Boolean flag that "
                "determines whether the "
                "discount is applied before "
                "or after tax calculations. "
                "When set to true, the "
                "discount is applied to the "
                "subtotal before tax is "
                "calculated, resulting in "
                "tax being calculated on the "
                "discounted amount. When set "
                "to false, the discount is "
                "applied after tax "
                "calculations, which may "
                "affect the final total "
                "differently depending on "
                "your tax configuration.",
                "example": True,
                "type": "boolean",
            },
            "is_inclusive_tax": {
                "description": "Boolean flag that specifies "
                "whether the line item rates "
                "include or exclude tax amounts. "
                "When set to true, the specified "
                "rates are inclusive of tax, "
                "meaning the tax amount is already "
                "included in the rate. When set to "
                "false, the rates are exclusive of "
                "tax, and tax will be calculated "
                "and added separately. This "
                "setting affects how tax "
                "calculations are performed and "
                "displayed on the purchase order.",
                "example": False,
                "type": "boolean",
                "x-node_available_in": [],
                "x-node_unavailable_in": ["us"],
            },
            "is_update_customer": {
                "description": "Check if customer should be updated",
                "type": "string",
            },
            "line_items": {
                "description": "Line items of purchase order.",
                "items": {
                    "properties": {
                        "account_id": {
                            "description": "Unique "
                            "identifier "
                            "of "
                            "the "
                            "accounting "
                            "account "
                            "for "
                            "the "
                            "line "
                            "item. "
                            "Mandatory "
                            "for "
                            "non-inventory "
                            "items/services. "
                            "Determines "
                            "expense "
                            "categorization "
                            "in "
                            "general "
                            "ledger.",
                            "example": "460000000074003",
                            "type": "string",
                        },
                        "acquisition_vat_id": {
                            "description": "ID of the VAT Acquistion",
                            "type": "string",
                            "x-node_available_in": ["uk", "eu"],
                            "x-node_unavailable_in": [],
                        },
                        "description": {
                            "description": "Additional "
                            "details, "
                            "specifications, "
                            "or "
                            "notes "
                            "about "
                            "the "
                            "line "
                            "item. "
                            "Can "
                            "include "
                            "technical "
                            "specs, "
                            "requirements, "
                            "delivery "
                            "instructions. "
                            "Appears "
                            "on "
                            "purchase "
                            "order "
                            "document "
                            "for "
                            "vendor "
                            "reference.",
                            "type": "string",
                        },
                        "hsn_or_sac": {
                            "description": "HSN or SAC Code for the Item",
                            "type": "string",
                            "x-node_available_in": ["in", "ke", "za"],
                            "x-node_unavailable_in": [],
                        },
                        "item_custom_fields": {
                            "items": {
                                "properties": {
                                    "index": {
                                        "description": "Index of the Custom Field",
                                        "example": 1,
                                        "type": "integer",
                                    },
                                    "value": {
                                        "description": "Value of the Custom Field",
                                        "example": "Normal",
                                        "type": "string",
                                    },
                                },
                                "type": "object",
                            },
                            "type": "array",
                        },
                        "item_id": {
                            "description": "Unique "
                            "identifier "
                            "of "
                            "the "
                            "item "
                            "or "
                            "service "
                            "in "
                            "the "
                            "line "
                            "item. "
                            "Mandatory "
                            "field "
                            "that "
                            "links "
                            "to "
                            "the "
                            "item "
                            "catalog. "
                            "Determines "
                            "item "
                            "details, "
                            "pricing, "
                            "and "
                            "inventory "
                            "tracking. "
                            "Obtain "
                            "from "
                            "GET "
                            "/items "
                            "API.",
                            "example": "460000000027009",
                            "type": "string",
                        },
                        "item_order": {
                            "description": "Sequential "
                            "order "
                            "of "
                            "line "
                            "item "
                            "within "
                            "purchase "
                            "order. "
                            "Determines "
                            "display "
                            "order "
                            "on "
                            "documents "
                            "and "
                            "reports. "
                            "Typically "
                            "numbered "
                            "sequentially "
                            "from "
                            "0 "
                            "or "
                            "1. "
                            "Maintains "
                            "consistency "
                            "across "
                            "related "
                            "documents.",
                            "example": 0,
                            "type": "integer",
                        },
                        "line_item_id": {
                            "description": "ID "
                            "of "
                            "the "
                            "line "
                            "item. "
                            "Mandatory "
                            "if "
                            "the "
                            "existing "
                            "line "
                            "item "
                            "has "
                            "to "
                            "be "
                            "updated. "
                            "If "
                            "empty, "
                            "a "
                            "new "
                            "line "
                            "item "
                            "will "
                            "be "
                            "created.",
                            "example": "460000000074009",
                            "type": "string",
                        },
                        "location_id": {
                            "description": "Unique "
                            "identifier "
                            "of "
                            "the "
                            "business "
                            "location "
                            "or "
                            "branch "
                            "where "
                            "this "
                            "purchase "
                            "order "
                            "is "
                            "being "
                            "created "
                            "and "
                            "managed. "
                            "This "
                            "field "
                            "is "
                            "used "
                            "to "
                            "associate "
                            "the "
                            "purchase "
                            "order "
                            "with "
                            "a "
                            "specific "
                            "location "
                            "within "
                            "your "
                            "organization, "
                            "enabling "
                            "location-based "
                            "reporting, "
                            "inventory "
                            "tracking, "
                            "and "
                            "multi-location "
                            "business "
                            "operations. "
                            "The "
                            "location "
                            "information "
                            "affects "
                            "how "
                            "the "
                            "purchase "
                            "order "
                            "is "
                            "processed "
                            "and "
                            "where "
                            "inventory "
                            "is "
                            "received.",
                            "example": "460000000038080",
                            "type": "string",
                        },
                        "name": {
                            "description": "Display "
                            "name "
                            "of "
                            "the "
                            "line "
                            "item "
                            "on "
                            "the "
                            "purchase "
                            "order. "
                            "Auto-populated "
                            "from "
                            "item "
                            "catalog "
                            "when "
                            "item_id "
                            "is "
                            "specified. "
                            "Can "
                            "be "
                            "customized. "
                            "Used "
                            "for "
                            "vendor "
                            "reference "
                            "and "
                            "documentation.",
                            "example": "Hard Drive",
                            "type": "string",
                        },
                        "project_id": {
                            "description": "ID of the project",
                            "example": 90300000087378,
                            "type": "string",
                        },
                        "quantity": {
                            "description": "Number "
                            "of "
                            "units "
                            "being "
                            "ordered. "
                            "Used "
                            "with "
                            "rate "
                            "to "
                            "calculate "
                            "total "
                            "line "
                            "item "
                            "amount. "
                            "Must "
                            "match "
                            "unit "
                            "of "
                            "measurement. "
                            "Represents "
                            "actual "
                            "order "
                            "quantity "
                            "for "
                            "delivery.",
                            "example": 1,
                            "type": "string",
                        },
                        "rate": {
                            "description": "Unit "
                            "price "
                            "per "
                            "item/service. "
                            "Used "
                            "to "
                            "calculate "
                            "total "
                            "line "
                            "item "
                            "amount. "
                            "Must "
                            "be in "
                            "purchase "
                            "order "
                            "currency. "
                            "Tax "
                            "inclusion "
                            "depends "
                            "on "
                            "is_inclusive_tax "
                            "setting. "
                            "Affects "
                            "pricing "
                            "calculations "
                            "and "
                            "vendor "
                            "billing.",
                            "example": 112,
                            "format": "double",
                            "type": "number",
                        },
                        "reverse_charge_tax_id": {
                            "description": "Unique "
                            "identifier "
                            "of "
                            "the "
                            "reverse "
                            "charge "
                            "tax "
                            "for "
                            "the "
                            "line "
                            "item. "
                            "Used "
                            "when "
                            "buyer "
                            "is "
                            "responsible "
                            "for "
                            "paying "
                            "tax "
                            "instead "
                            "of "
                            "vendor. "
                            "Applicable "
                            "for "
                            "unregistered "
                            "vendors "
                            "or "
                            "specific "
                            "tax "
                            "regulations. "
                            "Must "
                            "reference "
                            "valid "
                            "reverse "
                            "charge "
                            "tax "
                            "configuration.",
                            "example": 460000000026068,
                            "type": "string",
                        },
                        "reverse_charge_vat_id": {
                            "description": "ID of the Reverse Charge",
                            "type": "string",
                            "x-node_available_in": ["uk", "eu"],
                            "x-node_unavailable_in": [],
                        },
                        "tags": {
                            "items": {
                                "properties": {
                                    "tag_id": {
                                        "description": "ID of the Tag",
                                        "format": "int64",
                                        "type": "integer",
                                    },
                                    "tag_option_id": {
                                        "description": "Id of the Tag Option",
                                        "format": "int64",
                                        "type": "integer",
                                    },
                                },
                                "type": "object",
                            },
                            "type": "array",
                        },
                        "tax_exemption_code": {
                            "description": "Code of the Tax Exemption",
                            "type": "string",
                            "x-node_available_in": ["in", "au", "ca", "mx"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_exemption_id": {
                            "description": "ID of the Tax Exemption",
                            "type": "string",
                            "x-node_available_in": ["in", "au", "ca"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_id": {
                            "description": "Unique "
                            "identifier "
                            "of "
                            "the "
                            "tax "
                            "for "
                            "the "
                            "line "
                            "item. "
                            "Determines "
                            "tax "
                            "rate, "
                            "name, "
                            "and "
                            "treatment "
                            "for "
                            "calculations. "
                            "Used "
                            "in "
                            "tax "
                            "amount "
                            "computation "
                            "and "
                            "display "
                            "on "
                            "purchase "
                            "order. "
                            "Obtain "
                            "from "
                            "taxes "
                            "API.",
                            "type": "string",
                        },
                        "tax_treatment_code": {
                            "description": "Specify "
                            "reason "
                            "for "
                            "using "
                            "out "
                            "of "
                            "scope.</br>Supported "
                            "values "
                            "for "
                            "<b>UAE</b> "
                            "are "
                            "<code>uae_same_tax_group</code>, "
                            "<code>uae_reimbursed_expense</code> "
                            "and "
                            "<code>uae_others</code>.</br> "
                            "Supported "
                            "values "
                            "for "
                            "<b>Bahrain</b> "
                            "are "
                            "<code>bahrain_same_tax_group</code>, "
                            "<code>bahrain_transfer_of_concern</code>, "
                            "<code>bahrain_disbursement</code>, "
                            "<code>bahrain_head_to_branch_transaction</code>, "
                            "<code>bahrain_warranty_repair_services</code> "
                            "and "
                            "<code>bahrain_others</code>.</br> "
                            "Supported "
                            "values "
                            "for "
                            "<b>KSA</b> "
                            "are "
                            "<code>ksa_reimbursed_expense</code>.",
                            "example": "uae_others",
                            "type": "string",
                            "x-node_available_in": ["gcc"],
                            "x-node_unavailable_in": [],
                        },
                        "tds_tax_id": {
                            "example": 90300000087370,
                            "type": "string",
                            "x-node_available_in": ["mx"],
                            "x-node_unavailable_in": [],
                        },
                        "unit": {
                            "description": "Unit "
                            "of "
                            "measurement "
                            "for "
                            "the "
                            "quantity "
                            "(e.g., "
                            "Nos, "
                            "kgs, "
                            "hours, "
                            "meters). "
                            "Should "
                            "match "
                            "vendor "
                            "pricing "
                            "structure. "
                            "Used "
                            "for "
                            "quantity "
                            "calculations "
                            "and "
                            "pricing.",
                            "example": "Nos",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "location_id": {
                "description": "Unique identifier of the business "
                "location or branch where this purchase "
                "order is being created and managed. "
                "This field is used to associate the "
                "purchase order with a specific "
                "location within your organization, "
                "enabling location-based reporting, "
                "inventory tracking, and multi-location "
                "business operations. The location "
                "information affects how the purchase "
                "order is processed and where inventory "
                "is received.",
                "example": "460000000038080",
                "type": "string",
            },
            "notes": {
                "description": "Additional information, instructions, or "
                "comments to be displayed on the purchase "
                "order document. This field is typically used "
                "for delivery instructions, special "
                "requirements, vendor communications, or any "
                "other information relevant to the purchase "
                "order. The notes appear on the purchase "
                "order PDF and are visible to the vendor.",
                "example": "Please deliver as soon as possible.",
                "type": "string",
            },
            "notes_default": {"description": "Default notes for purchase order", "type": "string"},
            "place_of_supply": {
                "description": "The place of supply is where a "
                "transaction is considered to have "
                "occurred for VAT purposes. For the "
                "supply of goods, the place of "
                "supply is the location of the "
                "goods when the supply occurs. For "
                "the supply of services, the place "
                "of supply should be where the "
                "supplier is established. (If not "
                "given, <code>place of "
                "contact</code> given for the "
                "contact will be "
                "taken)<br/>Supported codes for UAE "
                "emirates are : </br>Abu Dhabi - "
                "<code>AB</code>,</br>Ajman - "
                "<code>AJ</code>,</br>Dubai - "
                "<code>DU</code>,</br>Fujairah - "
                "<code>FU</code>,</br>Ras "
                "al-Khaimah - "
                "<code>RA</code>,</br>Sharjah - "
                "<code>SH</code>,</br>Umm al-Quwain "
                "- <code>UM</code>.<br/>Supported "
                "codes for the GCC countries are : "
                "</br>United Arab Emirates - "
                "<code>AE</code>,</br>Saudi Arabia "
                "- <code>SA</code>,</br>Bahrain - "
                "<code>BH</code>,</br>Kuwait - "
                "<code>KW</code>,</br>Oman - "
                "<code>OM</code>,</br>Qatar - "
                "<code>QA</code>.",
                "example": "DU",
                "type": "string",
                "x-node_available_in": ["gcc"],
                "x-node_unavailable_in": [],
            },
            "pricebook_id": {
                "description": "Unique identifier of the pricebook to "
                "be used for this purchase order. The "
                "pricebook contains predefined pricing "
                "information for items and services. "
                "This field is optional and if not "
                "specified, the default pricebook will "
                "be used. You can obtain the pricebook "
                "ID by listing all available "
                "pricebooks in your organization. "
                "Ensure the pricebook exists and "
                "contains the relevant pricing "
                "information before referencing its ID "
                "here.",
                "example": 460000000026089,
                "type": "string",
            },
            "purchaseorder_number": {
                "description": "Unique identifier for the "
                "purchase order. This field is "
                "mandatory when auto number "
                "generation is disabled for "
                "your organization. If auto "
                "numbering is enabled, this "
                "field can be left empty as "
                "the system will automatically "
                "generate a sequential "
                "purchase order number. When "
                "manually specifying a number, "
                "ensure it follows your "
                "organization's numbering "
                "convention and is unique "
                "across all purchase orders.",
                "example": "PO-00001",
                "type": "string",
            },
            "reference_number": {
                "description": "External reference number or "
                "identifier for the purchase "
                "order. This field is optional and "
                "can be used to store additional "
                "reference information such as "
                "vendor order numbers, internal "
                "tracking codes, or any other "
                "external system identifiers. This "
                "reference number will be "
                "displayed on the purchase order "
                "document and can be used for "
                "cross-referencing with external "
                "systems or internal tracking "
                "purposes.",
                "example": "ER/0034",
                "type": "string",
            },
            "salesorder_id": {
                "description": "Unique identifier of the sales order "
                "that is linked to this purchase "
                "order. This field establishes a "
                "connection between the sales order "
                "and purchase order, typically used "
                "in drop-shipping scenarios where you "
                "need to procure items to fulfill a "
                "customer's sales order. The linked "
                "sales order information may be "
                "displayed on the purchase order for "
                "vendor reference and internal "
                "tracking purposes.",
                "example": "460000124728314",
                "format": "int64",
                "type": "integer",
            },
            "ship_via": {"description": "Shipment Preference", "type": "string"},
            "source_of_supply": {
                "description": "Place from where the "
                "goods/services are supplied. (If "
                "not given, <code>place of "
                "contact</code> given for the "
                "contact will be taken)",
                "example": "AP",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "tax_treatment": {
                "description": "VAT treatment for the purchase "
                "order. Choose whether the vendor "
                "falls under: "
                "<code>vat_registered</code>,<code>vat_not_registered</code>,<code>gcc_vat_not_registered</code>,<code>gcc_vat_registered</code>,<code>non_gcc</code>.</br><code>dz_vat_registered</code> "
                "and "
                "<code>dz_vat_not_registered</code> "
                "are supported only for "
                "<b>UAE</b>.</b></br><code>home_country_mexico</code>,<code>border_region_mexico</code>,<code>non_mexico</code> "
                "supported only for "
                "<b>MX</b>.<br/><b>For Kenya "
                "Edition:</b> "
                "<code>vat_registered</code> "
                ",<code>vat_not_registered</code> "
                ",<code>non_kenya</code>(A business "
                "that is located outside "
                "Kenya).<br/><b>For SouthAfrica "
                "Edition:</b> "
                "<code>vat_registered</code>, "
                "<code>vat_not_registered</code>, "
                "<code>overseas</code>(A business "
                "that is located outside "
                "SouthAfrica).",
                "example": "vat_registered",
                "x-node_available_in": ["gcc", "mx", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "template_id": {
                "description": "Unique identifier of the PDF template "
                "linked to the purchase order. Obtain "
                "this value from the `template_id` "
                "field in the response of the GET "
                "`/purchaseorders/templates` API for "
                "your organization. Determines which "
                "template is used for the purchase "
                "order PDF document, controlling the "
                "layout, formatting, and visual "
                "appearance of the generated purchase "
                "order.",
                "example": "460000000011003",
                "type": "string",
            },
            "terms": {
                "description": "Terms and conditions text to be displayed on "
                "the purchase order document. This field is "
                "used to specify payment terms, delivery "
                "conditions, return policies, warranty "
                "information, or any other legal or business "
                "terms that apply to this transaction. The "
                "terms appear on the purchase order PDF and "
                "form part of the contractual agreement with "
                "the vendor.",
                "example": "Thanks for your business.",
                "type": "string",
            },
            "terms_default": {"description": "Default terms for Purchase Orders", "type": "string"},
            "vat_treatment": {
                "description": "(Optional) VAT treatment for the "
                "purchase order. VAT treatment "
                "denotes the location of the vendor, "
                "if the vendor resides in UK then the "
                "VAT treatment is <code>uk</code>. If "
                "the vendor is in an EU country & VAT "
                "registered, you are resides in "
                "Northen Ireland and purchasing Goods "
                "then his VAT treatment is "
                "<code>eu_vat_registered</code> and "
                "if he resides outside the UK then "
                "his VAT treatment is "
                "<code>overseas</code>(For Pre "
                "Brexit, this can be split as "
                "<code>eu_vat_registered</code>, "
                "<code>eu_vat_not_registered</code> "
                "and <code>non_eu</code>).",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
            "vendor_id": {
                "description": "Unique identifier of the vendor for whom "
                "the purchase order is being created. "
                "This value is mandatory to associate the "
                "purchase order with a specific vendor in "
                "your organization. You can obtain the "
                "vendor ID by listing all vendors using "
                "the contacts API. Ensure the vendor "
                "exists before referencing their ID here.",
                "example": "460000000026049",
                "type": "string",
            },
        },
        "required": ["vendor_id", "line_items"],
        "type": "object",
    },
    "UPDATECUSTOMFIELDSPURCHASEORDER_REQUEST_BODY_SCHEMA": {
        "description": "Custom fields for purchase order.",
        "items": {
            "properties": {
                "customfield_id": {
                    "example": "46000000012845",
                    "format": "int64",
                    "type": "integer",
                },
                "value": {
                    "description": "Value of the Custom Field",
                    "example": "Normal",
                    "type": "string",
                },
            },
            "type": "object",
        },
        "type": "array",
    },
    "SENDPURCHASEORDEREMAIL_REQUEST_BODY_SCHEMA": {
        "properties": {
            "bcc_mail_ids": {
                "description": "Array of email address of the recipients to be BCC ed.",
                "example": ["mark@safInstruments.com"],
                "items": {"type": "string"},
                "type": "array",
            },
            "body": {
                "description": "Body of the mail",
                "example": "Dear Bowman and Co, <br><br>The purchase order "
                "(PO-00001) is attached with this email. "
                "<br><br>An overview of the purchase order is "
                "available below: <br>Purchase Order # : PO-00001 "
                "<br>Date : 10 Feb 2014 <br>Amount : $112.00(in "
                "USD) <br><br>Please go through it and confirm the "
                "order. We look forward to working with you "
                "again<br><br><br><br>Regards<br><br>Zillium "
                "Inc<br><br>",
                "type": "string",
            },
            "cc_mail_ids": {
                "description": "Array of email address of the recipients to be cced.",
                "example": ["peterparker@bowmanfurniture.com"],
                "items": {"type": "string"},
                "type": "array",
            },
            "from_address_id": {
                "description": "ID of From Address of the Email Address",
                "example": "460000008392548",
                "format": "int64",
                "type": "integer",
            },
            "mail_documents": {
                "items": {
                    "properties": {
                        "document_id": {
                            "description": "ID of the Document",
                            "format": "int64",
                            "type": "integer",
                        },
                        "file_name": {
                            "description": "Name "
                            "of "
                            "the "
                            "attached "
                            "document "
                            "file. "
                            "Includes "
                            "file "
                            "extension "
                            "and "
                            "represents "
                            "the "
                            "original "
                            "filename "
                            "as "
                            "uploaded. "
                            "Used "
                            "for "
                            "display "
                            "purposes "
                            "and "
                            "file "
                            "identification "
                            "in "
                            "the "
                            "system.",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "send_from_org_email_id": {
                "description": "Boolean to trigger the "
                "email from the "
                "organization's email "
                "address.",
                "example": True,
                "type": "boolean",
            },
            "subject": {
                "description": "Subject of the mail.",
                "example": "Purchase Order from Zillium Inc (PO #: PO-00001)",
                "type": "string",
            },
            "to_mail_ids": {
                "description": "Array of email address of the recipients.",
                "example": ["willsmith@bowmanfurniture.com"],
                "items": {"type": "string"},
                "type": "array",
            },
        },
        "required": ["to_mail_ids", "body"],
        "type": "object",
    },
    "UPDATEPURCHASEORDERBILLINGADDRESS_REQUEST_BODY_SCHEMA": {
        "properties": {
            "address": {
                "description": "Address associated with the Purchase Order",
                "type": "string",
            },
            "attention": {
                "description": "The name or designation of the specific "
                "person who should be contacted or "
                "notified regarding the delivery of goods "
                "or services from this purchase order. "
                "This field is typically used to specify "
                "the primary contact person at the "
                "delivery location, such as a warehouse "
                "manager, office administrator, or "
                "project coordinator who will receive and "
                "process the delivered items.",
                "type": "string",
            },
            "city": {"description": "City involved in the Address", "type": "string"},
            "country": {"description": "Country involved in the Address", "type": "string"},
            "fax": {"description": "Fax Number", "type": "string"},
            "is_update_customer": {
                "description": "Check if customer should be updated",
                "type": "string",
            },
            "state": {"description": "State Involved in the Address", "type": "string"},
            "zip": {"description": "ZIP Code of the Address", "type": "string"},
        },
        "type": "object",
    },
    "ADDPURCHASEORDERCOMMENT_REQUEST_BODY_SCHEMA": {
        "properties": {
            "description": {
                "description": "The description of the comment.",
                "example": "This is a comment.",
                "type": "string",
            },
            "expected_delivery_date": {
                "description": "The expected delivery date "
                "when the goods or services "
                "ordered in this purchase "
                "order should be received. "
                "This date is used for "
                "planning, scheduling, and "
                "tracking deliveries. It "
                "helps in managing "
                "inventory, coordinating "
                "with vendors, and ensuring "
                "timely receipt of ordered "
                "items. The date should be "
                "in YYYY-MM-DD format.",
                "type": "string",
            },
        },
        "required": ["description", "expected_delivery_date"],
        "type": "object",
    },
    "UPDATEPURCHASEORDERCOMMENT_REQUEST_BODY_SCHEMA": {
        "properties": {
            "description": {
                "description": "The description of the comment.",
                "example": "This is a comment.",
                "type": "string",
            },
            "expected_delivery_date": {
                "description": "The expected delivery date "
                "when the goods or services "
                "ordered in this purchase "
                "order should be received. "
                "This date is used for "
                "planning, scheduling, and "
                "tracking deliveries. It "
                "helps in managing "
                "inventory, coordinating "
                "with vendors, and ensuring "
                "timely receipt of ordered "
                "items. The date should be "
                "in YYYY-MM-DD format.",
                "type": "string",
            },
        },
        "type": "object",
    },
    "CREATERECURRINGBILL_REQUEST_BODY_SCHEMA": {
        "properties": {
            "abn": {"type": "string", "x-node_available_in": ["au"], "x-node_unavailable_in": []},
            "currency_id": {
                "description": "ID of the Currency",
                "example": "460000000000099",
                "type": "string",
            },
            "custom_fields": {
                "items": {
                    "properties": {
                        "index": {"description": "Index of the custom field", "type": "integer"},
                        "value": {"description": "Value of the Custom Field", "type": "string"},
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "destination_of_supply": {
                "description": "Place where the "
                "goods/services are supplied "
                "to. (If not given, "
                "organisation's home state "
                "will be taken)",
                "example": "TN",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "discount": {
                "description": "Discount applied to the recurrence. It "
                "can be either in % or in amount. E.g: "
                "12.5% or 190.",
                "example": "30%",
                "type": "string",
            },
            "discount_account_id": {
                "description": "ID of the account associated with the discount account.",
                "example": "460000000000403",
                "type": "string",
            },
            "end_date": {
                "description": "Date on which recurring bill has to "
                "expire. Can be left as empty to run "
                "forever. Format [yyyy-mm-dd].",
                "example": "2013-12-18",
                "type": "string",
            },
            "gst_no": {
                "description": "15 digit GST identification number of the vendor.",
                "example": "22AAAAA0000A1Z5",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "gst_treatment": {
                "description": "Choose whether the contact is GST "
                "registered/unregistered/consumer/overseas. "
                "Allowed values are <code> "
                "business_gst </code> , <code> "
                "business_none </code> , <code> "
                "overseas </code> , <code> consumer "
                "</code>.",
                "example": "business_gst",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "is_abn_quoted": {
                "type": "string",
                "x-node_available_in": ["au"],
                "x-node_unavailable_in": [],
            },
            "is_discount_before_tax": {
                "description": "To specify discount applied in before /after tax.",
                "example": True,
                "type": "boolean",
            },
            "is_inclusive_tax": {
                "description": "Used to specify whether the line "
                "item rates are inclusive or "
                "exclusive of tax.",
                "example": False,
                "type": "boolean",
                "x-node_available_in": [],
                "x-node_unavailable_in": ["us"],
            },
            "is_reverse_charge_applied": {
                "description": "Applicable for transactions where you pay reverse charge",
                "example": True,
                "type": "boolean",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "is_tds_applied": {
                "description": "Check if TDS is applied",
                "type": "boolean",
                "x-node_available_in": ["in", "global", "au"],
                "x-node_unavailable_in": [],
            },
            "line_items": {
                "description": "Line items of a recurrence bill.",
                "items": {
                    "properties": {
                        "account_id": {
                            "description": "ID of the account associated with the line item.",
                            "example": "460000000000403",
                            "type": "string",
                        },
                        "acquisition_vat_id": {
                            "description": "(Optional) "
                            "This "
                            "is "
                            "the "
                            "ID "
                            "of "
                            "the "
                            "tax "
                            "applied "
                            "in "
                            "case "
                            "this "
                            "is "
                            "an "
                            "EU "
                            "- "
                            "goods "
                            "purchase "
                            "and "
                            "acquisition "
                            "VAT "
                            "needs "
                            "to "
                            "be "
                            "reported.",
                            "type": "string",
                            "x-node_available_in": ["uk"],
                            "x-node_unavailable_in": [],
                        },
                        "customer_id": {"description": "ID of the Customer", "type": "string"},
                        "description": {
                            "description": "Description of the line item.",
                            "type": "string",
                        },
                        "hsn_or_sac": {
                            "description": "Add HSN/SAC code for your goods/services",
                            "example": 80540,
                            "type": "string",
                            "x-node_available_in": ["in", "ke", "za"],
                            "x-node_unavailable_in": [],
                        },
                        "is_billable": {
                            "description": "Check if entity is Billable",
                            "example": False,
                            "type": "boolean",
                        },
                        "item_custom_fields": {
                            "items": {
                                "properties": {
                                    "custom_field_id": {"format": "int64", "type": "integer"},
                                    "index": {
                                        "description": "Index of the custom field",
                                        "type": "integer",
                                    },
                                    "label": {
                                        "description": "Label of the Custom Field",
                                        "type": "string",
                                    },
                                    "value": {
                                        "description": "Value of the Custom Field",
                                        "type": "string",
                                    },
                                },
                                "type": "object",
                            },
                            "type": "array",
                        },
                        "item_id": {
                            "description": "ID of the Item",
                            "example": "460000000054135",
                            "type": "string",
                        },
                        "item_order": {"example": 1, "type": "integer"},
                        "line_item_id": {
                            "description": "ID of the Line Item",
                            "example": "460000000067009",
                            "type": "string",
                        },
                        "location_id": {
                            "description": "Location ID",
                            "example": "460000000038080",
                            "type": "string",
                        },
                        "name": {"type": "string"},
                        "product_type": {
                            "description": "Type "
                            "of "
                            "the "
                            "bill. "
                            "This "
                            "denotes "
                            "whether "
                            "the "
                            "bill "
                            "line "
                            "item "
                            "is "
                            "to "
                            "be "
                            "treated "
                            "as "
                            "a "
                            "goods "
                            "or "
                            "service "
                            "purchase. "
                            "This "
                            "only "
                            "need "
                            "to "
                            "be "
                            "specified "
                            "in "
                            "case "
                            "purchase "
                            "order "
                            "is "
                            "not "
                            "enabled. "
                            "Allowed "
                            "Values: "
                            "<code> "
                            "digital_service</code>, "
                            "<code>goods</code> "
                            "and "
                            "<code>service</code>.",
                            "type": "string",
                            "x-node_available_in": ["eu", "uk"],
                            "x-node_unavailable_in": [],
                        },
                        "project_id": {"description": "ID of the Project", "type": "string"},
                        "quantity": {
                            "description": "Quantity of the line item.",
                            "example": 1,
                            "format": "double",
                            "type": "number",
                        },
                        "rate": {
                            "description": "Rate of the line item.",
                            "example": 10,
                            "format": "double",
                            "type": "number",
                        },
                        "reverse_charge_tax_id": {
                            "description": "Reverse charge tax ID",
                            "example": 460000000038056,
                            "type": "string",
                            "x-node_available_in": ["in", "gcc", "za"],
                            "x-node_unavailable_in": [],
                        },
                        "reverse_charge_vat_id": {
                            "description": "(Optional) "
                            "This "
                            "is "
                            "the "
                            "ID "
                            "of "
                            "the "
                            "tax "
                            "applied "
                            "in "
                            "case "
                            "this "
                            "is "
                            "a "
                            "non "
                            "UK "
                            "- "
                            "service "
                            "purchase "
                            "and "
                            "reverse "
                            "charge "
                            "VAT "
                            "needs "
                            "to "
                            "be "
                            "reported.",
                            "type": "string",
                            "x-node_available_in": ["uk"],
                            "x-node_unavailable_in": [],
                        },
                        "serial_numbers": {"items": {"type": "string"}, "type": "array"},
                        "tags": {
                            "items": {
                                "properties": {
                                    "tag_id": {
                                        "description": "ID of the Tag",
                                        "example": "460000000054178",
                                        "format": "int64",
                                        "type": "integer",
                                    },
                                    "tag_option_id": {
                                        "description": "Id of the Tag Option",
                                        "example": "460000000054180",
                                        "format": "int64",
                                        "type": "integer",
                                    },
                                },
                                "type": "object",
                            },
                            "type": "array",
                        },
                        "tax_exemption_code": {
                            "description": "Code of the Tax Exemption Applied",
                            "type": "string",
                            "x-node_available_in": ["in", "au", "ca"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_exemption_id": {
                            "description": "ID of the Tax Exemption Applied",
                            "type": "string",
                            "x-node_available_in": ["in", "au", "ca"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_id": {
                            "description": "ID of the tax or tax group applied to the line item.",
                            "example": "460000000027005",
                            "type": "string",
                            "x-node_available_in": [],
                            "x-node_unavailable_in": ["us"],
                        },
                        "tax_treatment_code": {
                            "description": "Specify "
                            "reason "
                            "for "
                            "using "
                            "out "
                            "of "
                            "scope.</br>Supported "
                            "values "
                            "for "
                            "<b>UAE</b> "
                            "are "
                            "<code>uae_same_tax_group</code>, "
                            "<code>uae_reimbursed_expense</code> "
                            "and "
                            "<code>uae_others</code>.</br> "
                            "Supported "
                            "values "
                            "for "
                            "<b>Bahrain</b> "
                            "are "
                            "<code>bahrain_same_tax_group</code>, "
                            "<code>bahrain_transfer_of_concern</code>, "
                            "<code>bahrain_disbursement</code>, "
                            "<code>bahrain_head_to_branch_transaction</code>, "
                            "<code>bahrain_warranty_repair_services</code> "
                            "and "
                            "<code>bahrain_others</code>.</br> "
                            "Supported "
                            "values "
                            "for "
                            "<b>KSA</b> "
                            "are "
                            "<code>ksa_reimbursed_expense</code>.",
                            "example": "uae_others",
                            "type": "string",
                            "x-node_available_in": ["gcc"],
                            "x-node_unavailable_in": [],
                        },
                        "tds_tax_id": {
                            "description": "TDS ID of the tax group applied to the line item",
                            "example": "460000000027001",
                            "type": "string",
                            "x-node_available_in": ["mx"],
                            "x-node_unavailable_in": [],
                        },
                        "unit": {
                            "description": "Unit of the Item",
                            "example": "kgs",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "location_id": {
                "description": "Location ID",
                "example": "460000000038080",
                "type": "string",
            },
            "notes": {
                "description": "Notes for the Bill",
                "example": "Thanks for your business.",
                "type": "string",
            },
            "payment_terms": {
                "description": "Number Referring to Payment Terms",
                "example": 0,
                "type": "integer",
            },
            "payment_terms_label": {
                "description": "Label of the Payment Terms",
                "example": "Due on Receipt",
                "type": "string",
            },
            "place_of_supply": {
                "description": "The place of supply is where a "
                "transaction is considered to have "
                "occurred for VAT purposes. For the "
                "supply of goods, the place of "
                "supply is the location of the "
                "goods when the supply occurs. For "
                "the supply of services, the place "
                "of supply should be where the "
                "supplier is established. (If not "
                "given, <code>place of "
                "contact</code> given for the "
                "contact will be "
                "taken)<br/>Supported codes for UAE "
                "emirates are : </br>Abu Dhabi - "
                "<code>AB</code>,</br>Ajman - "
                "<code>AJ</code>,</br>Dubai - "
                "<code>DU</code>,</br>Fujairah - "
                "<code>FU</code>,</br>Ras "
                "al-Khaimah - "
                "<code>RA</code>,</br>Sharjah - "
                "<code>SH</code>,</br>Umm al-Quwain "
                "- <code>UM</code>.<br/>Supported "
                "codes for the GCC countries are : "
                "</br>United Arab Emirates - "
                "<code>AE</code>,</br>Saudi Arabia "
                "- <code>SA</code>,</br>Bahrain - "
                "<code>BH</code>,</br>Kuwait - "
                "<code>KW</code>,</br>Oman - "
                "<code>OM</code>,</br>Qatar - "
                "<code>QA</code>.",
                "example": "DU",
                "type": "string",
                "x-node_available_in": ["gcc"],
                "x-node_unavailable_in": [],
            },
            "pricebook_id": {
                "description": "Enter ID of the price book.",
                "example": 460000000038090,
                "type": "string",
            },
            "recurrence_frequency": {
                "description": "Description for recurrence_frequency",
                "example": "",
                "type": "string",
            },
            "recurrence_name": {
                "description": "Name of the Recurring Bill. Max-length [100]",
                "example": "Monthly Rental",
                "type": "string",
            },
            "repeat_every": {
                "description": "Description for repeat_every",
                "example": "",
                "type": "string",
            },
            "source_of_supply": {
                "description": "Place from where the "
                "goods/services are supplied. (If "
                "not given, <code>place of "
                "contact</code> given for the "
                "contact will be taken)",
                "example": "AP",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "start_date": {
                "description": "Start date of the recurring bill. Bills "
                "will not be generated for dates prior "
                "to the current date. Format "
                "[yyyy-mm-dd].",
                "example": "2013-11-18",
                "type": "string",
            },
            "tax_treatment": {
                "description": "VAT treatment for the bill. Choose "
                "whether the vendor falls under: "
                "<code>vat_registered</code>,<code>vat_not_registered</code>,<code>gcc_vat_not_registered</code>,<code>gcc_vat_registered</code>,<code>non_gcc</code>.</br><code>dz_vat_registered</code> "
                "and "
                "<code>dz_vat_not_registered</code> "
                "are supported only for "
                "<b>UAE</b>.</b></br><code>home_country_mexico</code>,<code>border_region_mexico</code>,<code>non_mexico</code> "
                "supported only for "
                "<b>MX</b>.<br/><b>For Kenya "
                "Edition:</b> "
                "<code>vat_registered</code> "
                ",<code>vat_not_registered</code> "
                ",<code>non_kenya</code>(A business "
                "that is located outside "
                "Kenya).<br/><b>For SouthAfrica "
                "Edition:</b> "
                "<code>vat_registered</code>, "
                "<code>vat_not_registered</code>, "
                "<code>overseas</code>(A business "
                "that is located outside "
                "SouthAfrica).",
                "example": "vat_registered",
                "type": "string",
                "x-node_available_in": ["gcc", "mx", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "terms": {
                "description": "Terms and Conditions for the Bill",
                "example": "Terms and conditions apply.",
                "type": "string",
            },
            "vat_reg_no": {
                "description": "<b>For UK Edition:</b> VAT Registration "
                "number of a contact with length should "
                "be between 2 and 12 characters.<br/> "
                "<b>For Avalara:</b> If you are doing "
                "sales in the European Union (EU) then "
                "provide VAT Registration Number of your "
                "customers here. This is used to "
                "calculate VAT for B2B sales, from "
                "Avalara.",
                "type": "string",
                "x-node_available_in": ["uk", "Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "vat_treatment": {
                "description": "(Optional) VAT treatment for the "
                "bill. VAT treatment denotes the "
                "location of the vendor, if the "
                "vendor resides in UK then the VAT "
                "treatment is <code>uk</code>. If the "
                "vendor is in an EU country & VAT "
                "registered, you are resides in "
                "Northen Ireland and purchasing Goods "
                "then his VAT treatment is "
                "<code>eu_vat_registered</code> and "
                "if he resides outside the UK then "
                "his VAT treatment is "
                "<code>overseas</code>(For Pre "
                "Brexit, this can be split as "
                "<code>eu_vat_registered</code>, "
                "<code>eu_vat_not_registered</code> "
                "and <code>non_eu</code>).",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
            "vendor_id": {
                "description": "ID of the vendor the bill has to be created.",
                "example": "460000000038029",
                "type": "string",
            },
        },
        "required": [
            "vendor_id",
            "recurrence_name",
            "start_date",
            "repeat_every",
            "recurrence_frequency",
        ],
        "type": "object",
    },
    "UPDATERECURRINGBILLCUSTOMFIELD_REQUEST_BODY_SCHEMA": {
        "properties": {
            "abn": {"type": "string", "x-node_available_in": ["au"], "x-node_unavailable_in": []},
            "currency_id": {
                "description": "ID of the Currency",
                "example": "460000000000099",
                "type": "string",
            },
            "custom_fields": {
                "items": {
                    "properties": {
                        "index": {"description": "Index of the custom field", "type": "integer"},
                        "value": {"description": "Value of the Custom Field", "type": "string"},
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "destination_of_supply": {
                "description": "Place where the "
                "goods/services are supplied "
                "to. (If not given, "
                "organisation's home state "
                "will be taken)",
                "example": "TN",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "discount": {
                "description": "Discount applied to the recurrence. It "
                "can be either in % or in amount. E.g: "
                "12.5% or 190.",
                "example": "30%",
                "type": "string",
            },
            "discount_account_id": {
                "description": "ID of the account associated with the discount account.",
                "example": "460000000000403",
                "type": "string",
            },
            "end_date": {
                "description": "Date on which recurring bill has to "
                "expire. Can be left as empty to run "
                "forever. Format [yyyy-mm-dd].",
                "example": "2013-12-18",
                "type": "string",
            },
            "gst_no": {
                "description": "15 digit GST identification number of the vendor.",
                "example": "22AAAAA0000A1Z5",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "gst_treatment": {
                "description": "Choose whether the contact is GST "
                "registered/unregistered/consumer/overseas. "
                "Allowed values are <code> "
                "business_gst </code> , <code> "
                "business_none </code> , <code> "
                "overseas </code> , <code> consumer "
                "</code>.",
                "example": "business_gst",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "is_abn_quoted": {
                "type": "string",
                "x-node_available_in": ["au"],
                "x-node_unavailable_in": [],
            },
            "is_discount_before_tax": {
                "description": "To specify discount applied in before /after tax.",
                "example": True,
                "type": "boolean",
            },
            "is_inclusive_tax": {
                "description": "Used to specify whether the line "
                "item rates are inclusive or "
                "exclusive of tax.",
                "example": False,
                "type": "boolean",
                "x-node_available_in": [],
                "x-node_unavailable_in": ["us"],
            },
            "is_reverse_charge_applied": {
                "description": "Applicable for transactions where you pay reverse charge",
                "example": True,
                "type": "boolean",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "is_tds_applied": {
                "description": "Check if TDS is applied",
                "type": "boolean",
                "x-node_available_in": ["in", "global", "au"],
                "x-node_unavailable_in": [],
            },
            "line_items": {
                "description": "Line items of a recurrence bill.",
                "items": {
                    "properties": {
                        "account_id": {
                            "description": "ID of the account associated with the line item.",
                            "example": "460000000000403",
                            "type": "string",
                        },
                        "acquisition_vat_id": {
                            "description": "(Optional) "
                            "This "
                            "is "
                            "the "
                            "ID "
                            "of "
                            "the "
                            "tax "
                            "applied "
                            "in "
                            "case "
                            "this "
                            "is "
                            "an "
                            "EU "
                            "- "
                            "goods "
                            "purchase "
                            "and "
                            "acquisition "
                            "VAT "
                            "needs "
                            "to "
                            "be "
                            "reported.",
                            "type": "string",
                            "x-node_available_in": ["uk"],
                            "x-node_unavailable_in": [],
                        },
                        "customer_id": {"description": "ID of the Customer", "type": "string"},
                        "description": {
                            "description": "Description of the line item.",
                            "type": "string",
                        },
                        "hsn_or_sac": {
                            "description": "Add HSN/SAC code for your goods/services",
                            "example": 80540,
                            "type": "string",
                            "x-node_available_in": ["in", "ke", "za"],
                            "x-node_unavailable_in": [],
                        },
                        "is_billable": {
                            "description": "Check if entity is Billable",
                            "example": False,
                            "type": "boolean",
                        },
                        "item_custom_fields": {
                            "items": {
                                "properties": {
                                    "custom_field_id": {"format": "int64", "type": "integer"},
                                    "index": {
                                        "description": "Index of the custom field",
                                        "type": "integer",
                                    },
                                    "label": {
                                        "description": "Label of the Custom Field",
                                        "type": "string",
                                    },
                                    "value": {
                                        "description": "Value of the Custom Field",
                                        "type": "string",
                                    },
                                },
                                "type": "object",
                            },
                            "type": "array",
                        },
                        "item_id": {
                            "description": "ID of the Item",
                            "example": "460000000054135",
                            "type": "string",
                        },
                        "item_order": {"example": 1, "type": "integer"},
                        "line_item_id": {
                            "description": "ID of the Line Item",
                            "example": "460000000067009",
                            "type": "string",
                        },
                        "location_id": {
                            "description": "Location ID",
                            "example": "460000000038080",
                            "type": "string",
                        },
                        "name": {"type": "string"},
                        "product_type": {
                            "description": "Type "
                            "of "
                            "the "
                            "bill. "
                            "This "
                            "denotes "
                            "whether "
                            "the "
                            "bill "
                            "line "
                            "item "
                            "is "
                            "to "
                            "be "
                            "treated "
                            "as "
                            "a "
                            "goods "
                            "or "
                            "service "
                            "purchase. "
                            "This "
                            "only "
                            "need "
                            "to "
                            "be "
                            "specified "
                            "in "
                            "case "
                            "purchase "
                            "order "
                            "is "
                            "not "
                            "enabled. "
                            "Allowed "
                            "Values: "
                            "<code> "
                            "digital_service</code>, "
                            "<code>goods</code> "
                            "and "
                            "<code>service</code>.",
                            "type": "string",
                            "x-node_available_in": ["eu", "uk"],
                            "x-node_unavailable_in": [],
                        },
                        "project_id": {"description": "ID of the Project", "type": "string"},
                        "quantity": {
                            "description": "Quantity of the line item.",
                            "example": 1,
                            "format": "double",
                            "type": "number",
                        },
                        "rate": {
                            "description": "Rate of the line item.",
                            "example": 10,
                            "format": "double",
                            "type": "number",
                        },
                        "reverse_charge_tax_id": {
                            "description": "Reverse charge tax ID",
                            "example": 460000000038056,
                            "type": "string",
                            "x-node_available_in": ["in", "gcc", "za"],
                            "x-node_unavailable_in": [],
                        },
                        "reverse_charge_vat_id": {
                            "description": "(Optional) "
                            "This "
                            "is "
                            "the "
                            "ID "
                            "of "
                            "the "
                            "tax "
                            "applied "
                            "in "
                            "case "
                            "this "
                            "is "
                            "a "
                            "non "
                            "UK "
                            "- "
                            "service "
                            "purchase "
                            "and "
                            "reverse "
                            "charge "
                            "VAT "
                            "needs "
                            "to "
                            "be "
                            "reported.",
                            "type": "string",
                            "x-node_available_in": ["uk"],
                            "x-node_unavailable_in": [],
                        },
                        "serial_numbers": {"items": {"type": "string"}, "type": "array"},
                        "tags": {
                            "items": {
                                "properties": {
                                    "tag_id": {
                                        "description": "ID of the Tag",
                                        "example": "460000000054178",
                                        "format": "int64",
                                        "type": "integer",
                                    },
                                    "tag_option_id": {
                                        "description": "Id of the Tag Option",
                                        "example": "460000000054180",
                                        "format": "int64",
                                        "type": "integer",
                                    },
                                },
                                "type": "object",
                            },
                            "type": "array",
                        },
                        "tax_exemption_code": {
                            "description": "Code of the Tax Exemption Applied",
                            "type": "string",
                            "x-node_available_in": ["in", "au", "ca"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_exemption_id": {
                            "description": "ID of the Tax Exemption Applied",
                            "type": "string",
                            "x-node_available_in": ["in", "au", "ca"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_id": {
                            "description": "ID of the tax or tax group applied to the line item.",
                            "example": "460000000027005",
                            "type": "string",
                            "x-node_available_in": [],
                            "x-node_unavailable_in": ["us"],
                        },
                        "tax_treatment_code": {
                            "description": "Specify "
                            "reason "
                            "for "
                            "using "
                            "out "
                            "of "
                            "scope.</br>Supported "
                            "values "
                            "for "
                            "<b>UAE</b> "
                            "are "
                            "<code>uae_same_tax_group</code>, "
                            "<code>uae_reimbursed_expense</code> "
                            "and "
                            "<code>uae_others</code>.</br> "
                            "Supported "
                            "values "
                            "for "
                            "<b>Bahrain</b> "
                            "are "
                            "<code>bahrain_same_tax_group</code>, "
                            "<code>bahrain_transfer_of_concern</code>, "
                            "<code>bahrain_disbursement</code>, "
                            "<code>bahrain_head_to_branch_transaction</code>, "
                            "<code>bahrain_warranty_repair_services</code> "
                            "and "
                            "<code>bahrain_others</code>.</br> "
                            "Supported "
                            "values "
                            "for "
                            "<b>KSA</b> "
                            "are "
                            "<code>ksa_reimbursed_expense</code>.",
                            "example": "uae_others",
                            "type": "string",
                            "x-node_available_in": ["gcc"],
                            "x-node_unavailable_in": [],
                        },
                        "tds_tax_id": {
                            "description": "TDS ID of the tax group applied to the line item",
                            "example": "460000000027001",
                            "type": "string",
                            "x-node_available_in": ["mx"],
                            "x-node_unavailable_in": [],
                        },
                        "unit": {
                            "description": "Unit of the Item",
                            "example": "kgs",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "location_id": {
                "description": "Location ID",
                "example": "460000000038080",
                "type": "string",
            },
            "notes": {
                "description": "Notes for the Bill",
                "example": "Thanks for your business.",
                "type": "string",
            },
            "payment_terms": {
                "description": "Number Referring to Payment Terms",
                "example": 0,
                "type": "integer",
            },
            "payment_terms_label": {
                "description": "Label of the Payment Terms",
                "example": "Due on Receipt",
                "type": "string",
            },
            "place_of_supply": {
                "description": "The place of supply is where a "
                "transaction is considered to have "
                "occurred for VAT purposes. For the "
                "supply of goods, the place of "
                "supply is the location of the "
                "goods when the supply occurs. For "
                "the supply of services, the place "
                "of supply should be where the "
                "supplier is established. (If not "
                "given, <code>place of "
                "contact</code> given for the "
                "contact will be "
                "taken)<br/>Supported codes for UAE "
                "emirates are : </br>Abu Dhabi - "
                "<code>AB</code>,</br>Ajman - "
                "<code>AJ</code>,</br>Dubai - "
                "<code>DU</code>,</br>Fujairah - "
                "<code>FU</code>,</br>Ras "
                "al-Khaimah - "
                "<code>RA</code>,</br>Sharjah - "
                "<code>SH</code>,</br>Umm al-Quwain "
                "- <code>UM</code>.<br/>Supported "
                "codes for the GCC countries are : "
                "</br>United Arab Emirates - "
                "<code>AE</code>,</br>Saudi Arabia "
                "- <code>SA</code>,</br>Bahrain - "
                "<code>BH</code>,</br>Kuwait - "
                "<code>KW</code>,</br>Oman - "
                "<code>OM</code>,</br>Qatar - "
                "<code>QA</code>.",
                "example": "DU",
                "type": "string",
                "x-node_available_in": ["gcc"],
                "x-node_unavailable_in": [],
            },
            "pricebook_id": {
                "description": "Enter ID of the price book.",
                "example": 460000000038090,
                "type": "string",
            },
            "pricebook_name": {"description": "Name of the price book", "type": "string"},
            "recurrence_frequency": {
                "description": "Description for recurrence_frequency",
                "example": "",
                "type": "string",
            },
            "recurrence_name": {
                "description": "Name of the Recurring Bill. Max-length [100]",
                "example": "Monthly Rental",
                "type": "string",
            },
            "recurring_bill_id": {"example": 982000000567240, "type": "string"},
            "repeat_every": {
                "description": "Description for repeat_every",
                "example": "",
                "type": "string",
            },
            "source_of_supply": {
                "description": "Place from where the "
                "goods/services are supplied. (If "
                "not given, <code>place of "
                "contact</code> given for the "
                "contact will be taken)",
                "example": "AP",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "start_date": {
                "description": "Start date of the recurring bill. Bills "
                "will not be generated for dates prior "
                "to the current date. Format "
                "[yyyy-mm-dd].",
                "example": "2013-11-18",
                "type": "string",
            },
            "status": {
                "description": "Status of the Recurring Bill",
                "example": "active",
                "type": "string",
            },
            "tax_treatment": {
                "description": "VAT treatment for the bill. Choose "
                "whether the vendor falls under: "
                "<code>vat_registered</code>,<code>vat_not_registered</code>,<code>gcc_vat_not_registered</code>,<code>gcc_vat_registered</code>,<code>non_gcc</code>.</br><code>dz_vat_registered</code> "
                "and "
                "<code>dz_vat_not_registered</code> "
                "are supported only for "
                "<b>UAE</b>.</b></br><code>home_country_mexico</code>,<code>border_region_mexico</code>,<code>non_mexico</code> "
                "supported only for "
                "<b>MX</b>.<br/><b>For Kenya "
                "Edition:</b> "
                "<code>vat_registered</code> "
                ",<code>vat_not_registered</code> "
                ",<code>non_kenya</code>(A business "
                "that is located outside "
                "Kenya).<br/><b>For SouthAfrica "
                "Edition:</b> "
                "<code>vat_registered</code>, "
                "<code>vat_not_registered</code>, "
                "<code>overseas</code>(A business "
                "that is located outside "
                "SouthAfrica).",
                "example": "vat_registered",
                "type": "string",
                "x-node_available_in": ["gcc", "mx", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "terms": {
                "description": "Terms and Conditions for the Bill",
                "example": "Terms and conditions apply.",
                "type": "string",
            },
            "vat_reg_no": {
                "description": "<b>For UK Edition:</b> VAT Registration "
                "number of a contact with length should "
                "be between 2 and 12 characters.<br/> "
                "<b>For Avalara:</b> If you are doing "
                "sales in the European Union (EU) then "
                "provide VAT Registration Number of your "
                "customers here. This is used to "
                "calculate VAT for B2B sales, from "
                "Avalara.",
                "type": "string",
                "x-node_available_in": ["uk", "Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "vat_treatment": {
                "description": "(Optional) VAT treatment for the "
                "bill. VAT treatment denotes the "
                "location of the vendor, if the "
                "vendor resides in UK then the VAT "
                "treatment is <code>uk</code>. If the "
                "vendor is in an EU country & VAT "
                "registered, you are resides in "
                "Northen Ireland and purchasing Goods "
                "then his VAT treatment is "
                "<code>eu_vat_registered</code> and "
                "if he resides outside the UK then "
                "his VAT treatment is "
                "<code>overseas</code>(For Pre "
                "Brexit, this can be split as "
                "<code>eu_vat_registered</code>, "
                "<code>eu_vat_not_registered</code> "
                "and <code>non_eu</code>).",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
            "vendor_id": {
                "description": "ID of the vendor the bill has to be created.",
                "example": "460000000038029",
                "type": "string",
            },
        },
        "required": [
            "vendor_id",
            "recurrence_name",
            "start_date",
            "repeat_every",
            "recurrence_frequency",
        ],
        "type": "object",
    },
    "UPDATERECURRINGBILL_REQUEST_BODY_SCHEMA": {
        "properties": {
            "abn": {"type": "string", "x-node_available_in": ["au"], "x-node_unavailable_in": []},
            "currency_id": {
                "description": "ID of the Currency",
                "example": "460000000000099",
                "type": "string",
            },
            "custom_fields": {
                "items": {
                    "properties": {
                        "index": {"description": "Index of the custom field", "type": "integer"},
                        "value": {"description": "Value of the Custom Field", "type": "string"},
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "destination_of_supply": {
                "description": "Place where the "
                "goods/services are supplied "
                "to. (If not given, "
                "organisation's home state "
                "will be taken)",
                "example": "TN",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "discount": {
                "description": "Discount applied to the recurrence. It "
                "can be either in % or in amount. E.g: "
                "12.5% or 190.",
                "example": "30%",
                "type": "string",
            },
            "discount_account_id": {
                "description": "ID of the account associated with the discount account.",
                "example": "460000000000403",
                "type": "string",
            },
            "end_date": {
                "description": "Date on which recurring bill has to "
                "expire. Can be left as empty to run "
                "forever. Format [yyyy-mm-dd].",
                "example": "2013-12-18",
                "type": "string",
            },
            "gst_no": {
                "description": "15 digit GST identification number of the vendor.",
                "example": "22AAAAA0000A1Z5",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "gst_treatment": {
                "description": "Choose whether the contact is GST "
                "registered/unregistered/consumer/overseas. "
                "Allowed values are <code> "
                "business_gst </code> , <code> "
                "business_none </code> , <code> "
                "overseas </code> , <code> consumer "
                "</code>.",
                "example": "business_gst",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "is_abn_quoted": {
                "type": "string",
                "x-node_available_in": ["au"],
                "x-node_unavailable_in": [],
            },
            "is_discount_before_tax": {
                "description": "To specify discount applied in before /after tax.",
                "example": True,
                "type": "boolean",
            },
            "is_inclusive_tax": {
                "description": "Used to specify whether the line "
                "item rates are inclusive or "
                "exclusive of tax.",
                "example": False,
                "type": "boolean",
                "x-node_available_in": [],
                "x-node_unavailable_in": ["us"],
            },
            "is_reverse_charge_applied": {
                "description": "Applicable for transactions where you pay reverse charge",
                "example": True,
                "type": "boolean",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "is_tds_applied": {
                "description": "Check if TDS is applied",
                "type": "boolean",
                "x-node_available_in": ["in", "global", "au"],
                "x-node_unavailable_in": [],
            },
            "line_items": {
                "description": "Line items of a recurrence bill.",
                "items": {
                    "properties": {
                        "account_id": {
                            "description": "ID of the account associated with the line item.",
                            "example": "460000000000403",
                            "type": "string",
                        },
                        "acquisition_vat_id": {
                            "description": "(Optional) "
                            "This "
                            "is "
                            "the "
                            "ID "
                            "of "
                            "the "
                            "tax "
                            "applied "
                            "in "
                            "case "
                            "this "
                            "is "
                            "an "
                            "EU "
                            "- "
                            "goods "
                            "purchase "
                            "and "
                            "acquisition "
                            "VAT "
                            "needs "
                            "to "
                            "be "
                            "reported.",
                            "type": "string",
                            "x-node_available_in": ["uk"],
                            "x-node_unavailable_in": [],
                        },
                        "customer_id": {"description": "ID of the Customer", "type": "string"},
                        "description": {
                            "description": "Description of the line item.",
                            "type": "string",
                        },
                        "hsn_or_sac": {
                            "description": "Add HSN/SAC code for your goods/services",
                            "example": 80540,
                            "type": "string",
                            "x-node_available_in": ["in", "ke", "za"],
                            "x-node_unavailable_in": [],
                        },
                        "is_billable": {
                            "description": "Check if entity is Billable",
                            "example": False,
                            "type": "boolean",
                        },
                        "item_custom_fields": {
                            "items": {
                                "properties": {
                                    "custom_field_id": {"format": "int64", "type": "integer"},
                                    "index": {
                                        "description": "Index of the custom field",
                                        "type": "integer",
                                    },
                                    "label": {
                                        "description": "Label of the Custom Field",
                                        "type": "string",
                                    },
                                    "value": {
                                        "description": "Value of the Custom Field",
                                        "type": "string",
                                    },
                                },
                                "type": "object",
                            },
                            "type": "array",
                        },
                        "item_id": {
                            "description": "ID of the Item",
                            "example": "460000000054135",
                            "type": "string",
                        },
                        "item_order": {"example": 1, "type": "integer"},
                        "line_item_id": {
                            "description": "ID of the Line Item",
                            "example": "460000000067009",
                            "type": "string",
                        },
                        "location_id": {
                            "description": "Location ID",
                            "example": "460000000038080",
                            "type": "string",
                        },
                        "name": {"type": "string"},
                        "product_type": {
                            "description": "Type "
                            "of "
                            "the "
                            "bill. "
                            "This "
                            "denotes "
                            "whether "
                            "the "
                            "bill "
                            "line "
                            "item "
                            "is "
                            "to "
                            "be "
                            "treated "
                            "as "
                            "a "
                            "goods "
                            "or "
                            "service "
                            "purchase. "
                            "This "
                            "only "
                            "need "
                            "to "
                            "be "
                            "specified "
                            "in "
                            "case "
                            "purchase "
                            "order "
                            "is "
                            "not "
                            "enabled. "
                            "Allowed "
                            "Values: "
                            "<code> "
                            "digital_service</code>, "
                            "<code>goods</code> "
                            "and "
                            "<code>service</code>.",
                            "type": "string",
                            "x-node_available_in": ["eu", "uk"],
                            "x-node_unavailable_in": [],
                        },
                        "project_id": {"description": "ID of the Project", "type": "string"},
                        "quantity": {
                            "description": "Quantity of the line item.",
                            "example": 1,
                            "format": "double",
                            "type": "number",
                        },
                        "rate": {
                            "description": "Rate of the line item.",
                            "example": 10,
                            "format": "double",
                            "type": "number",
                        },
                        "reverse_charge_tax_id": {
                            "description": "Reverse charge tax ID",
                            "example": 460000000038056,
                            "type": "string",
                            "x-node_available_in": ["in", "gcc", "za"],
                            "x-node_unavailable_in": [],
                        },
                        "reverse_charge_vat_id": {
                            "description": "(Optional) "
                            "This "
                            "is "
                            "the "
                            "ID "
                            "of "
                            "the "
                            "tax "
                            "applied "
                            "in "
                            "case "
                            "this "
                            "is "
                            "a "
                            "non "
                            "UK "
                            "- "
                            "service "
                            "purchase "
                            "and "
                            "reverse "
                            "charge "
                            "VAT "
                            "needs "
                            "to "
                            "be "
                            "reported.",
                            "type": "string",
                            "x-node_available_in": ["uk"],
                            "x-node_unavailable_in": [],
                        },
                        "serial_numbers": {"items": {"type": "string"}, "type": "array"},
                        "tags": {
                            "items": {
                                "properties": {
                                    "tag_id": {
                                        "description": "ID of the Tag",
                                        "example": "460000000054178",
                                        "format": "int64",
                                        "type": "integer",
                                    },
                                    "tag_option_id": {
                                        "description": "Id of the Tag Option",
                                        "example": "460000000054180",
                                        "format": "int64",
                                        "type": "integer",
                                    },
                                },
                                "type": "object",
                            },
                            "type": "array",
                        },
                        "tax_exemption_code": {
                            "description": "Code of the Tax Exemption Applied",
                            "type": "string",
                            "x-node_available_in": ["in", "au", "ca"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_exemption_id": {
                            "description": "ID of the Tax Exemption Applied",
                            "type": "string",
                            "x-node_available_in": ["in", "au", "ca"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_id": {
                            "description": "ID of the tax or tax group applied to the line item.",
                            "example": "460000000027005",
                            "type": "string",
                            "x-node_available_in": [],
                            "x-node_unavailable_in": ["us"],
                        },
                        "tax_treatment_code": {
                            "description": "Specify "
                            "reason "
                            "for "
                            "using "
                            "out "
                            "of "
                            "scope.</br>Supported "
                            "values "
                            "for "
                            "<b>UAE</b> "
                            "are "
                            "<code>uae_same_tax_group</code>, "
                            "<code>uae_reimbursed_expense</code> "
                            "and "
                            "<code>uae_others</code>.</br> "
                            "Supported "
                            "values "
                            "for "
                            "<b>Bahrain</b> "
                            "are "
                            "<code>bahrain_same_tax_group</code>, "
                            "<code>bahrain_transfer_of_concern</code>, "
                            "<code>bahrain_disbursement</code>, "
                            "<code>bahrain_head_to_branch_transaction</code>, "
                            "<code>bahrain_warranty_repair_services</code> "
                            "and "
                            "<code>bahrain_others</code>.</br> "
                            "Supported "
                            "values "
                            "for "
                            "<b>KSA</b> "
                            "are "
                            "<code>ksa_reimbursed_expense</code>.",
                            "example": "uae_others",
                            "type": "string",
                            "x-node_available_in": ["gcc"],
                            "x-node_unavailable_in": [],
                        },
                        "tds_tax_id": {
                            "description": "TDS ID of the tax group applied to the line item",
                            "example": "460000000027001",
                            "type": "string",
                            "x-node_available_in": ["mx"],
                            "x-node_unavailable_in": [],
                        },
                        "unit": {
                            "description": "Unit of the Item",
                            "example": "kgs",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "location_id": {
                "description": "Location ID",
                "example": "460000000038080",
                "type": "string",
            },
            "notes": {
                "description": "Notes for the Bill",
                "example": "Thanks for your business.",
                "type": "string",
            },
            "payment_terms": {
                "description": "Number Referring to Payment Terms",
                "example": 0,
                "type": "integer",
            },
            "payment_terms_label": {
                "description": "Label of the Payment Terms",
                "example": "Due on Receipt",
                "type": "string",
            },
            "place_of_supply": {
                "description": "The place of supply is where a "
                "transaction is considered to have "
                "occurred for VAT purposes. For the "
                "supply of goods, the place of "
                "supply is the location of the "
                "goods when the supply occurs. For "
                "the supply of services, the place "
                "of supply should be where the "
                "supplier is established. (If not "
                "given, <code>place of "
                "contact</code> given for the "
                "contact will be "
                "taken)<br/>Supported codes for UAE "
                "emirates are : </br>Abu Dhabi - "
                "<code>AB</code>,</br>Ajman - "
                "<code>AJ</code>,</br>Dubai - "
                "<code>DU</code>,</br>Fujairah - "
                "<code>FU</code>,</br>Ras "
                "al-Khaimah - "
                "<code>RA</code>,</br>Sharjah - "
                "<code>SH</code>,</br>Umm al-Quwain "
                "- <code>UM</code>.<br/>Supported "
                "codes for the GCC countries are : "
                "</br>United Arab Emirates - "
                "<code>AE</code>,</br>Saudi Arabia "
                "- <code>SA</code>,</br>Bahrain - "
                "<code>BH</code>,</br>Kuwait - "
                "<code>KW</code>,</br>Oman - "
                "<code>OM</code>,</br>Qatar - "
                "<code>QA</code>.",
                "example": "DU",
                "type": "string",
                "x-node_available_in": ["gcc"],
                "x-node_unavailable_in": [],
            },
            "pricebook_id": {
                "description": "Enter ID of the price book.",
                "example": 460000000038090,
                "type": "string",
            },
            "pricebook_name": {"description": "Name of the price book", "type": "string"},
            "recurrence_frequency": {
                "description": "Description for recurrence_frequency",
                "example": "",
                "type": "string",
            },
            "recurrence_name": {
                "description": "Name of the Recurring Bill. Max-length [100]",
                "example": "Monthly Rental",
                "type": "string",
            },
            "recurring_bill_id": {"example": 982000000567240, "type": "string"},
            "repeat_every": {
                "description": "Description for repeat_every",
                "example": "",
                "type": "string",
            },
            "source_of_supply": {
                "description": "Place from where the "
                "goods/services are supplied. (If "
                "not given, <code>place of "
                "contact</code> given for the "
                "contact will be taken)",
                "example": "AP",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "start_date": {
                "description": "Start date of the recurring bill. Bills "
                "will not be generated for dates prior "
                "to the current date. Format "
                "[yyyy-mm-dd].",
                "example": "2013-11-18",
                "type": "string",
            },
            "status": {
                "description": "Status of the Recurring Bill",
                "example": "active",
                "type": "string",
            },
            "tax_treatment": {
                "description": "VAT treatment for the bill. Choose "
                "whether the vendor falls under: "
                "<code>vat_registered</code>,<code>vat_not_registered</code>,<code>gcc_vat_not_registered</code>,<code>gcc_vat_registered</code>,<code>non_gcc</code>.</br><code>dz_vat_registered</code> "
                "and "
                "<code>dz_vat_not_registered</code> "
                "are supported only for "
                "<b>UAE</b>.</b></br><code>home_country_mexico</code>,<code>border_region_mexico</code>,<code>non_mexico</code> "
                "supported only for "
                "<b>MX</b>.<br/><b>For Kenya "
                "Edition:</b> "
                "<code>vat_registered</code> "
                ",<code>vat_not_registered</code> "
                ",<code>non_kenya</code>(A business "
                "that is located outside "
                "Kenya).<br/><b>For SouthAfrica "
                "Edition:</b> "
                "<code>vat_registered</code>, "
                "<code>vat_not_registered</code>, "
                "<code>overseas</code>(A business "
                "that is located outside "
                "SouthAfrica).",
                "example": "vat_registered",
                "type": "string",
                "x-node_available_in": ["gcc", "mx", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "terms": {
                "description": "Terms and Conditions for the Bill",
                "example": "Terms and conditions apply.",
                "type": "string",
            },
            "vat_reg_no": {
                "description": "<b>For UK Edition:</b> VAT Registration "
                "number of a contact with length should "
                "be between 2 and 12 characters.<br/> "
                "<b>For Avalara:</b> If you are doing "
                "sales in the European Union (EU) then "
                "provide VAT Registration Number of your "
                "customers here. This is used to "
                "calculate VAT for B2B sales, from "
                "Avalara.",
                "type": "string",
                "x-node_available_in": ["uk", "Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "vat_treatment": {
                "description": "(Optional) VAT treatment for the "
                "bill. VAT treatment denotes the "
                "location of the vendor, if the "
                "vendor resides in UK then the VAT "
                "treatment is <code>uk</code>. If the "
                "vendor is in an EU country & VAT "
                "registered, you are resides in "
                "Northen Ireland and purchasing Goods "
                "then his VAT treatment is "
                "<code>eu_vat_registered</code> and "
                "if he resides outside the UK then "
                "his VAT treatment is "
                "<code>overseas</code>(For Pre "
                "Brexit, this can be split as "
                "<code>eu_vat_registered</code>, "
                "<code>eu_vat_not_registered</code> "
                "and <code>non_eu</code>).",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
            "vendor_id": {
                "description": "ID of the vendor the bill has to be created.",
                "example": "460000000038029",
                "type": "string",
            },
        },
        "required": [
            "vendor_id",
            "recurrence_name",
            "start_date",
            "repeat_every",
            "recurrence_frequency",
        ],
        "type": "object",
    },
    "CREATERECURRINGEXPENSE_REQUEST_BODY_SCHEMA": {
        "properties": {
            "account_id": {"example": 982000000561057, "type": "string"},
            "acquisition_vat_id": {
                "description": "This is the ID of the tax "
                "applied in case this is an EU - "
                "goods expense and acquisition "
                "VAT needs to be reported.",
                "example": " ",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
            "amount": {
                "description": "Recurring Expense amount.",
                "example": 112.5,
                "format": "double",
                "type": "number",
            },
            "currency_id": {"example": 982000000567001, "type": "string"},
            "custom_fields": {
                "description": "Custom fields for a recurring-expense.",
                "items": {
                    "properties": {
                        "customfield_id": {
                            "example": "46000000012845",
                            "format": "int64",
                            "type": "integer",
                        },
                        "value": {
                            "description": "Value of the Custom Field",
                            "example": "Normal",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "customer_id": {
                "description": "Search expenses by customer id.",
                "example": 982000000567001,
                "type": "string",
            },
            "destination_of_supply": {
                "description": "Place where the "
                "goods/services are supplied "
                "to. (If not given, "
                "organisation's home state "
                "will be taken)",
                "example": "TN",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "end_date": {
                "description": "Date on which recurring expense has to "
                "expire. Can be left as empty to run "
                "forever. Format [yyyy-mm-dd].",
                "example": " ",
                "type": "string",
            },
            "exchange_rate": {"example": 1, "format": "double", "type": "number"},
            "gst_no": {
                "description": "15 digit GST identification number of the vendor.",
                "example": "22AAAAA0000A1Z5",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "is_billable": {"example": True, "type": "boolean"},
            "is_inclusive_tax": {"example": False, "type": "boolean"},
            "line_items": {
                "items": {
                    "properties": {
                        "account_id": {"example": 982000000561057, "type": "string"},
                        "acquisition_vat_id": {
                            "description": "This "
                            "is "
                            "the "
                            "ID "
                            "of "
                            "the "
                            "tax "
                            "applied "
                            "in "
                            "case "
                            "this "
                            "is "
                            "an "
                            "EU "
                            "- "
                            "goods "
                            "expense "
                            "and "
                            "acquisition "
                            "VAT "
                            "needs "
                            "to "
                            "be "
                            "reported.",
                            "example": " ",
                            "type": "string",
                            "x-node_available_in": ["uk"],
                            "x-node_unavailable_in": [],
                        },
                        "amount": {
                            "description": "Recurring Expense amount.",
                            "example": 112.5,
                            "format": "double",
                            "type": "number",
                        },
                        "description": {
                            "description": "Search "
                            "recurring "
                            "expenses "
                            "by "
                            "description. "
                            "Max-length "
                            "[100]",
                            "example": " ",
                            "type": "string",
                        },
                        "item_order": {"example": 1, "type": "string"},
                        "line_item_id": {"example": 10763000000140068, "type": "string"},
                        "product_type": {
                            "description": "Type "
                            "of "
                            "the "
                            "expense. "
                            "This "
                            "denotes "
                            "whether "
                            "the "
                            "expense "
                            "is "
                            "to "
                            "be "
                            "treated "
                            "as "
                            "a "
                            "goods "
                            "or "
                            "service "
                            "or "
                            "capital "
                            "asset "
                            "purchase. "
                            "Allowed "
                            "Values:<br/> "
                            "<b>For "
                            "UK "
                            "edition:</b><code>digital_service</code>, "
                            "<code>goods</code> "
                            "and "
                            "<code>service</code>.<br/><b>For "
                            "SouthAfrica "
                            "Edition:</b> "
                            "<code>service</code>, "
                            "<code>goods</code>, "
                            "<code>capital_service</code> "
                            "and "
                            "<code>capital_goods</code>",
                            "example": "goods",
                            "type": "string",
                            "x-node_available_in": ["uk", "za"],
                            "x-node_unavailable_in": [],
                        },
                        "reverse_charge_tax_id": {
                            "description": "Enter "
                            "reverse "
                            "charge "
                            "tax "
                            "ID<br\\><b>For "
                            "SouthAfrica "
                            "edition:</b>(Required "
                            "if "
                            "customer "
                            "tax "
                            "treatment "
                            "is "
                            "<code>vat_registered</code>)<br/>Used "
                            "to "
                            "specify "
                            "whether "
                            "the "
                            "transaction "
                            "is "
                            "applicable "
                            "for "
                            "Domestic "
                            "Reverse "
                            "Charge "
                            "(DRC) "
                            "or "
                            "not.",
                            "example": 982000000567254,
                            "type": "string",
                            "x-node_available_in": ["in", "gcc", "za"],
                            "x-node_unavailable_in": [],
                        },
                        "reverse_charge_vat_id": {
                            "description": "This "
                            "is "
                            "the "
                            "ID "
                            "of "
                            "the "
                            "tax "
                            "applied "
                            "in "
                            "case "
                            "this "
                            "is "
                            "a "
                            "non "
                            "UK "
                            "- "
                            "service "
                            "expense "
                            "and "
                            "reverse "
                            "charge "
                            "VAT "
                            "needs "
                            "to "
                            "be "
                            "reported.",
                            "example": " ",
                            "type": "string",
                            "x-node_available_in": ["in", "uk"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_exemption_code": {
                            "description": "Enter the code for tax exemption",
                            "type": "string",
                            "x-node_available_in": ["in", "mx"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_exemption_id": {
                            "description": "Enter ID of the tax exemption",
                            "example": 982000000567267,
                            "type": "string",
                            "x-node_available_in": ["in", "mx"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_id": {"example": 982000000566007, "type": "string"},
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "location_id": {
                "description": "Location ID",
                "example": "460000000038080",
                "type": "string",
            },
            "place_of_supply": {
                "description": "The place of supply is where a "
                "transaction is considered to have "
                "occurred for VAT purposes. For the "
                "supply of goods, the place of "
                "supply is the location of the "
                "goods when the supply occurs. For "
                "the supply of services, the place "
                "of supply should be where the "
                "supplier is established. (If not "
                "given, <code>place of "
                "contact</code> given for the "
                "contact will be "
                "taken)<br/>Supported codes for UAE "
                "emirates are : </br>Abu Dhabi - "
                "<code>AB</code>,</br>Ajman - "
                "<code>AJ</code>,</br>Dubai - "
                "<code>DU</code>,</br>Fujairah - "
                "<code>FU</code>,</br>Ras "
                "al-Khaimah - "
                "<code>RA</code>,</br>Sharjah - "
                "<code>SH</code>,</br>Umm al-Quwain "
                "- <code>UM</code>.<br/>Supported "
                "codes for the GCC countries are : "
                "</br>United Arab Emirates - "
                "<code>AE</code>,</br>Saudi Arabia "
                "- <code>SA</code>,</br>Bahrain - "
                "<code>BH</code>,</br>Kuwait - "
                "<code>KW</code>,</br>Oman - "
                "<code>OM</code>,</br>Qatar - "
                "<code>QA</code>.",
                "example": "DU",
                "type": "string",
                "x-node_available_in": ["gcc"],
                "x-node_unavailable_in": [],
            },
            "product_type": {
                "description": "Type of the expense. This denotes "
                "whether the expense is to be treated "
                "as a goods or service or capital "
                "asset purchase. Allowed Values:<br/> "
                "<b>For UK "
                "edition:</b><code>digital_service</code>, "
                "<code>goods</code> and "
                "<code>service</code>.<br/><b>For "
                "SouthAfrica Edition:</b> "
                "<code>service</code>, "
                "<code>goods</code>, "
                "<code>capital_service</code> and "
                "<code>capital_goods</code>",
                "example": "goods",
                "type": "string",
                "x-node_available_in": ["uk", "za"],
                "x-node_unavailable_in": [],
            },
            "project_id": {"example": " ", "type": "string"},
            "recurrence_frequency": {"example": "months", "type": "string"},
            "recurrence_name": {
                "description": "Name of the Recurring Expense. Max-length [100]",
                "example": "Monthly Rental",
                "type": "string",
            },
            "repeat_every": {"example": 1, "type": "string"},
            "reverse_charge_tax_id": {
                "description": "Enter reverse charge tax "
                "ID<br\\><b>For SouthAfrica "
                "edition:</b>(Required if "
                "customer tax treatment is "
                "<code>vat_registered</code>)<br/>Used "
                "to specify whether the "
                "transaction is applicable "
                "for Domestic Reverse Charge "
                "(DRC) or not.",
                "example": 982000000567254,
                "type": "string",
                "x-node_available_in": ["in", "gcc", "za"],
                "x-node_unavailable_in": [],
            },
            "reverse_charge_vat_id": {
                "description": "This is the ID of the tax "
                "applied in case this is a "
                "non UK - service expense and "
                "reverse charge VAT needs to "
                "be reported.",
                "example": " ",
                "type": "string",
                "x-node_available_in": ["in", "uk"],
                "x-node_unavailable_in": [],
            },
            "source_of_supply": {
                "description": "Place from where the "
                "goods/services are supplied. (If "
                "not given, <code>place of "
                "contact</code> given for the "
                "contact will be taken)",
                "example": "AP",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "start_date": {
                "description": "Start date of the recurring expense. "
                "Expenses will not be generated for "
                "dates prior to the current date. Format "
                "[yyyy-mm-dd].",
                "example": "2016-11-19T00:00:00.000Z",
                "type": "string",
            },
            "tax_id": {"example": 982000000566007, "type": "string"},
            "tax_treatment": {
                "description": "VAT treatment for the recurring "
                "expense.Choose whether the contact "
                "falls under: "
                "<code>vat_registered</code>,<code>vat_not_registered</code>,<code>gcc_vat_not_registered</code>,<code>gcc_vat_registered</code>,<code>non_gcc</code>.</br><code>dz_vat_registered</code> "
                "and "
                "<code>dz_vat_not_registered</code> "
                "are supported only for "
                "<b>UAE</b>.<br/><b>For Kenya "
                "Edition:</b> "
                "<code>vat_registered</code> "
                ",<code>vat_not_registered</code> "
                ",<code>non_kenya</code>(A business "
                "that is located outside "
                "Kenya).<br/><b>For SouthAfrica "
                "Edition:</b> "
                "<code>vat_registered</code>, "
                "<code>vat_not_registered</code>, "
                "<code>overseas</code>(A business "
                "that is located outside "
                "SouthAfrica).",
                "example": "vat_registered",
                "type": "string",
                "x-node_available_in": ["gcc", "mx", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "vat_treatment": {
                "description": "VAT treatment for the expense. VAT "
                "treatment denotes the location of "
                "the vendor, if the vendor resides in "
                "UK then the VAT treatment is "
                "<code>uk</code>. If the vendor is in "
                "an EU country & VAT registered, you "
                "are resides in Northen Ireland and "
                "purchasing Goods then his VAT "
                "treatment is "
                "<code>eu_vat_registered</code> and "
                "if he resides outside the UK then "
                "his VAT treatment is "
                "<code>overseas</code>(For Pre "
                "Brexit, this can be split as "
                "<code>eu_vat_registered</code>, "
                "<code>eu_vat_not_registered</code> "
                "and <code>non_eu</code>).",
                "example": "eu_vat_not_registered",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
        },
        "required": [
            "account_id",
            "recurrence_name",
            "start_date",
            "recurrence_frequency",
            "repeat_every",
            "amount",
        ],
        "type": "object",
    },
    "UPDATERECURRINGEXPENSE_REQUEST_BODY_SCHEMA": {
        "properties": {
            "account_id": {"example": 982000000561057, "type": "string"},
            "acquisition_vat_id": {
                "description": "This is the ID of the tax "
                "applied in case this is an EU - "
                "goods expense and acquisition "
                "VAT needs to be reported.",
                "example": " ",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
            "amount": {
                "description": "Recurring Expense amount.",
                "example": 112.5,
                "format": "double",
                "type": "number",
            },
            "currency_id": {"example": 982000000567001, "type": "string"},
            "custom_fields": {
                "description": "Custom fields for a recurring-expense.",
                "items": {
                    "properties": {
                        "customfield_id": {
                            "example": "46000000012845",
                            "format": "int64",
                            "type": "integer",
                        },
                        "value": {
                            "description": "Value of the Custom Field",
                            "example": "Normal",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "customer_id": {
                "description": "Search expenses by customer id.",
                "example": 982000000567001,
                "type": "string",
            },
            "destination_of_supply": {
                "description": "Place where the "
                "goods/services are supplied "
                "to. (If not given, "
                "organisation's home state "
                "will be taken)",
                "example": "TN",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "end_date": {
                "description": "Date on which recurring expense has to "
                "expire. Can be left as empty to run "
                "forever. Format [yyyy-mm-dd].",
                "example": " ",
                "type": "string",
            },
            "exchange_rate": {"example": 1, "format": "double", "type": "number"},
            "gst_no": {
                "description": "15 digit GST identification number of the vendor.",
                "example": "22AAAAA0000A1Z5",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "is_billable": {"example": True, "type": "boolean"},
            "is_inclusive_tax": {"example": False, "type": "boolean"},
            "line_items": {
                "items": {
                    "properties": {
                        "account_id": {"example": 982000000561057, "type": "string"},
                        "acquisition_vat_id": {
                            "description": "This "
                            "is "
                            "the "
                            "ID "
                            "of "
                            "the "
                            "tax "
                            "applied "
                            "in "
                            "case "
                            "this "
                            "is "
                            "an "
                            "EU "
                            "- "
                            "goods "
                            "expense "
                            "and "
                            "acquisition "
                            "VAT "
                            "needs "
                            "to "
                            "be "
                            "reported.",
                            "example": " ",
                            "type": "string",
                            "x-node_available_in": ["uk"],
                            "x-node_unavailable_in": [],
                        },
                        "amount": {
                            "description": "Recurring Expense amount.",
                            "example": 112.5,
                            "format": "double",
                            "type": "number",
                        },
                        "description": {
                            "description": "Search "
                            "recurring "
                            "expenses "
                            "by "
                            "description. "
                            "Max-length "
                            "[100]",
                            "example": " ",
                            "type": "string",
                        },
                        "item_order": {"example": 1, "type": "string"},
                        "line_item_id": {"example": 10763000000140068, "type": "string"},
                        "product_type": {
                            "description": "Type "
                            "of "
                            "the "
                            "expense. "
                            "This "
                            "denotes "
                            "whether "
                            "the "
                            "expense "
                            "is "
                            "to "
                            "be "
                            "treated "
                            "as "
                            "a "
                            "goods "
                            "or "
                            "service "
                            "or "
                            "capital "
                            "asset "
                            "purchase. "
                            "Allowed "
                            "Values:<br/> "
                            "<b>For "
                            "UK "
                            "edition:</b><code>digital_service</code>, "
                            "<code>goods</code> "
                            "and "
                            "<code>service</code>.<br/><b>For "
                            "SouthAfrica "
                            "Edition:</b> "
                            "<code>service</code>, "
                            "<code>goods</code>, "
                            "<code>capital_service</code> "
                            "and "
                            "<code>capital_goods</code>",
                            "example": "goods",
                            "type": "string",
                            "x-node_available_in": ["uk", "za"],
                            "x-node_unavailable_in": [],
                        },
                        "reverse_charge_tax_id": {
                            "description": "Enter "
                            "reverse "
                            "charge "
                            "tax "
                            "ID<br\\><b>For "
                            "SouthAfrica "
                            "edition:</b>(Required "
                            "if "
                            "customer "
                            "tax "
                            "treatment "
                            "is "
                            "<code>vat_registered</code>)<br/>Used "
                            "to "
                            "specify "
                            "whether "
                            "the "
                            "transaction "
                            "is "
                            "applicable "
                            "for "
                            "Domestic "
                            "Reverse "
                            "Charge "
                            "(DRC) "
                            "or "
                            "not.",
                            "example": 982000000567254,
                            "type": "string",
                            "x-node_available_in": ["in", "gcc", "za"],
                            "x-node_unavailable_in": [],
                        },
                        "reverse_charge_vat_id": {
                            "description": "This "
                            "is "
                            "the "
                            "ID "
                            "of "
                            "the "
                            "tax "
                            "applied "
                            "in "
                            "case "
                            "this "
                            "is "
                            "a "
                            "non "
                            "UK "
                            "- "
                            "service "
                            "expense "
                            "and "
                            "reverse "
                            "charge "
                            "VAT "
                            "needs "
                            "to "
                            "be "
                            "reported.",
                            "example": " ",
                            "type": "string",
                            "x-node_available_in": ["in", "uk"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_exemption_code": {
                            "description": "Enter the code for tax exemption",
                            "type": "string",
                            "x-node_available_in": ["in", "mx"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_exemption_id": {
                            "description": "Enter ID of the tax exemption",
                            "example": 982000000567267,
                            "type": "string",
                            "x-node_available_in": ["in", "mx"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_id": {"example": 982000000566007, "type": "string"},
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "location_id": {
                "description": "Location ID",
                "example": "460000000038080",
                "type": "string",
            },
            "place_of_supply": {
                "description": "The place of supply is where a "
                "transaction is considered to have "
                "occurred for VAT purposes. For the "
                "supply of goods, the place of "
                "supply is the location of the "
                "goods when the supply occurs. For "
                "the supply of services, the place "
                "of supply should be where the "
                "supplier is established. (If not "
                "given, <code>place of "
                "contact</code> given for the "
                "contact will be "
                "taken)<br/>Supported codes for UAE "
                "emirates are : </br>Abu Dhabi - "
                "<code>AB</code>,</br>Ajman - "
                "<code>AJ</code>,</br>Dubai - "
                "<code>DU</code>,</br>Fujairah - "
                "<code>FU</code>,</br>Ras "
                "al-Khaimah - "
                "<code>RA</code>,</br>Sharjah - "
                "<code>SH</code>,</br>Umm al-Quwain "
                "- <code>UM</code>.<br/>Supported "
                "codes for the GCC countries are : "
                "</br>United Arab Emirates - "
                "<code>AE</code>,</br>Saudi Arabia "
                "- <code>SA</code>,</br>Bahrain - "
                "<code>BH</code>,</br>Kuwait - "
                "<code>KW</code>,</br>Oman - "
                "<code>OM</code>,</br>Qatar - "
                "<code>QA</code>.",
                "example": "DU",
                "type": "string",
                "x-node_available_in": ["gcc"],
                "x-node_unavailable_in": [],
            },
            "product_type": {
                "description": "Type of the expense. This denotes "
                "whether the expense is to be treated "
                "as a goods or service or capital "
                "asset purchase. Allowed Values:<br/> "
                "<b>For UK "
                "edition:</b><code>digital_service</code>, "
                "<code>goods</code> and "
                "<code>service</code>.<br/><b>For "
                "SouthAfrica Edition:</b> "
                "<code>service</code>, "
                "<code>goods</code>, "
                "<code>capital_service</code> and "
                "<code>capital_goods</code>",
                "example": "goods",
                "type": "string",
                "x-node_available_in": ["uk", "za"],
                "x-node_unavailable_in": [],
            },
            "project_id": {"example": " ", "type": "string"},
            "recurrence_frequency": {"example": "months", "type": "string"},
            "recurrence_name": {
                "description": "Name of the Recurring Expense. Max-length [100]",
                "example": "Monthly Rental",
                "type": "string",
            },
            "repeat_every": {"example": 1, "type": "string"},
            "reverse_charge_tax_id": {
                "description": "Enter reverse charge tax "
                "ID<br\\><b>For SouthAfrica "
                "edition:</b>(Required if "
                "customer tax treatment is "
                "<code>vat_registered</code>)<br/>Used "
                "to specify whether the "
                "transaction is applicable "
                "for Domestic Reverse Charge "
                "(DRC) or not.",
                "example": 982000000567254,
                "type": "string",
                "x-node_available_in": ["in", "gcc", "za"],
                "x-node_unavailable_in": [],
            },
            "reverse_charge_vat_id": {
                "description": "This is the ID of the tax "
                "applied in case this is a "
                "non UK - service expense and "
                "reverse charge VAT needs to "
                "be reported.",
                "example": " ",
                "type": "string",
                "x-node_available_in": ["in", "uk"],
                "x-node_unavailable_in": [],
            },
            "source_of_supply": {
                "description": "Place from where the "
                "goods/services are supplied. (If "
                "not given, <code>place of "
                "contact</code> given for the "
                "contact will be taken)",
                "example": "AP",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "start_date": {
                "description": "Start date of the recurring expense. "
                "Expenses will not be generated for "
                "dates prior to the current date. Format "
                "[yyyy-mm-dd].",
                "example": "2016-11-19T00:00:00.000Z",
                "type": "string",
            },
            "tax_id": {"example": 982000000566007, "type": "string"},
            "tax_treatment": {
                "description": "VAT treatment for the recurring "
                "expense.Choose whether the contact "
                "falls under: "
                "<code>vat_registered</code>,<code>vat_not_registered</code>,<code>gcc_vat_not_registered</code>,<code>gcc_vat_registered</code>,<code>non_gcc</code>.</br><code>dz_vat_registered</code> "
                "and "
                "<code>dz_vat_not_registered</code> "
                "are supported only for "
                "<b>UAE</b>.<br/><b>For Kenya "
                "Edition:</b> "
                "<code>vat_registered</code> "
                ",<code>vat_not_registered</code> "
                ",<code>non_kenya</code>(A business "
                "that is located outside "
                "Kenya).<br/><b>For SouthAfrica "
                "Edition:</b> "
                "<code>vat_registered</code>, "
                "<code>vat_not_registered</code>, "
                "<code>overseas</code>(A business "
                "that is located outside "
                "SouthAfrica).",
                "example": "vat_registered",
                "type": "string",
                "x-node_available_in": ["gcc", "mx", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "vat_treatment": {
                "description": "VAT treatment for the expense. VAT "
                "treatment denotes the location of "
                "the vendor, if the vendor resides in "
                "UK then the VAT treatment is "
                "<code>uk</code>. If the vendor is in "
                "an EU country & VAT registered, you "
                "are resides in Northen Ireland and "
                "purchasing Goods then his VAT "
                "treatment is "
                "<code>eu_vat_registered</code> and "
                "if he resides outside the UK then "
                "his VAT treatment is "
                "<code>overseas</code>(For Pre "
                "Brexit, this can be split as "
                "<code>eu_vat_registered</code>, "
                "<code>eu_vat_not_registered</code> "
                "and <code>non_eu</code>).",
                "example": "eu_vat_not_registered",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
        },
        "required": [
            "account_id",
            "recurrence_name",
            "start_date",
            "recurrence_frequency",
            "repeat_every",
            "amount",
        ],
        "type": "object",
    },
    "MODIFYRECURRINGEXPENSE_REQUEST_BODY_SCHEMA": {
        "properties": {
            "account_id": {"example": 982000000561057, "type": "string"},
            "acquisition_vat_id": {
                "description": "This is the ID of the tax "
                "applied in case this is an EU - "
                "goods expense and acquisition "
                "VAT needs to be reported.",
                "example": " ",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
            "amount": {
                "description": "Recurring Expense amount.",
                "example": 112.5,
                "format": "double",
                "type": "number",
            },
            "currency_id": {"example": 982000000567001, "type": "string"},
            "custom_fields": {
                "description": "Custom fields for a recurring-expense.",
                "items": {
                    "properties": {
                        "customfield_id": {
                            "example": "46000000012845",
                            "format": "int64",
                            "type": "integer",
                        },
                        "value": {
                            "description": "Value of the Custom Field",
                            "example": "Normal",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "customer_id": {
                "description": "Search expenses by customer id.",
                "example": 982000000567001,
                "type": "string",
            },
            "destination_of_supply": {
                "description": "Place where the "
                "goods/services are supplied "
                "to. (If not given, "
                "organisation's home state "
                "will be taken)",
                "example": "TN",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "end_date": {
                "description": "Date on which recurring expense has to "
                "expire. Can be left as empty to run "
                "forever. Format [yyyy-mm-dd].",
                "example": " ",
                "type": "string",
            },
            "exchange_rate": {"example": 1, "format": "double", "type": "number"},
            "gst_no": {
                "description": "15 digit GST identification number of the vendor.",
                "example": "22AAAAA0000A1Z5",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "is_billable": {"example": True, "type": "boolean"},
            "is_inclusive_tax": {"example": False, "type": "boolean"},
            "line_items": {
                "items": {
                    "properties": {
                        "account_id": {"example": 982000000561057, "type": "string"},
                        "acquisition_vat_id": {
                            "description": "This "
                            "is "
                            "the "
                            "ID "
                            "of "
                            "the "
                            "tax "
                            "applied "
                            "in "
                            "case "
                            "this "
                            "is "
                            "an "
                            "EU "
                            "- "
                            "goods "
                            "expense "
                            "and "
                            "acquisition "
                            "VAT "
                            "needs "
                            "to "
                            "be "
                            "reported.",
                            "example": " ",
                            "type": "string",
                            "x-node_available_in": ["uk"],
                            "x-node_unavailable_in": [],
                        },
                        "amount": {
                            "description": "Recurring Expense amount.",
                            "example": 112.5,
                            "format": "double",
                            "type": "number",
                        },
                        "description": {
                            "description": "Search "
                            "recurring "
                            "expenses "
                            "by "
                            "description. "
                            "Max-length "
                            "[100]",
                            "example": " ",
                            "type": "string",
                        },
                        "item_order": {"example": 1, "type": "string"},
                        "line_item_id": {"example": 10763000000140068, "type": "string"},
                        "product_type": {
                            "description": "Type "
                            "of "
                            "the "
                            "expense. "
                            "This "
                            "denotes "
                            "whether "
                            "the "
                            "expense "
                            "is "
                            "to "
                            "be "
                            "treated "
                            "as "
                            "a "
                            "goods "
                            "or "
                            "service "
                            "or "
                            "capital "
                            "asset "
                            "purchase. "
                            "Allowed "
                            "Values:<br/> "
                            "<b>For "
                            "UK "
                            "edition:</b><code>digital_service</code>, "
                            "<code>goods</code> "
                            "and "
                            "<code>service</code>.<br/><b>For "
                            "SouthAfrica "
                            "Edition:</b> "
                            "<code>service</code>, "
                            "<code>goods</code>, "
                            "<code>capital_service</code> "
                            "and "
                            "<code>capital_goods</code>",
                            "example": "goods",
                            "type": "string",
                            "x-node_available_in": ["uk", "za"],
                            "x-node_unavailable_in": [],
                        },
                        "reverse_charge_tax_id": {
                            "description": "Enter "
                            "reverse "
                            "charge "
                            "tax "
                            "ID<br\\><b>For "
                            "SouthAfrica "
                            "edition:</b>(Required "
                            "if "
                            "customer "
                            "tax "
                            "treatment "
                            "is "
                            "<code>vat_registered</code>)<br/>Used "
                            "to "
                            "specify "
                            "whether "
                            "the "
                            "transaction "
                            "is "
                            "applicable "
                            "for "
                            "Domestic "
                            "Reverse "
                            "Charge "
                            "(DRC) "
                            "or "
                            "not.",
                            "example": 982000000567254,
                            "type": "string",
                            "x-node_available_in": ["in", "gcc", "za"],
                            "x-node_unavailable_in": [],
                        },
                        "reverse_charge_vat_id": {
                            "description": "This "
                            "is "
                            "the "
                            "ID "
                            "of "
                            "the "
                            "tax "
                            "applied "
                            "in "
                            "case "
                            "this "
                            "is "
                            "a "
                            "non "
                            "UK "
                            "- "
                            "service "
                            "expense "
                            "and "
                            "reverse "
                            "charge "
                            "VAT "
                            "needs "
                            "to "
                            "be "
                            "reported.",
                            "example": " ",
                            "type": "string",
                            "x-node_available_in": ["in", "uk"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_exemption_code": {
                            "description": "Enter the code for tax exemption",
                            "type": "string",
                            "x-node_available_in": ["in", "mx"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_exemption_id": {
                            "description": "Enter ID of the tax exemption",
                            "example": 982000000567267,
                            "type": "string",
                            "x-node_available_in": ["in", "mx"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_id": {"example": 982000000566007, "type": "string"},
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "location_id": {
                "description": "Location ID",
                "example": "460000000038080",
                "type": "string",
            },
            "place_of_supply": {
                "description": "The place of supply is where a "
                "transaction is considered to have "
                "occurred for VAT purposes. For the "
                "supply of goods, the place of "
                "supply is the location of the "
                "goods when the supply occurs. For "
                "the supply of services, the place "
                "of supply should be where the "
                "supplier is established. (If not "
                "given, <code>place of "
                "contact</code> given for the "
                "contact will be "
                "taken)<br/>Supported codes for UAE "
                "emirates are : </br>Abu Dhabi - "
                "<code>AB</code>,</br>Ajman - "
                "<code>AJ</code>,</br>Dubai - "
                "<code>DU</code>,</br>Fujairah - "
                "<code>FU</code>,</br>Ras "
                "al-Khaimah - "
                "<code>RA</code>,</br>Sharjah - "
                "<code>SH</code>,</br>Umm al-Quwain "
                "- <code>UM</code>.<br/>Supported "
                "codes for the GCC countries are : "
                "</br>United Arab Emirates - "
                "<code>AE</code>,</br>Saudi Arabia "
                "- <code>SA</code>,</br>Bahrain - "
                "<code>BH</code>,</br>Kuwait - "
                "<code>KW</code>,</br>Oman - "
                "<code>OM</code>,</br>Qatar - "
                "<code>QA</code>.",
                "example": "DU",
                "type": "string",
                "x-node_available_in": ["gcc"],
                "x-node_unavailable_in": [],
            },
            "product_type": {
                "description": "Type of the expense. This denotes "
                "whether the expense is to be treated "
                "as a goods or service or capital "
                "asset purchase. Allowed Values:<br/> "
                "<b>For UK "
                "edition:</b><code>digital_service</code>, "
                "<code>goods</code> and "
                "<code>service</code>.<br/><b>For "
                "SouthAfrica Edition:</b> "
                "<code>service</code>, "
                "<code>goods</code>, "
                "<code>capital_service</code> and "
                "<code>capital_goods</code>",
                "example": "goods",
                "type": "string",
                "x-node_available_in": ["uk", "za"],
                "x-node_unavailable_in": [],
            },
            "project_id": {"example": " ", "type": "string"},
            "recurrence_frequency": {"example": "months", "type": "string"},
            "recurrence_name": {
                "description": "Name of the Recurring Expense. Max-length [100]",
                "example": "Monthly Rental",
                "type": "string",
            },
            "repeat_every": {"example": 1, "type": "string"},
            "reverse_charge_tax_id": {
                "description": "Enter reverse charge tax "
                "ID<br\\><b>For SouthAfrica "
                "edition:</b>(Required if "
                "customer tax treatment is "
                "<code>vat_registered</code>)<br/>Used "
                "to specify whether the "
                "transaction is applicable "
                "for Domestic Reverse Charge "
                "(DRC) or not.",
                "example": 982000000567254,
                "type": "string",
                "x-node_available_in": ["in", "gcc", "za"],
                "x-node_unavailable_in": [],
            },
            "reverse_charge_vat_id": {
                "description": "This is the ID of the tax "
                "applied in case this is a "
                "non UK - service expense and "
                "reverse charge VAT needs to "
                "be reported.",
                "example": " ",
                "type": "string",
                "x-node_available_in": ["in", "uk"],
                "x-node_unavailable_in": [],
            },
            "source_of_supply": {
                "description": "Place from where the "
                "goods/services are supplied. (If "
                "not given, <code>place of "
                "contact</code> given for the "
                "contact will be taken)",
                "example": "AP",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "start_date": {
                "description": "Start date of the recurring expense. "
                "Expenses will not be generated for "
                "dates prior to the current date. Format "
                "[yyyy-mm-dd].",
                "example": "2016-11-19T00:00:00.000Z",
                "type": "string",
            },
            "tax_id": {"example": 982000000566007, "type": "string"},
            "tax_treatment": {
                "description": "VAT treatment for the recurring "
                "expense.Choose whether the contact "
                "falls under: "
                "<code>vat_registered</code>,<code>vat_not_registered</code>,<code>gcc_vat_not_registered</code>,<code>gcc_vat_registered</code>,<code>non_gcc</code>.</br><code>dz_vat_registered</code> "
                "and "
                "<code>dz_vat_not_registered</code> "
                "are supported only for "
                "<b>UAE</b>.<br/><b>For Kenya "
                "Edition:</b> "
                "<code>vat_registered</code> "
                ",<code>vat_not_registered</code> "
                ",<code>non_kenya</code>(A business "
                "that is located outside "
                "Kenya).<br/><b>For SouthAfrica "
                "Edition:</b> "
                "<code>vat_registered</code>, "
                "<code>vat_not_registered</code>, "
                "<code>overseas</code>(A business "
                "that is located outside "
                "SouthAfrica).",
                "example": "vat_registered",
                "type": "string",
                "x-node_available_in": ["gcc", "mx", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "vat_treatment": {
                "description": "VAT treatment for the expense. VAT "
                "treatment denotes the location of "
                "the vendor, if the vendor resides in "
                "UK then the VAT treatment is "
                "<code>uk</code>. If the vendor is in "
                "an EU country & VAT registered, you "
                "are resides in Northen Ireland and "
                "purchasing Goods then his VAT "
                "treatment is "
                "<code>eu_vat_registered</code> and "
                "if he resides outside the UK then "
                "his VAT treatment is "
                "<code>overseas</code>(For Pre "
                "Brexit, this can be split as "
                "<code>eu_vat_registered</code>, "
                "<code>eu_vat_not_registered</code> "
                "and <code>non_eu</code>).",
                "example": "eu_vat_not_registered",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
        },
        "required": [
            "account_id",
            "recurrence_name",
            "start_date",
            "recurrence_frequency",
            "repeat_every",
            "amount",
        ],
        "type": "object",
    },
    "CREATERECURRINGINVOICE_REQUEST_BODY_SCHEMA": {
        "properties": {
            "adjustment": {
                "description": "Adjustments made to the invoice.",
                "example": 0,
                "format": "double",
                "type": "number",
            },
            "adjustment_description": {
                "description": "Customize the adjustment description. E.g: Rounding off.",
                "example": "Rounding off",
                "type": "string",
            },
            "allow_partial_payments": {
                "description": "Choose <code>false</code> "
                "for PPU-Single Payments and "
                "<code>true</code> for "
                "PPD-Installment Payments",
                "example": True,
                "type": "boolean",
                "x-node_available_in": ["mx"],
                "x-node_unavailable_in": [],
            },
            "avatax_exempt_no": {
                "description": "Exemption certificate number of the customer. Max-length [25]",
                "type": "string",
                "x-node_available_in": ["Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "avatax_tax_code": {
                "description": "A tax code is a unique label used to group items together.",
                "example": " ",
                "type": "string",
            },
            "avatax_use_code": {
                "description": "Used to group like customers for "
                "exemption purposes. It is a custom "
                "value that links customers to a "
                "tax rule. Select from Avalara "
                "[standard codes][1] or enter a "
                "custom code. Max-length [25]",
                "type": "string",
                "x-node_available_in": ["Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "billing_address": {
                "properties": {
                    "address": {
                        "description": "Billing address for the invoice",
                        "example": "4900 Hopyard Rd, Suite 310",
                        "type": "string",
                    },
                    "city": {
                        "description": "City of the customer's billing address.",
                        "example": "Pleasanton",
                        "type": "string",
                    },
                    "country": {
                        "description": "Country of the customer's billing address.",
                        "example": "U.S.A",
                        "type": "string",
                    },
                    "fax": {
                        "description": "Customer's fax number.",
                        "example": "+1-925-924-9600",
                        "type": "string",
                    },
                    "state": {
                        "description": "State of the customer's billing address.",
                        "example": "CA",
                        "type": "string",
                    },
                    "street2": {"example": "McMillan Avenue", "type": "string"},
                    "zip": {
                        "description": "Zip code of the customer's billing address.",
                        "example": "94588",
                        "type": "string",
                    },
                },
                "type": "object",
            },
            "cfdi_usage": {
                "description": "Choose CFDI Usage.</br>Allowed values: "
                "<code>acquisition_of_merchandise</code>, "
                "<code>return_discount_bonus</code>, "
                "<code>general_expense</code>, "
                "<code>buildings</code>, "
                "<code>furniture_office_equipment</code>, "
                "<code>transport_equipment</code>, "
                "<code>computer_equipmentdye_molds_tools</code>, "
                "<code>telephone_communication</code>, "
                "<code>satellite_communication</code>, "
                "<code>other_machinery_equipment</code>, "
                "<code>hospital_expense</code>, "
                "<code>medical_expense_disability</code>, "
                "<code>funeral_expense</code>, "
                "<code>donation</code>, "
                "<code>interest_mortage_loans</code>, "
                "<code>contribution_sar</code>, "
                "<code>medical_expense_insurance_pormium</code>, "
                "<code>school_transportation_expense</code>, "
                "<code>deposit_saving_account</code>, "
                "<code>payment_educational_service</code>, "
                "<code>no_tax_effect</code>, "
                "<code>payment</code>, "
                "<code>payroll</code>.",
                "example": "acquisition_of_merchandise",
                "type": "string",
                "x-node_available_in": ["mx"],
                "x-node_unavailable_in": [],
            },
            "contact_persons_associated": {
                "description": "Contact Persons associated with the transaction.",
                "items": {
                    "properties": {
                        "communication_preference": {
                            "description": "Preferred "
                            "modes "
                            "of "
                            "communication "
                            "for "
                            "the "
                            "contact "
                            "person "
                            "at "
                            "transaction "
                            "level.",
                            "properties": {
                                "is_email_enabled": {
                                    "description": "Used "
                                    "to "
                                    "check "
                                    "if "
                                    "Email "
                                    "communication "
                                    "preference "
                                    "is "
                                    "enabled "
                                    "for "
                                    "the "
                                    "contact "
                                    "person "
                                    "at "
                                    "transaction "
                                    "level.",
                                    "example": True,
                                    "type": "boolean",
                                },
                                "is_whatsapp_enabled": {
                                    "description": "Used "
                                    "to "
                                    "check "
                                    "if "
                                    "WhatsApp "
                                    "communication "
                                    "preference "
                                    "is "
                                    "enabled "
                                    "for "
                                    "the "
                                    "contact "
                                    "person "
                                    "at "
                                    "transaction "
                                    "level.",
                                    "example": True,
                                    "type": "boolean",
                                    "x-node_available_in": ["WhatsApp integration"],
                                },
                            },
                            "type": "object",
                        },
                        "contact_person_id": {
                            "description": "Unique ID of the Contact Person.",
                            "example": 982000000567003,
                            "format": "int64",
                            "type": "integer",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "currency_id": {
                "description": "The currenct id of the currency",
                "example": "982000000000190",
                "type": "string",
            },
            "custom_fields": {
                "items": {
                    "properties": {
                        "data_type": {
                            "description": "Data type of the custom field.",
                            "example": "text",
                            "type": "string",
                        },
                        "label": {
                            "description": "Label of the custom field.",
                            "example": "label",
                            "type": "string",
                        },
                        "value": {
                            "description": "Value of the custom field.",
                            "example": "129890",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "customer_id": {
                "description": "Customer ID of the customer for whom "
                "the recurring invoice is raised.",
                "example": "903000000000099",
                "type": "string",
            },
            "description": {
                "description": "A small description about the item. Max-length [2000]",
                "example": "prorated amount for items",
                "type": "string",
            },
            "discount": {
                "description": "Discount applied to the invoice. It can "
                "be either in % or in amount. E.g: 12.5% "
                "or 190.",
                "example": "30%",
                "type": "string",
            },
            "discount_type": {
                "description": "How the discount is specified. "
                "Allowed values: "
                "<code>entity_level</code> and "
                "<code>item_level</code>.",
                "example": "entity level",
                "type": "string",
            },
            "email": {
                "description": "Email address of the customer.",
                "example": "benjamin.george@bowmanfurniture.com",
                "type": "string",
            },
            "end_date": {
                "description": "The date on which the recurring invoice expires.",
                "example": "2017-06-12",
                "type": "string",
            },
            "exchange_rate": {
                "description": "Exchange rate for the currency associated with the customer.",
                "example": "5.5",
                "type": "string",
            },
            "gst_no": {
                "description": "15 digit GST identification number of the customer.",
                "example": "22AAAAA0000A1Z5",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "gst_treatment": {
                "description": "Choose whether the contact is GST "
                "registered/unregistered/consumer/overseas. "
                "Allowed values are <code> "
                "business_gst </code> , <code> "
                "business_none </code> , <code> "
                "overseas </code> , <code> consumer "
                "</code>.",
                "example": "business_gst",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "is_discount_before_tax": {
                "description": "Used to specify how the "
                "discount has to applied. "
                "Either before or after the "
                "calculation of tax.",
                "example": True,
                "type": "boolean",
            },
            "is_inclusive_tax": {
                "description": "Used to specify whether the line "
                "item rates are inclusive or "
                "exclusive of tax.",
                "example": False,
                "type": "boolean",
                "x-node_available_in": [],
                "x-node_unavailable_in": ["us", "ca"],
            },
            "is_reverse_charge_applied": {
                "description": "(Required if customer "
                "tax treatment is "
                "<code>vat_registered</code>)<br/>Used "
                "to specify whether the "
                "transaction is "
                "applicable for Domestic "
                "Reverse Charge (DRC) or "
                "not.",
                "example": True,
                "type": "boolean",
                "x-node_available_in": ["za"],
                "x-node_unavailable_in": [],
            },
            "item_id": {
                "description": "Unique string generated for the item for "
                "which invoice is to be sent.",
                "example": "90300000081501",
                "type": "string",
            },
            "line_items": {
                "description": "Line items of an invoice.",
                "items": {
                    "properties": {
                        "header_name": {
                            "description": "Name of the item header",
                            "example": "Electronic devices",
                            "type": "string",
                        },
                        "hsn_or_sac": {
                            "description": "Add HSN/SAC code for your goods/services",
                            "example": 80540,
                            "type": "string",
                            "x-node_available_in": ["in", "ke", "za"],
                            "x-node_unavailable_in": [],
                        },
                        "item_total": {
                            "description": "Total "
                            "rate "
                            "raised "
                            "by "
                            "this "
                            "item. "
                            "This "
                            "would "
                            "be "
                            "the "
                            "multiplicative "
                            "product "
                            "of "
                            "item "
                            "price "
                            "and "
                            "quantity.",
                            "example": 100,
                            "format": "double",
                            "type": "number",
                        },
                        "line_item_id": {
                            "description": "The line item id",
                            "example": "982000000567021",
                            "type": "string",
                        },
                        "location_id": {
                            "description": "Location ID",
                            "example": "460000000038080",
                            "type": "string",
                        },
                        "name": {
                            "description": "The name of the line item. max-length [100]",
                            "example": "Hard Drive",
                            "type": "string",
                        },
                        "product_type": {
                            "description": "Enter "
                            "<code>goods</code> "
                            "or "
                            "<code>services</code> "
                            ".<br/><b>For "
                            "SouthAfrica "
                            "Edition:</b> "
                            "<code>service</code>, "
                            "<code>goods</code>, "
                            "<code>capital_service</code> "
                            "and "
                            "<code>capital_goods</code>",
                            "example": "goods",
                            "type": "string",
                        },
                        "project_id": {
                            "description": "ID of the project",
                            "example": 90300000087378,
                            "type": "string",
                        },
                        "quantity": {
                            "description": "Quantity of the item included.",
                            "example": 1,
                            "format": "int32",
                            "type": "integer",
                        },
                        "sat_item_key_code": {
                            "description": "Add "
                            "SAT "
                            "Item "
                            "Key "
                            "Code "
                            "for "
                            "your "
                            "goods/services. "
                            "Download "
                            "the "
                            "<a "
                            "href= "
                            "http://omawww.sat.gob.mx/tramitesyservicios/Paginas/documentos/catCFDI_V_4_07122022.xls  "
                            ">CFDI "
                            "Catalogs.</a>",
                            "example": 71121206,
                            "type": "string",
                            "x-node_available_in": ["mx"],
                            "x-node_unavailable_in": [],
                        },
                        "tags": {
                            "description": "Filter all your reports based on the tag",
                            "items": {
                                "properties": {
                                    "tag_id": {
                                        "description": "ID of the reporting tag",
                                        "example": 982000000009070,
                                        "type": "string",
                                    },
                                    "tag_option_id": {
                                        "description": "ID of the reporting tag's option",
                                        "example": 982000000002670,
                                        "type": "string",
                                    },
                                },
                                "type": "object",
                            },
                            "type": "array",
                        },
                        "tax_id": {
                            "description": "ID "
                            "of "
                            "the "
                            "tax "
                            "or "
                            "tax "
                            "group "
                            "associated "
                            "to "
                            "the "
                            "recurring "
                            "invoice.",
                            "example": "903000000000356",
                        },
                        "tax_treatment_code": {
                            "description": "Specify "
                            "reason "
                            "for "
                            "using "
                            "out "
                            "of "
                            "scope.</br>Supported "
                            "values "
                            "for "
                            "UAE "
                            "are "
                            "<code>uae_same_tax_group</code>, "
                            "<code>uae_reimbursed_expense</code> "
                            "and "
                            "<code>uae_others</code>.</br> "
                            "Supported "
                            "values "
                            "for "
                            "Bahrain "
                            "are "
                            "<code>bahrain_same_tax_group</code>, "
                            "<code>bahrain_transfer_of_concern</code>, "
                            "<code>bahrain_disbursement</code>, "
                            "<code>bahrain_head_to_branch_transaction</code>, "
                            "<code>bahrain_warranty_repair_services</code> "
                            "and "
                            "<code>bahrain_others</code>.</br>Supported "
                            "values "
                            "for "
                            "Saudi "
                            "Arabia "
                            "are "
                            "<code>ksa_pvt_health</code>, "
                            "<code>ksa_pvt_edu</code>, "
                            "<code>ksa_reimbursed_expense</code> "
                            "and "
                            "<code>ksa_house_sales</code>.",
                            "example": "uae_others",
                            "type": "string",
                            "x-node_available_in": ["gcc"],
                            "x-node_unavailable_in": [],
                        },
                        "tds_tax_id": {
                            "description": "ID "
                            "of "
                            "the "
                            "TDS "
                            "tax "
                            "or "
                            "TDS "
                            "tax "
                            "group "
                            "associated "
                            "to "
                            "the "
                            "recurring "
                            "invoice.",
                            "example": "903000000000357",
                            "type": "string",
                            "x-node_available_in": ["mx"],
                            "x-node_unavailable_in": [],
                        },
                        "unitkey_code": {
                            "description": "Add "
                            "SAT "
                            "Unit "
                            "Key "
                            "Code "
                            "for "
                            "your "
                            "goods/services. "
                            "Download "
                            "the "
                            "<a "
                            "href= "
                            "http://omawww.sat.gob.mx/tramitesyservicios/Paginas/documentos/catCFDI_V_4_07122022.xls  "
                            ">CFDI "
                            "Catalogs.</a>",
                            "example": "box",
                            "type": "string",
                            "x-node_available_in": ["mx"],
                            "x-node_unavailable_in": [],
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "location_id": {
                "description": "Location ID",
                "example": "460000000038080",
                "type": "string",
            },
            "name": {
                "description": "The name of the line item. max-length [100]",
                "example": "Hard Drive",
                "type": "string",
            },
            "payment_options": {
                "properties": {
                    "payment_gateways": {
                        "items": {
                            "properties": {
                                "additional_field1": {
                                    "description": "Paypal "
                                    "payment "
                                    "method. "
                                    "Allowed "
                                    "Values: "
                                    "<code>standard</code> "
                                    "and "
                                    "<code>adaptive</code>",
                                    "example": "standard",
                                    "type": "string",
                                },
                                "configured": {
                                    "description": "Boolean "
                                    "check "
                                    "to "
                                    "see "
                                    "if "
                                    "a "
                                    "payment "
                                    "gateway "
                                    "ahs "
                                    "been "
                                    "configured",
                                    "example": True,
                                    "type": "boolean",
                                },
                                "gateway_name": {
                                    "description": "Name "
                                    "of "
                                    "the "
                                    "payment "
                                    "gateway "
                                    "associated "
                                    "with "
                                    "the "
                                    "invoice. "
                                    "E.g. "
                                    "paypal, "
                                    "stripe.Allowed "
                                    "Values: "
                                    "<code>paypal</code>, "
                                    "<code>authorize_net</code>, "
                                    "<code>payflow_pro</code>, "
                                    "<code>stripe</code>, "
                                    "<code>2checkout</code> "
                                    "and "
                                    "<code>braintree</code>",
                                    "example": "paypal",
                                    "type": "string",
                                },
                            },
                            "type": "object",
                        },
                        "type": "array",
                    }
                },
                "type": "object",
            },
            "payment_terms": {
                "description": "Payment terms in days. E.g: "
                "15,30,60. Invoice due date will be "
                "calculated based on this.",
                "example": 0,
                "type": "integer",
            },
            "payment_terms_label": {
                "description": "Used to overridethe default "
                "payment terms label. Default "
                'value for 15 days is "Next 15 '
                'days".',
                "example": "Next 15 days",
                "type": "string",
            },
            "place_of_supply": {
                "description": "Place where the goods/services are "
                "supplied to. (If not given, "
                "<code>place of contact</code> "
                "given for the contact will be "
                "taken)<br/>Supported codes for UAE "
                "emirates are : </br>Abu Dhabi - "
                "<code>AB</code>,</br>Ajman - "
                "<code>AJ</code>,</br>Dubai - "
                "<code>DU</code>,</br>Fujairah - "
                "<code>FU</code>,</br>Ras "
                "al-Khaimah - "
                "<code>RA</code>,</br>Sharjah - "
                "<code>SH</code>,</br>Umm al-Quwain "
                "- <code>UM</code><br/>Supported "
                "codes for the GCC countries are : "
                "</br>United Arab Emirates - "
                "<code>AE</code>,</br>Saudi Arabia "
                "- <code>SA</code>,</br>Bahrain - "
                "<code>BH</code>,</br>Kuwait - "
                "<code>KW</code>,</br>Oman - "
                "<code>OM</code>,</br>Qatar - "
                "<code>QA</code>.",
                "example": "TN",
                "type": "string",
                "x-node_available_in": ["in", "gcc"],
                "x-node_unavailable_in": [],
            },
            "quantity": {
                "description": "Quantity of the item included.",
                "example": 1,
                "format": "int32",
                "type": "integer",
            },
            "rate": {
                "description": "Rate of the line item.",
                "example": 0,
                "format": "double",
                "type": "number",
            },
            "recurrence_frequency": {
                "description": "The frequency of time "
                "interval at which the invoice "
                "is to be generated.",
                "enum": ["weeks"],
                "example": "weeks",
                "type": "string",
            },
            "recurrence_name": {
                "description": "Unique name for the recurring "
                "profile given by the user. "
                "Max-length [100]",
                "example": "MonthlyInvoice",
                "type": "string",
            },
            "reference_number": {
                "description": "The Order number of the Recurring Invoice.",
                "example": "12314",
                "type": "string",
            },
            "repeat_every": {
                "description": "The period between every recurrency frequency.",
                "example": 2,
                "type": "integer",
            },
            "salesperson_name": {
                "description": "Name of the sales person",
                "example": " ",
                "type": "string",
                "x-node_available_in": ["us", "au", "ca"],
                "x-node_unavailable_in": [],
            },
            "shipping_address": {
                "properties": {
                    "address": {
                        "description": "Billing address for the invoice",
                        "example": "4900 Hopyard Rd, Suite 310",
                        "type": "string",
                    },
                    "city": {
                        "description": "City of the customer's billing address.",
                        "example": "Pleasanton",
                        "type": "string",
                    },
                    "country": {
                        "description": "Country of the customer's billing address.",
                        "example": "U.S.A",
                        "type": "string",
                    },
                    "fax": {
                        "description": "Customer's fax number.",
                        "example": "+1-925-924-9600",
                        "type": "string",
                    },
                    "state": {
                        "description": "State of the customer's billing address.",
                        "example": "CA",
                        "type": "string",
                    },
                    "zip": {
                        "description": "Zip code of the customer's billing address.",
                        "example": "94588",
                        "type": "string",
                    },
                },
                "type": "object",
            },
            "shipping_charge": {
                "description": "Shipping charges applied to the invoice.",
                "example": 0,
                "format": "double",
                "type": "number",
            },
            "start_date": {
                "description": "The date on which the recurring invoice starts.",
                "example": "2016-06-12",
                "type": "string",
            },
            "tax_authority_id": {
                "description": "Unique ID of the tax authority. "
                "Tax authority depends on the "
                "location of the customer. For "
                "example, if the customer is "
                "located in NY, then the tax "
                "authority is NY tax authority.",
                "example": "903000006345",
                "type": "string",
                "x-node_available_in": ["us"],
                "x-node_unavailable_in": [],
            },
            "tax_exemption_id": {
                "description": "Unique ID of the tax exemption.",
                "example": "903000006345",
                "type": "string",
                "x-node_available_in": ["in", "us", "au", "ca"],
                "x-node_unavailable_in": [],
            },
            "tax_id": {
                "description": "ID of the tax or tax group associated to the recurring invoice.",
                "example": "903000000000356",
            },
            "tax_treatment": {
                "description": "Choose whether the vat treatment for "
                "the contact falls under: "
                "<code>vat_registered</code>,<code>vat_not_registered</code>,<code>gcc_vat_not_registered</code>,<code>gcc_vat_registered</code>,<code>non_gcc</code>.</br><code>dz_vat_registered</code> "
                "and "
                "<code>dz_vat_not_registered</code> "
                "supported only for "
                "<b>UAE</b>.</br><code>home_country_mexico</code>,<code>border_region_mexico</code>,<code>non_mexico</code> "
                "supported only for <b>MX</b>. "
                "<br/><b>For Kenya Edition:</b> "
                "<code>vat_registered</code> "
                ",<code>vat_not_registered</code> "
                ",<code>non_kenya</code>(A business "
                "that is located outside "
                "Kenya).<br/><b>For SouthAfrica "
                "Edition:</b> "
                "<code>vat_registered</code>, "
                "<code>vat_not_registered</code>, "
                "<code>overseas</code>(A business "
                "that is located outside "
                "SouthAfrica).",
                "example": "vat_registered",
                "type": "string",
                "x-node_available_in": ["gcc", "mx", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "template_id": {
                "description": "Unique ID of the recurring invoice template.",
                "example": "90300000001336",
                "type": "string",
            },
            "unit": {
                "description": "Unit of the line item. E.g: kgs, Nos.",
                "example": "kgs",
                "type": "string",
            },
            "vat_treatment": {
                "description": "(Optional) VAT treatment for the "
                "invoices. VAT treatment denotes the "
                "location of the customer, if the "
                "customer resides in UK then the VAT "
                "treatment is <code>uk</code>. If the "
                "customer is in an EU country & VAT "
                "registered, you are resides in "
                "Northen Ireland and selling Goods "
                "then his VAT treatment is "
                "<code>eu_vat_registered</code>, if "
                "he resides outside of the UK then "
                "his VAT treatment is "
                "<code>overseas</code> (For Pre "
                "Brexit, this can be split as "
                "<code>eu_vat_registered</code>, "
                "<code>eu_vat_not_registered</code> "
                "and <code>non_eu</code>).",
                "example": "overseas",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
        },
        "required": ["recurrence_name", "customer_id", "recurrence_frequency"],
        "type": "object",
    },
    "UPDATERECURRINGINVOICECUSTOMFIELD_REQUEST_BODY_SCHEMA": {
        "properties": {
            "allow_partial_payments": {
                "description": "Choose <code>false</code> "
                "for PPU-Single Payments and "
                "<code>true</code> for "
                "PPD-Installment Payments",
                "example": True,
                "type": "boolean",
                "x-node_available_in": ["mx"],
                "x-node_unavailable_in": [],
            },
            "avatax_exempt_no": {
                "description": "Exemption certificate number of the customer. Max-length [25]",
                "type": "string",
                "x-node_available_in": ["Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "avatax_use_code": {
                "description": "Used to group like customers for "
                "exemption purposes. It is a custom "
                "value that links customers to a "
                "tax rule. Select from Avalara "
                "[standard codes][1] or enter a "
                "custom code. Max-length [25]",
                "type": "string",
                "x-node_available_in": ["Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "cfdi_usage": {
                "description": "Choose CFDI Usage.</br>Allowed values: "
                "<code>acquisition_of_merchandise</code>, "
                "<code>return_discount_bonus</code>, "
                "<code>general_expense</code>, "
                "<code>buildings</code>, "
                "<code>furniture_office_equipment</code>, "
                "<code>transport_equipment</code>, "
                "<code>computer_equipmentdye_molds_tools</code>, "
                "<code>telephone_communication</code>, "
                "<code>satellite_communication</code>, "
                "<code>other_machinery_equipment</code>, "
                "<code>hospital_expense</code>, "
                "<code>medical_expense_disability</code>, "
                "<code>funeral_expense</code>, "
                "<code>donation</code>, "
                "<code>interest_mortage_loans</code>, "
                "<code>contribution_sar</code>, "
                "<code>medical_expense_insurance_pormium</code>, "
                "<code>school_transportation_expense</code>, "
                "<code>deposit_saving_account</code>, "
                "<code>payment_educational_service</code>, "
                "<code>no_tax_effect</code>, "
                "<code>payment</code>, "
                "<code>payroll</code>.",
                "example": "acquisition_of_merchandise",
                "type": "string",
                "x-node_available_in": ["mx"],
                "x-node_unavailable_in": [],
            },
            "contact_persons_associated": {
                "description": "Contact Persons associated with the transaction.",
                "items": {
                    "properties": {
                        "communication_preference": {
                            "description": "Preferred "
                            "modes "
                            "of "
                            "communication "
                            "for "
                            "the "
                            "contact "
                            "person "
                            "at "
                            "transaction "
                            "level.",
                            "properties": {
                                "is_email_enabled": {
                                    "description": "Used "
                                    "to "
                                    "check "
                                    "if "
                                    "Email "
                                    "communication "
                                    "preference "
                                    "is "
                                    "enabled "
                                    "for "
                                    "the "
                                    "contact "
                                    "person "
                                    "at "
                                    "transaction "
                                    "level.",
                                    "example": True,
                                    "type": "boolean",
                                },
                                "is_whatsapp_enabled": {
                                    "description": "Used "
                                    "to "
                                    "check "
                                    "if "
                                    "WhatsApp "
                                    "communication "
                                    "preference "
                                    "is "
                                    "enabled "
                                    "for "
                                    "the "
                                    "contact "
                                    "person "
                                    "at "
                                    "transaction "
                                    "level.",
                                    "example": True,
                                    "type": "boolean",
                                    "x-node_available_in": ["WhatsApp integration"],
                                },
                            },
                            "type": "object",
                        },
                        "contact_person_id": {
                            "description": "Unique ID of the Contact Person.",
                            "example": 982000000567003,
                            "format": "int64",
                            "type": "integer",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "currency_id": {
                "description": "The currenct id of the currency",
                "example": "982000000000190",
                "type": "string",
            },
            "custom_fields": {
                "items": {
                    "properties": {
                        "data_type": {
                            "description": "Data type of the custom field.",
                            "example": "text",
                            "type": "string",
                        },
                        "label": {
                            "description": "Label of the custom field.",
                            "example": "label",
                            "type": "string",
                        },
                        "value": {
                            "description": "Value of the custom field.",
                            "example": "129890",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "customer_id": {
                "description": "Customer ID of the customer for whom "
                "the recurring invoice is raised.",
                "example": "903000000000099",
                "type": "string",
            },
            "email": {
                "description": "Email address of the customer.",
                "example": "benjamin.george@bowmanfurniture.com",
                "type": "string",
            },
            "end_date": {
                "description": "The date on which the recurring invoice expires.",
                "example": "2017-06-12",
                "type": "string",
            },
            "gst_no": {
                "description": "15 digit GST identification number of the customer.",
                "example": "22AAAAA0000A1Z5",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "gst_treatment": {
                "description": "Choose whether the contact is GST "
                "registered/unregistered/consumer/overseas. "
                "Allowed values are <code> "
                "business_gst </code> , <code> "
                "business_none </code> , <code> "
                "overseas </code> , <code> consumer "
                "</code>.",
                "example": "business_gst",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "is_reverse_charge_applied": {
                "description": "(Required if customer "
                "tax treatment is "
                "<code>vat_registered</code>)<br/>Used "
                "to specify whether the "
                "transaction is "
                "applicable for Domestic "
                "Reverse Charge (DRC) or "
                "not.",
                "example": True,
                "type": "boolean",
                "x-node_available_in": ["za"],
                "x-node_unavailable_in": [],
            },
            "line_items": {
                "description": "Line items of an invoice.",
                "items": {
                    "properties": {
                        "avatax_tax_code": {
                            "description": "A "
                            "tax "
                            "code "
                            "is "
                            "a "
                            "unique "
                            "label "
                            "used "
                            "to "
                            "group "
                            "items "
                            "together.",
                            "example": " ",
                            "type": "string",
                        },
                        "avatax_use_code": {
                            "description": "Used "
                            "to "
                            "group "
                            "like "
                            "customers "
                            "for "
                            "exemption "
                            "purposes. "
                            "It "
                            "is "
                            "a "
                            "custom "
                            "value "
                            "that "
                            "links "
                            "customers "
                            "to "
                            "a "
                            "tax "
                            "rule. "
                            "Select "
                            "from "
                            "Avalara "
                            "[standard "
                            "codes][1] "
                            "or "
                            "enter "
                            "a "
                            "custom "
                            "code. "
                            "Max-length "
                            "[25]",
                            "type": "string",
                            "x-node_available_in": ["Avalara Integration"],
                            "x-node_unavailable_in": [],
                        },
                        "description": {
                            "description": "A small description about the item. Max-length [2000]",
                            "example": "prorated amount for items",
                            "type": "string",
                        },
                        "discount": {
                            "description": "Discount "
                            "applied "
                            "to "
                            "the "
                            "invoice. "
                            "It "
                            "can "
                            "be "
                            "either "
                            "in "
                            "% "
                            "or "
                            "in "
                            "amount. "
                            "E.g: "
                            "12.5% "
                            "or "
                            "190.",
                            "example": "30%",
                            "type": "string",
                        },
                        "header_id": {
                            "description": "ID of the item header",
                            "example": 982000000000670,
                            "type": "string",
                        },
                        "header_name": {
                            "description": "Name of the item header",
                            "example": "Electronic devices",
                            "type": "string",
                        },
                        "hsn_or_sac": {
                            "description": "Add HSN/SAC code for your goods/services",
                            "example": 80540,
                            "type": "string",
                            "x-node_available_in": ["in", "ke", "za"],
                            "x-node_unavailable_in": [],
                        },
                        "item_id": {
                            "description": "Unique "
                            "string "
                            "generated "
                            "for "
                            "the "
                            "item "
                            "for "
                            "which "
                            "invoice "
                            "is "
                            "to "
                            "be "
                            "sent.",
                            "example": "90300000081501",
                            "type": "string",
                        },
                        "item_total": {
                            "description": "Total "
                            "rate "
                            "raised "
                            "by "
                            "this "
                            "item. "
                            "This "
                            "would "
                            "be "
                            "the "
                            "multiplicative "
                            "product "
                            "of "
                            "item "
                            "price "
                            "and "
                            "quantity.",
                            "example": 100,
                            "format": "double",
                            "type": "number",
                        },
                        "location_id": {
                            "description": "Location ID",
                            "example": "460000000038080",
                            "type": "string",
                        },
                        "name": {
                            "description": "The name of the line item. max-length [100]",
                            "example": "Hard Drive",
                            "type": "string",
                        },
                        "product_type": {
                            "description": "Enter "
                            "<code>goods</code> "
                            "or "
                            "<code>services</code> "
                            ".<br/><b>For "
                            "SouthAfrica "
                            "Edition:</b> "
                            "<code>service</code>, "
                            "<code>goods</code>, "
                            "<code>capital_service</code> "
                            "and "
                            "<code>capital_goods</code>",
                            "example": "goods",
                            "type": "string",
                        },
                        "project_id": {
                            "description": "ID of the project",
                            "example": 90300000087378,
                            "type": "string",
                        },
                        "quantity": {
                            "description": "Quantity of the item included.",
                            "example": 1,
                            "format": "int32",
                            "type": "integer",
                        },
                        "rate": {
                            "description": "Rate of the line item.",
                            "example": 0,
                            "format": "double",
                            "type": "number",
                        },
                        "sat_item_key_code": {
                            "description": "Add "
                            "SAT "
                            "Item "
                            "Key "
                            "Code "
                            "for "
                            "your "
                            "goods/services. "
                            "Download "
                            "the "
                            "<a "
                            "href= "
                            "http://omawww.sat.gob.mx/tramitesyservicios/Paginas/documentos/catCFDI_V_4_07122022.xls  "
                            ">CFDI "
                            "Catalogs.</a>",
                            "example": 71121206,
                            "type": "string",
                            "x-node_available_in": ["mx"],
                            "x-node_unavailable_in": [],
                        },
                        "tags": {
                            "description": "Filter all your reports based on the tag",
                            "items": {
                                "properties": {
                                    "tag_id": {
                                        "description": "ID of the reporting tag",
                                        "example": 982000000009070,
                                        "type": "string",
                                    },
                                    "tag_option_id": {
                                        "description": "ID of the reporting tag's option",
                                        "example": 982000000002670,
                                        "type": "string",
                                    },
                                },
                                "type": "object",
                            },
                            "type": "array",
                        },
                        "tax_exemption_id": {
                            "description": "Unique ID of the tax exemption.",
                            "example": "903000006345",
                            "type": "string",
                            "x-node_available_in": ["in", "us", "au", "ca"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_id": {
                            "description": "ID "
                            "of "
                            "the "
                            "tax "
                            "or "
                            "tax "
                            "group "
                            "associated "
                            "to "
                            "the "
                            "recurring "
                            "invoice.",
                            "example": "903000000000356",
                        },
                        "tax_treatment_code": {
                            "description": "Specify "
                            "reason "
                            "for "
                            "using "
                            "out "
                            "of "
                            "scope.</br>Supported "
                            "values "
                            "for "
                            "UAE "
                            "are "
                            "<code>uae_same_tax_group</code>, "
                            "<code>uae_reimbursed_expense</code> "
                            "and "
                            "<code>uae_others</code>.</br> "
                            "Supported "
                            "values "
                            "for "
                            "Bahrain "
                            "are "
                            "<code>bahrain_same_tax_group</code>, "
                            "<code>bahrain_transfer_of_concern</code>, "
                            "<code>bahrain_disbursement</code>, "
                            "<code>bahrain_head_to_branch_transaction</code>, "
                            "<code>bahrain_warranty_repair_services</code> "
                            "and "
                            "<code>bahrain_others</code>.</br>Supported "
                            "values "
                            "for "
                            "Saudi "
                            "Arabia "
                            "are "
                            "<code>ksa_pvt_health</code>, "
                            "<code>ksa_pvt_edu</code>, "
                            "<code>ksa_reimbursed_expense</code> "
                            "and "
                            "<code>ksa_house_sales</code>.",
                            "example": "uae_others",
                            "type": "string",
                            "x-node_available_in": ["gcc"],
                            "x-node_unavailable_in": [],
                        },
                        "tds_tax_id": {
                            "description": "ID "
                            "of "
                            "the "
                            "TDS "
                            "tax "
                            "or "
                            "TDS "
                            "tax "
                            "group "
                            "associated "
                            "to "
                            "the "
                            "recurring "
                            "invoice.",
                            "example": "903000000000357",
                            "type": "string",
                            "x-node_available_in": ["mx"],
                            "x-node_unavailable_in": [],
                        },
                        "unitkey_code": {
                            "description": "Add "
                            "SAT "
                            "Unit "
                            "Key "
                            "Code "
                            "for "
                            "your "
                            "goods/services. "
                            "Download "
                            "the "
                            "<a "
                            "href= "
                            "http://omawww.sat.gob.mx/tramitesyservicios/Paginas/documentos/catCFDI_V_4_07122022.xls  "
                            ">CFDI "
                            "Catalogs.</a>",
                            "example": "box",
                            "type": "string",
                            "x-node_available_in": ["mx"],
                            "x-node_unavailable_in": [],
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "location_id": {
                "description": "Location ID",
                "example": "460000000038080",
                "type": "string",
            },
            "payment_options": {
                "properties": {
                    "payment_gateways": {
                        "items": {
                            "properties": {
                                "additional_field1": {
                                    "description": "Paypal "
                                    "payment "
                                    "method. "
                                    "Allowed "
                                    "Values: "
                                    "<code>standard</code> "
                                    "and "
                                    "<code>adaptive</code>",
                                    "example": "standard",
                                    "type": "string",
                                },
                                "configured": {
                                    "description": "Boolean "
                                    "check "
                                    "to "
                                    "see "
                                    "if "
                                    "a "
                                    "payment "
                                    "gateway "
                                    "ahs "
                                    "been "
                                    "configured",
                                    "example": True,
                                    "type": "boolean",
                                },
                                "gateway_name": {
                                    "description": "Name "
                                    "of "
                                    "the "
                                    "payment "
                                    "gateway "
                                    "associated "
                                    "with "
                                    "the "
                                    "invoice. "
                                    "E.g. "
                                    "paypal, "
                                    "stripe.Allowed "
                                    "Values: "
                                    "<code>paypal</code>, "
                                    "<code>authorize_net</code>, "
                                    "<code>payflow_pro</code>, "
                                    "<code>stripe</code>, "
                                    "<code>2checkout</code> "
                                    "and "
                                    "<code>braintree</code>",
                                    "example": "paypal",
                                    "type": "string",
                                },
                            },
                            "type": "object",
                        },
                        "type": "array",
                    }
                },
                "type": "object",
            },
            "place_of_supply": {
                "description": "Place where the goods/services are "
                "supplied to. (If not given, "
                "<code>place of contact</code> "
                "given for the contact will be "
                "taken)<br/>Supported codes for UAE "
                "emirates are : </br>Abu Dhabi - "
                "<code>AB</code>,</br>Ajman - "
                "<code>AJ</code>,</br>Dubai - "
                "<code>DU</code>,</br>Fujairah - "
                "<code>FU</code>,</br>Ras "
                "al-Khaimah - "
                "<code>RA</code>,</br>Sharjah - "
                "<code>SH</code>,</br>Umm al-Quwain "
                "- <code>UM</code><br/>Supported "
                "codes for the GCC countries are : "
                "</br>United Arab Emirates - "
                "<code>AE</code>,</br>Saudi Arabia "
                "- <code>SA</code>,</br>Bahrain - "
                "<code>BH</code>,</br>Kuwait - "
                "<code>KW</code>,</br>Oman - "
                "<code>OM</code>,</br>Qatar - "
                "<code>QA</code>.",
                "example": "TN",
                "type": "string",
                "x-node_available_in": ["in", "gcc"],
                "x-node_unavailable_in": [],
            },
            "recurrence_frequency": {
                "description": "The frequency of time "
                "interval at which the invoice "
                "is to be generated.",
                "enum": ["weeks"],
                "example": "weeks",
                "type": "string",
            },
            "recurrence_name": {
                "description": "Unique name for the recurring "
                "profile given by the user. "
                "Max-length [100]",
                "example": "MonthlyInvoice",
                "type": "string",
            },
            "reference_number": {
                "description": "The Order number of the Recurring Invoice.",
                "example": "12314",
                "type": "string",
            },
            "repeat_every": {
                "description": "The period between every recurrency frequency.",
                "example": 2,
                "type": "integer",
            },
            "start_date": {
                "description": "The date on which the recurring invoice starts.",
                "example": "2016-06-12",
                "type": "string",
            },
            "tax_authority_id": {
                "description": "Unique ID of the tax authority. "
                "Tax authority depends on the "
                "location of the customer. For "
                "example, if the customer is "
                "located in NY, then the tax "
                "authority is NY tax authority.",
                "example": "903000006345",
                "type": "string",
                "x-node_available_in": ["us"],
                "x-node_unavailable_in": [],
            },
            "tax_exemption_id": {
                "description": "Unique ID of the tax exemption.",
                "example": "903000006345",
                "type": "string",
                "x-node_available_in": ["in", "us", "au", "ca"],
                "x-node_unavailable_in": [],
            },
            "tax_id": {
                "description": "ID of the tax or tax group associated to the recurring invoice.",
                "example": "903000000000356",
            },
            "tax_treatment": {
                "description": "Choose whether the vat treatment for "
                "the contact falls under: "
                "<code>vat_registered</code>,<code>vat_not_registered</code>,<code>gcc_vat_not_registered</code>,<code>gcc_vat_registered</code>,<code>non_gcc</code>.</br><code>dz_vat_registered</code> "
                "and "
                "<code>dz_vat_not_registered</code> "
                "supported only for "
                "<b>UAE</b>.</br><code>home_country_mexico</code>,<code>border_region_mexico</code>,<code>non_mexico</code> "
                "supported only for <b>MX</b>. "
                "<br/><b>For Kenya Edition:</b> "
                "<code>vat_registered</code> "
                ",<code>vat_not_registered</code> "
                ",<code>non_kenya</code>(A business "
                "that is located outside "
                "Kenya).<br/><b>For SouthAfrica "
                "Edition:</b> "
                "<code>vat_registered</code>, "
                "<code>vat_not_registered</code>, "
                "<code>overseas</code>(A business "
                "that is located outside "
                "SouthAfrica).",
                "example": "vat_registered",
                "type": "string",
                "x-node_available_in": ["gcc", "mx", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "vat_treatment": {
                "description": "(Optional) VAT treatment for the "
                "invoices. VAT treatment denotes the "
                "location of the customer, if the "
                "customer resides in UK then the VAT "
                "treatment is <code>uk</code>. If the "
                "customer is in an EU country & VAT "
                "registered, you are resides in "
                "Northen Ireland and selling Goods "
                "then his VAT treatment is "
                "<code>eu_vat_registered</code>, if "
                "he resides outside of the UK then "
                "his VAT treatment is "
                "<code>overseas</code> (For Pre "
                "Brexit, this can be split as "
                "<code>eu_vat_registered</code>, "
                "<code>eu_vat_not_registered</code> "
                "and <code>non_eu</code>).",
                "example": "overseas",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
        },
        "required": ["recurrence_name", "customer_id", "recurrence_frequency"],
        "type": "object",
    },
    "UPDATERECURRINGINVOICE_REQUEST_BODY_SCHEMA": {
        "properties": {
            "allow_partial_payments": {
                "description": "Choose <code>false</code> "
                "for PPU-Single Payments and "
                "<code>true</code> for "
                "PPD-Installment Payments",
                "example": True,
                "type": "boolean",
                "x-node_available_in": ["mx"],
                "x-node_unavailable_in": [],
            },
            "avatax_exempt_no": {
                "description": "Exemption certificate number of the customer. Max-length [25]",
                "type": "string",
                "x-node_available_in": ["Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "avatax_use_code": {
                "description": "Used to group like customers for "
                "exemption purposes. It is a custom "
                "value that links customers to a "
                "tax rule. Select from Avalara "
                "[standard codes][1] or enter a "
                "custom code. Max-length [25]",
                "type": "string",
                "x-node_available_in": ["Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "cfdi_usage": {
                "description": "Choose CFDI Usage.</br>Allowed values: "
                "<code>acquisition_of_merchandise</code>, "
                "<code>return_discount_bonus</code>, "
                "<code>general_expense</code>, "
                "<code>buildings</code>, "
                "<code>furniture_office_equipment</code>, "
                "<code>transport_equipment</code>, "
                "<code>computer_equipmentdye_molds_tools</code>, "
                "<code>telephone_communication</code>, "
                "<code>satellite_communication</code>, "
                "<code>other_machinery_equipment</code>, "
                "<code>hospital_expense</code>, "
                "<code>medical_expense_disability</code>, "
                "<code>funeral_expense</code>, "
                "<code>donation</code>, "
                "<code>interest_mortage_loans</code>, "
                "<code>contribution_sar</code>, "
                "<code>medical_expense_insurance_pormium</code>, "
                "<code>school_transportation_expense</code>, "
                "<code>deposit_saving_account</code>, "
                "<code>payment_educational_service</code>, "
                "<code>no_tax_effect</code>, "
                "<code>payment</code>, "
                "<code>payroll</code>.",
                "example": "acquisition_of_merchandise",
                "type": "string",
                "x-node_available_in": ["mx"],
                "x-node_unavailable_in": [],
            },
            "contact_persons_associated": {
                "description": "Contact Persons associated with the transaction.",
                "items": {
                    "properties": {
                        "communication_preference": {
                            "description": "Preferred "
                            "modes "
                            "of "
                            "communication "
                            "for "
                            "the "
                            "contact "
                            "person "
                            "at "
                            "transaction "
                            "level.",
                            "properties": {
                                "is_email_enabled": {
                                    "description": "Used "
                                    "to "
                                    "check "
                                    "if "
                                    "Email "
                                    "communication "
                                    "preference "
                                    "is "
                                    "enabled "
                                    "for "
                                    "the "
                                    "contact "
                                    "person "
                                    "at "
                                    "transaction "
                                    "level.",
                                    "example": True,
                                    "type": "boolean",
                                },
                                "is_whatsapp_enabled": {
                                    "description": "Used "
                                    "to "
                                    "check "
                                    "if "
                                    "WhatsApp "
                                    "communication "
                                    "preference "
                                    "is "
                                    "enabled "
                                    "for "
                                    "the "
                                    "contact "
                                    "person "
                                    "at "
                                    "transaction "
                                    "level.",
                                    "example": True,
                                    "type": "boolean",
                                    "x-node_available_in": ["WhatsApp integration"],
                                },
                            },
                            "type": "object",
                        },
                        "contact_person_id": {
                            "description": "Unique ID of the Contact Person.",
                            "example": 982000000567003,
                            "format": "int64",
                            "type": "integer",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "currency_id": {
                "description": "The currenct id of the currency",
                "example": "982000000000190",
                "type": "string",
            },
            "custom_fields": {
                "items": {
                    "properties": {
                        "data_type": {
                            "description": "Data type of the custom field.",
                            "example": "text",
                            "type": "string",
                        },
                        "label": {
                            "description": "Label of the custom field.",
                            "example": "label",
                            "type": "string",
                        },
                        "value": {
                            "description": "Value of the custom field.",
                            "example": "129890",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "customer_id": {
                "description": "Customer ID of the customer for whom "
                "the recurring invoice is raised.",
                "example": "903000000000099",
                "type": "string",
            },
            "email": {
                "description": "Email address of the customer.",
                "example": "benjamin.george@bowmanfurniture.com",
                "type": "string",
            },
            "end_date": {
                "description": "The date on which the recurring invoice expires.",
                "example": "2017-06-12",
                "type": "string",
            },
            "gst_no": {
                "description": "15 digit GST identification number of the customer.",
                "example": "22AAAAA0000A1Z5",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "gst_treatment": {
                "description": "Choose whether the contact is GST "
                "registered/unregistered/consumer/overseas. "
                "Allowed values are <code> "
                "business_gst </code> , <code> "
                "business_none </code> , <code> "
                "overseas </code> , <code> consumer "
                "</code>.",
                "example": "business_gst",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "is_reverse_charge_applied": {
                "description": "(Required if customer "
                "tax treatment is "
                "<code>vat_registered</code>)<br/>Used "
                "to specify whether the "
                "transaction is "
                "applicable for Domestic "
                "Reverse Charge (DRC) or "
                "not.",
                "example": True,
                "type": "boolean",
                "x-node_available_in": ["za"],
                "x-node_unavailable_in": [],
            },
            "line_items": {
                "description": "Line items of an invoice.",
                "items": {
                    "properties": {
                        "avatax_tax_code": {
                            "description": "A "
                            "tax "
                            "code "
                            "is "
                            "a "
                            "unique "
                            "label "
                            "used "
                            "to "
                            "group "
                            "items "
                            "together.",
                            "example": " ",
                            "type": "string",
                        },
                        "avatax_use_code": {
                            "description": "Used "
                            "to "
                            "group "
                            "like "
                            "customers "
                            "for "
                            "exemption "
                            "purposes. "
                            "It "
                            "is "
                            "a "
                            "custom "
                            "value "
                            "that "
                            "links "
                            "customers "
                            "to "
                            "a "
                            "tax "
                            "rule. "
                            "Select "
                            "from "
                            "Avalara "
                            "[standard "
                            "codes][1] "
                            "or "
                            "enter "
                            "a "
                            "custom "
                            "code. "
                            "Max-length "
                            "[25]",
                            "type": "string",
                            "x-node_available_in": ["Avalara Integration"],
                            "x-node_unavailable_in": [],
                        },
                        "description": {
                            "description": "A small description about the item. Max-length [2000]",
                            "example": "prorated amount for items",
                            "type": "string",
                        },
                        "discount": {
                            "description": "Discount "
                            "applied "
                            "to "
                            "the "
                            "invoice. "
                            "It "
                            "can "
                            "be "
                            "either "
                            "in "
                            "% "
                            "or "
                            "in "
                            "amount. "
                            "E.g: "
                            "12.5% "
                            "or "
                            "190.",
                            "example": "30%",
                            "type": "string",
                        },
                        "header_id": {
                            "description": "ID of the item header",
                            "example": 982000000000670,
                            "type": "string",
                        },
                        "header_name": {
                            "description": "Name of the item header",
                            "example": "Electronic devices",
                            "type": "string",
                        },
                        "hsn_or_sac": {
                            "description": "Add HSN/SAC code for your goods/services",
                            "example": 80540,
                            "type": "string",
                            "x-node_available_in": ["in", "ke", "za"],
                            "x-node_unavailable_in": [],
                        },
                        "item_id": {
                            "description": "Unique "
                            "string "
                            "generated "
                            "for "
                            "the "
                            "item "
                            "for "
                            "which "
                            "invoice "
                            "is "
                            "to "
                            "be "
                            "sent.",
                            "example": "90300000081501",
                            "type": "string",
                        },
                        "item_total": {
                            "description": "Total "
                            "rate "
                            "raised "
                            "by "
                            "this "
                            "item. "
                            "This "
                            "would "
                            "be "
                            "the "
                            "multiplicative "
                            "product "
                            "of "
                            "item "
                            "price "
                            "and "
                            "quantity.",
                            "example": 100,
                            "format": "double",
                            "type": "number",
                        },
                        "location_id": {
                            "description": "Location ID",
                            "example": "460000000038080",
                            "type": "string",
                        },
                        "name": {
                            "description": "The name of the line item. max-length [100]",
                            "example": "Hard Drive",
                            "type": "string",
                        },
                        "product_type": {
                            "description": "Enter "
                            "<code>goods</code> "
                            "or "
                            "<code>services</code> "
                            ".<br/><b>For "
                            "SouthAfrica "
                            "Edition:</b> "
                            "<code>service</code>, "
                            "<code>goods</code>, "
                            "<code>capital_service</code> "
                            "and "
                            "<code>capital_goods</code>",
                            "example": "goods",
                            "type": "string",
                        },
                        "project_id": {
                            "description": "ID of the project",
                            "example": 90300000087378,
                            "type": "string",
                        },
                        "quantity": {
                            "description": "Quantity of the item included.",
                            "example": 1,
                            "format": "int32",
                            "type": "integer",
                        },
                        "rate": {
                            "description": "Rate of the line item.",
                            "example": 0,
                            "format": "double",
                            "type": "number",
                        },
                        "sat_item_key_code": {
                            "description": "Add "
                            "SAT "
                            "Item "
                            "Key "
                            "Code "
                            "for "
                            "your "
                            "goods/services. "
                            "Download "
                            "the "
                            "<a "
                            "href= "
                            "http://omawww.sat.gob.mx/tramitesyservicios/Paginas/documentos/catCFDI_V_4_07122022.xls  "
                            ">CFDI "
                            "Catalogs.</a>",
                            "example": 71121206,
                            "type": "string",
                            "x-node_available_in": ["mx"],
                            "x-node_unavailable_in": [],
                        },
                        "tags": {
                            "description": "Filter all your reports based on the tag",
                            "items": {
                                "properties": {
                                    "tag_id": {
                                        "description": "ID of the reporting tag",
                                        "example": 982000000009070,
                                        "type": "string",
                                    },
                                    "tag_option_id": {
                                        "description": "ID of the reporting tag's option",
                                        "example": 982000000002670,
                                        "type": "string",
                                    },
                                },
                                "type": "object",
                            },
                            "type": "array",
                        },
                        "tax_exemption_id": {
                            "description": "Unique ID of the tax exemption.",
                            "example": "903000006345",
                            "type": "string",
                            "x-node_available_in": ["in", "us", "au", "ca"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_id": {
                            "description": "ID "
                            "of "
                            "the "
                            "tax "
                            "or "
                            "tax "
                            "group "
                            "associated "
                            "to "
                            "the "
                            "recurring "
                            "invoice.",
                            "example": "903000000000356",
                        },
                        "tax_treatment_code": {
                            "description": "Specify "
                            "reason "
                            "for "
                            "using "
                            "out "
                            "of "
                            "scope.</br>Supported "
                            "values "
                            "for "
                            "UAE "
                            "are "
                            "<code>uae_same_tax_group</code>, "
                            "<code>uae_reimbursed_expense</code> "
                            "and "
                            "<code>uae_others</code>.</br> "
                            "Supported "
                            "values "
                            "for "
                            "Bahrain "
                            "are "
                            "<code>bahrain_same_tax_group</code>, "
                            "<code>bahrain_transfer_of_concern</code>, "
                            "<code>bahrain_disbursement</code>, "
                            "<code>bahrain_head_to_branch_transaction</code>, "
                            "<code>bahrain_warranty_repair_services</code> "
                            "and "
                            "<code>bahrain_others</code>.</br>Supported "
                            "values "
                            "for "
                            "Saudi "
                            "Arabia "
                            "are "
                            "<code>ksa_pvt_health</code>, "
                            "<code>ksa_pvt_edu</code>, "
                            "<code>ksa_reimbursed_expense</code> "
                            "and "
                            "<code>ksa_house_sales</code>.",
                            "example": "uae_others",
                            "type": "string",
                            "x-node_available_in": ["gcc"],
                            "x-node_unavailable_in": [],
                        },
                        "tds_tax_id": {
                            "description": "ID "
                            "of "
                            "the "
                            "TDS "
                            "tax "
                            "or "
                            "TDS "
                            "tax "
                            "group "
                            "associated "
                            "to "
                            "the "
                            "recurring "
                            "invoice.",
                            "example": "903000000000357",
                            "type": "string",
                            "x-node_available_in": ["mx"],
                            "x-node_unavailable_in": [],
                        },
                        "unitkey_code": {
                            "description": "Add "
                            "SAT "
                            "Unit "
                            "Key "
                            "Code "
                            "for "
                            "your "
                            "goods/services. "
                            "Download "
                            "the "
                            "<a "
                            "href= "
                            "http://omawww.sat.gob.mx/tramitesyservicios/Paginas/documentos/catCFDI_V_4_07122022.xls  "
                            ">CFDI "
                            "Catalogs.</a>",
                            "example": "box",
                            "type": "string",
                            "x-node_available_in": ["mx"],
                            "x-node_unavailable_in": [],
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "location_id": {
                "description": "Location ID",
                "example": "460000000038080",
                "type": "string",
            },
            "payment_options": {
                "properties": {
                    "payment_gateways": {
                        "items": {
                            "properties": {
                                "additional_field1": {
                                    "description": "Paypal "
                                    "payment "
                                    "method. "
                                    "Allowed "
                                    "Values: "
                                    "<code>standard</code> "
                                    "and "
                                    "<code>adaptive</code>",
                                    "example": "standard",
                                    "type": "string",
                                },
                                "configured": {
                                    "description": "Boolean "
                                    "check "
                                    "to "
                                    "see "
                                    "if "
                                    "a "
                                    "payment "
                                    "gateway "
                                    "ahs "
                                    "been "
                                    "configured",
                                    "example": True,
                                    "type": "boolean",
                                },
                                "gateway_name": {
                                    "description": "Name "
                                    "of "
                                    "the "
                                    "payment "
                                    "gateway "
                                    "associated "
                                    "with "
                                    "the "
                                    "invoice. "
                                    "E.g. "
                                    "paypal, "
                                    "stripe.Allowed "
                                    "Values: "
                                    "<code>paypal</code>, "
                                    "<code>authorize_net</code>, "
                                    "<code>payflow_pro</code>, "
                                    "<code>stripe</code>, "
                                    "<code>2checkout</code> "
                                    "and "
                                    "<code>braintree</code>",
                                    "example": "paypal",
                                    "type": "string",
                                },
                            },
                            "type": "object",
                        },
                        "type": "array",
                    }
                },
                "type": "object",
            },
            "place_of_supply": {
                "description": "Place where the goods/services are "
                "supplied to. (If not given, "
                "<code>place of contact</code> "
                "given for the contact will be "
                "taken)<br/>Supported codes for UAE "
                "emirates are : </br>Abu Dhabi - "
                "<code>AB</code>,</br>Ajman - "
                "<code>AJ</code>,</br>Dubai - "
                "<code>DU</code>,</br>Fujairah - "
                "<code>FU</code>,</br>Ras "
                "al-Khaimah - "
                "<code>RA</code>,</br>Sharjah - "
                "<code>SH</code>,</br>Umm al-Quwain "
                "- <code>UM</code><br/>Supported "
                "codes for the GCC countries are : "
                "</br>United Arab Emirates - "
                "<code>AE</code>,</br>Saudi Arabia "
                "- <code>SA</code>,</br>Bahrain - "
                "<code>BH</code>,</br>Kuwait - "
                "<code>KW</code>,</br>Oman - "
                "<code>OM</code>,</br>Qatar - "
                "<code>QA</code>.",
                "example": "TN",
                "type": "string",
                "x-node_available_in": ["in", "gcc"],
                "x-node_unavailable_in": [],
            },
            "recurrence_frequency": {
                "description": "The frequency of time "
                "interval at which the invoice "
                "is to be generated.",
                "enum": ["weeks"],
                "example": "weeks",
                "type": "string",
            },
            "recurrence_name": {
                "description": "Unique name for the recurring "
                "profile given by the user. "
                "Max-length [100]",
                "example": "MonthlyInvoice",
                "type": "string",
            },
            "reference_number": {
                "description": "The Order number of the Recurring Invoice.",
                "example": "12314",
                "type": "string",
            },
            "repeat_every": {
                "description": "The period between every recurrency frequency.",
                "example": 2,
                "type": "integer",
            },
            "start_date": {
                "description": "The date on which the recurring invoice starts.",
                "example": "2016-06-12",
                "type": "string",
            },
            "tax_authority_id": {
                "description": "Unique ID of the tax authority. "
                "Tax authority depends on the "
                "location of the customer. For "
                "example, if the customer is "
                "located in NY, then the tax "
                "authority is NY tax authority.",
                "example": "903000006345",
                "type": "string",
                "x-node_available_in": ["us"],
                "x-node_unavailable_in": [],
            },
            "tax_exemption_id": {
                "description": "Unique ID of the tax exemption.",
                "example": "903000006345",
                "type": "string",
                "x-node_available_in": ["in", "us", "au", "ca"],
                "x-node_unavailable_in": [],
            },
            "tax_id": {
                "description": "ID of the tax or tax group associated to the recurring invoice.",
                "example": "903000000000356",
            },
            "tax_treatment": {
                "description": "Choose whether the vat treatment for "
                "the contact falls under: "
                "<code>vat_registered</code>,<code>vat_not_registered</code>,<code>gcc_vat_not_registered</code>,<code>gcc_vat_registered</code>,<code>non_gcc</code>.</br><code>dz_vat_registered</code> "
                "and "
                "<code>dz_vat_not_registered</code> "
                "supported only for "
                "<b>UAE</b>.</br><code>home_country_mexico</code>,<code>border_region_mexico</code>,<code>non_mexico</code> "
                "supported only for <b>MX</b>. "
                "<br/><b>For Kenya Edition:</b> "
                "<code>vat_registered</code> "
                ",<code>vat_not_registered</code> "
                ",<code>non_kenya</code>(A business "
                "that is located outside "
                "Kenya).<br/><b>For SouthAfrica "
                "Edition:</b> "
                "<code>vat_registered</code>, "
                "<code>vat_not_registered</code>, "
                "<code>overseas</code>(A business "
                "that is located outside "
                "SouthAfrica).",
                "example": "vat_registered",
                "type": "string",
                "x-node_available_in": ["gcc", "mx", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "vat_treatment": {
                "description": "(Optional) VAT treatment for the "
                "invoices. VAT treatment denotes the "
                "location of the customer, if the "
                "customer resides in UK then the VAT "
                "treatment is <code>uk</code>. If the "
                "customer is in an EU country & VAT "
                "registered, you are resides in "
                "Northen Ireland and selling Goods "
                "then his VAT treatment is "
                "<code>eu_vat_registered</code>, if "
                "he resides outside of the UK then "
                "his VAT treatment is "
                "<code>overseas</code> (For Pre "
                "Brexit, this can be split as "
                "<code>eu_vat_registered</code>, "
                "<code>eu_vat_not_registered</code> "
                "and <code>non_eu</code>).",
                "example": "overseas",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
        },
        "required": ["recurrence_name", "customer_id", "recurrence_frequency"],
        "type": "object",
    },
    "STOPRECURRINGINVOICE_REQUEST_BODY_SCHEMA": {
        "properties": {
            "recurring_invoice_id": {
                "description": "Unique ID of the recurring invoice generated by the server.",
                "example": "90300000072369",
                "type": "string",
            }
        },
        "type": "object",
    },
    "RESUMERECURRINGINVOICE_REQUEST_BODY_SCHEMA": {
        "properties": {
            "recurring_invoice_id": {
                "description": "Unique ID of the recurring invoice generated by the server.",
                "example": "90300000072369",
                "type": "string",
            }
        },
        "type": "object",
    },
    "UPDATERECURRINGINVOICETEMPLATE_REQUEST_BODY_SCHEMA": {
        "properties": {
            "recurring_invoice_id": {
                "description": "Unique ID of the recurring invoice generated by the server.",
                "example": "90300000072369",
                "type": "string",
            },
            "template_id": {
                "description": "Unique ID of the recurring invoice template.",
                "example": "90300043563547",
                "type": "string",
            },
        },
        "type": "object",
    },
    "CREATERETAINERINVOICE_REQUEST_BODY_SCHEMA": {
        "properties": {
            "contact_persons_associated": {
                "description": "Contact Persons associated with the transaction.",
                "items": {
                    "properties": {
                        "communication_preference": {
                            "description": "Preferred "
                            "modes "
                            "of "
                            "communication "
                            "for "
                            "the "
                            "contact "
                            "person "
                            "at "
                            "transaction "
                            "level.",
                            "properties": {
                                "is_email_enabled": {
                                    "description": "Used "
                                    "to "
                                    "check "
                                    "if "
                                    "Email "
                                    "communication "
                                    "preference "
                                    "is "
                                    "enabled "
                                    "for "
                                    "the "
                                    "contact "
                                    "person "
                                    "at "
                                    "transaction "
                                    "level.",
                                    "example": True,
                                    "type": "boolean",
                                },
                                "is_whatsapp_enabled": {
                                    "description": "Used "
                                    "to "
                                    "check "
                                    "if "
                                    "WhatsApp "
                                    "communication "
                                    "preference "
                                    "is "
                                    "enabled "
                                    "for "
                                    "the "
                                    "contact "
                                    "person "
                                    "at "
                                    "transaction "
                                    "level.",
                                    "example": True,
                                    "type": "boolean",
                                    "x-node_available_in": ["WhatsApp integration"],
                                },
                            },
                            "type": "object",
                        },
                        "contact_person_id": {
                            "description": "Unique ID of the Contact Person.",
                            "example": 982000000567003,
                            "format": "int64",
                            "type": "integer",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "custom_fields": {
                "description": "Custom fields for a reatiner invoice.",
                "items": {
                    "properties": {
                        "index": {
                            "description": "The index of the custom field",
                            "example": 1,
                            "type": "integer",
                        },
                        "label": {
                            "description": "The label of the custom field.",
                            "example": "Delivery Date",
                            "type": "string",
                        },
                        "show_on_pdf": {
                            "description": "Boolean "
                            "value "
                            "to "
                            "check "
                            "if "
                            "the "
                            "custom "
                            "field "
                            "is "
                            "to "
                            "be "
                            "dispplayed "
                            "on "
                            "the "
                            "pdf.",
                            "example": False,
                            "type": "boolean",
                        },
                        "value": {"example": "The value of the custom field", "type": "string"},
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "customer_id": {
                "description": "ID of the customer the retainer invoice has to be created.",
                "example": 982000000567001,
                "type": "string",
            },
            "date": {
                "description": "The date of creation of the retainer invoice.",
                "example": "2013-11-17",
                "type": "string",
            },
            "line_items": {
                "description": "Line items of an invoice.",
                "items": {
                    "properties": {
                        "description": {
                            "description": "The description of the line items. Max-length [2000]",
                            "example": "500GB, USB 2.0 interface 1400 rpm, protective hard case.",
                            "type": "string",
                        },
                        "item_order": {
                            "description": "The order of the line item_order",
                            "example": 1,
                            "type": "integer",
                        },
                        "rate": {
                            "description": "Rate of the line item.",
                            "example": 120,
                            "format": "double",
                            "type": "number",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "location_id": {
                "description": "Location ID",
                "example": "460000000038080",
                "type": "string",
            },
            "notes": {
                "description": "The notes added below expressing gratitude "
                "or for conveying some information.",
                "example": "Looking forward for your business.",
                "type": "string",
            },
            "payment_options": {
                "description": "Payment options for the retainer "
                "invoice, online payment gateways "
                "and bank accounts. Will be "
                "displayed in the pdf.",
                "properties": {
                    "payment_gateways": {
                        "description": "Online payment gateways through which payment can be made.",
                        "items": {
                            "properties": {
                                "additional_field1": {
                                    "description": "Paypal "
                                    "payment "
                                    "method. "
                                    "Allowed "
                                    "Values: "
                                    "<code>standard</code> "
                                    "and "
                                    "<code>adaptive</code>",
                                    "example": "standard",
                                    "type": "string",
                                },
                                "configured": {
                                    "description": "Boolean "
                                    "check "
                                    "to "
                                    "see "
                                    "if "
                                    "a "
                                    "payment "
                                    "gateway "
                                    "ahs "
                                    "been "
                                    "configured",
                                    "example": True,
                                    "type": "boolean",
                                },
                                "gateway_name": {
                                    "description": "Name "
                                    "of "
                                    "the "
                                    "payment "
                                    "gateway "
                                    "associated "
                                    "with "
                                    "the "
                                    "retainer "
                                    "invoice. "
                                    "E.g. "
                                    "paypal, "
                                    "stripe.Allowed "
                                    "Values: "
                                    "<code>paypal</code>, "
                                    "<code>authorize_net</code>, "
                                    "<code>payflow_pro</code>, "
                                    "<code>stripe</code>, "
                                    "<code>2checkout</code> "
                                    "and "
                                    "<code>braintree</code>",
                                    "example": "paypal",
                                    "type": "string",
                                },
                            },
                            "type": "object",
                        },
                        "type": "array",
                    }
                },
                "type": "object",
            },
            "place_of_supply": {
                "description": "Place where the goods/services are "
                "supplied to. (If not given, "
                "<code>place of contact</code> "
                "given for the contact will be "
                "taken)",
                "example": "TN",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "reference_number": {
                "description": "The reference number of the retainer invoice. Max-length [100]",
                "example": " ",
                "type": "string",
            },
            "template_id": {
                "description": "ID of the pdf template associated with the retainer invoice.",
                "example": 982000000000143,
                "type": "string",
            },
            "terms": {
                "description": "The terms added below expressing gratitude "
                "or for conveying some information.",
                "example": "Terms & Conditions apply",
                "type": "string",
            },
        },
        "required": ["customer_id", "line_items"],
        "type": "object",
    },
    "MODIFYINVOICE_REQUEST_BODY_SCHEMA": {
        "properties": {
            "contact_persons_associated": {
                "description": "Contact Persons associated with the transaction.",
                "items": {
                    "properties": {
                        "communication_preference": {
                            "description": "Preferred "
                            "modes "
                            "of "
                            "communication "
                            "for "
                            "the "
                            "contact "
                            "person "
                            "at "
                            "transaction "
                            "level.",
                            "properties": {
                                "is_email_enabled": {
                                    "description": "Used "
                                    "to "
                                    "check "
                                    "if "
                                    "Email "
                                    "communication "
                                    "preference "
                                    "is "
                                    "enabled "
                                    "for "
                                    "the "
                                    "contact "
                                    "person "
                                    "at "
                                    "transaction "
                                    "level.",
                                    "example": True,
                                    "type": "boolean",
                                },
                                "is_whatsapp_enabled": {
                                    "description": "Used "
                                    "to "
                                    "check "
                                    "if "
                                    "WhatsApp "
                                    "communication "
                                    "preference "
                                    "is "
                                    "enabled "
                                    "for "
                                    "the "
                                    "contact "
                                    "person "
                                    "at "
                                    "transaction "
                                    "level.",
                                    "example": True,
                                    "type": "boolean",
                                    "x-node_available_in": ["WhatsApp integration"],
                                },
                            },
                            "type": "object",
                        },
                        "contact_person_id": {
                            "description": "Unique ID of the Contact Person.",
                            "example": 982000000567003,
                            "format": "int64",
                            "type": "integer",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "custom_fields": {
                "description": "Custom fields for a reatiner invoice.",
                "items": {
                    "properties": {
                        "index": {
                            "description": "The index of the custom field",
                            "example": 1,
                            "type": "integer",
                        },
                        "label": {
                            "description": "The label of the custom field.",
                            "example": "Delivery Date",
                            "type": "string",
                        },
                        "show_on_pdf": {
                            "description": "Boolean "
                            "value "
                            "to "
                            "check "
                            "if "
                            "the "
                            "custom "
                            "field "
                            "is "
                            "to "
                            "be "
                            "dispplayed "
                            "on "
                            "the "
                            "pdf.",
                            "example": False,
                            "type": "boolean",
                        },
                        "value": {"example": "The value of the custom field", "type": "string"},
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "customer_id": {
                "description": "ID of the customer the retainer invoice has to be created.",
                "example": 982000000567001,
                "type": "string",
            },
            "date": {
                "description": "The date of creation of the retainer invoice.",
                "example": "2013-11-17",
                "type": "string",
            },
            "line_items": {
                "description": "Line items of a retainer invoice.",
                "items": {
                    "properties": {
                        "description": {
                            "description": "The description of the line items. Max-length [2000]",
                            "example": "500GB, USB 2.0 interface 1400 rpm, protective hard case.",
                            "type": "string",
                        },
                        "item_order": {
                            "description": "The order of the line item_order",
                            "example": 1,
                            "type": "integer",
                        },
                        "rate": {
                            "description": "Rate of the line item.",
                            "example": 120,
                            "format": "double",
                            "type": "number",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "location_id": {
                "description": "Location ID",
                "example": "460000000038080",
                "type": "string",
            },
            "notes": {
                "description": "The notes added below expressing gratitude "
                "or for conveying some information.",
                "example": "Looking forward for your business.",
                "type": "string",
            },
            "payment_options": {
                "description": "Payment options for the retainer "
                "invoice, online payment gateways "
                "and bank accounts. Will be "
                "displayed in the pdf.",
                "properties": {
                    "payment_gateways": {
                        "description": "Online payment gateways through which payment can be made.",
                        "items": {
                            "properties": {
                                "additional_field1": {
                                    "description": "Paypal "
                                    "payment "
                                    "method. "
                                    "Allowed "
                                    "Values: "
                                    "<code>standard</code> "
                                    "and "
                                    "<code>adaptive</code>",
                                    "example": "standard",
                                    "type": "string",
                                },
                                "configured": {
                                    "description": "Boolean "
                                    "check "
                                    "to "
                                    "see "
                                    "if "
                                    "a "
                                    "payment "
                                    "gateway "
                                    "ahs "
                                    "been "
                                    "configured",
                                    "example": True,
                                    "type": "boolean",
                                },
                                "gateway_name": {
                                    "description": "Name "
                                    "of "
                                    "the "
                                    "payment "
                                    "gateway "
                                    "associated "
                                    "with "
                                    "the "
                                    "retainer "
                                    "invoice. "
                                    "E.g. "
                                    "paypal, "
                                    "stripe.Allowed "
                                    "Values: "
                                    "<code>paypal</code>, "
                                    "<code>authorize_net</code>, "
                                    "<code>payflow_pro</code>, "
                                    "<code>stripe</code>, "
                                    "<code>2checkout</code> "
                                    "and "
                                    "<code>braintree</code>",
                                    "example": "paypal",
                                    "type": "string",
                                },
                            },
                            "type": "object",
                        },
                        "type": "array",
                    }
                },
                "type": "object",
            },
            "place_of_supply": {
                "description": "Place where the goods/services are "
                "supplied to. (If not given, "
                "<code>place of contact</code> "
                "given for the contact will be "
                "taken)",
                "example": "TN",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "project_id": {
                "description": "ID of the project",
                "example": 982000000567154,
                "type": "string",
            },
            "reference_number": {
                "description": "The reference number of the retainer invoice. Max-length [100]",
                "example": " ",
                "type": "string",
            },
            "template_id": {
                "description": "ID of the pdf template associated with the retainer invoice.",
                "example": 982000000000143,
                "type": "string",
            },
            "terms": {
                "description": "The terms added below expressing gratitude "
                "or for conveying some information.",
                "example": "Terms & Conditions apply",
                "type": "string",
            },
        },
        "required": ["customer_id", "line_items"],
        "type": "object",
    },
    "EMAILRETAINERINVOICETOCUSTOMER_REQUEST_BODY_SCHEMA": {
        "properties": {
            "body": {
                "description": "The body of the mail",
                "example": "Dear Customer,         <br><br><br><br>Thanks for "
                "your business.         <br><br><br><br>The "
                "retainer invoice RET-00001 is attached with this "
                "email. You can choose the easy way out and <a "
                "href= "
                "https://invoice.zoho.com/SecurePayment?CInvoiceID=b9800228e011ae86abe71227bdacb3c68e1af685f647dcaed747812e0b9314635e55ac6223925675b371fcbd2d5ae3dc  "
                ">pay online for this invoice.</a>         "
                "<br><br>Here's an overview of the invoice for "
                "your reference.         <br><br><br><br>Invoice "
                "Overview:         <br><br>Invoice  : "
                "INV-00001         <br><br>Date : 05 Aug "
                "2013         <br><br>Amount : $541.82         "
                "<br><br><br><br>It was great working with you. "
                "Looking forward to working with you "
                "again.<br><br><br>\\nRegards<br>\\nZillium "
                'Inc<br>\\n",',
                "type": "string",
            },
            "cc_mail_ids": {
                "description": "Array of email address of the recipients to be cced.",
                "example": ["peterparker@bowmanfurniture.com"],
                "items": {"type": "string"},
                "type": "array",
            },
            "send_from_org_email_id": {
                "description": "Boolean to trigger the email from the organization's email address",
                "example": False,
                "type": "boolean",
            },
            "subject": {
                "description": "The subject of the mail",
                "example": "Retainer Invoice from Zillium Inc (Retainer Invoice#: RET-00001)",
                "type": "string",
            },
            "to_mail_ids": {
                "description": "Array of email address of the recipients.",
                "example": ["willsmith@bowmanfurniture.com"],
                "items": {"type": "string"},
                "type": "array",
            },
        },
        "required": ["to_mail_ids"],
        "type": "object",
    },
    "UPDATEBILLINGADDRESSRETAINERINVOICE_REQUEST_BODY_SCHEMA": {
        "properties": {
            "address": {
                "description": "address of the customer",
                "example": "B-1104, 11F, \n"
                "Horizon International Tower, \n"
                "No. 6, ZhiChun Road, HaiDian District",
                "type": "string",
            },
            "city": {"description": "city of the customer", "example": "Beijing", "type": "string"},
            "country": {"description": "country of the customer", "type": "string"},
            "fax": {
                "description": "fax of the customer",
                "example": "+86-10-82637827",
                "type": "string",
            },
            "state": {
                "description": "state of the customer",
                "example": "Beijing",
                "type": "string",
            },
            "zip": {"description": "zip of the customer", "example": 1000881, "type": "string"},
        },
        "type": "object",
    },
    "ATTACHFILETOINVOICE_REQUEST_BODY_SCHEMA": {
        "properties": {
            "attachment": {
                "description": "The file to be attached. It has to be sent in multipart/formdata",
                "format": "binary",
                "type": "string",
            },
            "can_send_in_mail": {"example": True, "type": "boolean"},
        },
        "type": "object",
    },
    "ADDRETAINERINVOICECOMMENT_REQUEST_BODY_SCHEMA": {
        "properties": {
            "description": {
                "description": "The description of the comment. Max-length [2000]",
                "example": "comment added",
                "type": "string",
            },
            "payment_expected_date": {"example": " ", "type": "string"},
            "show_comment_to_clients": {
                "description": "Boolean to check if the comment to be shown to the clients",
                "example": True,
                "type": "boolean",
            },
        },
        "type": "object",
    },
    "UPDATERETAINERINVOICECOMMENT_REQUEST_BODY_SCHEMA": {
        "properties": {
            "description": {"description": "The comment on a retainer invoice", "type": "string"},
            "show_comment_to_clients": {
                "description": "Boolean to check if the comment to be shown to the clients",
                "example": True,
                "type": "boolean",
            },
        },
        "type": "object",
    },
    "CREATESALESORDER_REQUEST_BODY_SCHEMA": {
        "properties": {
            "adjustment": {
                "description": "Manual modification amount applied to "
                "the sales order total for rounding "
                "corrections, special pricing "
                "arrangements, or other "
                "business-specific adjustments. Supports "
                "positive and negative values for "
                "additions or deductions from the order "
                "total.",
                "example": 0.2,
                "format": "double",
                "type": "number",
            },
            "adjustment_description": {
                "description": "Textual explanation for the "
                "adjustment amount applied "
                "to the sales order. "
                "Provides audit trail "
                "documentation, "
                "justification for pricing "
                "modifications, and "
                "contextual information for "
                "financial reporting and "
                "compliance verification "
                "purposes.",
                "example": "Adjustment",
                "type": "string",
            },
            "avatax_exempt_no": {
                "description": "Exemption certificate number of the customer.",
                "type": "string",
                "x-node_available_in": ["Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "avatax_use_code": {
                "description": "Used to group like customers for "
                "exemption purposes. It is a custom "
                "value that links customers to a "
                "tax rule.",
                "type": "string",
                "x-node_available_in": ["Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "billing_address_id": {
                "description": "Unique identifier referencing "
                "the customer billing address "
                "entity. Determines the address "
                "used for invoice generation, "
                "payment processing, tax "
                "jurisdiction calculations, and "
                "financial record-keeping. Must "
                "correspond to a valid address "
                "record associated with the "
                "specified customer account.",
                "example": 460000000032174,
                "type": "string",
            },
            "contact_persons_associated": {
                "description": "Contact Persons associated with the transaction.",
                "items": {
                    "properties": {
                        "communication_preference": {
                            "description": "Preferred "
                            "modes "
                            "of "
                            "communication "
                            "for "
                            "the "
                            "contact "
                            "person "
                            "at "
                            "transaction "
                            "level.",
                            "properties": {
                                "is_email_enabled": {
                                    "description": "Used "
                                    "to "
                                    "check "
                                    "if "
                                    "Email "
                                    "communication "
                                    "preference "
                                    "is "
                                    "enabled "
                                    "for "
                                    "the "
                                    "contact "
                                    "person "
                                    "at "
                                    "transaction "
                                    "level.",
                                    "example": True,
                                    "type": "boolean",
                                },
                                "is_whatsapp_enabled": {
                                    "description": "Used "
                                    "to "
                                    "check "
                                    "if "
                                    "WhatsApp "
                                    "communication "
                                    "preference "
                                    "is "
                                    "enabled "
                                    "for "
                                    "the "
                                    "contact "
                                    "person "
                                    "at "
                                    "transaction "
                                    "level.",
                                    "example": True,
                                    "type": "boolean",
                                    "x-node_available_in": ["WhatsApp integration"],
                                },
                            },
                            "type": "object",
                        },
                        "contact_person_id": {
                            "description": "Unique ID of the Contact Person.",
                            "example": 982000000567003,
                            "format": "int64",
                            "type": "integer",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "crm_custom_reference_id": {"type": "string"},
            "crm_owner_id": {"type": "string"},
            "currency_id": {
                "description": "Unique identifier for the currency "
                "used in the sales order transaction. "
                "Determines pricing display, exchange "
                "rate calculations, and affects "
                "financial reporting. If not specified, "
                "the organization default currency will "
                "be used automatically. Can be fetched "
                "from the Get Currencies API or "
                "retrieved from your organization "
                "currency settings.",
                "example": "460000000000097",
                "type": "string",
            },
            "custom_fields": {
                "description": "Custom fields for a sales order.",
                "items": {
                    "properties": {
                        "customfield_id": {
                            "description": "ID of the Custom Field",
                            "example": "460000000639129",
                            "format": "int64",
                            "type": "integer",
                        },
                        "value": {
                            "description": "Value of the Custom Field",
                            "example": "Normal",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "customer_id": {
                "description": "Unique identifier for the customer "
                "receiving the sales order. This ID "
                "links the order to a specific customer "
                "account and determines billing "
                "information, payment terms, pricing "
                "rules, and tax calculations based on "
                "customer settings. Can be fetched from "
                "the Get Contacts API or retrieved from "
                "existing customer records in your "
                "organization.",
                "example": "460000000017138",
                "type": "string",
            },
            "date": {
                "description": "Date when the sales order was created in "
                "YYYY-MM-DD format. This date affects order "
                "processing timelines, delivery schedules, "
                "payment terms calculation, and appears on "
                "customer-facing documents and internal "
                "reports.",
                "example": "2014-07-28",
                "type": "string",
            },
            "delivery_method": {
                "description": "Specification of the "
                "transportation and delivery "
                "mechanism for order fulfillment. "
                "Determines shipping costs, "
                "delivery timelines, carrier "
                "selection, and customer "
                "communication regarding order "
                "status and tracking information.",
                "example": "Air",
                "type": "string",
            },
            "discount": {
                "description": "Discount value applied to the sales order "
                "total, specified as either percentage or "
                "absolute amount. Supports decimal "
                "precision and affects final pricing "
                "calculations, tax computations, and "
                "financial reporting. Format: percentage "
                '(e.g., "12.5%") or amount (e.g., "190").',
                "type": "string",
            },
            "discount_type": {
                "description": "Classification of discount "
                "application scope within the sales "
                "order. <code>entity_level</code> "
                "applies discount to the entire order "
                "total, while <code>item_level</code> "
                "applies discount to individual line "
                "items. Determines discount "
                "calculation methodology and affects "
                "pricing structure.",
                "example": "entity_level",
                "type": "string",
            },
            "documents": {
                "example": ["document_id", "file_name"],
                "items": {"type": "string"},
                "type": "array",
            },
            "estimate_id": {
                "description": "ID of the estimate associated with the Sales Order",
                "type": "string",
            },
            "exchange_rate": {
                "description": "Currency conversion rate from the "
                "transaction currency to the "
                "organization base currency. Required "
                "for multi-currency transactions to "
                "ensure accurate financial reporting, "
                "profit calculations, and tax "
                "computations in the base currency "
                "denomination.",
                "example": 1.233,
                "format": "double",
                "type": "number",
            },
            "gst_no": {
                "description": "15 digit GST identification number of the customer.",
                "example": "22AAAAA0000A1Z5",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "gst_treatment": {
                "description": "Choose whether the contact is GST "
                "registered/unregistered/consumer/overseas. "
                "Allowed values are <code> "
                "business_gst </code> , <code> "
                "business_none </code> , <code> "
                "overseas </code> , <code> consumer "
                "</code>.",
                "example": "business_gst",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "is_discount_before_tax": {
                "description": "Boolean flag determining "
                "the sequence of discount "
                "application in tax "
                "calculations. When true, "
                "discount is applied before "
                "tax computation; when "
                "false, discount is applied "
                "after tax calculation. "
                "Affects final pricing "
                "accuracy and tax compliance "
                "reporting.",
                "example": True,
                "type": "boolean",
            },
            "is_inclusive_tax": {
                "description": "Used to specify whether the line "
                "item rates are inclusive or "
                "exclusive of tax.",
                "example": False,
                "type": "boolean",
                "x-node_available_in": [],
                "x-node_unavailable_in": ["us", "ca"],
            },
            "is_reverse_charge_applied": {
                "description": "(Required if customer "
                "tax treatment is "
                "<code>vat_registered</code>)<br/>Used "
                "to specify whether the "
                "transaction is "
                "applicable for Domestic "
                "Reverse Charge (DRC) or "
                "not.",
                "example": True,
                "type": "boolean",
                "x-node_available_in": ["za"],
                "x-node_unavailable_in": [],
            },
            "is_update_customer": {
                "description": "Boolean flag indicating whether "
                "customer billing address "
                "information should be "
                "synchronized with the sales "
                "order data. When enabled, "
                "updates the customer master "
                "record with address "
                "modifications, ensuring data "
                "consistency across customer "
                "relationship management "
                "systems.",
                "example": False,
                "type": "boolean",
            },
            "line_items": {
                "description": "Line items of a sales order.",
                "items": {
                    "properties": {
                        "avatax_exempt_no": {
                            "description": "Exemption certificate number of the customer.",
                            "type": "string",
                            "x-node_available_in": ["Avalara Integration"],
                            "x-node_unavailable_in": [],
                        },
                        "avatax_use_code": {
                            "description": "Used "
                            "to "
                            "group "
                            "like "
                            "customers "
                            "for "
                            "exemption "
                            "purposes. "
                            "It "
                            "is "
                            "a "
                            "custom "
                            "value "
                            "that "
                            "links "
                            "customers "
                            "to "
                            "a "
                            "tax "
                            "rule.",
                            "type": "string",
                            "x-node_available_in": ["Avalara Integration"],
                            "x-node_unavailable_in": [],
                        },
                        "description": {
                            "description": "Description of the line item.",
                            "example": "500GB, USB 2.0 interface 1400 rpm, protective hard case.",
                            "type": "string",
                        },
                        "discount": {
                            "description": "Discount "
                            "value "
                            "applied "
                            "to "
                            "the "
                            "sales "
                            "order "
                            "total, "
                            "specified "
                            "as "
                            "either "
                            "percentage "
                            "or "
                            "absolute "
                            "amount. "
                            "Supports "
                            "decimal "
                            "precision "
                            "and "
                            "affects "
                            "final "
                            "pricing "
                            "calculations, "
                            "tax "
                            "computations, "
                            "and "
                            "financial "
                            "reporting. "
                            "Format: "
                            "percentage "
                            "(e.g., "
                            '"12.5%") '
                            "or "
                            "amount "
                            "(e.g., "
                            '"190").',
                            "type": "string",
                        },
                        "hsn_or_sac": {
                            "description": "Add HSN/SAC code for your goods/services",
                            "example": 80540,
                            "type": "string",
                            "x-node_available_in": ["in", "za", "ke"],
                            "x-node_unavailable_in": [],
                        },
                        "item_custom_fields": {
                            "description": "Custom fields for a sales order items.",
                            "items": {
                                "properties": {
                                    "customfield_id": {
                                        "description": "ID of the Custom Field",
                                        "example": "460000000639129",
                                        "format": "int64",
                                        "type": "integer",
                                    },
                                    "value": {
                                        "description": "Value of the Custom Field",
                                        "example": "Normal",
                                        "type": "string",
                                    },
                                },
                                "type": "object",
                            },
                            "type": "array",
                        },
                        "item_id": {
                            "description": "ID of the item.",
                            "example": "460000000017088",
                            "type": "string",
                        },
                        "item_order": {"example": 0, "type": "integer"},
                        "location_id": {
                            "description": "Unique "
                            "identifier "
                            "for "
                            "the "
                            "business "
                            "location "
                            "entity. "
                            "Specifies "
                            "the "
                            "organizational "
                            "location "
                            "where "
                            "the "
                            "sales "
                            "order "
                            "transaction "
                            "is "
                            "processed, "
                            "affecting "
                            "tax "
                            "jurisdiction "
                            "calculations, "
                            "inventory "
                            "allocation, "
                            "reporting "
                            "segmentation, "
                            "and "
                            "location-specific "
                            "business "
                            "rules "
                            "enforcement. "
                            "Can "
                            "be "
                            "retrieved "
                            "from "
                            "the "
                            "Locations "
                            "API.",
                            "example": "460000000038080",
                            "type": "string",
                        },
                        "name": {
                            "description": "Name of the line item.",
                            "example": "Hard Drive",
                            "type": "string",
                        },
                        "product_type": {
                            "description": "Enter "
                            "<code>goods</code> "
                            "or "
                            "<code>services</code> "
                            ".<br/><b>For "
                            "SouthAfrica "
                            "Edition:</b> "
                            "<code>service</code>, "
                            "<code>goods</code>, "
                            "<code>capital_service</code> "
                            "and "
                            "<code>capital_goods</code>",
                            "example": "goods",
                            "type": "string",
                        },
                        "project_id": {
                            "description": "ID of the project",
                            "example": 90300000087378,
                            "type": "string",
                        },
                        "quantity": {
                            "description": "Quantity of the line item.",
                            "example": 40,
                            "format": "double",
                            "type": "number",
                        },
                        "rate": {
                            "description": "Rate of the line item.",
                            "example": 120,
                            "format": "double",
                            "type": "number",
                        },
                        "sat_item_key_code": {
                            "description": "Add "
                            "SAT "
                            "Item "
                            "Key "
                            "Code "
                            "for "
                            "your "
                            "goods/services. "
                            "Download "
                            "the "
                            "<a "
                            "href= "
                            "http://omawww.sat.gob.mx/tramitesyservicios/Paginas/documentos/catCFDI_V_4_07122022.xls  "
                            ">CFDI "
                            "Catalogs.</a>",
                            "example": 71121206,
                            "type": "string",
                            "x-node_available_in": ["mx"],
                            "x-node_unavailable_in": [],
                        },
                        "tags": {
                            "description": "Filter all your reports based on the tag",
                            "items": {
                                "properties": {
                                    "tag_id": {
                                        "description": "ID of the reporting tag",
                                        "example": 462000000009070,
                                        "type": "string",
                                    },
                                    "tag_option_id": {
                                        "description": "ID of the reporting tag's option",
                                        "example": 462000000002670,
                                        "type": "string",
                                    },
                                },
                                "type": "object",
                            },
                            "type": "array",
                        },
                        "tax_exemption_code": {
                            "description": "Code of Tax Exemption that is applied",
                            "type": "string",
                            "x-node_available_in": ["in", "us", "mx"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_exemption_id": {
                            "description": "ID of the tax exemption applied",
                            "type": "string",
                            "x-node_available_in": ["in", "us"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_id": {
                            "description": "ID of the tax or tax group applied",
                            "example": "460000000017094",
                            "type": "string",
                        },
                        "tax_treatment_code": {
                            "description": "Specify "
                            "reason "
                            "for "
                            "using "
                            "out "
                            "of "
                            "scope.</br>Supported "
                            "values "
                            "for "
                            "<b>UAE</b> "
                            "are "
                            "<code>uae_same_tax_group</code>, "
                            "<code>uae_reimbursed_expense</code> "
                            "and "
                            "<code>uae_others</code>.</br> "
                            "Supported "
                            "values "
                            "for "
                            "<b>Bahrain</b> "
                            "are "
                            "<code>bahrain_same_tax_group</code>, "
                            "<code>bahrain_transfer_of_concern</code>, "
                            "<code>bahrain_disbursement</code>, "
                            "<code>bahrain_head_to_branch_transaction</code>, "
                            "<code>bahrain_warranty_repair_services</code> "
                            "and "
                            "<code>bahrain_others</code>.</br>Supported "
                            "values "
                            "for "
                            "<b>Saudi "
                            "Arabia</b> "
                            "are "
                            "<code>ksa_pvt_health</code>, "
                            "<code>ksa_pvt_edu</code>, "
                            "<code>ksa_reimbursed_expense</code> "
                            "and "
                            "<code>ksa_house_sales</code>.",
                            "example": "uae_others",
                            "type": "string",
                            "x-node_available_in": ["gcc"],
                            "x-node_unavailable_in": [],
                        },
                        "tds_tax_id": {
                            "description": "ID of the TDS tax or TDS tax group applied",
                            "example": "460000000017098",
                            "type": "string",
                            "x-node_available_in": ["mx"],
                            "x-node_unavailable_in": [],
                        },
                        "unit": {
                            "description": "Unit of the line item e.g. kgs, Nos.",
                            "example": "Nos",
                            "type": "string",
                        },
                        "unitkey_code": {
                            "description": "Add "
                            "SAT "
                            "Unit "
                            "Key "
                            "Code "
                            "for "
                            "your "
                            "goods/services. "
                            "Download "
                            "the "
                            "<a "
                            "href= "
                            "http://omawww.sat.gob.mx/tramitesyservicios/Paginas/documentos/catCFDI_V_4_07122022.xls  "
                            ">CFDI "
                            "Catalogs.</a>",
                            "example": "E48",
                            "type": "string",
                            "x-node_available_in": ["mx"],
                            "x-node_unavailable_in": [],
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "location_id": {
                "description": "Unique identifier for the business "
                "location entity. Specifies the "
                "organizational location where the "
                "sales order transaction is processed, "
                "affecting tax jurisdiction "
                "calculations, inventory allocation, "
                "reporting segmentation, and "
                "location-specific business rules "
                "enforcement. Can be retrieved from the "
                "Locations API.",
                "example": "460000000038080",
                "type": "string",
            },
            "merchant_id": {
                "description": "ID of the merchant",
                "example": "460000000000597",
                "type": "string",
            },
            "notes": {
                "description": "Free-form text field containing additional "
                "information, instructions, or comments "
                "related to the sales order. This field "
                "supports internal documentation, "
                "customer-specific requirements, special "
                "handling instructions, and "
                "inter-departmental communication for order "
                "processing workflows.",
                "type": "string",
            },
            "notes_default": {"description": "Default Notes for the Sales Order", "type": "string"},
            "place_of_supply": {
                "description": "Place where the goods/services are "
                "supplied to. (If not given, "
                "<code>place of contact</code> "
                "given for the contact will be "
                "taken)<br/>Supported codes for UAE "
                "emirates are : </br>Abu Dhabi - "
                "<code>AB</code>,</br>Ajman - "
                "<code>AJ</code>,</br>Dubai - "
                "<code>DU</code>,</br>Fujairah - "
                "<code>FU</code>,</br>Ras "
                "al-Khaimah - "
                "<code>RA</code>,</br>Sharjah - "
                "<code>SH</code>,</br>Umm al-Quwain "
                "- <code>UM</code><br/>Supported "
                "codes for the GCC countries are : "
                "</br>United Arab Emirates - "
                "<code>AE</code>,</br>Saudi Arabia "
                "- <code>SA</code>,</br>Bahrain - "
                "<code>BH</code>,</br>Kuwait - "
                "<code>KW</code>,</br>Oman - "
                "<code>OM</code>,</br>Qatar - "
                "<code>QA</code>.",
                "example": "TN",
                "type": "string",
                "x-node_available_in": ["in", "gcc"],
                "x-node_unavailable_in": [],
            },
            "pricebook_id": {
                "description": "Unique identifier for the pricing "
                "structure applied to the sales order. "
                "Determines item rates, discount "
                "rules, and pricing policies based on "
                "customer segments, volume tiers, or "
                "promotional campaigns. Can be "
                "retrieved from the Pricebooks API.",
                "type": "string",
            },
            "reference_number": {
                "description": "External reference identifier for "
                "cross-referencing with customer "
                "purchase orders, internal "
                "tracking systems, or third-party "
                "applications. Used for order "
                "reconciliation, customer "
                "communication, and integration "
                "with external business systems "
                "and workflows.",
                "example": "REF-001",
                "type": "string",
            },
            "salesorder_number": {
                "description": "Unique alphanumeric identifier "
                "for the sales order entity. "
                "Required when automatic "
                "numbering is disabled in "
                "organization settings. Must be "
                "unique within the organization "
                "and follows the configured "
                "numbering sequence pattern for "
                "sales order identification and "
                "tracking.",
                "example": "SO-00001",
                "type": "string",
            },
            "salesperson_id": {
                "description": "Unique identifier for the "
                "salesperson responsible for this "
                "sales order. Links the order to a "
                "specific sales representative "
                "customer relationship management, "
                "and sales reporting purposes.",
                "example": "460000000000097",
                "type": "string",
            },
            "salesperson_name": {
                "description": "Full name of the sales "
                "representative assigned to this "
                "sales order. Automatically "
                "populated when salesperson_id is "
                "specified.",
                "example": "John Roberts",
                "type": "string",
            },
            "shipment_date": {
                "description": "Expected or actual date when goods "
                "will be shipped to the customer in "
                "YYYY-MM-DD format. Used for delivery "
                "planning, customer communication, "
                "inventory management, and tracking "
                "order fulfillment timelines.",
                "type": "string",
            },
            "shipping_address_id": {
                "description": "Unique identifier referencing "
                "the customer shipping address "
                "entity. Specifies the delivery "
                "destination for goods "
                "fulfillment, logistics "
                "planning, shipping cost "
                "calculations, and delivery "
                "confirmation processes. Must "
                "correspond to a valid address "
                "record within the customer "
                "address registry.",
                "type": "string",
            },
            "shipping_charge": {
                "description": "Additional cost associated with "
                "product delivery and logistics "
                "services. Applied to the sales "
                "order total and affects final "
                "pricing calculations, profit "
                "margins, and customer billing. "
                "Supports decimal precision for "
                "accurate cost allocation.",
                "example": 2,
                "format": "double",
                "type": "number",
            },
            "tax_authority_id": {
                "description": "ID of the tax authority. Tax "
                "authority depends on the location "
                "of the customer.",
                "type": "string",
                "x-node_available_in": ["us"],
                "x-node_unavailable_in": [],
            },
            "tax_authority_name": {
                "description": "Tax Authority's name.",
                "type": "string",
                "x-node_available_in": ["us", "mx"],
                "x-node_unavailable_in": [],
            },
            "tax_exemption_code": {
                "description": "Code of Tax Exemption that is applied",
                "type": "string",
                "x-node_available_in": ["in", "us", "mx"],
                "x-node_unavailable_in": [],
            },
            "tax_exemption_id": {
                "description": "ID of the tax exemption applied",
                "type": "string",
                "x-node_available_in": ["in", "us"],
                "x-node_unavailable_in": [],
            },
            "tax_id": {
                "description": "Tax ID for the Sales Order.",
                "example": "460000000017094",
                "type": "string",
            },
            "tax_treatment": {
                "description": "VAT treatment for the sales "
                "order.Allowed Values: "
                "<code>vat_registered</code>,<code>vat_not_registered</code>,<code>gcc_vat_not_registered</code>,<code>gcc_vat_registered</code>,<code>non_gcc</code>.</br><code>dz_vat_registered</code> "
                "and "
                "<code>dz_vat_not_registered</code> "
                "supported only for "
                "<b>UAE</b>.</b></br><code>home_country_mexico</code>,<code>border_region_mexico</code>,<code>non_mexico</code> "
                "supported only for <b>MX</b>. "
                "<br/><b>For Kenya Edition:</b> "
                "<code>vat_registered</code> "
                ",<code>vat_not_registered</code> "
                ",<code>non_kenya</code>(A business "
                "that is located outside "
                "Kenya).<br/><b>For SouthAfrica "
                "Edition:</b> "
                "<code>vat_registered</code>, "
                "<code>vat_not_registered</code>, "
                "<code>overseas</code>(A business "
                "that is located outside "
                "SouthAfrica).",
                "example": "vat_registered",
                "type": "string",
                "x-node_available_in": ["gcc", "mx", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "template_id": {
                "description": "Unique identifier for the PDF document "
                "template used for sales order "
                "presentation. Determines document "
                "layout, branding elements, formatting "
                "specifications, and visual "
                "presentation standards for "
                "customer-facing documents and printed "
                "materials.",
                "example": "460000000021001",
                "type": "string",
            },
            "terms": {
                "description": "Contractual terms and conditions governing "
                "the sales order transaction. Defines payment "
                "obligations, delivery specifications, "
                "warranty provisions, liability limitations, "
                "and other legal stipulations that establish "
                "the binding agreement between the "
                "organization and customer for this specific "
                "transaction.",
                "type": "string",
            },
            "terms_default": {"description": "Default Terms of the Sales Order", "type": "string"},
            "vat_treatment": {
                "description": "(Optional) VAT treatment for the "
                "sales order. VAT treatment denotes "
                "the location of the customer, if the "
                "customer resides in UK then the VAT "
                "treatment is <code>uk</code>. If the "
                "customer is in an EU country & VAT "
                "registered, you are resides in "
                "Northen Ireland and purchasing Goods "
                "then his VAT treatment is "
                "<code>eu_vat_registered</code> and "
                "if he resides outside the UK then "
                "his VAT treatment is "
                "<code>overseas</code>(For Pre "
                "Brexit, this can be split as "
                "<code>eu_vat_registered</code>, "
                "<code>eu_vat_not_registered</code> "
                "and <code>non_eu</code>).",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
            "zcrm_potential_id": {
                "description": "Unique identifier linking the "
                "sales order to a Zoho CRM "
                "potential record.",
                "example": "460000000033001",
                "type": "string",
            },
            "zcrm_potential_name": {
                "description": "Descriptive name of the Zoho "
                "CRM potential record "
                "associated with this sales "
                "order.",
                "type": "string",
            },
        },
        "required": ["customer_id"],
        "type": "object",
    },
    "UPDATESALESORDERWITHCUSTOMFIELD_REQUEST_BODY_SCHEMA": {
        "properties": {
            "adjustment": {
                "description": "Manual modification amount applied to "
                "the sales order total for rounding "
                "corrections, special pricing "
                "arrangements, or other "
                "business-specific adjustments. Supports "
                "positive and negative values for "
                "additions or deductions from the order "
                "total.",
                "example": 0.2,
                "format": "double",
                "type": "number",
            },
            "adjustment_description": {
                "description": "Textual explanation for the "
                "adjustment amount applied "
                "to the sales order. "
                "Provides audit trail "
                "documentation, "
                "justification for pricing "
                "modifications, and "
                "contextual information for "
                "financial reporting and "
                "compliance verification "
                "purposes.",
                "example": "Adjustment",
                "type": "string",
            },
            "avatax_exempt_no": {
                "description": "Exemption certificate number of the customer.",
                "type": "string",
                "x-node_available_in": ["Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "avatax_use_code": {
                "description": "Used to group like customers for "
                "exemption purposes. It is a custom "
                "value that links customers to a "
                "tax rule.",
                "type": "string",
                "x-node_available_in": ["Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "billing_address_id": {
                "description": "Unique identifier referencing "
                "the customer billing address "
                "entity. Determines the address "
                "used for invoice generation, "
                "payment processing, tax "
                "jurisdiction calculations, and "
                "financial record-keeping. Must "
                "correspond to a valid address "
                "record associated with the "
                "specified customer account.",
                "example": 460000000032174,
                "type": "string",
            },
            "contact_persons_associated": {
                "description": "Contact Persons associated with the transaction.",
                "items": {
                    "properties": {
                        "communication_preference": {
                            "description": "Preferred "
                            "modes "
                            "of "
                            "communication "
                            "for "
                            "the "
                            "contact "
                            "person "
                            "at "
                            "transaction "
                            "level.",
                            "properties": {
                                "is_email_enabled": {
                                    "description": "Used "
                                    "to "
                                    "check "
                                    "if "
                                    "Email "
                                    "communication "
                                    "preference "
                                    "is "
                                    "enabled "
                                    "for "
                                    "the "
                                    "contact "
                                    "person "
                                    "at "
                                    "transaction "
                                    "level.",
                                    "example": True,
                                    "type": "boolean",
                                },
                                "is_whatsapp_enabled": {
                                    "description": "Used "
                                    "to "
                                    "check "
                                    "if "
                                    "WhatsApp "
                                    "communication "
                                    "preference "
                                    "is "
                                    "enabled "
                                    "for "
                                    "the "
                                    "contact "
                                    "person "
                                    "at "
                                    "transaction "
                                    "level.",
                                    "example": True,
                                    "type": "boolean",
                                    "x-node_available_in": ["WhatsApp integration"],
                                },
                            },
                            "type": "object",
                        },
                        "contact_person_id": {
                            "description": "Unique ID of the Contact Person.",
                            "example": 982000000567003,
                            "format": "int64",
                            "type": "integer",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "crm_custom_reference_id": {"type": "string"},
            "crm_owner_id": {"type": "string"},
            "currency_id": {
                "description": "Unique identifier for the currency "
                "used in the sales order transaction. "
                "Determines pricing display, exchange "
                "rate calculations, and affects "
                "financial reporting. If not specified, "
                "the organization default currency will "
                "be used automatically. Can be fetched "
                "from the Get Currencies API or "
                "retrieved from your organization "
                "currency settings.",
                "example": "460000000000097",
                "type": "string",
            },
            "custom_fields": {
                "description": "Custom fields for a sales order.",
                "items": {
                    "properties": {
                        "customfield_id": {
                            "description": "ID of the Custom Field",
                            "example": "460000000639129",
                            "format": "int64",
                            "type": "integer",
                        },
                        "value": {
                            "description": "Value of the Custom Field",
                            "example": "Normal",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "customer_id": {
                "description": "Unique identifier for the customer "
                "receiving the sales order. This ID "
                "links the order to a specific customer "
                "account and determines billing "
                "information, payment terms, pricing "
                "rules, and tax calculations based on "
                "customer settings. Can be fetched from "
                "the Get Contacts API or retrieved from "
                "existing customer records in your "
                "organization.",
                "example": "460000000017138",
                "type": "string",
            },
            "date": {
                "description": "Date when the sales order was created in "
                "YYYY-MM-DD format. This date affects order "
                "processing timelines, delivery schedules, "
                "payment terms calculation, and appears on "
                "customer-facing documents and internal "
                "reports.",
                "example": "2014-07-28",
                "type": "string",
            },
            "delivery_method": {
                "description": "Specification of the "
                "transportation and delivery "
                "mechanism for order fulfillment. "
                "Determines shipping costs, "
                "delivery timelines, carrier "
                "selection, and customer "
                "communication regarding order "
                "status and tracking information.",
                "example": "Air",
                "type": "string",
            },
            "discount": {
                "description": "Discount value applied to the sales order "
                "total, specified as either percentage or "
                "absolute amount. Supports decimal "
                "precision and affects final pricing "
                "calculations, tax computations, and "
                "financial reporting. Format: percentage "
                '(e.g., "12.5%") or amount (e.g., "190").',
                "type": "string",
            },
            "discount_type": {
                "description": "Classification of discount "
                "application scope within the sales "
                "order. <code>entity_level</code> "
                "applies discount to the entire order "
                "total, while <code>item_level</code> "
                "applies discount to individual line "
                "items. Determines discount "
                "calculation methodology and affects "
                "pricing structure.",
                "example": "entity_level",
                "type": "string",
            },
            "documents": {
                "example": ["document_id", "file_name"],
                "items": {"type": "string"},
                "type": "array",
            },
            "exchange_rate": {
                "description": "Currency conversion rate from the "
                "transaction currency to the "
                "organization base currency. Required "
                "for multi-currency transactions to "
                "ensure accurate financial reporting, "
                "profit calculations, and tax "
                "computations in the base currency "
                "denomination.",
                "example": 1.233,
                "format": "double",
                "type": "number",
            },
            "gst_no": {
                "description": "15 digit GST identification number of the customer.",
                "example": "22AAAAA0000A1Z5",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "gst_treatment": {
                "description": "Choose whether the contact is GST "
                "registered/unregistered/consumer/overseas. "
                "Allowed values are <code> "
                "business_gst </code> , <code> "
                "business_none </code> , <code> "
                "overseas </code> , <code> consumer "
                "</code>.",
                "example": "business_gst",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "is_discount_before_tax": {
                "description": "Boolean flag determining "
                "the sequence of discount "
                "application in tax "
                "calculations. When true, "
                "discount is applied before "
                "tax computation; when "
                "false, discount is applied "
                "after tax calculation. "
                "Affects final pricing "
                "accuracy and tax compliance "
                "reporting.",
                "example": True,
                "type": "boolean",
            },
            "is_inclusive_tax": {
                "description": "Used to specify whether the line "
                "item rates are inclusive or "
                "exclusive of tax.",
                "example": False,
                "type": "boolean",
                "x-node_available_in": [],
                "x-node_unavailable_in": ["us", "ca"],
            },
            "is_reverse_charge_applied": {
                "description": "(Required if customer "
                "tax treatment is "
                "<code>vat_registered</code>)<br/>Used "
                "to specify whether the "
                "transaction is "
                "applicable for Domestic "
                "Reverse Charge (DRC) or "
                "not.",
                "example": True,
                "type": "boolean",
                "x-node_available_in": ["za"],
                "x-node_unavailable_in": [],
            },
            "is_update_customer": {
                "description": "Boolean flag indicating whether "
                "customer billing address "
                "information should be "
                "synchronized with the sales "
                "order data. When enabled, "
                "updates the customer master "
                "record with address "
                "modifications, ensuring data "
                "consistency across customer "
                "relationship management "
                "systems.",
                "example": False,
                "type": "boolean",
            },
            "line_items": {
                "description": "Line items of a sales order.",
                "items": {
                    "properties": {
                        "avatax_exempt_no": {
                            "description": "Exemption certificate number of the customer.",
                            "type": "string",
                            "x-node_available_in": ["Avalara Integration"],
                            "x-node_unavailable_in": [],
                        },
                        "avatax_use_code": {
                            "description": "Used "
                            "to "
                            "group "
                            "like "
                            "customers "
                            "for "
                            "exemption "
                            "purposes. "
                            "It "
                            "is "
                            "a "
                            "custom "
                            "value "
                            "that "
                            "links "
                            "customers "
                            "to "
                            "a "
                            "tax "
                            "rule.",
                            "type": "string",
                            "x-node_available_in": ["Avalara Integration"],
                            "x-node_unavailable_in": [],
                        },
                        "description": {
                            "description": "Description of the line item.",
                            "example": "500GB, USB 2.0 interface 1400 rpm, protective hard case.",
                            "type": "string",
                        },
                        "discount": {
                            "description": "Discount "
                            "value "
                            "applied "
                            "to "
                            "the "
                            "sales "
                            "order "
                            "total, "
                            "specified "
                            "as "
                            "either "
                            "percentage "
                            "or "
                            "absolute "
                            "amount. "
                            "Supports "
                            "decimal "
                            "precision "
                            "and "
                            "affects "
                            "final "
                            "pricing "
                            "calculations, "
                            "tax "
                            "computations, "
                            "and "
                            "financial "
                            "reporting. "
                            "Format: "
                            "percentage "
                            "(e.g., "
                            '"12.5%") '
                            "or "
                            "amount "
                            "(e.g., "
                            '"190").',
                            "type": "string",
                        },
                        "item_custom_fields": {
                            "description": "Custom fields for a sales order items.",
                            "items": {
                                "properties": {
                                    "customfield_id": {
                                        "description": "ID of the Custom Field",
                                        "example": "460000000639129",
                                        "format": "int64",
                                        "type": "integer",
                                    },
                                    "value": {
                                        "description": "Value of the Custom Field",
                                        "example": "Normal",
                                        "type": "string",
                                    },
                                },
                                "type": "object",
                            },
                            "type": "array",
                        },
                        "item_id": {
                            "description": "ID of the item.",
                            "example": "460000000017088",
                            "type": "string",
                        },
                        "item_order": {"example": 0, "type": "integer"},
                        "line_item_id": {
                            "description": "ID "
                            "of "
                            "the "
                            "line "
                            "item. "
                            "Mandatory "
                            "if "
                            "the "
                            "existing "
                            "line "
                            "item "
                            "has "
                            "to "
                            "be "
                            "updated. "
                            "If "
                            "empty, "
                            "a "
                            "new "
                            "line "
                            "item "
                            "will "
                            "be "
                            "created.",
                            "example": "460000000039131",
                            "type": "string",
                        },
                        "location_id": {
                            "description": "Unique "
                            "identifier "
                            "for "
                            "the "
                            "business "
                            "location "
                            "entity. "
                            "Specifies "
                            "the "
                            "organizational "
                            "location "
                            "where "
                            "the "
                            "sales "
                            "order "
                            "transaction "
                            "is "
                            "processed, "
                            "affecting "
                            "tax "
                            "jurisdiction "
                            "calculations, "
                            "inventory "
                            "allocation, "
                            "reporting "
                            "segmentation, "
                            "and "
                            "location-specific "
                            "business "
                            "rules "
                            "enforcement. "
                            "Can "
                            "be "
                            "retrieved "
                            "from "
                            "the "
                            "Locations "
                            "API.",
                            "example": "460000000038080",
                            "type": "string",
                        },
                        "name": {
                            "description": "Name of the line item.",
                            "example": "Hard Drive",
                            "type": "string",
                        },
                        "project_id": {
                            "description": "ID of the project",
                            "example": 90300000087378,
                            "type": "string",
                        },
                        "quantity": {
                            "description": "Quantity of the line item.",
                            "example": 40,
                            "format": "double",
                            "type": "number",
                        },
                        "rate": {
                            "description": "Rate of the line item.",
                            "example": 120,
                            "format": "double",
                            "type": "number",
                        },
                        "tags": {
                            "description": "Filter all your reports based on the tag",
                            "items": {
                                "properties": {
                                    "tag_id": {
                                        "description": "ID of the reporting tag",
                                        "example": 462000000009070,
                                        "type": "string",
                                    },
                                    "tag_option_id": {
                                        "description": "ID of the reporting tag's option",
                                        "example": 462000000002670,
                                        "type": "string",
                                    },
                                },
                                "type": "object",
                            },
                            "type": "array",
                        },
                        "tax_exemption_code": {
                            "description": "Code of Tax Exemption that is applied",
                            "type": "string",
                            "x-node_available_in": ["in", "us", "mx"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_exemption_id": {
                            "description": "ID of the tax exemption applied",
                            "type": "string",
                            "x-node_available_in": ["in", "us"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_id": {
                            "description": "Tax ID for the Sales Order.",
                            "example": "460000000017094",
                            "type": "string",
                        },
                        "tax_treatment_code": {
                            "description": "Specify "
                            "reason "
                            "for "
                            "using "
                            "out "
                            "of "
                            "scope.</br>Supported "
                            "values "
                            "for "
                            "<b>UAE</b> "
                            "are "
                            "<code>uae_same_tax_group</code>, "
                            "<code>uae_reimbursed_expense</code> "
                            "and "
                            "<code>uae_others</code>.</br> "
                            "Supported "
                            "values "
                            "for "
                            "<b>Bahrain</b> "
                            "are "
                            "<code>bahrain_same_tax_group</code>, "
                            "<code>bahrain_transfer_of_concern</code>, "
                            "<code>bahrain_disbursement</code>, "
                            "<code>bahrain_head_to_branch_transaction</code>, "
                            "<code>bahrain_warranty_repair_services</code> "
                            "and "
                            "<code>bahrain_others</code>.</br>Supported "
                            "values "
                            "for "
                            "<b>Saudi "
                            "Arabia</b> "
                            "are "
                            "<code>ksa_pvt_health</code>, "
                            "<code>ksa_pvt_edu</code>, "
                            "<code>ksa_reimbursed_expense</code> "
                            "and "
                            "<code>ksa_house_sales</code>.",
                            "example": "uae_others",
                            "type": "string",
                            "x-node_available_in": ["gcc"],
                            "x-node_unavailable_in": [],
                        },
                        "tds_tax_id": {
                            "description": "ID of the TDS tax or TDS tax group applied",
                            "example": "460000000017098",
                            "type": "string",
                            "x-node_available_in": ["mx"],
                            "x-node_unavailable_in": [],
                        },
                        "unit": {
                            "description": "Unit of the line item e.g. kgs, Nos.",
                            "example": "Nos",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "location_id": {
                "description": "Unique identifier for the business "
                "location entity. Specifies the "
                "organizational location where the "
                "sales order transaction is processed, "
                "affecting tax jurisdiction "
                "calculations, inventory allocation, "
                "reporting segmentation, and "
                "location-specific business rules "
                "enforcement. Can be retrieved from the "
                "Locations API.",
                "example": "460000000038080",
                "type": "string",
            },
            "merchant_id": {
                "description": "ID of the merchant",
                "example": "460000000000597",
                "type": "string",
            },
            "notes": {
                "description": "Free-form text field containing additional "
                "information, instructions, or comments "
                "related to the sales order. This field "
                "supports internal documentation, "
                "customer-specific requirements, special "
                "handling instructions, and "
                "inter-departmental communication for order "
                "processing workflows.",
                "type": "string",
            },
            "notes_default": {"description": "Default Notes for the Sales Order", "type": "string"},
            "place_of_supply": {
                "description": "Place where the goods/services are "
                "supplied to. (If not given, "
                "<code>place of contact</code> "
                "given for the contact will be "
                "taken)<br/>Supported codes for UAE "
                "emirates are : </br>Abu Dhabi - "
                "<code>AB</code>,</br>Ajman - "
                "<code>AJ</code>,</br>Dubai - "
                "<code>DU</code>,</br>Fujairah - "
                "<code>FU</code>,</br>Ras "
                "al-Khaimah - "
                "<code>RA</code>,</br>Sharjah - "
                "<code>SH</code>,</br>Umm al-Quwain "
                "- <code>UM</code><br/>Supported "
                "codes for the GCC countries are : "
                "</br>United Arab Emirates - "
                "<code>AE</code>,</br>Saudi Arabia "
                "- <code>SA</code>,</br>Bahrain - "
                "<code>BH</code>,</br>Kuwait - "
                "<code>KW</code>,</br>Oman - "
                "<code>OM</code>,</br>Qatar - "
                "<code>QA</code>.",
                "example": "TN",
                "type": "string",
                "x-node_available_in": ["in", "gcc"],
                "x-node_unavailable_in": [],
            },
            "pricebook_id": {
                "description": "Unique identifier for the pricing "
                "structure applied to the sales order. "
                "Determines item rates, discount "
                "rules, and pricing policies based on "
                "customer segments, volume tiers, or "
                "promotional campaigns. Can be "
                "retrieved from the Pricebooks API.",
                "type": "string",
            },
            "reference_number": {
                "description": "External reference identifier for "
                "cross-referencing with customer "
                "purchase orders, internal "
                "tracking systems, or third-party "
                "applications. Used for order "
                "reconciliation, customer "
                "communication, and integration "
                "with external business systems "
                "and workflows.",
                "example": "REF-001",
                "type": "string",
            },
            "salesorder_number": {
                "description": "Unique alphanumeric identifier "
                "for the sales order entity. "
                "Required when automatic "
                "numbering is disabled in "
                "organization settings. Must be "
                "unique within the organization "
                "and follows the configured "
                "numbering sequence pattern for "
                "sales order identification and "
                "tracking.",
                "example": "SO-00001",
                "type": "string",
            },
            "salesperson_id": {
                "description": "Unique identifier for the "
                "salesperson responsible for this "
                "sales order. Links the order to a "
                "specific sales representative "
                "customer relationship management, "
                "and sales reporting purposes.",
                "example": "460000000000097",
                "type": "string",
            },
            "salesperson_name": {
                "description": "Full name of the sales "
                "representative assigned to this "
                "sales order. Automatically "
                "populated when salesperson_id is "
                "specified.",
                "example": "John Roberts",
                "type": "string",
            },
            "shipment_date": {
                "description": "Expected or actual date when goods "
                "will be shipped to the customer in "
                "YYYY-MM-DD format. Used for delivery "
                "planning, customer communication, "
                "inventory management, and tracking "
                "order fulfillment timelines.",
                "type": "string",
            },
            "shipping_address_id": {
                "description": "Unique identifier referencing "
                "the customer shipping address "
                "entity. Specifies the delivery "
                "destination for goods "
                "fulfillment, logistics "
                "planning, shipping cost "
                "calculations, and delivery "
                "confirmation processes. Must "
                "correspond to a valid address "
                "record within the customer "
                "address registry.",
                "type": "string",
            },
            "shipping_charge": {
                "description": "Additional cost associated with "
                "product delivery and logistics "
                "services. Applied to the sales "
                "order total and affects final "
                "pricing calculations, profit "
                "margins, and customer billing. "
                "Supports decimal precision for "
                "accurate cost allocation.",
                "example": 2,
                "format": "double",
                "type": "number",
            },
            "tax_authority_id": {
                "description": "ID of the tax authority. Tax "
                "authority depends on the location "
                "of the customer.",
                "type": "string",
                "x-node_available_in": ["us"],
                "x-node_unavailable_in": [],
            },
            "tax_authority_name": {
                "description": "Tax Authority's name.",
                "type": "string",
                "x-node_available_in": ["us", "mx"],
                "x-node_unavailable_in": [],
            },
            "tax_exemption_code": {
                "description": "Code of Tax Exemption that is applied",
                "type": "string",
                "x-node_available_in": ["in", "us", "mx"],
                "x-node_unavailable_in": [],
            },
            "tax_exemption_id": {
                "description": "ID of the tax exemption applied",
                "type": "string",
                "x-node_available_in": ["in", "us"],
                "x-node_unavailable_in": [],
            },
            "tax_id": {
                "description": "Tax ID for the Sales Order.",
                "example": "460000000017094",
                "type": "string",
            },
            "tax_treatment": {
                "description": "VAT treatment for the sales "
                "order.Allowed Values: "
                "<code>vat_registered</code>,<code>vat_not_registered</code>,<code>gcc_vat_not_registered</code>,<code>gcc_vat_registered</code>,<code>non_gcc</code>.</br><code>dz_vat_registered</code> "
                "and "
                "<code>dz_vat_not_registered</code> "
                "supported only for "
                "<b>UAE</b>.</b></br><code>home_country_mexico</code>,<code>border_region_mexico</code>,<code>non_mexico</code> "
                "supported only for <b>MX</b>. "
                "<br/><b>For Kenya Edition:</b> "
                "<code>vat_registered</code> "
                ",<code>vat_not_registered</code> "
                ",<code>non_kenya</code>(A business "
                "that is located outside "
                "Kenya).<br/><b>For SouthAfrica "
                "Edition:</b> "
                "<code>vat_registered</code>, "
                "<code>vat_not_registered</code>, "
                "<code>overseas</code>(A business "
                "that is located outside "
                "SouthAfrica).",
                "example": "vat_registered",
                "type": "string",
                "x-node_available_in": ["gcc", "mx", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "template_id": {
                "description": "Unique identifier for the PDF document "
                "template used for sales order "
                "presentation. Determines document "
                "layout, branding elements, formatting "
                "specifications, and visual "
                "presentation standards for "
                "customer-facing documents and printed "
                "materials.",
                "example": "460000000021001",
                "type": "string",
            },
            "terms": {
                "description": "Contractual terms and conditions governing "
                "the sales order transaction. Defines payment "
                "obligations, delivery specifications, "
                "warranty provisions, liability limitations, "
                "and other legal stipulations that establish "
                "the binding agreement between the "
                "organization and customer for this specific "
                "transaction.",
                "type": "string",
            },
            "terms_default": {"description": "Default Terms of the Sales Order", "type": "string"},
            "vat_treatment": {
                "description": "(Optional) VAT treatment for the "
                "sales order. VAT treatment denotes "
                "the location of the customer, if the "
                "customer resides in UK then the VAT "
                "treatment is <code>uk</code>. If the "
                "customer is in an EU country & VAT "
                "registered, you are resides in "
                "Northen Ireland and purchasing Goods "
                "then his VAT treatment is "
                "<code>eu_vat_registered</code> and "
                "if he resides outside the UK then "
                "his VAT treatment is "
                "<code>overseas</code>(For Pre "
                "Brexit, this can be split as "
                "<code>eu_vat_registered</code>, "
                "<code>eu_vat_not_registered</code> "
                "and <code>non_eu</code>).",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
            "zcrm_potential_id": {
                "description": "Unique identifier linking the "
                "sales order to a Zoho CRM "
                "potential record.",
                "example": "460000000033001",
                "type": "string",
            },
            "zcrm_potential_name": {
                "description": "Descriptive name of the Zoho "
                "CRM potential record "
                "associated with this sales "
                "order.",
                "type": "string",
            },
        },
        "required": ["customer_id"],
        "type": "object",
    },
    "UPDATESALESORDERINZOHOBOOKS_REQUEST_BODY_SCHEMA": {
        "properties": {
            "adjustment": {
                "description": "Manual modification amount applied to "
                "the sales order total for rounding "
                "corrections, special pricing "
                "arrangements, or other "
                "business-specific adjustments. Supports "
                "positive and negative values for "
                "additions or deductions from the order "
                "total.",
                "example": 0.2,
                "format": "double",
                "type": "number",
            },
            "adjustment_description": {
                "description": "Textual explanation for the "
                "adjustment amount applied "
                "to the sales order. "
                "Provides audit trail "
                "documentation, "
                "justification for pricing "
                "modifications, and "
                "contextual information for "
                "financial reporting and "
                "compliance verification "
                "purposes.",
                "example": "Adjustment",
                "type": "string",
            },
            "avatax_exempt_no": {
                "description": "Exemption certificate number of the customer.",
                "type": "string",
                "x-node_available_in": ["Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "avatax_use_code": {
                "description": "Used to group like customers for "
                "exemption purposes. It is a custom "
                "value that links customers to a "
                "tax rule.",
                "type": "string",
                "x-node_available_in": ["Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "billing_address_id": {
                "description": "Unique identifier referencing "
                "the customer billing address "
                "entity. Determines the address "
                "used for invoice generation, "
                "payment processing, tax "
                "jurisdiction calculations, and "
                "financial record-keeping. Must "
                "correspond to a valid address "
                "record associated with the "
                "specified customer account.",
                "example": 460000000032174,
                "type": "string",
            },
            "contact_persons_associated": {
                "description": "Contact Persons associated with the transaction.",
                "items": {
                    "properties": {
                        "communication_preference": {
                            "description": "Preferred "
                            "modes "
                            "of "
                            "communication "
                            "for "
                            "the "
                            "contact "
                            "person "
                            "at "
                            "transaction "
                            "level.",
                            "properties": {
                                "is_email_enabled": {
                                    "description": "Used "
                                    "to "
                                    "check "
                                    "if "
                                    "Email "
                                    "communication "
                                    "preference "
                                    "is "
                                    "enabled "
                                    "for "
                                    "the "
                                    "contact "
                                    "person "
                                    "at "
                                    "transaction "
                                    "level.",
                                    "example": True,
                                    "type": "boolean",
                                },
                                "is_whatsapp_enabled": {
                                    "description": "Used "
                                    "to "
                                    "check "
                                    "if "
                                    "WhatsApp "
                                    "communication "
                                    "preference "
                                    "is "
                                    "enabled "
                                    "for "
                                    "the "
                                    "contact "
                                    "person "
                                    "at "
                                    "transaction "
                                    "level.",
                                    "example": True,
                                    "type": "boolean",
                                    "x-node_available_in": ["WhatsApp integration"],
                                },
                            },
                            "type": "object",
                        },
                        "contact_person_id": {
                            "description": "Unique ID of the Contact Person.",
                            "example": 982000000567003,
                            "format": "int64",
                            "type": "integer",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "crm_custom_reference_id": {"type": "string"},
            "crm_owner_id": {"type": "string"},
            "currency_id": {
                "description": "Unique identifier for the currency "
                "used in the sales order transaction. "
                "Determines pricing display, exchange "
                "rate calculations, and affects "
                "financial reporting. If not specified, "
                "the organization default currency will "
                "be used automatically. Can be fetched "
                "from the Get Currencies API or "
                "retrieved from your organization "
                "currency settings.",
                "example": "460000000000097",
                "type": "string",
            },
            "custom_fields": {
                "description": "Custom fields for a sales order.",
                "items": {
                    "properties": {
                        "customfield_id": {
                            "description": "ID of the Custom Field",
                            "example": "460000000639129",
                            "format": "int64",
                            "type": "integer",
                        },
                        "value": {
                            "description": "Value of the Custom Field",
                            "example": "Normal",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "customer_id": {
                "description": "Unique identifier for the customer "
                "receiving the sales order. This ID "
                "links the order to a specific customer "
                "account and determines billing "
                "information, payment terms, pricing "
                "rules, and tax calculations based on "
                "customer settings. Can be fetched from "
                "the Get Contacts API or retrieved from "
                "existing customer records in your "
                "organization.",
                "example": "460000000017138",
                "type": "string",
            },
            "date": {
                "description": "Date when the sales order was created in "
                "YYYY-MM-DD format. This date affects order "
                "processing timelines, delivery schedules, "
                "payment terms calculation, and appears on "
                "customer-facing documents and internal "
                "reports.",
                "example": "2014-07-28",
                "type": "string",
            },
            "delivery_method": {
                "description": "Specification of the "
                "transportation and delivery "
                "mechanism for order fulfillment. "
                "Determines shipping costs, "
                "delivery timelines, carrier "
                "selection, and customer "
                "communication regarding order "
                "status and tracking information.",
                "example": "Air",
                "type": "string",
            },
            "discount": {
                "description": "Discount value applied to the sales order "
                "total, specified as either percentage or "
                "absolute amount. Supports decimal "
                "precision and affects final pricing "
                "calculations, tax computations, and "
                "financial reporting. Format: percentage "
                '(e.g., "12.5%") or amount (e.g., "190").',
                "type": "string",
            },
            "discount_type": {
                "description": "Classification of discount "
                "application scope within the sales "
                "order. <code>entity_level</code> "
                "applies discount to the entire order "
                "total, while <code>item_level</code> "
                "applies discount to individual line "
                "items. Determines discount "
                "calculation methodology and affects "
                "pricing structure.",
                "example": "entity_level",
                "type": "string",
            },
            "documents": {
                "example": ["document_id", "file_name"],
                "items": {"type": "string"},
                "type": "array",
            },
            "exchange_rate": {
                "description": "Currency conversion rate from the "
                "transaction currency to the "
                "organization base currency. Required "
                "for multi-currency transactions to "
                "ensure accurate financial reporting, "
                "profit calculations, and tax "
                "computations in the base currency "
                "denomination.",
                "example": 1.233,
                "format": "double",
                "type": "number",
            },
            "gst_no": {
                "description": "15 digit GST identification number of the customer.",
                "example": "22AAAAA0000A1Z5",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "gst_treatment": {
                "description": "Choose whether the contact is GST "
                "registered/unregistered/consumer/overseas. "
                "Allowed values are <code> "
                "business_gst </code> , <code> "
                "business_none </code> , <code> "
                "overseas </code> , <code> consumer "
                "</code>.",
                "example": "business_gst",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "is_discount_before_tax": {
                "description": "Boolean flag determining "
                "the sequence of discount "
                "application in tax "
                "calculations. When true, "
                "discount is applied before "
                "tax computation; when "
                "false, discount is applied "
                "after tax calculation. "
                "Affects final pricing "
                "accuracy and tax compliance "
                "reporting.",
                "example": True,
                "type": "boolean",
            },
            "is_inclusive_tax": {
                "description": "Used to specify whether the line "
                "item rates are inclusive or "
                "exclusive of tax.",
                "example": False,
                "type": "boolean",
                "x-node_available_in": [],
                "x-node_unavailable_in": ["us", "ca"],
            },
            "is_reverse_charge_applied": {
                "description": "(Required if customer "
                "tax treatment is "
                "<code>vat_registered</code>)<br/>Used "
                "to specify whether the "
                "transaction is "
                "applicable for Domestic "
                "Reverse Charge (DRC) or "
                "not.",
                "example": True,
                "type": "boolean",
                "x-node_available_in": ["za"],
                "x-node_unavailable_in": [],
            },
            "is_update_customer": {
                "description": "Boolean flag indicating whether "
                "customer billing address "
                "information should be "
                "synchronized with the sales "
                "order data. When enabled, "
                "updates the customer master "
                "record with address "
                "modifications, ensuring data "
                "consistency across customer "
                "relationship management "
                "systems.",
                "example": False,
                "type": "boolean",
            },
            "line_items": {
                "description": "Line items of a sales order.",
                "items": {
                    "properties": {
                        "avatax_exempt_no": {
                            "description": "Exemption certificate number of the customer.",
                            "type": "string",
                            "x-node_available_in": ["Avalara Integration"],
                            "x-node_unavailable_in": [],
                        },
                        "avatax_use_code": {
                            "description": "Used "
                            "to "
                            "group "
                            "like "
                            "customers "
                            "for "
                            "exemption "
                            "purposes. "
                            "It "
                            "is "
                            "a "
                            "custom "
                            "value "
                            "that "
                            "links "
                            "customers "
                            "to "
                            "a "
                            "tax "
                            "rule.",
                            "type": "string",
                            "x-node_available_in": ["Avalara Integration"],
                            "x-node_unavailable_in": [],
                        },
                        "description": {
                            "description": "Description of the line item.",
                            "example": "500GB, USB 2.0 interface 1400 rpm, protective hard case.",
                            "type": "string",
                        },
                        "discount": {
                            "description": "Discount "
                            "value "
                            "applied "
                            "to "
                            "the "
                            "sales "
                            "order "
                            "total, "
                            "specified "
                            "as "
                            "either "
                            "percentage "
                            "or "
                            "absolute "
                            "amount. "
                            "Supports "
                            "decimal "
                            "precision "
                            "and "
                            "affects "
                            "final "
                            "pricing "
                            "calculations, "
                            "tax "
                            "computations, "
                            "and "
                            "financial "
                            "reporting. "
                            "Format: "
                            "percentage "
                            "(e.g., "
                            '"12.5%") '
                            "or "
                            "amount "
                            "(e.g., "
                            '"190").',
                            "type": "string",
                        },
                        "item_custom_fields": {
                            "description": "Custom fields for a sales order items.",
                            "items": {
                                "properties": {
                                    "customfield_id": {
                                        "description": "ID of the Custom Field",
                                        "example": "460000000639129",
                                        "format": "int64",
                                        "type": "integer",
                                    },
                                    "value": {
                                        "description": "Value of the Custom Field",
                                        "example": "Normal",
                                        "type": "string",
                                    },
                                },
                                "type": "object",
                            },
                            "type": "array",
                        },
                        "item_id": {
                            "description": "ID of the item.",
                            "example": "460000000017088",
                            "type": "string",
                        },
                        "item_order": {"example": 0, "type": "integer"},
                        "line_item_id": {
                            "description": "ID "
                            "of "
                            "the "
                            "line "
                            "item. "
                            "Mandatory "
                            "if "
                            "the "
                            "existing "
                            "line "
                            "item "
                            "has "
                            "to "
                            "be "
                            "updated. "
                            "If "
                            "empty, "
                            "a "
                            "new "
                            "line "
                            "item "
                            "will "
                            "be "
                            "created.",
                            "example": "460000000039131",
                            "type": "string",
                        },
                        "location_id": {
                            "description": "Unique "
                            "identifier "
                            "for "
                            "the "
                            "business "
                            "location "
                            "entity. "
                            "Specifies "
                            "the "
                            "organizational "
                            "location "
                            "where "
                            "the "
                            "sales "
                            "order "
                            "transaction "
                            "is "
                            "processed, "
                            "affecting "
                            "tax "
                            "jurisdiction "
                            "calculations, "
                            "inventory "
                            "allocation, "
                            "reporting "
                            "segmentation, "
                            "and "
                            "location-specific "
                            "business "
                            "rules "
                            "enforcement. "
                            "Can "
                            "be "
                            "retrieved "
                            "from "
                            "the "
                            "Locations "
                            "API.",
                            "example": "460000000038080",
                            "type": "string",
                        },
                        "name": {
                            "description": "Name of the line item.",
                            "example": "Hard Drive",
                            "type": "string",
                        },
                        "project_id": {
                            "description": "ID of the project",
                            "example": 90300000087378,
                            "type": "string",
                        },
                        "quantity": {
                            "description": "Quantity of the line item.",
                            "example": 40,
                            "format": "double",
                            "type": "number",
                        },
                        "rate": {
                            "description": "Rate of the line item.",
                            "example": 120,
                            "format": "double",
                            "type": "number",
                        },
                        "tags": {
                            "description": "Filter all your reports based on the tag",
                            "items": {
                                "properties": {
                                    "tag_id": {
                                        "description": "ID of the reporting tag",
                                        "example": 462000000009070,
                                        "type": "string",
                                    },
                                    "tag_option_id": {
                                        "description": "ID of the reporting tag's option",
                                        "example": 462000000002670,
                                        "type": "string",
                                    },
                                },
                                "type": "object",
                            },
                            "type": "array",
                        },
                        "tax_exemption_code": {
                            "description": "Code of Tax Exemption that is applied",
                            "type": "string",
                            "x-node_available_in": ["in", "us", "mx"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_exemption_id": {
                            "description": "ID of the tax exemption applied",
                            "type": "string",
                            "x-node_available_in": ["in", "us"],
                            "x-node_unavailable_in": [],
                        },
                        "tax_id": {
                            "description": "Tax ID for the Sales Order.",
                            "example": "460000000017094",
                            "type": "string",
                        },
                        "tax_treatment_code": {
                            "description": "Specify "
                            "reason "
                            "for "
                            "using "
                            "out "
                            "of "
                            "scope.</br>Supported "
                            "values "
                            "for "
                            "<b>UAE</b> "
                            "are "
                            "<code>uae_same_tax_group</code>, "
                            "<code>uae_reimbursed_expense</code> "
                            "and "
                            "<code>uae_others</code>.</br> "
                            "Supported "
                            "values "
                            "for "
                            "<b>Bahrain</b> "
                            "are "
                            "<code>bahrain_same_tax_group</code>, "
                            "<code>bahrain_transfer_of_concern</code>, "
                            "<code>bahrain_disbursement</code>, "
                            "<code>bahrain_head_to_branch_transaction</code>, "
                            "<code>bahrain_warranty_repair_services</code> "
                            "and "
                            "<code>bahrain_others</code>.</br>Supported "
                            "values "
                            "for "
                            "<b>Saudi "
                            "Arabia</b> "
                            "are "
                            "<code>ksa_pvt_health</code>, "
                            "<code>ksa_pvt_edu</code>, "
                            "<code>ksa_reimbursed_expense</code> "
                            "and "
                            "<code>ksa_house_sales</code>.",
                            "example": "uae_others",
                            "type": "string",
                            "x-node_available_in": ["gcc"],
                            "x-node_unavailable_in": [],
                        },
                        "tds_tax_id": {
                            "description": "ID of the TDS tax or TDS tax group applied",
                            "example": "460000000017098",
                            "type": "string",
                            "x-node_available_in": ["mx"],
                            "x-node_unavailable_in": [],
                        },
                        "unit": {
                            "description": "Unit of the line item e.g. kgs, Nos.",
                            "example": "Nos",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "location_id": {
                "description": "Unique identifier for the business "
                "location entity. Specifies the "
                "organizational location where the "
                "sales order transaction is processed, "
                "affecting tax jurisdiction "
                "calculations, inventory allocation, "
                "reporting segmentation, and "
                "location-specific business rules "
                "enforcement. Can be retrieved from the "
                "Locations API.",
                "example": "460000000038080",
                "type": "string",
            },
            "merchant_id": {
                "description": "ID of the merchant",
                "example": "460000000000597",
                "type": "string",
            },
            "notes": {
                "description": "Free-form text field containing additional "
                "information, instructions, or comments "
                "related to the sales order. This field "
                "supports internal documentation, "
                "customer-specific requirements, special "
                "handling instructions, and "
                "inter-departmental communication for order "
                "processing workflows.",
                "type": "string",
            },
            "notes_default": {"description": "Default Notes for the Sales Order", "type": "string"},
            "place_of_supply": {
                "description": "Place where the goods/services are "
                "supplied to. (If not given, "
                "<code>place of contact</code> "
                "given for the contact will be "
                "taken)<br/>Supported codes for UAE "
                "emirates are : </br>Abu Dhabi - "
                "<code>AB</code>,</br>Ajman - "
                "<code>AJ</code>,</br>Dubai - "
                "<code>DU</code>,</br>Fujairah - "
                "<code>FU</code>,</br>Ras "
                "al-Khaimah - "
                "<code>RA</code>,</br>Sharjah - "
                "<code>SH</code>,</br>Umm al-Quwain "
                "- <code>UM</code><br/>Supported "
                "codes for the GCC countries are : "
                "</br>United Arab Emirates - "
                "<code>AE</code>,</br>Saudi Arabia "
                "- <code>SA</code>,</br>Bahrain - "
                "<code>BH</code>,</br>Kuwait - "
                "<code>KW</code>,</br>Oman - "
                "<code>OM</code>,</br>Qatar - "
                "<code>QA</code>.",
                "example": "TN",
                "type": "string",
                "x-node_available_in": ["in", "gcc"],
                "x-node_unavailable_in": [],
            },
            "pricebook_id": {
                "description": "Unique identifier for the pricing "
                "structure applied to the sales order. "
                "Determines item rates, discount "
                "rules, and pricing policies based on "
                "customer segments, volume tiers, or "
                "promotional campaigns. Can be "
                "retrieved from the Pricebooks API.",
                "type": "string",
            },
            "reference_number": {
                "description": "External reference identifier for "
                "cross-referencing with customer "
                "purchase orders, internal "
                "tracking systems, or third-party "
                "applications. Used for order "
                "reconciliation, customer "
                "communication, and integration "
                "with external business systems "
                "and workflows.",
                "example": "REF-001",
                "type": "string",
            },
            "salesorder_number": {
                "description": "Unique alphanumeric identifier "
                "for the sales order entity. "
                "Required when automatic "
                "numbering is disabled in "
                "organization settings. Must be "
                "unique within the organization "
                "and follows the configured "
                "numbering sequence pattern for "
                "sales order identification and "
                "tracking.",
                "example": "SO-00001",
                "type": "string",
            },
            "salesperson_id": {
                "description": "Unique identifier for the "
                "salesperson responsible for this "
                "sales order. Links the order to a "
                "specific sales representative "
                "customer relationship management, "
                "and sales reporting purposes.",
                "example": "460000000000097",
                "type": "string",
            },
            "salesperson_name": {
                "description": "Full name of the sales "
                "representative assigned to this "
                "sales order. Automatically "
                "populated when salesperson_id is "
                "specified.",
                "example": "John Roberts",
                "type": "string",
            },
            "shipment_date": {
                "description": "Expected or actual date when goods "
                "will be shipped to the customer in "
                "YYYY-MM-DD format. Used for delivery "
                "planning, customer communication, "
                "inventory management, and tracking "
                "order fulfillment timelines.",
                "type": "string",
            },
            "shipping_address_id": {
                "description": "Unique identifier referencing "
                "the customer shipping address "
                "entity. Specifies the delivery "
                "destination for goods "
                "fulfillment, logistics "
                "planning, shipping cost "
                "calculations, and delivery "
                "confirmation processes. Must "
                "correspond to a valid address "
                "record within the customer "
                "address registry.",
                "type": "string",
            },
            "shipping_charge": {
                "description": "Additional cost associated with "
                "product delivery and logistics "
                "services. Applied to the sales "
                "order total and affects final "
                "pricing calculations, profit "
                "margins, and customer billing. "
                "Supports decimal precision for "
                "accurate cost allocation.",
                "example": 2,
                "format": "double",
                "type": "number",
            },
            "tax_authority_id": {
                "description": "ID of the tax authority. Tax "
                "authority depends on the location "
                "of the customer.",
                "type": "string",
                "x-node_available_in": ["us"],
                "x-node_unavailable_in": [],
            },
            "tax_authority_name": {
                "description": "Tax Authority's name.",
                "type": "string",
                "x-node_available_in": ["us", "mx"],
                "x-node_unavailable_in": [],
            },
            "tax_exemption_code": {
                "description": "Code of Tax Exemption that is applied",
                "type": "string",
                "x-node_available_in": ["in", "us", "mx"],
                "x-node_unavailable_in": [],
            },
            "tax_exemption_id": {
                "description": "ID of the tax exemption applied",
                "type": "string",
                "x-node_available_in": ["in", "us"],
                "x-node_unavailable_in": [],
            },
            "tax_id": {
                "description": "Tax ID for the Sales Order.",
                "example": "460000000017094",
                "type": "string",
            },
            "tax_treatment": {
                "description": "VAT treatment for the sales "
                "order.Allowed Values: "
                "<code>vat_registered</code>,<code>vat_not_registered</code>,<code>gcc_vat_not_registered</code>,<code>gcc_vat_registered</code>,<code>non_gcc</code>.</br><code>dz_vat_registered</code> "
                "and "
                "<code>dz_vat_not_registered</code> "
                "supported only for "
                "<b>UAE</b>.</b></br><code>home_country_mexico</code>,<code>border_region_mexico</code>,<code>non_mexico</code> "
                "supported only for <b>MX</b>. "
                "<br/><b>For Kenya Edition:</b> "
                "<code>vat_registered</code> "
                ",<code>vat_not_registered</code> "
                ",<code>non_kenya</code>(A business "
                "that is located outside "
                "Kenya).<br/><b>For SouthAfrica "
                "Edition:</b> "
                "<code>vat_registered</code>, "
                "<code>vat_not_registered</code>, "
                "<code>overseas</code>(A business "
                "that is located outside "
                "SouthAfrica).",
                "example": "vat_registered",
                "type": "string",
                "x-node_available_in": ["gcc", "mx", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "template_id": {
                "description": "Unique identifier for the PDF document "
                "template used for sales order "
                "presentation. Determines document "
                "layout, branding elements, formatting "
                "specifications, and visual "
                "presentation standards for "
                "customer-facing documents and printed "
                "materials.",
                "example": "460000000021001",
                "type": "string",
            },
            "terms": {
                "description": "Contractual terms and conditions governing "
                "the sales order transaction. Defines payment "
                "obligations, delivery specifications, "
                "warranty provisions, liability limitations, "
                "and other legal stipulations that establish "
                "the binding agreement between the "
                "organization and customer for this specific "
                "transaction.",
                "type": "string",
            },
            "terms_default": {"description": "Default Terms of the Sales Order", "type": "string"},
            "vat_treatment": {
                "description": "(Optional) VAT treatment for the "
                "sales order. VAT treatment denotes "
                "the location of the customer, if the "
                "customer resides in UK then the VAT "
                "treatment is <code>uk</code>. If the "
                "customer is in an EU country & VAT "
                "registered, you are resides in "
                "Northen Ireland and purchasing Goods "
                "then his VAT treatment is "
                "<code>eu_vat_registered</code> and "
                "if he resides outside the UK then "
                "his VAT treatment is "
                "<code>overseas</code>(For Pre "
                "Brexit, this can be split as "
                "<code>eu_vat_registered</code>, "
                "<code>eu_vat_not_registered</code> "
                "and <code>non_eu</code>).",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
            "zcrm_potential_id": {
                "description": "Unique identifier linking the "
                "sales order to a Zoho CRM "
                "potential record.",
                "example": "460000000033001",
                "type": "string",
            },
            "zcrm_potential_name": {
                "description": "Descriptive name of the Zoho "
                "CRM potential record "
                "associated with this sales "
                "order.",
                "type": "string",
            },
        },
        "required": ["customer_id"],
        "type": "object",
    },
    "UPDATESALESORDERCUSTOMFIELDS_REQUEST_BODY_SCHEMA": {
        "description": "Custom fields for a sales order.",
        "items": {
            "properties": {
                "customfield_id": {
                    "description": "ID of the Custom Field",
                    "example": "460000000639129",
                    "format": "int64",
                    "type": "integer",
                },
                "index": {"example": 1, "type": "integer"},
                "label": {"example": "Priority", "type": "string"},
                "value": {
                    "description": "Value of the Custom Field",
                    "example": "Normal",
                    "type": "string",
                },
            },
            "type": "object",
        },
        "type": "array",
    },
    "MARKSALESORDERASVOID_REQUEST_BODY_SCHEMA": {
        "properties": {
            "reason": {
                "description": "Reason to convert sales order as void . "
                "<code>Maximum Length: 500 </code>",
                "example": " ",
                "type": "string",
            }
        },
        "type": "object",
    },
    "EMAILSALESORDERTOCUSTOMER_REQUEST_BODY_SCHEMA": {
        "properties": {
            "bcc_mail_ids": {
                "description": "Array of email address of the recipients to be BCC ed.",
                "example": ["mark@safInstruments.com"],
                "items": {"type": "string"},
                "type": "array",
            },
            "body": {
                "description": "Body of the mail.",
                "example": "<br>Dear SAF Instruments Inc,&nbsp;<br><br>Thanks "
                "for your interest in our services. Please find "
                "our sales order attached with this mail.<br><br> "
                "An overview of the sales order is available below "
                "for your reference: &nbsp;<br><br> "
                "----------------------------------------------------------------------------------------<br> "
                "<h2>Sales Order&nbsp;# :&nbsp;SO-00001</h2><br> "
                "----------------------------------------------------------------------------------------<br> "
                "<b>&nbsp;Order Date &nbsp; &nbsp;&nbsp;&nbsp;: "
                "&nbsp;28 Jul 2014</b><br><b>&nbsp;Amount &nbsp; "
                "&nbsp; &nbsp; &nbsp; &nbsp; : "
                "&nbsp;&nbsp;$12,400.00</b><br>----------------------------------------------------------------------------------------<br><br><span>Assuring "
                "you of our best services at all "
                "times.</span><br><br><br>Regards,<br><br>John<br>Zillium "
                "Inc<br><br><br>",
                "type": "string",
            },
            "cc_mail_ids": {
                "description": "Array of email address of the recipients to be CC ed.",
                "example": ["smith@safInstruments.com"],
                "items": {"type": "string"},
                "type": "array",
            },
            "documents": {
                "description": "Documents of the Sales Order",
                "format": "binary",
                "type": "string",
            },
            "from_address_id": {
                "description": "From Address of the Email Address",
                "example": "johnRoberts@safInstrument.com",
                "type": "string",
            },
            "invoice_id": {
                "description": "ID of the invoice",
                "example": 460000000028192,
                "type": "string",
            },
            "send_from_org_email_id": {
                "description": "Boolean to trigger the "
                "email from the "
                "organization's email "
                "address.",
                "example": True,
                "type": "boolean",
            },
            "subject": {
                "description": "Subject of the mail.",
                "example": "Sales Order from Zillium Inc (Sales Order #: SO-00001)",
                "type": "string",
            },
            "to_mail_ids": {
                "description": "Array of email address of the recipients.",
                "example": ["john@safInstruments.com"],
                "items": {"type": "string"},
                "type": "array",
            },
        },
        "required": ["to_mail_ids", "subject", "body"],
        "type": "object",
    },
    "UPDATESALESORDERBILLINGADDRESS_REQUEST_BODY_SCHEMA": {
        "properties": {
            "address": {
                "description": "Address",
                "example": "B-1104, 11F, \n"
                "Horizon International Tower, \n"
                "No. 6, ZhiChun Road, HaiDian District",
                "type": "string",
            },
            "attention": {"type": "string"},
            "city": {"description": "City of the address", "example": "Beijing", "type": "string"},
            "country": {
                "description": "Country of the Address",
                "example": "China",
                "type": "string",
            },
            "fax": {"description": "Fax Number", "example": "+86-10-82637827", "type": "string"},
            "is_one_off_address": {"example": True, "type": "boolean"},
            "is_update_customer": {
                "description": "Boolean flag indicating whether "
                "customer billing address "
                "information should be "
                "synchronized with the sales "
                "order data. When enabled, "
                "updates the customer master "
                "record with address "
                "modifications, ensuring data "
                "consistency across customer "
                "relationship management "
                "systems.",
                "example": False,
                "type": "boolean",
            },
            "is_verified": {
                "description": "Check if the Address is verified",
                "type": "boolean",
                "x-node_available_in": ["Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "phone": {
                "description": "Phone Number of the Contact Person.",
                "example": "+1-925-921-9201",
                "type": "string",
            },
            "state": {
                "description": "State of the Address",
                "example": "Beijing",
                "type": "string",
            },
            "zip": {
                "description": "ZIP Code of the Address",
                "example": "1000881",
                "type": "string",
            },
        },
        "type": "object",
    },
    "UPDATESHIPPINGADDRESSSALESORDER_REQUEST_BODY_SCHEMA": {
        "properties": {
            "address": {
                "description": "Address",
                "example": "B-1104, 11F, \n"
                "Horizon International Tower, \n"
                "No. 6, ZhiChun Road, HaiDian District",
                "type": "string",
            },
            "attention": {"type": "string"},
            "city": {"description": "City of the address", "example": "Beijing", "type": "string"},
            "country": {
                "description": "Country of the Address",
                "example": "China",
                "type": "string",
            },
            "fax": {"description": "Fax Number", "example": "+86-10-82637827", "type": "string"},
            "is_one_off_address": {"example": True, "type": "boolean"},
            "is_update_customer": {
                "description": "Boolean flag indicating whether "
                "customer billing address "
                "information should be "
                "synchronized with the sales "
                "order data. When enabled, "
                "updates the customer master "
                "record with address "
                "modifications, ensuring data "
                "consistency across customer "
                "relationship management "
                "systems.",
                "example": False,
                "type": "boolean",
            },
            "is_verified": {
                "description": "Check if the Address is verified",
                "type": "boolean",
                "x-node_available_in": ["Avalara Integration"],
                "x-node_unavailable_in": [],
            },
            "state": {
                "description": "State of the Address",
                "example": "Beijing",
                "type": "string",
            },
            "zip": {
                "description": "ZIP Code of the Address",
                "example": "1000881",
                "type": "string",
            },
        },
        "type": "object",
    },
    "ADDSALESORDERCOMMENT_REQUEST_BODY_SCHEMA": {
        "properties": {
            "description": {
                "description": "The description of the comment.",
                "example": "This is a comment.",
                "type": "string",
            }
        },
        "type": "object",
    },
    "UPDATESALESORDERCOMMENT_REQUEST_BODY_SCHEMA": {
        "properties": {
            "description": {
                "description": "The description of the comment.",
                "example": "This is a comment.",
                "type": "string",
            }
        },
        "type": "object",
    },
    "CREATESALESRECEIPT_REQUEST_BODY_SCHEMA": {
        "properties": {
            "customer_id": {
                "description": "Unique identifier for the customer",
                "example": "460000000017138",
                "type": "string",
            },
            "date": {
                "description": "Date of the sales receipt",
                "example": "2014-07-28",
                "type": "string",
            },
            "line_items": {
                "description": "Line items for the sales receipt",
                "items": {
                    "properties": {
                        "item_id": {
                            "description": "ID of the item",
                            "example": "460000000017088",
                            "type": "string",
                        },
                        "quantity": {
                            "description": "Quantity of the item",
                            "example": 2,
                            "format": "double",
                            "type": "number",
                        },
                        "rate": {
                            "description": "Rate of the item",
                            "example": 120,
                            "format": "double",
                            "type": "number",
                        },
                        "tax_id": {
                            "description": "ID of the tax to be applied",
                            "example": "460000000017094",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "notes": {
                "description": "Notes for the sales receipt",
                "example": "Thank you for your business",
                "type": "string",
            },
            "payment_mode": {
                "description": "Mode through which payment was "
                "received. Allowed values: cash, "
                "check, credit_card, bank_transfer, "
                "etc.",
                "example": "cash",
                "type": "string",
            },
            "receipt_number": {
                "description": "Sales receipt number (required if auto-numbering is disabled)",
                "example": "SR-00001",
                "type": "string",
            },
            "terms": {
                "description": "Terms and conditions",
                "example": "Payment received in full",
                "type": "string",
            },
        },
        "required": ["customer_id", "payment_mode"],
        "type": "object",
    },
    "UPDATESALESRECEIPT_REQUEST_BODY_SCHEMA": {
        "properties": {
            "customer_id": {
                "description": "Unique identifier for the customer",
                "example": "460000000017138",
                "type": "string",
            },
            "date": {
                "description": "Date of the sales receipt",
                "example": "2014-07-28",
                "type": "string",
            },
            "line_items": {
                "description": "Line items for the sales receipt",
                "items": {
                    "properties": {
                        "item_id": {
                            "description": "ID of the item",
                            "example": "460000000017088",
                            "type": "string",
                        },
                        "quantity": {
                            "description": "Quantity of the item",
                            "example": 2,
                            "format": "double",
                            "type": "number",
                        },
                        "rate": {
                            "description": "Rate of the item",
                            "example": 120,
                            "format": "double",
                            "type": "number",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "notes": {
                "description": "Notes for the sales receipt",
                "example": "Thank you for your business",
                "type": "string",
            },
            "payment_mode": {
                "description": "Mode through which payment was received",
                "example": "cash",
                "type": "string",
            },
            "receipt_number": {
                "description": "Sales receipt number",
                "example": "SR-00001",
                "type": "string",
            },
        },
        "required": ["customer_id"],
        "type": "object",
    },
    "EMAILSALESRECEIPTTOCUSTOMER_REQUEST_BODY_SCHEMA": {
        "properties": {
            "body": {
                "description": "Body of the mail",
                "example": "Please find the sales receipt attached.",
                "type": "string",
            },
            "subject": {
                "description": "Subject of the mail",
                "example": "Sales Receipt from Zillium Inc",
                "type": "string",
            },
            "to_mail_ids": {
                "description": "Array of email addresses of the recipients",
                "example": ["john@safinstruments.com"],
                "items": {"type": "string"},
                "type": "array",
            },
        },
        "required": ["to_mail_ids", "subject", "body"],
        "type": "object",
    },
    "ADDPROJECTTASK_REQUEST_BODY_SCHEMA": {
        "properties": {
            "budget_hours": {"description": "Task budget hours.", "example": "", "type": "integer"},
            "description": {
                "description": "The description of the project.",
                "example": "",
                "type": "string",
            },
            "rate": {"description": "Hourly rate for a task.", "example": 3, "type": "integer"},
            "task_name": {
                "description": "The name of the task. <code>Max-length [100]</code>",
                "example": "Painting",
                "type": "string",
            },
        },
        "required": ["task_name"],
        "type": "object",
    },
    "UPDATEPROJECTTASK_REQUEST_BODY_SCHEMA": {
        "properties": {
            "budget_hours": {"description": "Task budget hours.", "example": "", "type": "integer"},
            "description": {
                "description": "The description of the project.",
                "example": "",
                "type": "string",
            },
            "rate": {"description": "Hourly rate for a task.", "example": 3, "type": "integer"},
            "task_name": {
                "description": "The name of the task. <code>Max-length [100]</code>",
                "example": "Painting",
                "type": "string",
            },
        },
        "required": ["task_name"],
        "type": "object",
    },
    "CREATEASSOCIATEDTAX_REQUEST_BODY_SCHEMA": {
        "properties": {
            "country_code": {
                "description": "Two letter country code for the EU "
                "country to which the tax belongs.",
                "example": "UK",
                "type": "string",
                "x-node_available_in": ["uk", "eu", "gcc", "global"],
                "x-node_unavailable_in": [],
            },
            "is_editable": {
                "description": "Check if tax is editable",
                "example": True,
                "type": "boolean",
            },
            "is_value_added": {
                "description": "Check if Tax is Value Added",
                "example": False,
                "type": "boolean",
            },
            "purchase_tax_expense_account_id": {
                "description": "Account ID in which Purchase Tax will be Computed",
                "format": "int64",
                "type": "integer",
                "x-node_available_in": ["au", "ca"],
                "x-node_unavailable_in": [],
            },
            "tax_authority_id": {
                "description": "ID of the tax authority. Tax "
                "authority depends on the location "
                "of the customer. For example, if "
                "the customer is located in NY, "
                "then the tax authority is NY tax "
                "authority.",
                "example": "460000000066001",
                "type": "string",
                "x-node_available_in": ["us", "mx"],
                "x-node_unavailable_in": [],
            },
            "tax_authority_name": {
                "description": "Name of the Tax Authority",
                "example": "Illinois Department of Revenue",
                "type": "string",
            },
            "tax_factor": {
                "description": "Type of Tax Factor. Allowed values: "
                "<code>rate</code>, <code>share</code>",
                "example": "rate",
                "type": "string",
                "x-node_available_in": ["mx"],
                "x-node_unavailable_in": [],
            },
            "tax_name": {
                "description": "Name of the Tax",
                "example": "Sales Group",
                "type": "string",
            },
            "tax_percentage": {
                "description": "Number of Percentage Taxable.",
                "example": 10.5,
                "format": "double",
                "type": "number",
            },
            "tax_specific_type": {
                "description": "Type of Tax For <b>Indian</b> "
                "Edition. Allowed Values : "
                "<code>igst</code> "
                ",<code>cgst</code> "
                ",<code>sgst</code> "
                ",<code>nil</code>, <code> cess "
                "</code>.</br>Type of Tax for "
                "<b>Mexico</b> Edition. Allowed "
                "Values : <code>isr</code>, "
                "<code>iva</code>, "
                "<code>ieps</code>.</br>Type of "
                "Tax for <b>South Africa</b> "
                "Edition. Allowed Values : "
                "</br><code>soa_less_than_28d</code> "
                "- Supply of accommodation not "
                "exceeding 28 days, "
                "</br><code>soa_more_than_28d</code> "
                "- Supply of accommodation "
                "exceeding than 28 days, "
                "</br><code>ciu_prev_tax_supply</code> "
                "- Change in use (Taxable "
                "supplies), "
                "</br><code>ciu_prev_nontax_supply</code> "
                "- Change in use (Non-Taxable "
                "supplies), "
                "</br><code>export_of_shg</code> "
                "- Export of second hand goods.",
                "type": "string",
                "x-node_available_in": ["in", "mx", "za"],
                "x-node_unavailable_in": [],
            },
            "tax_type": {
                "description": "Type to determine whether it is a simple "
                "or compound tax. <code>Allowed Values: "
                "tax and compound_tax</code>",
                "example": "tax",
                "type": "string",
            },
            "update_draft_invoice": {
                "description": "Check if Draft Invoices should be updated",
                "example": False,
                "type": "boolean",
            },
            "update_draft_so": {
                "description": "Check if Draft Sales Orders should be updated",
                "example": False,
                "type": "boolean",
            },
            "update_project": {
                "description": "Check if Projects should be updated",
                "example": False,
                "type": "boolean",
            },
            "update_recurring_bills": {
                "description": "Check if Recurring Bills should be updated",
                "example": False,
                "type": "boolean",
            },
            "update_recurring_expense": {
                "description": "Check if recurring expenses should be updated",
                "example": False,
                "type": "boolean",
            },
            "update_recurring_invoice": {
                "description": "Check if recurring invoice should be updated",
                "example": False,
                "type": "boolean",
            },
            "update_subscription": {
                "description": "Check if Subscriptions should be updated",
                "example": False,
                "type": "boolean",
            },
        },
        "type": "object",
    },
    "UPDATETAXDETAILS_REQUEST_BODY_SCHEMA": {
        "properties": {
            "country_code": {
                "description": "Two letter country code for the EU "
                "country to which the tax belongs.",
                "example": "UK",
                "type": "string",
                "x-node_available_in": ["uk", "eu", "gcc", "global"],
                "x-node_unavailable_in": [],
            },
            "is_editable": {
                "description": "Check if tax is editable",
                "example": True,
                "type": "boolean",
            },
            "is_value_added": {
                "description": "Check if Tax is Value Added",
                "example": False,
                "type": "boolean",
            },
            "purchase_tax_expense_account_id": {
                "description": "Account ID in which Purchase Tax will be Computed",
                "format": "int64",
                "type": "integer",
                "x-node_available_in": ["au", "ca"],
                "x-node_unavailable_in": [],
            },
            "tax_authority_id": {
                "description": "ID of the tax authority. Tax "
                "authority depends on the location "
                "of the customer. For example, if "
                "the customer is located in NY, "
                "then the tax authority is NY tax "
                "authority.",
                "example": "460000000066001",
                "type": "string",
                "x-node_available_in": ["us", "mx"],
                "x-node_unavailable_in": [],
            },
            "tax_authority_name": {
                "description": "Name of the Tax Authority",
                "example": "Illinois Department of Revenue",
                "type": "string",
            },
            "tax_factor": {
                "description": "Type of Tax Factor. Allowed values: "
                "<code>rate</code>, <code>share</code>",
                "example": "rate",
                "type": "string",
                "x-node_available_in": ["mx"],
                "x-node_unavailable_in": [],
            },
            "tax_id": {
                "description": "ID of the Tax",
                "example": "982000000566009",
                "type": "string",
            },
            "tax_name": {
                "description": "Name of the Tax",
                "example": "Sales Group",
                "type": "string",
            },
            "tax_percentage": {
                "description": "Number of Percentage Taxable.",
                "example": 10.5,
                "format": "double",
                "type": "number",
            },
            "tax_specific_type": {
                "description": "Type of Tax For <b>Indian</b> "
                "Edition. Allowed Values : "
                "<code>igst</code> "
                ",<code>cgst</code> "
                ",<code>sgst</code> "
                ",<code>nil</code>, <code> cess "
                "</code>.</br>Type of Tax for "
                "<b>Mexico</b> Edition. Allowed "
                "Values : <code>isr</code>, "
                "<code>iva</code>, "
                "<code>ieps</code>.</br>Type of "
                "Tax for <b>South Africa</b> "
                "Edition. Allowed Values : "
                "</br><code>soa_less_than_28d</code> "
                "- Supply of accommodation not "
                "exceeding 28 days, "
                "</br><code>soa_more_than_28d</code> "
                "- Supply of accommodation "
                "exceeding than 28 days, "
                "</br><code>ciu_prev_tax_supply</code> "
                "- Change in use (Taxable "
                "supplies), "
                "</br><code>ciu_prev_nontax_supply</code> "
                "- Change in use (Non-Taxable "
                "supplies), "
                "</br><code>export_of_shg</code> "
                "- Export of second hand goods.",
                "type": "string",
                "x-node_available_in": ["in", "mx", "za"],
                "x-node_unavailable_in": [],
            },
            "tax_type": {
                "description": "Type to determine whether it is a simple "
                "or compound tax. <code>Allowed Values: "
                "tax and compound_tax</code>",
                "example": "tax",
                "type": "string",
            },
            "tds_payable_account_id": {
                "description": "Input Tax ID. The amount of "
                "money charged to you as Tax "
                "on your purchases.",
                "example": "132086000000107337",
                "type": "string",
                "x-node_available_in": ["mx"],
                "x-node_unavailable_in": [],
            },
            "update_draft_invoice": {
                "description": "Check if Draft Invoices should be updated",
                "example": False,
                "type": "boolean",
            },
            "update_draft_so": {
                "description": "Check if Draft Sales Orders should be updated",
                "example": False,
                "type": "boolean",
            },
            "update_project": {
                "description": "Check if Projects should be updated",
                "example": False,
                "type": "boolean",
            },
            "update_recurring_bills": {
                "description": "Check if Recurring Bills should be updated",
                "example": False,
                "type": "boolean",
            },
            "update_recurring_expense": {
                "description": "Check if recurring expenses should be updated",
                "example": False,
                "type": "boolean",
            },
            "update_recurring_invoice": {
                "description": "Check if recurring invoice should be updated",
                "example": False,
                "type": "boolean",
            },
            "update_subscription": {
                "description": "Check if Subscriptions should be updated",
                "example": False,
                "type": "boolean",
            },
        },
        "type": "object",
    },
    "UPDATETAXGROUPDETAILS_REQUEST_BODY_SCHEMA": {
        "properties": {
            "tax_group_name": {
                "description": "Name of the tax group to be created.",
                "example": "Sales Group",
                "type": "string",
            },
            "taxes": {
                "description": "Comma Seperated list of tax IDs that are to "
                "be associated to the tax group.",
                "example": "982000000566009",
                "type": "string",
            },
        },
        "type": "object",
    },
    "CREATETAXGROUP_REQUEST_BODY_SCHEMA": {
        "properties": {
            "tax_group_name": {
                "description": "Name of the tax group to be created.",
                "example": "Sales Group",
                "type": "string",
            },
            "taxes": {
                "description": "Comma Seperated list of tax IDs that are to "
                "be associated to the tax group.",
                "example": "982000000566009",
                "type": "string",
            },
        },
        "type": "object",
    },
    "CREATETAXAUTHORITY_REQUEST_BODY_SCHEMA": {
        "properties": {
            "description": {
                "description": "Description.",
                "example": "The New York State Department of  Taxation and Finance",
                "type": "string",
            },
            "registration_number": {
                "description": "Registration Number of the Tax Authority",
                "type": "string",
                "x-node_available_in": ["ca"],
                "x-node_unavailable_in": [],
            },
            "registration_number_label": {
                "type": "string",
                "x-node_available_in": ["ca"],
                "x-node_unavailable_in": [],
            },
            "tax_authority_name": {
                "description": "Name of the Tax Authority",
                "example": "Illinois Department of Revenue",
                "type": "string",
            },
        },
        "required": ["tax_authority_name"],
        "type": "object",
    },
    "UPDATETAXAUTHORITYDETAILS_REQUEST_BODY_SCHEMA": {
        "properties": {
            "description": {
                "description": "Description.",
                "example": "The New York State Department of  Taxation and Finance",
                "type": "string",
            },
            "registration_number": {
                "description": "Registration Number of the Tax Authority",
                "type": "string",
                "x-node_available_in": ["ca"],
                "x-node_unavailable_in": [],
            },
            "registration_number_label": {
                "type": "string",
                "x-node_available_in": ["ca"],
                "x-node_unavailable_in": [],
            },
            "tax_authority_name": {
                "description": "Name of the Tax Authority",
                "example": "Illinois Department of Revenue",
                "type": "string",
            },
        },
        "type": "object",
    },
    "CREATETAXEXEMPTION_REQUEST_BODY_SCHEMA": {
        "properties": {
            "description": {
                "description": "Description",
                "example": "Tax exempted because the contact is a reseller.",
                "type": "string",
            },
            "tax_exemption_code": {
                "description": "Code of the Tax Exemption",
                "example": "RESELLER",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "type": {
                "description": "Type of the tax exemption, can be "
                "<code>customer</code> or <code>item</code>.",
                "example": "customer",
                "type": "string",
            },
        },
        "required": ["tax_exemption_code", "type"],
        "type": "object",
    },
    "UPDATETAXEXEMPTIONDETAILS_REQUEST_BODY_SCHEMA": {
        "properties": {
            "description": {
                "description": "Description",
                "example": "Tax exempted because the contact is a reseller.",
                "type": "string",
            },
            "tax_exemption_code": {
                "description": "Code of the Tax Exemption",
                "example": "RESELLER",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "type": {
                "description": "Type of the tax exemption, can be "
                "<code>customer</code> or <code>item</code>.",
                "example": "customer",
                "type": "string",
            },
        },
        "required": ["tax_exemption_code", "type"],
        "type": "object",
    },
    "LOGTIMEENTRIES_REQUEST_BODY_SCHEMA": {
        "properties": {
            "begin_time": {
                "description": "Time the user started working on this "
                "task. <code>Time-Format [HH:mm]</code>",
                "example": "10:00",
                "type": "string",
            },
            "cost_rate": {
                "description": "Hourly cost rate",
                "example": 10,
                "format": "double",
                "type": "number",
            },
            "end_time": {
                "description": "Time the user stopped working on this "
                "task. <code>Time-Format [HH:mm]</code>",
                "example": "15:00",
                "type": "string",
            },
            "is_billable": {
                "description": "Whether it is billable or not.",
                "example": True,
                "type": "boolean",
            },
            "log_date": {
                "description": "Date on which the user spent on the task. "
                "<code>Date-Format [HH:mm]</code>",
                "example": "2013-09-17",
                "type": "string",
            },
            "log_time": {
                "description": "Time the user spent on this task. Either "
                "send this attribute or begin and end time "
                "attributes. <code>Time-Format "
                "[HH:mm]</code>",
                "example": " ",
                "type": "string",
            },
            "notes": {
                "description": "Description of the work done. <code>Max-length [500]</code>",
                "example": " ",
                "type": "string",
            },
            "project_id": {
                "description": "ID of the project.",
                "example": "Network Distribution",
                "type": "string",
            },
            "start_timer": {"description": "Start timer.", "example": " ", "type": "string"},
            "task_id": {
                "description": "ID of the task.",
                "example": "460000000044001",
                "type": "string",
            },
            "user_id": {
                "description": "ID of the user.",
                "example": "460000000024003",
                "type": "string",
            },
        },
        "required": ["project_id", "task_id", "user_id", "log_date"],
        "type": "object",
    },
    "UPDATETIMEENTRY_REQUEST_BODY_SCHEMA": {
        "properties": {
            "begin_time": {
                "description": "Time the user started working on this "
                "task. <code>Time-Format [HH:mm]</code>",
                "example": "10:00",
                "type": "string",
            },
            "cost_rate": {
                "description": "Hourly cost rate",
                "example": 0,
                "format": "double",
                "type": "number",
            },
            "end_time": {
                "description": "Time the user stopped working on this "
                "task. <code>Time-Format [HH:mm]</code>",
                "example": "15:00",
                "type": "string",
            },
            "is_billable": {
                "description": "Whether it is billable or not.",
                "example": True,
                "type": "boolean",
            },
            "log_date": {
                "description": "Date on which the user spent on the task. "
                "<code>Date-Format [HH:mm]</code>",
                "example": "2013-09-17",
                "type": "string",
            },
            "log_time": {
                "description": "Time the user spent on this task. Either "
                "send this attribute or begin and end time "
                "attributes. <code>Time-Format "
                "[HH:mm]</code>",
                "example": " ",
                "type": "string",
            },
            "notes": {
                "description": "Description of the work done. <code>Max-length [500]</code>",
                "example": " ",
                "type": "string",
            },
            "project_id": {
                "description": "ID of the project.",
                "example": "Network Distribution",
                "type": "string",
            },
            "start_timer": {"description": "Start timer.", "example": " ", "type": "string"},
            "task_id": {
                "description": "ID of the task.",
                "example": "460000000044001",
                "type": "string",
            },
            "user_id": {
                "description": "ID of the user.",
                "example": "460000000024003",
                "type": "string",
            },
        },
        "required": ["project_id", "task_id", "user_id", "log_date"],
        "type": "object",
    },
    "CREATEORGANIZATIONUSER_REQUEST_BODY_SCHEMA": {
        "properties": {
            "cost_rate": {
                "description": "Hourly cost rate",
                "example": 0,
                "format": "double",
                "type": "number",
            },
            "email": {
                "description": "email address of the user",
                "example": "johndavid@zilliuminc.com",
                "type": "string",
            },
            "name": {"description": "name of the user", "example": "Sujin Kumar", "type": "string"},
            "role_id": {"example": "982000000006005", "type": "string"},
        },
        "required": ["name", "email"],
        "type": "object",
    },
    "UPDATEUSERDETAILS_REQUEST_BODY_SCHEMA": {
        "properties": {
            "cost_rate": {
                "description": "Hourly cost rate",
                "example": 0,
                "format": "double",
                "type": "number",
            },
            "email": {
                "description": "email address of the user",
                "example": "johndavid@zilliuminc.com",
                "type": "string",
            },
            "name": {"description": "name of the user", "example": "Sujin Kumar", "type": "string"},
            "role_id": {"example": "982000000006005", "type": "string"},
        },
        "required": ["name", "email"],
        "type": "object",
    },
    "CREATEVENDORCREDIT_REQUEST_BODY_SCHEMA": {
        "properties": {
            "currency_id": {
                "description": "Unique identifier for the currency "
                "used in the vendor credit. Can differ "
                "from vendor currency if multi-currency "
                "is enabled. Retrieve currency IDs from "
                "the List Currencies API endpoint in "
                "the currency section.",
                "example": "3000000000083",
                "type": "string",
            },
            "custom_fields": {
                "items": {
                    "properties": {
                        "custom_field_id": {
                            "description": "ID of the Custom Field",
                            "format": "int64",
                            "type": "integer",
                        },
                        "index": {"description": "Index of the Custom Field", "type": "integer"},
                        "label": {"description": "Label of the Custom Field", "type": "string"},
                        "value": {"description": "Value of the Custom Field", "type": "string"},
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "date": {
                "description": "The date on which the vendor credit is "
                "created. Must be in yyyy-mm-dd format. This "
                "date determines the accounting period and "
                "affects tax calculations.",
                "example": "2014-08-28",
                "type": "string",
            },
            "destination_of_supply": {
                "description": "Place where the "
                "goods/services are supplied "
                "to. (If not given, "
                "organisation's home state "
                "will be taken)",
                "example": "TN",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "documents": {
                "items": {
                    "properties": {
                        "document_id": {
                            "description": "ID of the Document",
                            "format": "int64",
                            "type": "integer",
                        },
                        "file_name": {"description": "Name of the file", "type": "string"},
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "exchange_rate": {
                "description": "Exchange rate for converting the "
                "vendor credit currency to base "
                "currency. Required when currency "
                "differs from base currency. Retrieve "
                "rates from currency exchange rate "
                "APIs.",
                "example": 1,
                "format": "double",
                "type": "number",
            },
            "gst_no": {
                "description": "15 digit GST identification number of the vendor.",
                "example": "22AAAAA0000A1Z5",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "gst_treatment": {
                "description": "Choose whether the contact is GST "
                "registered/unregistered/consumer/overseas. "
                "Allowed values are <code> "
                "business_gst </code> , <code> "
                "business_none </code> , <code> "
                "overseas </code> , <code> consumer "
                "</code>.",
                "example": "business_gst",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "is_inclusive_tax": {
                "description": "Set to true if line item rates "
                "include tax amounts. When true, "
                "tax is already included in the "
                "item rates. When false, tax will "
                "be calculated and added to the "
                "rates.",
                "example": False,
                "type": "boolean",
                "x-node_available_in": [],
                "x-node_unavailable_in": ["us"],
            },
            "is_update_customer": {
                "description": "Set to true to update customer "
                "information when creating the "
                "vendor credit. This will modify "
                "the associated customer record "
                "with new details from the "
                "vendor credit.",
                "example": False,
                "type": "boolean",
            },
            "line_items": {
                "description": "Line items of a vendor credit.",
                "items": {
                    "properties": {
                        "account_id": {
                            "description": "Unique "
                            "identifier "
                            "for "
                            "the "
                            "chart "
                            "of "
                            "accounts "
                            "entry. "
                            "Retrieve "
                            "account "
                            "IDs "
                            "from "
                            "the "
                            "List "
                            "Chart "
                            "of "
                            "Accounts "
                            "API "
                            "endpoint. "
                            "Determines "
                            "which "
                            "account "
                            "the "
                            "line "
                            "item "
                            "affects "
                            "for "
                            "accounting "
                            "purposes.",
                            "example": "460000000020097",
                            "type": "string",
                        },
                        "description": {
                            "description": "Detailed "
                            "description "
                            "of "
                            "the "
                            "line "
                            "item. "
                            "Provides "
                            "additional "
                            "information "
                            "about "
                            "the "
                            "product "
                            "or "
                            "service "
                            "being "
                            "credited. "
                            "Displayed "
                            "on "
                            "the "
                            "vendor "
                            "credit "
                            "document.",
                            "type": "string",
                        },
                        "hsn_or_sac": {
                            "description": "HSN Code",
                            "type": "string",
                            "x-node_available_in": ["in", "ke", "za"],
                            "x-node_unavailable_in": [],
                        },
                        "item_custom_fields": {
                            "items": {
                                "properties": {
                                    "custom_field_id": {
                                        "description": "ID of the Custom Field",
                                        "format": "int64",
                                        "type": "integer",
                                    },
                                    "index": {
                                        "description": "Index of the Custom Field",
                                        "type": "integer",
                                    },
                                    "label": {
                                        "description": "Label of the Custom Field",
                                        "type": "string",
                                    },
                                    "value": {
                                        "description": "Value of the Custom Field",
                                        "type": "string",
                                    },
                                },
                                "type": "object",
                            },
                            "type": "array",
                        },
                        "item_id": {
                            "description": "Unique "
                            "identifier "
                            "for "
                            "the "
                            "item "
                            "in "
                            "the "
                            "line "
                            "item. "
                            "Retrieve "
                            "item "
                            "IDs "
                            "from "
                            "the "
                            "List "
                            "Items "
                            "API "
                            "endpoint "
                            "in "
                            "the "
                            "items "
                            "section. "
                            "Links "
                            "the "
                            "line "
                            "item "
                            "to "
                            "a "
                            "specific "
                            "product "
                            "or "
                            "service.",
                            "example": "460000000020071",
                            "type": "string",
                        },
                        "item_order": {
                            "description": "Sequential "
                            "order "
                            "number "
                            "for "
                            "the "
                            "line "
                            "item. "
                            "Determines "
                            "the "
                            "display "
                            "order "
                            "of "
                            "line "
                            "items "
                            "on "
                            "the "
                            "vendor "
                            "credit "
                            "document. "
                            "Lower "
                            "numbers "
                            "appear "
                            "first.",
                            "example": 0,
                            "type": "integer",
                        },
                        "line_item_id": {
                            "description": "Unique "
                            "identifier "
                            "for "
                            "the "
                            "line "
                            "item "
                            "within "
                            "the "
                            "vendor "
                            "credit. "
                            "System-generated "
                            "ID "
                            "used "
                            "for "
                            "identifying "
                            "and "
                            "referencing "
                            "specific "
                            "line "
                            "items "
                            "in "
                            "the "
                            "vendor "
                            "credit.",
                            "example": "460000000020077",
                            "type": "string",
                        },
                        "location_id": {
                            "description": "Unique "
                            "identifier "
                            "for "
                            "the "
                            "business "
                            "location. "
                            "Retrieve "
                            "location "
                            "IDs "
                            "from "
                            "the "
                            "List "
                            "Locations "
                            "API "
                            "endpoint "
                            "in "
                            "the "
                            "locations "
                            "section. "
                            "Determines "
                            "tax "
                            "settings "
                            "and "
                            "business "
                            "rules.",
                            "example": "460000000038080",
                            "type": "string",
                        },
                        "name": {
                            "description": "Name "
                            "or "
                            "title "
                            "of "
                            "the "
                            "line "
                            "item. "
                            "Describes "
                            "the "
                            "product "
                            "or "
                            "service "
                            "being "
                            "credited. "
                            "This "
                            "name "
                            "is "
                            "displayed "
                            "on "
                            "the "
                            "vendor "
                            "credit "
                            "document.",
                            "example": "Premium Plan - Web hosting",
                            "type": "string",
                        },
                        "project_id": {
                            "description": "ID of the project",
                            "example": 90300000087378,
                            "type": "string",
                        },
                        "quantity": {
                            "description": "Number "
                            "of "
                            "units "
                            "being "
                            "credited "
                            "for "
                            "this "
                            "line "
                            "item. "
                            "Must "
                            "be "
                            "a "
                            "positive "
                            "number. "
                            "Used "
                            "to "
                            "calculate "
                            "the "
                            "total "
                            "amount "
                            "for "
                            "the "
                            "line "
                            "item.",
                            "example": 1,
                            "format": "double",
                            "type": "number",
                        },
                        "rate": {
                            "description": "Unit "
                            "price "
                            "or "
                            "rate "
                            "for "
                            "the "
                            "line "
                            "item. "
                            "The "
                            "amount "
                            "per "
                            "unit "
                            "before "
                            "taxes "
                            "and "
                            "discounts. "
                            "Used "
                            "with "
                            "quantity "
                            "to "
                            "calculate "
                            "the "
                            "line "
                            "total.",
                            "example": 30,
                            "format": "double",
                            "type": "number",
                        },
                        "reverse_charge_tax_id": {
                            "description": "ID of the reverse charge tax",
                            "example": 460000000057089,
                            "type": "string",
                            "x-node_available_in": ["in", "gcc", "za"],
                            "x-node_unavailable_in": [],
                        },
                        "serial_numbers": {"items": {"type": "string"}, "type": "array"},
                        "tags": {
                            "description": "Array "
                            "of "
                            "tags "
                            "associated "
                            "with "
                            "the "
                            "line "
                            "item. "
                            "Each "
                            "tag "
                            "contains "
                            "tag_id "
                            "and "
                            "tag_option_id "
                            "for "
                            "categorization "
                            "and "
                            "tracking "
                            "purposes.",
                            "items": {
                                "properties": {
                                    "tag_id": {
                                        "description": "ID of the tag",
                                        "format": "int64",
                                        "type": "integer",
                                    },
                                    "tag_option_id": {
                                        "description": "ID of the tag option",
                                        "format": "int64",
                                        "type": "integer",
                                    },
                                },
                                "type": "object",
                            },
                            "type": "array",
                        },
                        "tax_id": {
                            "description": "Unique "
                            "identifier "
                            "for "
                            "the "
                            "tax "
                            "applied "
                            "to "
                            "the "
                            "line "
                            "item. "
                            "Retrieve "
                            "tax "
                            "IDs "
                            "from "
                            "the "
                            "List "
                            "Taxes "
                            "API "
                            "endpoint "
                            "in "
                            "the "
                            "taxes "
                            "section. "
                            "Determines "
                            "tax "
                            "calculations "
                            "for "
                            "this "
                            "line "
                            "item.",
                            "type": "string",
                        },
                        "tax_treatment_code": {
                            "description": "Specify "
                            "reason "
                            "for "
                            "using "
                            "out "
                            "of "
                            "scope.</br>Supported "
                            "values "
                            "for "
                            "<b>UAE</b> "
                            "are "
                            "<code>uae_same_tax_group</code>, "
                            "<code>uae_reimbursed_expense</code> "
                            "and "
                            "<code>uae_others</code>.</br> "
                            "Supported "
                            "values "
                            "for "
                            "<b>Bahrain</b> "
                            "are "
                            "<code>bahrain_same_tax_group</code>, "
                            "<code>bahrain_transfer_of_concern</code>, "
                            "<code>bahrain_disbursement</code>, "
                            "<code>bahrain_head_to_branch_transaction</code>, "
                            "<code>bahrain_warranty_repair_services</code> "
                            "and "
                            "<code>bahrain_others</code>.</br> "
                            "Supported "
                            "values "
                            "for "
                            "<b>KSA</b> "
                            "are "
                            "<code>ksa_reimbursed_expense</code>.",
                            "example": "uae_others",
                            "type": "string",
                            "x-node_available_in": ["gcc"],
                            "x-node_unavailable_in": [],
                        },
                        "tds_tax_id": {
                            "description": "TDS "
                            "Tax "
                            "ID "
                            "of "
                            "the "
                            "Tax "
                            "associated "
                            "with "
                            "the "
                            "Vendor "
                            "Credit",
                            "type": "string",
                            "x-node_available_in": ["mx"],
                            "x-node_unavailable_in": [],
                        },
                        "unit": {
                            "description": "Unit "
                            "of "
                            "measurement "
                            "for "
                            "the "
                            "line "
                            "item "
                            "quantity. "
                            "Examples: "
                            "kgs, "
                            "Nos, "
                            "hours, "
                            "pieces. "
                            "Used "
                            "to "
                            "specify "
                            "how "
                            "the "
                            "quantity "
                            "is "
                            "measured.",
                            "example": "Nos",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "location_id": {
                "description": "Unique identifier for the business "
                "location. Retrieve location IDs from "
                "the List Locations API endpoint in the "
                "locations section. Determines tax "
                "settings and business rules.",
                "example": "460000000038080",
                "type": "string",
            },
            "notes": {
                "description": "Additional notes or comments for the vendor "
                "credit. Displayed on the vendor credit "
                "document for vendor reference. Max-length "
                "[5000]",
                "type": "string",
            },
            "place_of_supply": {
                "description": "The place of supply is where a "
                "transaction is considered to have "
                "occurred for VAT purposes. For the "
                "supply of goods, the place of "
                "supply is the location of the "
                "goods when the supply occurs. For "
                "the supply of services, the place "
                "of supply should be where the "
                "supplier is established. (If not "
                "given, <code>place of "
                "contact</code> given for the "
                "contact will be "
                "taken)<br/>Supported codes for UAE "
                "emirates are : </br>Abu Dhabi - "
                "<code>AB</code>,</br>Ajman - "
                "<code>AJ</code>,</br>Dubai - "
                "<code>DU</code>,</br>Fujairah - "
                "<code>FU</code>,</br>Ras "
                "al-Khaimah - "
                "<code>RA</code>,</br>Sharjah - "
                "<code>SH</code>,</br>Umm al-Quwain "
                "- <code>UM</code>.<br/>Supported "
                "codes for the GCC countries are : "
                "</br>United Arab Emirates - "
                "<code>AE</code>,</br>Saudi Arabia "
                "- <code>SA</code>,</br>Bahrain - "
                "<code>BH</code>,</br>Kuwait - "
                "<code>KW</code>,</br>Oman - "
                "<code>OM</code>,</br>Qatar - "
                "<code>QA</code>.",
                "example": "DU",
                "type": "string",
                "x-node_available_in": ["gcc"],
                "x-node_unavailable_in": [],
            },
            "pricebook_id": {
                "description": "Unique identifier for the pricebook "
                "used for pricing items in the vendor "
                "credit. Retrieve pricebook IDs from "
                "the pricebooks API endpoint.",
                "type": "string",
            },
            "reference_number": {
                "description": "Optional reference number for "
                "tracking purposes. Can be any "
                "custom string or auto-generated. "
                "Useful for linking to external "
                "systems or internal tracking. "
                "Max-Length [100]",
                "type": "string",
            },
            "source_of_supply": {
                "description": "Place from where the "
                "goods/services are supplied. (If "
                "not given, <code>place of "
                "contact</code> given for the "
                "contact will be taken)",
                "example": "TN",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "tax_treatment": {
                "description": "VAT treatment for the vendor credit. "
                "Choose whether the vendor falls "
                "under: "
                "<code>vat_registered</code>,<code>vat_not_registered</code>,<code>gcc_vat_not_registered</code>,<code>gcc_vat_registered</code>,<code>non_gcc</code>.</br><code>dz_vat_registered</code> "
                "and "
                "<code>dz_vat_not_registered</code> "
                "are supported only for "
                "<b>UAE</b>.</b></br><code>home_country_mexico</code>,<code>border_region_mexico</code>,<code>non_mexico</code> "
                "supported only for "
                "<b>MX</b>.<br/><b>For Kenya "
                "Edition:</b> "
                "<code>vat_registered</code> "
                ",<code>vat_not_registered</code> "
                ",<code>non_kenya</code>(A business "
                "that is located outside "
                "Kenya).<br/><b>For SouthAfrica "
                "Edition:</b> "
                "<code>vat_registered</code>, "
                "<code>vat_not_registered</code>, "
                "<code>overseas</code>(A business "
                "that is located outside "
                "SouthAfrica).",
                "example": "vat_registered",
                "type": "string",
                "x-node_available_in": ["gcc", "mx", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "vat_treatment": {
                "description": "VAT treatment for the vendor "
                "credits. VAT treatment denotes the "
                "location of the customer, if the "
                "customer resides in UK then the VAT "
                "treatment is <code>uk</code>. If the "
                "vendor is in an EU country & VAT "
                "registered, you are resides in "
                "Northen Ireland and purchasing Goods "
                "then his VAT treatment is "
                "<code>eu_vat_registered</code>and if "
                "he resides outside the EU then his "
                "VAT treatment is "
                "<code>overseas</code>(For Pre "
                "Brexit, this can be split as "
                "<code>eu_vat_registered</code>, "
                "<code>eu_vat_not_registered</code> "
                "and <code>non_eu</code>).",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
            "vendor_credit_number": {
                "description": "Mandatory if auto number generation is disabled.",
                "example": "DN-00002",
                "type": "string",
            },
            "vendor_id": {
                "description": "Unique identifier for the vendor "
                "contact. Retrieve vendor IDs from the "
                "Get Contacts API endpoint in the "
                "contacts section. This ID links the "
                "vendor credit to the specific vendor "
                "record.",
                "example": "460000000020029",
                "type": "string",
            },
        },
        "required": ["vendor_id"],
        "type": "object",
    },
    "UPDATEVENDORCREDIT_REQUEST_BODY_SCHEMA": {
        "properties": {
            "currency_id": {
                "description": "Unique identifier for the currency "
                "used in the vendor credit. Can differ "
                "from vendor currency if multi-currency "
                "is enabled. Retrieve currency IDs from "
                "the List Currencies API endpoint in "
                "the currency section.",
                "example": "3000000000083",
                "type": "string",
            },
            "custom_fields": {
                "items": {
                    "properties": {
                        "custom_field_id": {
                            "description": "ID of the Custom Field",
                            "format": "int64",
                            "type": "integer",
                        },
                        "index": {"description": "Index of the Custom Field", "type": "integer"},
                        "label": {"description": "Label of the Custom Field", "type": "string"},
                        "value": {"description": "Value of the Custom Field", "type": "string"},
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "date": {
                "description": "The date on which the vendor credit is "
                "created. Must be in yyyy-mm-dd format. This "
                "date determines the accounting period and "
                "affects tax calculations.",
                "example": "2014-08-28",
                "type": "string",
            },
            "destination_of_supply": {
                "description": "Place where the "
                "goods/services are supplied "
                "to. (If not given, "
                "organisation's home state "
                "will be taken)",
                "example": "TN",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "documents": {
                "items": {
                    "properties": {
                        "document_id": {
                            "description": "ID of the Document",
                            "format": "int64",
                            "type": "integer",
                        },
                        "file_name": {"description": "Name of the file", "type": "string"},
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "exchange_rate": {
                "description": "Exchange rate for converting the "
                "vendor credit currency to base "
                "currency. Required when currency "
                "differs from base currency. Retrieve "
                "rates from currency exchange rate "
                "APIs.",
                "example": 1,
                "format": "double",
                "type": "number",
            },
            "gst_no": {
                "description": "15 digit GST identification number of the vendor.",
                "example": "22AAAAA0000A1Z5",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "gst_treatment": {
                "description": "Choose whether the contact is GST "
                "registered/unregistered/consumer/overseas. "
                "Allowed values are <code> "
                "business_gst </code> , <code> "
                "business_none </code> , <code> "
                "overseas </code> , <code> consumer "
                "</code>.",
                "example": "business_gst",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "is_inclusive_tax": {
                "description": "Set to true if line item rates "
                "include tax amounts. When true, "
                "tax is already included in the "
                "item rates. When false, tax will "
                "be calculated and added to the "
                "rates.",
                "example": False,
                "type": "boolean",
                "x-node_available_in": [],
                "x-node_unavailable_in": ["us"],
            },
            "is_update_customer": {
                "description": "Set to true to update customer "
                "information when creating the "
                "vendor credit. This will modify "
                "the associated customer record "
                "with new details from the "
                "vendor credit.",
                "example": False,
                "type": "boolean",
            },
            "line_items": {
                "description": "Line items of a vendor credit.",
                "items": {
                    "properties": {
                        "account_id": {
                            "description": "Unique "
                            "identifier "
                            "for "
                            "the "
                            "chart "
                            "of "
                            "accounts "
                            "entry. "
                            "Retrieve "
                            "account "
                            "IDs "
                            "from "
                            "the "
                            "List "
                            "Chart "
                            "of "
                            "Accounts "
                            "API "
                            "endpoint. "
                            "Determines "
                            "which "
                            "account "
                            "the "
                            "line "
                            "item "
                            "affects "
                            "for "
                            "accounting "
                            "purposes.",
                            "example": "460000000020097",
                            "type": "string",
                        },
                        "description": {
                            "description": "Detailed "
                            "description "
                            "of "
                            "the "
                            "line "
                            "item. "
                            "Provides "
                            "additional "
                            "information "
                            "about "
                            "the "
                            "product "
                            "or "
                            "service "
                            "being "
                            "credited. "
                            "Displayed "
                            "on "
                            "the "
                            "vendor "
                            "credit "
                            "document.",
                            "type": "string",
                        },
                        "hsn_or_sac": {
                            "description": "HSN Code",
                            "type": "string",
                            "x-node_available_in": ["in", "ke", "za"],
                            "x-node_unavailable_in": [],
                        },
                        "item_custom_fields": {
                            "items": {
                                "properties": {
                                    "custom_field_id": {
                                        "description": "ID of the Custom Field",
                                        "format": "int64",
                                        "type": "integer",
                                    },
                                    "index": {
                                        "description": "Index of the Custom Field",
                                        "type": "integer",
                                    },
                                    "label": {
                                        "description": "Label of the Custom Field",
                                        "type": "string",
                                    },
                                    "value": {
                                        "description": "Value of the Custom Field",
                                        "type": "string",
                                    },
                                },
                                "type": "object",
                            },
                            "type": "array",
                        },
                        "item_id": {
                            "description": "Unique "
                            "identifier "
                            "for "
                            "the "
                            "item "
                            "in "
                            "the "
                            "line "
                            "item. "
                            "Retrieve "
                            "item "
                            "IDs "
                            "from "
                            "the "
                            "List "
                            "Items "
                            "API "
                            "endpoint "
                            "in "
                            "the "
                            "items "
                            "section. "
                            "Links "
                            "the "
                            "line "
                            "item "
                            "to "
                            "a "
                            "specific "
                            "product "
                            "or "
                            "service.",
                            "example": "460000000020071",
                            "type": "string",
                        },
                        "item_order": {
                            "description": "Sequential "
                            "order "
                            "number "
                            "for "
                            "the "
                            "line "
                            "item. "
                            "Determines "
                            "the "
                            "display "
                            "order "
                            "of "
                            "line "
                            "items "
                            "on "
                            "the "
                            "vendor "
                            "credit "
                            "document. "
                            "Lower "
                            "numbers "
                            "appear "
                            "first.",
                            "example": 0,
                            "type": "integer",
                        },
                        "line_item_id": {
                            "description": "Unique "
                            "identifier "
                            "for "
                            "the "
                            "line "
                            "item "
                            "within "
                            "the "
                            "vendor "
                            "credit. "
                            "System-generated "
                            "ID "
                            "used "
                            "for "
                            "identifying "
                            "and "
                            "referencing "
                            "specific "
                            "line "
                            "items "
                            "in "
                            "the "
                            "vendor "
                            "credit.",
                            "example": "460000000020077",
                            "type": "string",
                        },
                        "location_id": {
                            "description": "Unique "
                            "identifier "
                            "for "
                            "the "
                            "business "
                            "location. "
                            "Retrieve "
                            "location "
                            "IDs "
                            "from "
                            "the "
                            "List "
                            "Locations "
                            "API "
                            "endpoint "
                            "in "
                            "the "
                            "locations "
                            "section. "
                            "Determines "
                            "tax "
                            "settings "
                            "and "
                            "business "
                            "rules.",
                            "example": "460000000038080",
                            "type": "string",
                        },
                        "name": {
                            "description": "Name "
                            "or "
                            "title "
                            "of "
                            "the "
                            "line "
                            "item. "
                            "Describes "
                            "the "
                            "product "
                            "or "
                            "service "
                            "being "
                            "credited. "
                            "This "
                            "name "
                            "is "
                            "displayed "
                            "on "
                            "the "
                            "vendor "
                            "credit "
                            "document.",
                            "example": "Premium Plan - Web hosting",
                            "type": "string",
                        },
                        "project_id": {
                            "description": "ID of the project",
                            "example": 90300000087378,
                            "type": "string",
                        },
                        "quantity": {
                            "description": "Number "
                            "of "
                            "units "
                            "being "
                            "credited "
                            "for "
                            "this "
                            "line "
                            "item. "
                            "Must "
                            "be "
                            "a "
                            "positive "
                            "number. "
                            "Used "
                            "to "
                            "calculate "
                            "the "
                            "total "
                            "amount "
                            "for "
                            "the "
                            "line "
                            "item.",
                            "example": 1,
                            "format": "double",
                            "type": "number",
                        },
                        "rate": {
                            "description": "Unit "
                            "price "
                            "or "
                            "rate "
                            "for "
                            "the "
                            "line "
                            "item. "
                            "The "
                            "amount "
                            "per "
                            "unit "
                            "before "
                            "taxes "
                            "and "
                            "discounts. "
                            "Used "
                            "with "
                            "quantity "
                            "to "
                            "calculate "
                            "the "
                            "line "
                            "total.",
                            "example": 30,
                            "format": "double",
                            "type": "number",
                        },
                        "reverse_charge_tax_id": {
                            "description": "ID of the reverse charge tax",
                            "example": 460000000057089,
                            "type": "string",
                            "x-node_available_in": ["in", "gcc", "za"],
                            "x-node_unavailable_in": [],
                        },
                        "serial_numbers": {"items": {"type": "string"}, "type": "array"},
                        "tags": {
                            "description": "Array "
                            "of "
                            "tags "
                            "associated "
                            "with "
                            "the "
                            "line "
                            "item. "
                            "Each "
                            "tag "
                            "contains "
                            "tag_id "
                            "and "
                            "tag_option_id "
                            "for "
                            "categorization "
                            "and "
                            "tracking "
                            "purposes.",
                            "items": {
                                "properties": {
                                    "tag_id": {
                                        "description": "ID of the tag",
                                        "format": "int64",
                                        "type": "integer",
                                    },
                                    "tag_option_id": {
                                        "description": "ID of the tag option",
                                        "format": "int64",
                                        "type": "integer",
                                    },
                                },
                                "type": "object",
                            },
                            "type": "array",
                        },
                        "tax_id": {
                            "description": "Unique "
                            "identifier "
                            "for "
                            "the "
                            "tax "
                            "applied "
                            "to "
                            "the "
                            "line "
                            "item. "
                            "Retrieve "
                            "tax "
                            "IDs "
                            "from "
                            "the "
                            "List "
                            "Taxes "
                            "API "
                            "endpoint "
                            "in "
                            "the "
                            "taxes "
                            "section. "
                            "Determines "
                            "tax "
                            "calculations "
                            "for "
                            "this "
                            "line "
                            "item.",
                            "type": "string",
                        },
                        "tax_treatment_code": {
                            "description": "Specify "
                            "reason "
                            "for "
                            "using "
                            "out "
                            "of "
                            "scope.</br>Supported "
                            "values "
                            "for "
                            "<b>UAE</b> "
                            "are "
                            "<code>uae_same_tax_group</code>, "
                            "<code>uae_reimbursed_expense</code> "
                            "and "
                            "<code>uae_others</code>.</br> "
                            "Supported "
                            "values "
                            "for "
                            "<b>Bahrain</b> "
                            "are "
                            "<code>bahrain_same_tax_group</code>, "
                            "<code>bahrain_transfer_of_concern</code>, "
                            "<code>bahrain_disbursement</code>, "
                            "<code>bahrain_head_to_branch_transaction</code>, "
                            "<code>bahrain_warranty_repair_services</code> "
                            "and "
                            "<code>bahrain_others</code>.</br> "
                            "Supported "
                            "values "
                            "for "
                            "<b>KSA</b> "
                            "are "
                            "<code>ksa_reimbursed_expense</code>.",
                            "example": "uae_others",
                            "type": "string",
                            "x-node_available_in": ["gcc"],
                            "x-node_unavailable_in": [],
                        },
                        "tds_tax_id": {
                            "description": "TDS "
                            "Tax "
                            "ID "
                            "of "
                            "the "
                            "Tax "
                            "associated "
                            "with "
                            "the "
                            "Vendor "
                            "Credit",
                            "type": "string",
                            "x-node_available_in": ["mx"],
                            "x-node_unavailable_in": [],
                        },
                        "unit": {
                            "description": "Unit "
                            "of "
                            "measurement "
                            "for "
                            "the "
                            "line "
                            "item "
                            "quantity. "
                            "Examples: "
                            "kgs, "
                            "Nos, "
                            "hours, "
                            "pieces. "
                            "Used "
                            "to "
                            "specify "
                            "how "
                            "the "
                            "quantity "
                            "is "
                            "measured.",
                            "example": "Nos",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "location_id": {
                "description": "Unique identifier for the business "
                "location. Retrieve location IDs from "
                "the List Locations API endpoint in the "
                "locations section. Determines tax "
                "settings and business rules.",
                "example": "460000000038080",
                "type": "string",
            },
            "notes": {
                "description": "Additional notes or comments for the vendor "
                "credit. Displayed on the vendor credit "
                "document for vendor reference. Max-length "
                "[5000]",
                "type": "string",
            },
            "place_of_supply": {
                "description": "The place of supply is where a "
                "transaction is considered to have "
                "occurred for VAT purposes. For the "
                "supply of goods, the place of "
                "supply is the location of the "
                "goods when the supply occurs. For "
                "the supply of services, the place "
                "of supply should be where the "
                "supplier is established. (If not "
                "given, <code>place of "
                "contact</code> given for the "
                "contact will be "
                "taken)<br/>Supported codes for UAE "
                "emirates are : </br>Abu Dhabi - "
                "<code>AB</code>,</br>Ajman - "
                "<code>AJ</code>,</br>Dubai - "
                "<code>DU</code>,</br>Fujairah - "
                "<code>FU</code>,</br>Ras "
                "al-Khaimah - "
                "<code>RA</code>,</br>Sharjah - "
                "<code>SH</code>,</br>Umm al-Quwain "
                "- <code>UM</code>.<br/>Supported "
                "codes for the GCC countries are : "
                "</br>United Arab Emirates - "
                "<code>AE</code>,</br>Saudi Arabia "
                "- <code>SA</code>,</br>Bahrain - "
                "<code>BH</code>,</br>Kuwait - "
                "<code>KW</code>,</br>Oman - "
                "<code>OM</code>,</br>Qatar - "
                "<code>QA</code>.",
                "example": "DU",
                "type": "string",
                "x-node_available_in": ["gcc"],
                "x-node_unavailable_in": [],
            },
            "pricebook_id": {
                "description": "Unique identifier for the pricebook "
                "used for pricing items in the vendor "
                "credit. Retrieve pricebook IDs from "
                "the pricebooks API endpoint.",
                "type": "string",
            },
            "reference_number": {
                "description": "Optional reference number for "
                "tracking purposes. Can be any "
                "custom string or auto-generated. "
                "Useful for linking to external "
                "systems or internal tracking. "
                "Max-Length [100]",
                "type": "string",
            },
            "source_of_supply": {
                "description": "Place from where the "
                "goods/services are supplied. (If "
                "not given, <code>place of "
                "contact</code> given for the "
                "contact will be taken)",
                "example": "TN",
                "type": "string",
                "x-node_available_in": ["in"],
                "x-node_unavailable_in": [],
            },
            "tax_treatment": {
                "description": "VAT treatment for the vendor credit. "
                "Choose whether the vendor falls "
                "under: "
                "<code>vat_registered</code>,<code>vat_not_registered</code>,<code>gcc_vat_not_registered</code>,<code>gcc_vat_registered</code>,<code>non_gcc</code>.</br><code>dz_vat_registered</code> "
                "and "
                "<code>dz_vat_not_registered</code> "
                "are supported only for "
                "<b>UAE</b>.</b></br><code>home_country_mexico</code>,<code>border_region_mexico</code>,<code>non_mexico</code> "
                "supported only for "
                "<b>MX</b>.<br/><b>For Kenya "
                "Edition:</b> "
                "<code>vat_registered</code> "
                ",<code>vat_not_registered</code> "
                ",<code>non_kenya</code>(A business "
                "that is located outside "
                "Kenya).<br/><b>For SouthAfrica "
                "Edition:</b> "
                "<code>vat_registered</code>, "
                "<code>vat_not_registered</code>, "
                "<code>overseas</code>(A business "
                "that is located outside "
                "SouthAfrica).",
                "example": "vat_registered",
                "type": "string",
                "x-node_available_in": ["gcc", "mx", "ke", "za"],
                "x-node_unavailable_in": [],
            },
            "vat_treatment": {
                "description": "VAT treatment for the vendor "
                "credits. VAT treatment denotes the "
                "location of the customer, if the "
                "customer resides in UK then the VAT "
                "treatment is <code>uk</code>. If the "
                "vendor is in an EU country & VAT "
                "registered, you are resides in "
                "Northen Ireland and purchasing Goods "
                "then his VAT treatment is "
                "<code>eu_vat_registered</code>and if "
                "he resides outside the EU then his "
                "VAT treatment is "
                "<code>overseas</code>(For Pre "
                "Brexit, this can be split as "
                "<code>eu_vat_registered</code>, "
                "<code>eu_vat_not_registered</code> "
                "and <code>non_eu</code>).",
                "type": "string",
                "x-node_available_in": ["uk"],
                "x-node_unavailable_in": [],
            },
            "vendor_credit_number": {
                "description": "Mandatory if auto number generation is disabled.",
                "example": "DN-00002",
                "type": "string",
            },
            "vendor_id": {
                "description": "Unique identifier for the vendor "
                "contact. Retrieve vendor IDs from the "
                "Get Contacts API endpoint in the "
                "contacts section. This ID links the "
                "vendor credit to the specific vendor "
                "record.",
                "example": "460000000020029",
                "type": "string",
            },
        },
        "required": ["vendor_id"],
        "type": "object",
    },
    "APPLYVENDORCREDITTOBILL_REQUEST_BODY_SCHEMA": {
        "properties": {
            "bills": {
                "description": "Amount applied from vendor credits to specified bills.",
                "items": {
                    "properties": {
                        "amount_applied": {
                            "description": "Amount applied to the bill.",
                            "example": 10,
                            "format": "double",
                            "type": "number",
                        },
                        "bill_id": {
                            "description": "Bill Associated with the Vendor Credit",
                            "example": "460000000057075",
                            "type": "string",
                        },
                    },
                    "required": ["bill_id", "amount_applied"],
                    "type": "object",
                },
                "type": "array",
            }
        },
        "required": ["bills"],
        "type": "object",
    },
    "REFUNDVENDORCREDIT_REQUEST_BODY_SCHEMA": {
        "properties": {
            "account_id": {
                "description": "Unique identifier for the chart of "
                "accounts entry. Retrieve account IDs "
                "from the List Chart of Accounts API "
                "endpoint. Determines which account the "
                "line item affects for accounting "
                "purposes.",
                "example": "460000000020097",
                "type": "string",
            },
            "amount": {"example": 13, "format": "double", "type": "number"},
            "date": {
                "description": "Date of Vendor Credit Refund",
                "example": "2014-08-30",
                "type": "string",
            },
            "description": {
                "description": "Detailed description of the line item. "
                "Provides additional information about "
                "the product or service being credited. "
                "Displayed on the vendor credit "
                "document.",
                "type": "string",
            },
            "exchange_rate": {
                "description": "Exchange rate for converting the "
                "vendor credit currency to base "
                "currency. Required when currency "
                "differs from base currency. Retrieve "
                "rates from currency exchange rate "
                "APIs.",
                "example": 1,
                "format": "double",
                "type": "number",
            },
            "reference_number": {
                "description": "Optional reference number for "
                "tracking purposes. Can be any "
                "custom string or auto-generated. "
                "Useful for linking to external "
                "systems or internal tracking. "
                "Max-Length [100]",
                "type": "string",
            },
            "refund_mode": {"description": "Mode of Refund", "example": "cash", "type": "string"},
        },
        "required": ["date", "amount", "account_id"],
        "type": "object",
    },
    "UPDATEVENDORCREDITREFUND_REQUEST_BODY_SCHEMA": {
        "properties": {
            "account_id": {
                "description": "Unique identifier for the chart of "
                "accounts entry. Retrieve account IDs "
                "from the List Chart of Accounts API "
                "endpoint. Determines which account the "
                "line item affects for accounting "
                "purposes.",
                "example": "460000000020097",
                "type": "string",
            },
            "amount": {"example": 13, "format": "double", "type": "number"},
            "date": {
                "description": "The date on which the vendor credit is "
                "created. Must be in yyyy-mm-dd format. This "
                "date determines the accounting period and "
                "affects tax calculations.",
                "example": "2014-08-28",
                "type": "string",
            },
            "description": {
                "description": "Detailed description of the line item. "
                "Provides additional information about "
                "the product or service being credited. "
                "Displayed on the vendor credit "
                "document.",
                "type": "string",
            },
            "exchange_rate": {
                "description": "Exchange rate for converting the "
                "vendor credit currency to base "
                "currency. Required when currency "
                "differs from base currency. Retrieve "
                "rates from currency exchange rate "
                "APIs.",
                "example": 1,
                "format": "double",
                "type": "number",
            },
            "reference_number": {
                "description": "Optional reference number for "
                "tracking purposes. Can be any "
                "custom string or auto-generated. "
                "Useful for linking to external "
                "systems or internal tracking. "
                "Max-Length [100]",
                "type": "string",
            },
            "refund_mode": {"description": "Mode of Refund", "example": "cash", "type": "string"},
        },
        "required": ["date", "amount", "account_id"],
        "type": "object",
    },
    "ADDVENDORCREDITCOMMENT_REQUEST_BODY_SCHEMA": {
        "properties": {
            "description": {
                "description": "Description of the Comment",
                "example": "Credits applied to Bill 1",
                "type": "string",
            }
        },
        "required": ["description"],
        "type": "object",
    },
    "CREATEVENDORPAYMENT_REQUEST_BODY_SCHEMA": {
        "properties": {
            "amount": {
                "description": "Total Amount of Vendor Payment",
                "example": 500,
                "format": "double",
                "type": "number",
            },
            "bills": {
                "description": "Individual bill payment details as array.",
                "items": {
                    "properties": {
                        "amount_applied": {
                            "description": "Amount applied to the bill.",
                            "example": 150,
                            "format": "double",
                            "type": "number",
                        },
                        "bill_id": {
                            "description": "ID of the bill the payment is to be applied.",
                            "example": "460000000053199",
                            "type": "string",
                        },
                        "bill_payment_id": {
                            "description": "ID of the Bill Payment",
                            "example": "460000000053221",
                            "type": "string",
                        },
                        "tax_amount_withheld": {
                            "description": "Tax Amount Withheld during Bill Payment",
                            "format": "double",
                            "type": "number",
                            "x-node_available_in": ["global", "in", "au"],
                            "x-node_unavailable_in": [],
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "check_details": {
                "items": {"type": "string"},
                "type": "array",
                "x-node_available_in": ["us", "ca"],
                "x-node_unavailable_in": [],
            },
            "custom_fields": {
                "items": {
                    "properties": {
                        "index": {"description": "Index of the Custom Field", "type": "integer"},
                        "value": {"description": "Value for the Custom Field", "type": "string"},
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "date": {
                "description": "Date the payment is made.",
                "example": "2013-10-07",
                "type": "string",
            },
            "description": {
                "description": "Description for the Vendor Payment recorded.",
                "type": "string",
            },
            "exchange_rate": {
                "description": "Exchange rate of the currency.",
                "example": 1,
                "format": "double",
                "type": "number",
            },
            "is_paid_via_print_check": {
                "description": "Check if the Bill Payment is paid Via Print Check Option",
                "example": False,
                "type": "boolean",
                "x-node_available_in": ["us", "ca", "mx"],
                "x-node_unavailable_in": [],
            },
            "location_id": {
                "description": "Location ID",
                "example": "460000000038080",
                "type": "string",
            },
            "paid_through_account_id": {
                "description": "ID of the cash/ bank account from which the payment is made.",
                "example": "460000000000358",
                "type": "string",
            },
            "payment_mode": {
                "description": "Mode of Vendor Payment",
                "example": "Stripe",
                "type": "string",
            },
            "reference_number": {
                "description": "Reference number for the Vendor Payment recorded.",
                "example": "REF#912300",
                "type": "string",
            },
            "vendor_id": {
                "description": "ID of the vendor associated with the Vendor Payment.",
                "example": "460000000026049",
                "type": "string",
            },
        },
        "required": ["amount"],
        "type": "object",
    },
    "UPDATEVENDORPAYMENTWITHCUSTOMID_REQUEST_BODY_SCHEMA": {
        "properties": {
            "amount": {
                "description": "Total Amount of Vendor Payment",
                "example": 500,
                "format": "double",
                "type": "number",
            },
            "bills": {
                "description": "Individual bill payment details as array.",
                "items": {
                    "properties": {
                        "amount_applied": {
                            "description": "Amount applied to the bill.",
                            "example": 150,
                            "format": "double",
                            "type": "number",
                        },
                        "bill_id": {
                            "description": "ID of the bill the payment is to be applied.",
                            "example": "460000000053199",
                            "type": "string",
                        },
                        "bill_payment_id": {
                            "description": "ID of the Bill Payment",
                            "example": "460000000053221",
                            "type": "string",
                        },
                        "tax_amount_withheld": {
                            "description": "Tax Amount Withheld during Bill Payment",
                            "format": "double",
                            "type": "number",
                            "x-node_available_in": ["global", "in", "au"],
                            "x-node_unavailable_in": [],
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "check_details": {
                "items": {"type": "string"},
                "type": "array",
                "x-node_available_in": ["us", "ca"],
                "x-node_unavailable_in": [],
            },
            "custom_fields": {
                "items": {
                    "properties": {
                        "index": {"description": "Index of the Custom Field", "type": "integer"},
                        "value": {"description": "Value for the Custom Field", "type": "string"},
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "date": {
                "description": "Date the payment is made.",
                "example": "2013-10-07",
                "type": "string",
            },
            "description": {
                "description": "Description for the Vendor Payment recorded.",
                "type": "string",
            },
            "exchange_rate": {
                "description": "Exchange rate of the currency.",
                "example": 1,
                "format": "double",
                "type": "number",
            },
            "is_paid_via_print_check": {
                "description": "Check if the Bill Payment is paid Via Print Check Option",
                "example": False,
                "type": "boolean",
                "x-node_available_in": ["us", "ca", "mx"],
                "x-node_unavailable_in": [],
            },
            "location_id": {
                "description": "Location ID",
                "example": "460000000038080",
                "type": "string",
            },
            "paid_through_account_id": {
                "description": "ID of the cash/ bank account from which the payment is made.",
                "example": "460000000000358",
                "type": "string",
            },
            "payment_mode": {
                "description": "Mode of Vendor Payment",
                "example": "Stripe",
                "type": "string",
            },
            "reference_number": {
                "description": "Reference number for the Vendor Payment recorded.",
                "example": "REF#912300",
                "type": "string",
            },
            "vendor_id": {
                "description": "ID of the vendor associated with the Vendor Payment.",
                "example": "460000000026049",
                "type": "string",
            },
        },
        "required": ["amount"],
        "type": "object",
    },
    "UPDATEVENDORPAYMENT_REQUEST_BODY_SCHEMA": {
        "properties": {
            "amount": {
                "description": "Total Amount of Vendor Payment",
                "example": 500,
                "format": "double",
                "type": "number",
            },
            "bills": {
                "description": "Individual bill payment details as array.",
                "items": {
                    "properties": {
                        "amount_applied": {
                            "description": "Amount applied to the bill.",
                            "example": 150,
                            "format": "double",
                            "type": "number",
                        },
                        "bill_id": {
                            "description": "ID of the bill the payment is to be applied.",
                            "example": "460000000053199",
                            "type": "string",
                        },
                        "bill_payment_id": {
                            "description": "ID of the Bill Payment",
                            "example": "460000000053221",
                            "type": "string",
                        },
                        "tax_amount_withheld": {
                            "description": "Tax Amount Withheld during Bill Payment",
                            "format": "double",
                            "type": "number",
                            "x-node_available_in": ["global", "in", "au"],
                            "x-node_unavailable_in": [],
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "check_details": {
                "items": {"type": "string"},
                "type": "array",
                "x-node_available_in": ["us", "ca"],
                "x-node_unavailable_in": [],
            },
            "custom_fields": {
                "items": {
                    "properties": {
                        "index": {"description": "Index of the Custom Field", "type": "integer"},
                        "value": {"description": "Value for the Custom Field", "type": "string"},
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "date": {
                "description": "Date the payment is made.",
                "example": "2013-10-07",
                "type": "string",
            },
            "description": {
                "description": "Description for the Vendor Payment recorded.",
                "type": "string",
            },
            "exchange_rate": {
                "description": "Exchange rate of the currency.",
                "example": 1,
                "format": "double",
                "type": "number",
            },
            "is_paid_via_print_check": {
                "description": "Check if the Bill Payment is paid Via Print Check Option",
                "example": False,
                "type": "boolean",
                "x-node_available_in": ["us", "ca", "mx"],
                "x-node_unavailable_in": [],
            },
            "location_id": {
                "description": "Location ID",
                "example": "460000000038080",
                "type": "string",
            },
            "paid_through_account_id": {
                "description": "ID of the cash/ bank account from which the payment is made.",
                "example": "460000000000358",
                "type": "string",
            },
            "payment_mode": {
                "description": "Mode of Vendor Payment",
                "example": "Stripe",
                "type": "string",
            },
            "reference_number": {
                "description": "Reference number for the Vendor Payment recorded.",
                "example": "REF#912300",
                "type": "string",
            },
            "vendor_id": {
                "description": "ID of the vendor associated with the Vendor Payment.",
                "example": "460000000026049",
                "type": "string",
            },
        },
        "required": ["amount"],
        "type": "object",
    },
    "REFUNDVENDOROVERPAYMENT_REQUEST_BODY_SCHEMA": {
        "properties": {
            "amount": {
                "description": "Total Amount of Vendor Payment",
                "example": 500,
                "format": "double",
                "type": "number",
            },
            "date": {
                "description": "Date of the Vendor Payment Refund.",
                "example": "2017-01-10",
                "type": "string",
            },
            "description": {
                "description": "Description of the Payment Refund",
                "example": "Payment Refund",
                "type": "string",
            },
            "exchange_rate": {
                "description": "Exchange rate of the currency.",
                "example": 1,
                "format": "double",
                "type": "number",
            },
            "reference_number": {
                "description": "Reference Number of the Payment Refund",
                "type": "string",
            },
            "refund_mode": {
                "description": "Mode in which refund is made.",
                "example": "cash",
                "type": "string",
            },
            "to_account_id": {
                "description": "The account to which payment is refunded.",
                "example": "460000000000385",
                "type": "string",
            },
        },
        "required": ["date", "amount", "to_account_id"],
        "type": "object",
    },
    "UPDATEVENDORPAYMENTREFUND_REQUEST_BODY_SCHEMA": {
        "properties": {
            "amount": {
                "description": "Total Amount of Vendor Payment",
                "example": 500,
                "format": "double",
                "type": "number",
            },
            "date": {
                "description": "Date of the Vendor Payment Refund.",
                "example": "2017-01-10",
                "type": "string",
            },
            "description": {
                "description": "Description of the Payment Refund",
                "example": "Payment Refund",
                "type": "string",
            },
            "exchange_rate": {
                "description": "Exchange rate of the currency.",
                "example": 1,
                "format": "double",
                "type": "number",
            },
            "reference_number": {
                "description": "Reference Number of the Payment Refund",
                "type": "string",
            },
            "refund_mode": {
                "description": "Mode in which refund is made.",
                "example": "cash",
                "type": "string",
            },
            "to_account_id": {
                "description": "The account to which payment is refunded.",
                "example": "460000000000385",
                "type": "string",
            },
        },
        "required": ["date", "amount", "to_account_id"],
        "type": "object",
    },
    "SENDVENDORPAYMENTEMAIL_REQUEST_BODY_SCHEMA": {
        "properties": {
            "body": {
                "description": "Body of the email",
                "example": "Dear Vendor,<br><br>Thank you for your "
                "services.<br><br>Please find attached the payment "
                "receipt for Payment#: VP-00001.<br><br>Payment "
                "Details:<br>Payment Number: VP-00001<br>Date: "
                "2024-01-15<br>Amount: $1,500.00<br><br>Best "
                "regards,<br>Your Company",
                "type": "string",
            },
            "cc_mail_ids": {
                "description": "Array of email address of the recipients to be CC'd.",
                "example": ["manager@example.com"],
                "items": {"type": "string"},
                "type": "array",
            },
            "email_template_id": {
                "description": "Get the email content based on a "
                "specific email template. If this "
                "param is not inputted, then the "
                "content will be based on the "
                "email template associated with "
                "the vendor. If no template is "
                "associated with the vendor, then "
                "default template will be used.",
                "type": "string",
            },
            "from_address_id": {
                "description": "From email address id",
                "example": "2000000011993",
                "type": "string",
            },
            "send_from_org_email_id": {
                "description": "Boolean to trigger the email from the organization's email address",
                "example": False,
                "type": "boolean",
            },
            "subject": {
                "description": "Subject of the email",
                "example": "Vendor Payment Receipt from Your Company (Payment#: VP-00001)",
                "type": "string",
            },
            "to_mail_ids": {
                "description": "Array of email address of the recipients.",
                "example": ["vendor@example.com"],
                "items": {"type": "string"},
                "type": "array",
            },
        },
        "required": ["to_mail_ids", "subject", "body"],
        "type": "object",
    },
}
