"""Request Body Schemas for API Tools

DO NOT EDIT THIS MODULE DIRECTLY.

THIS MODULE WAS AUTO-GENERATED AND CONTAINS OpenAPI REQUEST BODY SCHEMAS
FOR TOOLS WITH COMPLEX REQUEST BODIES. ANY CHANGES TO THIS MODULE WILL
BE OVERWRITTEN BY THE TRANSPILER.
"""

from typing import Any

REQUEST_BODY_SCHEMAS: dict[str, Any] = {
    "UPDATEDATASTOREITEM_REQUEST_BODY_SCHEMA": {
        "description": "Request to update specific fields on an existing datastore item.",
        "properties": {
            "data": {
                "description": "Data wrapper containing the item identifier "
                "and the changes to apply during the update "
                "operation.",
                "properties": {
                    "attributes": {
                        "description": "Attributes for "
                        "updating a "
                        "datastore item, "
                        "including the "
                        "item key and "
                        "changes to "
                        "apply.",
                        "properties": {
                            "id": {
                                "description": "The unique identifier of the item being updated.",
                                "type": "string",
                            },
                            "item_changes": {
                                "description": "Changes "
                                "to "
                                "apply "
                                "to "
                                "a "
                                "datastore "
                                "item "
                                "using "
                                "set "
                                "operations.",
                                "properties": {
                                    "ops_set": {
                                        "additionalProperties": {},
                                        "description": "Set "
                                        "operation "
                                        "that "
                                        "contains "
                                        "key-value "
                                        "pairs "
                                        "to "
                                        "set "
                                        "on "
                                        "the "
                                        "datastore "
                                        "item.",
                                        "type": "object",
                                    }
                                },
                                "type": "object",
                            },
                            "item_key": {
                                "description": "The "
                                "primary "
                                "key "
                                "that "
                                "identifies "
                                "the "
                                "item "
                                "to "
                                "update. "
                                "Cannot "
                                "exceed "
                                "256 "
                                "characters.",
                                "example": "",
                                "maxLength": 256,
                                "type": "string",
                            },
                        },
                        "required": ["item_changes", "item_key"],
                        "type": "object",
                    },
                    "id": {
                        "description": "The unique identifier of the datastore item.",
                        "type": "string",
                    },
                    "type": {
                        "default": "items",
                        "description": "The resource type for datastore items.",
                        "enum": ["items"],
                        "example": "items",
                        "type": "string",
                        "x-enum-varnames": ["ITEMS"],
                    },
                },
                "required": ["type"],
                "type": "object",
            }
        },
        "type": "object",
    },
    "BULKUPDATEDATASTOREITEMS_REQUEST_BODY_SCHEMA": {
        "description": "Request to insert multiple items into a datastore in a single operation.",
        "properties": {
            "data": {
                "description": "Data wrapper containing the items to insert "
                "and their configuration for the bulk insert "
                "operation.",
                "properties": {
                    "attributes": {
                        "description": "Configuration "
                        "for bulk "
                        "inserting "
                        "multiple items "
                        "into a "
                        "datastore.",
                        "properties": {
                            "conflict_mode": {
                                "description": "How "
                                "to "
                                "handle "
                                "conflicts "
                                "when "
                                "inserting "
                                "items "
                                "that "
                                "already "
                                "exist "
                                "in "
                                "the "
                                "datastore.",
                                "enum": ["fail_on_conflict", "overwrite_on_conflict"],
                                "example": "overwrite_on_conflict",
                                "type": "string",
                                "x-enum-varnames": ["FAIL_ON_CONFLICT", "OVERWRITE_ON_CONFLICT"],
                            },
                            "values": {
                                "description": "An "
                                "array "
                                "of "
                                "items "
                                "to "
                                "add "
                                "to "
                                "the "
                                "datastore, "
                                "where "
                                "each "
                                "item "
                                "is "
                                "a "
                                "set "
                                "of "
                                "key-value "
                                "pairs "
                                "representing "
                                "the "
                                "item's "
                                "data. "
                                "Up "
                                "to "
                                "100 "
                                "items "
                                "can "
                                "be "
                                "updated "
                                "in "
                                "a "
                                "single "
                                "request.",
                                "example": [
                                    {"data": "example data", "key": "value"},
                                    {"data": "example data2", "key": "value2"},
                                ],
                                "items": {
                                    "additionalProperties": {},
                                    "description": "A "
                                    "single "
                                    "item's "
                                    "data "
                                    "as "
                                    "key-value "
                                    "pairs. "
                                    "Key "
                                    "names "
                                    "cannot "
                                    "exceed "
                                    "63 "
                                    "characters.",
                                    "type": "object",
                                },
                                "maxItems": 100,
                                "type": "array",
                            },
                        },
                        "required": ["values"],
                        "type": "object",
                    },
                    "type": {
                        "default": "items",
                        "description": "The resource type for datastore items.",
                        "enum": ["items"],
                        "example": "items",
                        "type": "string",
                        "x-enum-varnames": ["ITEMS"],
                    },
                },
                "required": ["type"],
                "type": "object",
            }
        },
        "type": "object",
    },
    "CREATEACTIONCONNECTION_REQUEST_BODY_SCHEMA": {
        "description": "Request used to create an action connection.",
        "properties": {
            "data": {
                "description": "Data related to the connection.",
                "properties": {
                    "attributes": {
                        "description": "The definition of `ActionConnectionAttributes` object.",
                        "properties": {
                            "integration": {
                                "description": "The "
                                "definition "
                                "of "
                                "`ActionConnectionIntegration` "
                                "object.",
                                "oneOf": [
                                    {
                                        "description": "The definition of `AWSIntegration` object.",
                                        "properties": {
                                            "credentials": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "`AWSCredentials` "
                                                "object.",
                                                "oneOf": [
                                                    {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "`AWSAssumeRole` "
                                                        "object.",
                                                        "properties": {
                                                            "account_id": {
                                                                "description": "AWS "
                                                                "account "
                                                                "the "
                                                                "connection "
                                                                "is "
                                                                "created "
                                                                "for",
                                                                "example": "111222333444",
                                                                "pattern": "^\\d{12}$",
                                                                "type": "string",
                                                            },
                                                            "external_id": {
                                                                "description": "External "
                                                                "ID "
                                                                "used "
                                                                "to "
                                                                "scope "
                                                                "which "
                                                                "connection "
                                                                "can "
                                                                "be "
                                                                "used "
                                                                "to "
                                                                "assume "
                                                                "the "
                                                                "role",
                                                                "example": "33a1011635c44b38a064cf14e82e1d8f",
                                                                "readOnly": True,
                                                                "type": "string",
                                                            },
                                                            "principal_id": {
                                                                "description": "AWS "
                                                                "account "
                                                                "that "
                                                                "will "
                                                                "assume "
                                                                "the "
                                                                "role",
                                                                "example": "123456789012",
                                                                "readOnly": True,
                                                                "type": "string",
                                                            },
                                                            "role": {
                                                                "description": "Role to assume",
                                                                "example": "my-role",
                                                                "type": "string",
                                                            },
                                                            "type": {
                                                                "description": "The "
                                                                "definition "
                                                                "of "
                                                                "`AWSAssumeRoleType` "
                                                                "object.",
                                                                "enum": ["AWSAssumeRole"],
                                                                "example": "AWSAssumeRole",
                                                                "type": "string",
                                                                "x-enum-varnames": [
                                                                    "AWSASSUMEROLE"
                                                                ],
                                                            },
                                                        },
                                                        "required": ["type", "account_id", "role"],
                                                        "type": "object",
                                                    }
                                                ],
                                            },
                                            "type": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "`AWSIntegrationType` "
                                                "object.",
                                                "enum": ["AWS"],
                                                "example": "AWS",
                                                "type": "string",
                                                "x-enum-varnames": ["AWS"],
                                            },
                                        },
                                        "required": ["type", "credentials"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "The "
                                        "definition "
                                        "of "
                                        "the "
                                        "`AnthropicIntegration` "
                                        "object.",
                                        "properties": {
                                            "credentials": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`AnthropicCredentials` "
                                                "object.",
                                                "oneOf": [
                                                    {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "the "
                                                        "`AnthropicAPIKey` "
                                                        "object.",
                                                        "properties": {
                                                            "api_token": {
                                                                "description": "The "
                                                                "`AnthropicAPIKey` "
                                                                "`api_token`.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                            "type": {
                                                                "description": "The "
                                                                "definition "
                                                                "of "
                                                                "the "
                                                                "`AnthropicAPIKey` "
                                                                "object.",
                                                                "enum": ["AnthropicAPIKey"],
                                                                "example": "AnthropicAPIKey",
                                                                "type": "string",
                                                                "x-enum-varnames": [
                                                                    "ANTHROPICAPIKEY"
                                                                ],
                                                            },
                                                        },
                                                        "required": ["type", "api_token"],
                                                        "type": "object",
                                                    }
                                                ],
                                            },
                                            "type": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`AnthropicIntegrationType` "
                                                "object.",
                                                "enum": ["Anthropic"],
                                                "example": "Anthropic",
                                                "type": "string",
                                                "x-enum-varnames": ["ANTHROPIC"],
                                            },
                                        },
                                        "required": ["type", "credentials"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "The "
                                        "definition "
                                        "of "
                                        "the "
                                        "`AsanaIntegration` "
                                        "object.",
                                        "properties": {
                                            "credentials": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`AsanaCredentials` "
                                                "object.",
                                                "oneOf": [
                                                    {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "the "
                                                        "`AsanaAccessToken` "
                                                        "object.",
                                                        "properties": {
                                                            "access_token": {
                                                                "description": "The "
                                                                "`AsanaAccessToken` "
                                                                "`access_token`.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                            "type": {
                                                                "description": "The "
                                                                "definition "
                                                                "of "
                                                                "the "
                                                                "`AsanaAccessToken` "
                                                                "object.",
                                                                "enum": ["AsanaAccessToken"],
                                                                "example": "AsanaAccessToken",
                                                                "type": "string",
                                                                "x-enum-varnames": [
                                                                    "ASANAACCESSTOKEN"
                                                                ],
                                                            },
                                                        },
                                                        "required": ["type", "access_token"],
                                                        "type": "object",
                                                    }
                                                ],
                                            },
                                            "type": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`AsanaIntegrationType` "
                                                "object.",
                                                "enum": ["Asana"],
                                                "example": "Asana",
                                                "type": "string",
                                                "x-enum-varnames": ["ASANA"],
                                            },
                                        },
                                        "required": ["type", "credentials"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "The "
                                        "definition "
                                        "of "
                                        "the "
                                        "`AzureIntegration` "
                                        "object.",
                                        "properties": {
                                            "credentials": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`AzureCredentials` "
                                                "object.",
                                                "oneOf": [
                                                    {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "the "
                                                        "`AzureTenant` "
                                                        "object.",
                                                        "properties": {
                                                            "app_client_id": {
                                                                "description": "The "
                                                                "Client "
                                                                "ID, "
                                                                "also "
                                                                "known "
                                                                "as "
                                                                "the "
                                                                "Application "
                                                                "ID "
                                                                "in "
                                                                "Azure, "
                                                                "is "
                                                                "a "
                                                                "unique "
                                                                "identifier "
                                                                "for "
                                                                "an "
                                                                "application. "
                                                                "It's "
                                                                "used "
                                                                "to "
                                                                "identify "
                                                                "the "
                                                                "application "
                                                                "during "
                                                                "the "
                                                                "authentication "
                                                                "process. "
                                                                "Your "
                                                                "Application "
                                                                "(client) "
                                                                "ID "
                                                                "is "
                                                                "listed "
                                                                "in "
                                                                "the "
                                                                "application's "
                                                                "overview "
                                                                "page. "
                                                                "You "
                                                                "can "
                                                                "navigate "
                                                                "to "
                                                                "your "
                                                                "application "
                                                                "via "
                                                                "the "
                                                                "Azure "
                                                                "Directory. ",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                            "client_secret": {
                                                                "description": "The "
                                                                "Client "
                                                                "Secret "
                                                                "is "
                                                                "a "
                                                                "confidential "
                                                                "piece "
                                                                "of "
                                                                "information "
                                                                "known "
                                                                "only "
                                                                "to "
                                                                "the "
                                                                "application "
                                                                "and "
                                                                "Azure "
                                                                "AD. "
                                                                "It's "
                                                                "used "
                                                                "to "
                                                                "prove "
                                                                "the "
                                                                "application's "
                                                                "identity. "
                                                                "Your "
                                                                "Client "
                                                                "Secret "
                                                                "is "
                                                                "available "
                                                                "from "
                                                                "the "
                                                                "application’s "
                                                                "secrets "
                                                                "page. "
                                                                "You "
                                                                "can "
                                                                "navigate "
                                                                "to "
                                                                "your "
                                                                "application "
                                                                "via "
                                                                "the "
                                                                "Azure "
                                                                "Directory.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                            "custom_scopes": {
                                                                "description": "If "
                                                                "provided, "
                                                                "the "
                                                                "custom "
                                                                "scope "
                                                                "to "
                                                                "be "
                                                                "requested "
                                                                "from "
                                                                "Microsoft "
                                                                "when "
                                                                "acquiring "
                                                                "an "
                                                                "OAuth "
                                                                "2 "
                                                                "access "
                                                                "token. "
                                                                "This "
                                                                "custom "
                                                                "scope "
                                                                "is "
                                                                "used "
                                                                "only "
                                                                "in "
                                                                "conjunction "
                                                                "with "
                                                                "the "
                                                                "HTTP "
                                                                "action. "
                                                                "A "
                                                                "resource's "
                                                                "scope "
                                                                "is "
                                                                "constructed "
                                                                "by "
                                                                "using "
                                                                "the "
                                                                "identifier "
                                                                "URI "
                                                                "for "
                                                                "the "
                                                                "resource "
                                                                "and "
                                                                ".default, "
                                                                "separated "
                                                                "by "
                                                                "a "
                                                                "forward "
                                                                "slash "
                                                                "(/) "
                                                                "as "
                                                                "follows:{identifierURI}/.default.",
                                                                "type": "string",
                                                            },
                                                            "tenant_id": {
                                                                "description": "The "
                                                                "Tenant "
                                                                "ID, "
                                                                "also "
                                                                "known "
                                                                "as "
                                                                "the "
                                                                "Directory "
                                                                "ID "
                                                                "in "
                                                                "Azure, "
                                                                "is "
                                                                "a "
                                                                "unique "
                                                                "identifier "
                                                                "that "
                                                                "represents "
                                                                "an "
                                                                "Azure "
                                                                "AD "
                                                                "instance. "
                                                                "Your "
                                                                "Tenant "
                                                                "ID "
                                                                "(Directory "
                                                                "ID) "
                                                                "is "
                                                                "listed "
                                                                "in "
                                                                "your "
                                                                "Active "
                                                                "Directory "
                                                                "overview "
                                                                "page "
                                                                "under "
                                                                "the "
                                                                "'Tenant "
                                                                "information' "
                                                                "section.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                            "type": {
                                                                "description": "The "
                                                                "definition "
                                                                "of "
                                                                "the "
                                                                "`AzureTenant` "
                                                                "object.",
                                                                "enum": ["AzureTenant"],
                                                                "example": "AzureTenant",
                                                                "type": "string",
                                                                "x-enum-varnames": ["AZURETENANT"],
                                                            },
                                                        },
                                                        "required": [
                                                            "type",
                                                            "tenant_id",
                                                            "app_client_id",
                                                            "client_secret",
                                                        ],
                                                        "type": "object",
                                                    }
                                                ],
                                            },
                                            "type": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`AzureIntegrationType` "
                                                "object.",
                                                "enum": ["Azure"],
                                                "example": "Azure",
                                                "type": "string",
                                                "x-enum-varnames": ["AZURE"],
                                            },
                                        },
                                        "required": ["type", "credentials"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "The "
                                        "definition "
                                        "of "
                                        "the "
                                        "`CircleCIIntegration` "
                                        "object.",
                                        "properties": {
                                            "credentials": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`CircleCICredentials` "
                                                "object.",
                                                "oneOf": [
                                                    {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "the "
                                                        "`CircleCIAPIKey` "
                                                        "object.",
                                                        "properties": {
                                                            "api_token": {
                                                                "description": "The "
                                                                "`CircleCIAPIKey` "
                                                                "`api_token`.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                            "type": {
                                                                "description": "The "
                                                                "definition "
                                                                "of "
                                                                "the "
                                                                "`CircleCIAPIKey` "
                                                                "object.",
                                                                "enum": ["CircleCIAPIKey"],
                                                                "example": "CircleCIAPIKey",
                                                                "type": "string",
                                                                "x-enum-varnames": [
                                                                    "CIRCLECIAPIKEY"
                                                                ],
                                                            },
                                                        },
                                                        "required": ["type", "api_token"],
                                                        "type": "object",
                                                    }
                                                ],
                                            },
                                            "type": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`CircleCIIntegrationType` "
                                                "object.",
                                                "enum": ["CircleCI"],
                                                "example": "CircleCI",
                                                "type": "string",
                                                "x-enum-varnames": ["CIRCLECI"],
                                            },
                                        },
                                        "required": ["type", "credentials"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "The "
                                        "definition "
                                        "of "
                                        "the "
                                        "`ClickupIntegration` "
                                        "object.",
                                        "properties": {
                                            "credentials": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`ClickupCredentials` "
                                                "object.",
                                                "oneOf": [
                                                    {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "the "
                                                        "`ClickupAPIKey` "
                                                        "object.",
                                                        "properties": {
                                                            "api_token": {
                                                                "description": "The "
                                                                "`ClickupAPIKey` "
                                                                "`api_token`.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                            "type": {
                                                                "description": "The "
                                                                "definition "
                                                                "of "
                                                                "the "
                                                                "`ClickupAPIKey` "
                                                                "object.",
                                                                "enum": ["ClickupAPIKey"],
                                                                "example": "ClickupAPIKey",
                                                                "type": "string",
                                                                "x-enum-varnames": [
                                                                    "CLICKUPAPIKEY"
                                                                ],
                                                            },
                                                        },
                                                        "required": ["type", "api_token"],
                                                        "type": "object",
                                                    }
                                                ],
                                            },
                                            "type": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`ClickupIntegrationType` "
                                                "object.",
                                                "enum": ["Clickup"],
                                                "example": "Clickup",
                                                "type": "string",
                                                "x-enum-varnames": ["CLICKUP"],
                                            },
                                        },
                                        "required": ["type", "credentials"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "The "
                                        "definition "
                                        "of "
                                        "the "
                                        "`CloudflareIntegration` "
                                        "object.",
                                        "properties": {
                                            "credentials": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`CloudflareCredentials` "
                                                "object.",
                                                "oneOf": [
                                                    {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "the "
                                                        "`CloudflareAPIToken` "
                                                        "object.",
                                                        "properties": {
                                                            "api_token": {
                                                                "description": "The "
                                                                "`CloudflareAPIToken` "
                                                                "`api_token`.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                            "type": {
                                                                "description": "The "
                                                                "definition "
                                                                "of "
                                                                "the "
                                                                "`CloudflareAPIToken` "
                                                                "object.",
                                                                "enum": ["CloudflareAPIToken"],
                                                                "example": "CloudflareAPIToken",
                                                                "type": "string",
                                                                "x-enum-varnames": [
                                                                    "CLOUDFLAREAPITOKEN"
                                                                ],
                                                            },
                                                        },
                                                        "required": ["type", "api_token"],
                                                        "type": "object",
                                                    },
                                                    {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "the "
                                                        "`CloudflareGlobalAPIToken` "
                                                        "object.",
                                                        "properties": {
                                                            "auth_email": {
                                                                "description": "The "
                                                                "`CloudflareGlobalAPIToken` "
                                                                "`auth_email`.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                            "global_api_key": {
                                                                "description": "The "
                                                                "`CloudflareGlobalAPIToken` "
                                                                "`global_api_key`.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                            "type": {
                                                                "description": "The "
                                                                "definition "
                                                                "of "
                                                                "the "
                                                                "`CloudflareGlobalAPIToken` "
                                                                "object.",
                                                                "enum": [
                                                                    "CloudflareGlobalAPIToken"
                                                                ],
                                                                "example": "CloudflareGlobalAPIToken",
                                                                "type": "string",
                                                                "x-enum-varnames": [
                                                                    "CLOUDFLAREGLOBALAPITOKEN"
                                                                ],
                                                            },
                                                        },
                                                        "required": [
                                                            "type",
                                                            "auth_email",
                                                            "global_api_key",
                                                        ],
                                                        "type": "object",
                                                    },
                                                ],
                                            },
                                            "type": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`CloudflareIntegrationType` "
                                                "object.",
                                                "enum": ["Cloudflare"],
                                                "example": "Cloudflare",
                                                "type": "string",
                                                "x-enum-varnames": ["CLOUDFLARE"],
                                            },
                                        },
                                        "required": ["type", "credentials"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "The "
                                        "definition "
                                        "of "
                                        "the "
                                        "`ConfigCatIntegration` "
                                        "object.",
                                        "properties": {
                                            "credentials": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`ConfigCatCredentials` "
                                                "object.",
                                                "oneOf": [
                                                    {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "the "
                                                        "`ConfigCatSDKKey` "
                                                        "object.",
                                                        "properties": {
                                                            "api_password": {
                                                                "description": "The "
                                                                "`ConfigCatSDKKey` "
                                                                "`api_password`.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                            "api_username": {
                                                                "description": "The "
                                                                "`ConfigCatSDKKey` "
                                                                "`api_username`.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                            "sdk_key": {
                                                                "description": "The "
                                                                "`ConfigCatSDKKey` "
                                                                "`sdk_key`.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                            "type": {
                                                                "description": "The "
                                                                "definition "
                                                                "of "
                                                                "the "
                                                                "`ConfigCatSDKKey` "
                                                                "object.",
                                                                "enum": ["ConfigCatSDKKey"],
                                                                "example": "ConfigCatSDKKey",
                                                                "type": "string",
                                                                "x-enum-varnames": [
                                                                    "CONFIGCATSDKKEY"
                                                                ],
                                                            },
                                                        },
                                                        "required": [
                                                            "type",
                                                            "sdk_key",
                                                            "api_username",
                                                            "api_password",
                                                        ],
                                                        "type": "object",
                                                    }
                                                ],
                                            },
                                            "type": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`ConfigCatIntegrationType` "
                                                "object.",
                                                "enum": ["ConfigCat"],
                                                "example": "ConfigCat",
                                                "type": "string",
                                                "x-enum-varnames": ["CONFIGCAT"],
                                            },
                                        },
                                        "required": ["type", "credentials"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "The "
                                        "definition "
                                        "of "
                                        "the "
                                        "`DatadogIntegration` "
                                        "object.",
                                        "properties": {
                                            "credentials": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`DatadogCredentials` "
                                                "object.",
                                                "oneOf": [
                                                    {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "the "
                                                        "`DatadogAPIKey` "
                                                        "object.",
                                                        "properties": {
                                                            "api_key": {
                                                                "description": "The "
                                                                "`DatadogAPIKey` "
                                                                "`api_key`.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                            "app_key": {
                                                                "description": "The "
                                                                "`DatadogAPIKey` "
                                                                "`app_key`.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                            "datacenter": {
                                                                "description": "The "
                                                                "`DatadogAPIKey` "
                                                                "`datacenter`.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                            "subdomain": {
                                                                "description": "Custom "
                                                                "subdomain "
                                                                "used "
                                                                "for "
                                                                "Datadog "
                                                                "URLs "
                                                                "generated "
                                                                "with "
                                                                "this "
                                                                "Connection. "
                                                                "For "
                                                                "example, "
                                                                "if "
                                                                "this "
                                                                "org "
                                                                "uses "
                                                                "`https://acme.datadoghq.com` "
                                                                "to "
                                                                "access "
                                                                "Datadog, "
                                                                "set "
                                                                "this "
                                                                "field "
                                                                "to "
                                                                "`acme`. "
                                                                "If "
                                                                "this "
                                                                "field "
                                                                "is "
                                                                "omitted, "
                                                                "generated "
                                                                "URLs "
                                                                "will "
                                                                "use "
                                                                "the "
                                                                "default "
                                                                "site "
                                                                "URL "
                                                                "for "
                                                                "its "
                                                                "datacenter "
                                                                "(see "
                                                                "[https://docs.datadoghq.com/getting_started/site](https://docs.datadoghq.com/getting_started/site)).",
                                                                "type": "string",
                                                            },
                                                            "type": {
                                                                "description": "The "
                                                                "definition "
                                                                "of "
                                                                "the "
                                                                "`DatadogAPIKey` "
                                                                "object.",
                                                                "enum": ["DatadogAPIKey"],
                                                                "example": "DatadogAPIKey",
                                                                "type": "string",
                                                                "x-enum-varnames": [
                                                                    "DATADOGAPIKEY"
                                                                ],
                                                            },
                                                        },
                                                        "required": [
                                                            "type",
                                                            "datacenter",
                                                            "api_key",
                                                            "app_key",
                                                        ],
                                                        "type": "object",
                                                    }
                                                ],
                                            },
                                            "type": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`DatadogIntegrationType` "
                                                "object.",
                                                "enum": ["Datadog"],
                                                "example": "Datadog",
                                                "type": "string",
                                                "x-enum-varnames": ["DATADOG"],
                                            },
                                        },
                                        "required": ["type", "credentials"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "The "
                                        "definition "
                                        "of "
                                        "the "
                                        "`FastlyIntegration` "
                                        "object.",
                                        "properties": {
                                            "credentials": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`FastlyCredentials` "
                                                "object.",
                                                "oneOf": [
                                                    {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "the "
                                                        "`FastlyAPIKey` "
                                                        "object.",
                                                        "properties": {
                                                            "api_key": {
                                                                "description": "The "
                                                                "`FastlyAPIKey` "
                                                                "`api_key`.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                            "type": {
                                                                "description": "The "
                                                                "definition "
                                                                "of "
                                                                "the "
                                                                "`FastlyAPIKey` "
                                                                "object.",
                                                                "enum": ["FastlyAPIKey"],
                                                                "example": "FastlyAPIKey",
                                                                "type": "string",
                                                                "x-enum-varnames": ["FASTLYAPIKEY"],
                                                            },
                                                        },
                                                        "required": ["type", "api_key"],
                                                        "type": "object",
                                                    }
                                                ],
                                            },
                                            "type": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`FastlyIntegrationType` "
                                                "object.",
                                                "enum": ["Fastly"],
                                                "example": "Fastly",
                                                "type": "string",
                                                "x-enum-varnames": ["FASTLY"],
                                            },
                                        },
                                        "required": ["type", "credentials"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "The "
                                        "definition "
                                        "of "
                                        "the "
                                        "`FreshserviceIntegration` "
                                        "object.",
                                        "properties": {
                                            "credentials": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`FreshserviceCredentials` "
                                                "object.",
                                                "oneOf": [
                                                    {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "the "
                                                        "`FreshserviceAPIKey` "
                                                        "object.",
                                                        "properties": {
                                                            "api_key": {
                                                                "description": "The "
                                                                "`FreshserviceAPIKey` "
                                                                "`api_key`.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                            "domain": {
                                                                "description": "The "
                                                                "`FreshserviceAPIKey` "
                                                                "`domain`.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                            "type": {
                                                                "description": "The "
                                                                "definition "
                                                                "of "
                                                                "the "
                                                                "`FreshserviceAPIKey` "
                                                                "object.",
                                                                "enum": ["FreshserviceAPIKey"],
                                                                "example": "FreshserviceAPIKey",
                                                                "type": "string",
                                                                "x-enum-varnames": [
                                                                    "FRESHSERVICEAPIKEY"
                                                                ],
                                                            },
                                                        },
                                                        "required": ["type", "domain", "api_key"],
                                                        "type": "object",
                                                    }
                                                ],
                                            },
                                            "type": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`FreshserviceIntegrationType` "
                                                "object.",
                                                "enum": ["Freshservice"],
                                                "example": "Freshservice",
                                                "type": "string",
                                                "x-enum-varnames": ["FRESHSERVICE"],
                                            },
                                        },
                                        "required": ["type", "credentials"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "The "
                                        "definition "
                                        "of "
                                        "the "
                                        "`GCPIntegration` "
                                        "object.",
                                        "properties": {
                                            "credentials": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`GCPCredentials` "
                                                "object.",
                                                "oneOf": [
                                                    {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "the "
                                                        "`GCPServiceAccount` "
                                                        "object.",
                                                        "properties": {
                                                            "private_key": {
                                                                "description": "The "
                                                                "`GCPServiceAccount` "
                                                                "`private_key`.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                            "service_account_email": {
                                                                "description": "The "
                                                                "`GCPServiceAccount` "
                                                                "`service_account_email`.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                            "type": {
                                                                "description": "The "
                                                                "definition "
                                                                "of "
                                                                "the "
                                                                "`GCPServiceAccount` "
                                                                "object.",
                                                                "enum": ["GCPServiceAccount"],
                                                                "example": "GCPServiceAccount",
                                                                "type": "string",
                                                                "x-enum-varnames": [
                                                                    "GCPSERVICEACCOUNT"
                                                                ],
                                                            },
                                                        },
                                                        "required": [
                                                            "type",
                                                            "service_account_email",
                                                            "private_key",
                                                        ],
                                                        "type": "object",
                                                    }
                                                ],
                                            },
                                            "type": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`GCPIntegrationType` "
                                                "object.",
                                                "enum": ["GCP"],
                                                "example": "GCP",
                                                "type": "string",
                                                "x-enum-varnames": ["GCP"],
                                            },
                                        },
                                        "required": ["type", "credentials"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "The "
                                        "definition "
                                        "of "
                                        "the "
                                        "`GeminiIntegration` "
                                        "object.",
                                        "properties": {
                                            "credentials": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`GeminiCredentials` "
                                                "object.",
                                                "oneOf": [
                                                    {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "the "
                                                        "`GeminiAPIKey` "
                                                        "object.",
                                                        "properties": {
                                                            "api_key": {
                                                                "description": "The "
                                                                "`GeminiAPIKey` "
                                                                "`api_key`.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                            "type": {
                                                                "description": "The "
                                                                "definition "
                                                                "of "
                                                                "the "
                                                                "`GeminiAPIKey` "
                                                                "object.",
                                                                "enum": ["GeminiAPIKey"],
                                                                "example": "GeminiAPIKey",
                                                                "type": "string",
                                                                "x-enum-varnames": ["GEMINIAPIKEY"],
                                                            },
                                                        },
                                                        "required": ["type", "api_key"],
                                                        "type": "object",
                                                    }
                                                ],
                                            },
                                            "type": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`GeminiIntegrationType` "
                                                "object.",
                                                "enum": ["Gemini"],
                                                "example": "Gemini",
                                                "type": "string",
                                                "x-enum-varnames": ["GEMINI"],
                                            },
                                        },
                                        "required": ["type", "credentials"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "The "
                                        "definition "
                                        "of "
                                        "the "
                                        "`GitlabIntegration` "
                                        "object.",
                                        "properties": {
                                            "credentials": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`GitlabCredentials` "
                                                "object.",
                                                "oneOf": [
                                                    {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "the "
                                                        "`GitlabAPIKey` "
                                                        "object.",
                                                        "properties": {
                                                            "api_token": {
                                                                "description": "The "
                                                                "`GitlabAPIKey` "
                                                                "`api_token`.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                            "type": {
                                                                "description": "The "
                                                                "definition "
                                                                "of "
                                                                "the "
                                                                "`GitlabAPIKey` "
                                                                "object.",
                                                                "enum": ["GitlabAPIKey"],
                                                                "example": "GitlabAPIKey",
                                                                "type": "string",
                                                                "x-enum-varnames": ["GITLABAPIKEY"],
                                                            },
                                                        },
                                                        "required": ["type", "api_token"],
                                                        "type": "object",
                                                    }
                                                ],
                                            },
                                            "type": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`GitlabIntegrationType` "
                                                "object.",
                                                "enum": ["Gitlab"],
                                                "example": "Gitlab",
                                                "type": "string",
                                                "x-enum-varnames": ["GITLAB"],
                                            },
                                        },
                                        "required": ["type", "credentials"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "The "
                                        "definition "
                                        "of "
                                        "the "
                                        "`GreyNoiseIntegration` "
                                        "object.",
                                        "properties": {
                                            "credentials": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`GreyNoiseCredentials` "
                                                "object.",
                                                "oneOf": [
                                                    {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "the "
                                                        "`GreyNoiseAPIKey` "
                                                        "object.",
                                                        "properties": {
                                                            "api_key": {
                                                                "description": "The "
                                                                "`GreyNoiseAPIKey` "
                                                                "`api_key`.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                            "type": {
                                                                "description": "The "
                                                                "definition "
                                                                "of "
                                                                "the "
                                                                "`GreyNoiseAPIKey` "
                                                                "object.",
                                                                "enum": ["GreyNoiseAPIKey"],
                                                                "example": "GreyNoiseAPIKey",
                                                                "type": "string",
                                                                "x-enum-varnames": [
                                                                    "GREYNOISEAPIKEY"
                                                                ],
                                                            },
                                                        },
                                                        "required": ["type", "api_key"],
                                                        "type": "object",
                                                    }
                                                ],
                                            },
                                            "type": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`GreyNoiseIntegrationType` "
                                                "object.",
                                                "enum": ["GreyNoise"],
                                                "example": "GreyNoise",
                                                "type": "string",
                                                "x-enum-varnames": ["GREYNOISE"],
                                            },
                                        },
                                        "required": ["type", "credentials"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "The "
                                        "definition "
                                        "of "
                                        "`HTTPIntegration` "
                                        "object.",
                                        "properties": {
                                            "base_url": {
                                                "description": "Base HTTP url for the integration",
                                                "example": "http://datadoghq.com",
                                                "type": "string",
                                            },
                                            "credentials": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "`HTTPCredentials` "
                                                "object.",
                                                "oneOf": [
                                                    {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "`HTTPTokenAuth` "
                                                        "object.",
                                                        "properties": {
                                                            "body": {
                                                                "description": "The "
                                                                "definition "
                                                                "of "
                                                                "`HTTPBody` "
                                                                "object.",
                                                                "properties": {
                                                                    "content": {
                                                                        "description": "Serialized "
                                                                        "body "
                                                                        "content",
                                                                        "example": '{"some-json": '
                                                                        '"with-value"}',
                                                                        "type": "string",
                                                                    },
                                                                    "content_type": {
                                                                        "description": "Content "
                                                                        "type "
                                                                        "of "
                                                                        "the "
                                                                        "body",
                                                                        "example": "application/json",
                                                                        "type": "string",
                                                                    },
                                                                },
                                                                "type": "object",
                                                            },
                                                            "headers": {
                                                                "description": "The "
                                                                "`HTTPTokenAuth` "
                                                                "`headers`.",
                                                                "items": {
                                                                    "description": "The "
                                                                    "definition "
                                                                    "of "
                                                                    "`HTTPHeader` "
                                                                    "object.",
                                                                    "properties": {
                                                                        "name": {
                                                                            "description": "The "
                                                                            "`HTTPHeader` "
                                                                            "`name`.",
                                                                            "example": "MyHttpHeader",
                                                                            "pattern": "^[A-Za-z][A-Za-z\\\\d\\\\-\\\\_]*$",
                                                                            "type": "string",
                                                                        },
                                                                        "value": {
                                                                            "description": "The "
                                                                            "`HTTPHeader` "
                                                                            "`value`.",
                                                                            "example": "Some "
                                                                            "header "
                                                                            "value",
                                                                            "type": "string",
                                                                        },
                                                                    },
                                                                    "required": ["name", "value"],
                                                                    "type": "object",
                                                                },
                                                                "type": "array",
                                                            },
                                                            "tokens": {
                                                                "description": "The "
                                                                "`HTTPTokenAuth` "
                                                                "`tokens`.",
                                                                "items": {
                                                                    "description": "The "
                                                                    "definition "
                                                                    "of "
                                                                    "`HTTPToken` "
                                                                    "object.",
                                                                    "properties": {
                                                                        "name": {
                                                                            "description": "The "
                                                                            "`HTTPToken` "
                                                                            "`name`.",
                                                                            "example": "MyToken",
                                                                            "pattern": "^[A-Za-z][A-Za-z\\\\d]*$",
                                                                            "type": "string",
                                                                        },
                                                                        "type": {
                                                                            "description": "The "
                                                                            "definition "
                                                                            "of "
                                                                            "`TokenType` "
                                                                            "object.",
                                                                            "enum": ["SECRET"],
                                                                            "example": "SECRET",
                                                                            "type": "string",
                                                                            "x-enum-varnames": [
                                                                                "SECRET"
                                                                            ],
                                                                        },
                                                                        "value": {
                                                                            "description": "The "
                                                                            "`HTTPToken` "
                                                                            "`value`.",
                                                                            "example": "Some "
                                                                            "Token "
                                                                            "Value",
                                                                            "type": "string",
                                                                        },
                                                                    },
                                                                    "required": [
                                                                        "name",
                                                                        "value",
                                                                        "type",
                                                                    ],
                                                                    "type": "object",
                                                                },
                                                                "type": "array",
                                                            },
                                                            "type": {
                                                                "description": "The "
                                                                "definition "
                                                                "of "
                                                                "`HTTPTokenAuthType` "
                                                                "object.",
                                                                "enum": ["HTTPTokenAuth"],
                                                                "example": "HTTPTokenAuth",
                                                                "type": "string",
                                                                "x-enum-varnames": [
                                                                    "HTTPTOKENAUTH"
                                                                ],
                                                            },
                                                            "url_parameters": {
                                                                "description": "The "
                                                                "`HTTPTokenAuth` "
                                                                "`url_parameters`.",
                                                                "items": {
                                                                    "description": "The "
                                                                    "definition "
                                                                    "of "
                                                                    "`UrlParam` "
                                                                    "object.",
                                                                    "properties": {
                                                                        "name": {
                                                                            "description": "Name "
                                                                            "for "
                                                                            "tokens.",
                                                                            "example": "MyTokenName",
                                                                            "pattern": "^[A-Za-z][A-Za-z\\\\d]*$",
                                                                            "type": "string",
                                                                        },
                                                                        "value": {
                                                                            "description": "The "
                                                                            "`UrlParam` "
                                                                            "`value`.",
                                                                            "example": "Some "
                                                                            "Url "
                                                                            "Parameter "
                                                                            "value",
                                                                            "type": "string",
                                                                        },
                                                                    },
                                                                    "required": ["name", "value"],
                                                                    "type": "object",
                                                                },
                                                                "type": "array",
                                                            },
                                                        },
                                                        "required": ["type"],
                                                        "type": "object",
                                                    }
                                                ],
                                            },
                                            "type": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "`HTTPIntegrationType` "
                                                "object.",
                                                "enum": ["HTTP"],
                                                "example": "HTTP",
                                                "type": "string",
                                                "x-enum-varnames": ["HTTP"],
                                            },
                                        },
                                        "required": ["type", "base_url", "credentials"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "The "
                                        "definition "
                                        "of "
                                        "the "
                                        "`LaunchDarklyIntegration` "
                                        "object.",
                                        "properties": {
                                            "credentials": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`LaunchDarklyCredentials` "
                                                "object.",
                                                "oneOf": [
                                                    {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "the "
                                                        "`LaunchDarklyAPIKey` "
                                                        "object.",
                                                        "properties": {
                                                            "api_token": {
                                                                "description": "The "
                                                                "`LaunchDarklyAPIKey` "
                                                                "`api_token`.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                            "type": {
                                                                "description": "The "
                                                                "definition "
                                                                "of "
                                                                "the "
                                                                "`LaunchDarklyAPIKey` "
                                                                "object.",
                                                                "enum": ["LaunchDarklyAPIKey"],
                                                                "example": "LaunchDarklyAPIKey",
                                                                "type": "string",
                                                                "x-enum-varnames": [
                                                                    "LAUNCHDARKLYAPIKEY"
                                                                ],
                                                            },
                                                        },
                                                        "required": ["type", "api_token"],
                                                        "type": "object",
                                                    }
                                                ],
                                            },
                                            "type": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`LaunchDarklyIntegrationType` "
                                                "object.",
                                                "enum": ["LaunchDarkly"],
                                                "example": "LaunchDarkly",
                                                "type": "string",
                                                "x-enum-varnames": ["LAUNCHDARKLY"],
                                            },
                                        },
                                        "required": ["type", "credentials"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "The "
                                        "definition "
                                        "of "
                                        "the "
                                        "`NotionIntegration` "
                                        "object.",
                                        "properties": {
                                            "credentials": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`NotionCredentials` "
                                                "object.",
                                                "oneOf": [
                                                    {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "the "
                                                        "`NotionAPIKey` "
                                                        "object.",
                                                        "properties": {
                                                            "api_token": {
                                                                "description": "The "
                                                                "`NotionAPIKey` "
                                                                "`api_token`.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                            "type": {
                                                                "description": "The "
                                                                "definition "
                                                                "of "
                                                                "the "
                                                                "`NotionAPIKey` "
                                                                "object.",
                                                                "enum": ["NotionAPIKey"],
                                                                "example": "NotionAPIKey",
                                                                "type": "string",
                                                                "x-enum-varnames": ["NOTIONAPIKEY"],
                                                            },
                                                        },
                                                        "required": ["type", "api_token"],
                                                        "type": "object",
                                                    }
                                                ],
                                            },
                                            "type": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`NotionIntegrationType` "
                                                "object.",
                                                "enum": ["Notion"],
                                                "example": "Notion",
                                                "type": "string",
                                                "x-enum-varnames": ["NOTION"],
                                            },
                                        },
                                        "required": ["type", "credentials"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "The "
                                        "definition "
                                        "of "
                                        "the "
                                        "`OktaIntegration` "
                                        "object.",
                                        "properties": {
                                            "credentials": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`OktaCredentials` "
                                                "object.",
                                                "oneOf": [
                                                    {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "the "
                                                        "`OktaAPIToken` "
                                                        "object.",
                                                        "properties": {
                                                            "api_token": {
                                                                "description": "The "
                                                                "`OktaAPIToken` "
                                                                "`api_token`.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                            "domain": {
                                                                "description": "The "
                                                                "`OktaAPIToken` "
                                                                "`domain`.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                            "type": {
                                                                "description": "The "
                                                                "definition "
                                                                "of "
                                                                "the "
                                                                "`OktaAPIToken` "
                                                                "object.",
                                                                "enum": ["OktaAPIToken"],
                                                                "example": "OktaAPIToken",
                                                                "type": "string",
                                                                "x-enum-varnames": ["OKTAAPITOKEN"],
                                                            },
                                                        },
                                                        "required": ["type", "domain", "api_token"],
                                                        "type": "object",
                                                    }
                                                ],
                                            },
                                            "type": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`OktaIntegrationType` "
                                                "object.",
                                                "enum": ["Okta"],
                                                "example": "Okta",
                                                "type": "string",
                                                "x-enum-varnames": ["OKTA"],
                                            },
                                        },
                                        "required": ["type", "credentials"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "The "
                                        "definition "
                                        "of "
                                        "the "
                                        "`OpenAIIntegration` "
                                        "object.",
                                        "properties": {
                                            "credentials": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`OpenAICredentials` "
                                                "object.",
                                                "oneOf": [
                                                    {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "the "
                                                        "`OpenAIAPIKey` "
                                                        "object.",
                                                        "properties": {
                                                            "api_token": {
                                                                "description": "The "
                                                                "`OpenAIAPIKey` "
                                                                "`api_token`.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                            "type": {
                                                                "description": "The "
                                                                "definition "
                                                                "of "
                                                                "the "
                                                                "`OpenAIAPIKey` "
                                                                "object.",
                                                                "enum": ["OpenAIAPIKey"],
                                                                "example": "OpenAIAPIKey",
                                                                "type": "string",
                                                                "x-enum-varnames": ["OPENAIAPIKEY"],
                                                            },
                                                        },
                                                        "required": ["type", "api_token"],
                                                        "type": "object",
                                                    }
                                                ],
                                            },
                                            "type": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`OpenAIIntegrationType` "
                                                "object.",
                                                "enum": ["OpenAI"],
                                                "example": "OpenAI",
                                                "type": "string",
                                                "x-enum-varnames": ["OPENAI"],
                                            },
                                        },
                                        "required": ["type", "credentials"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "The "
                                        "definition "
                                        "of "
                                        "the "
                                        "`ServiceNowIntegration` "
                                        "object.",
                                        "properties": {
                                            "credentials": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`ServiceNowCredentials` "
                                                "object.",
                                                "oneOf": [
                                                    {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "the "
                                                        "`ServiceNowBasicAuth` "
                                                        "object.",
                                                        "properties": {
                                                            "instance": {
                                                                "description": "The "
                                                                "`ServiceNowBasicAuth` "
                                                                "`instance`.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                            "password": {
                                                                "description": "The "
                                                                "`ServiceNowBasicAuth` "
                                                                "`password`.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                            "type": {
                                                                "description": "The "
                                                                "definition "
                                                                "of "
                                                                "the "
                                                                "`ServiceNowBasicAuth` "
                                                                "object.",
                                                                "enum": ["ServiceNowBasicAuth"],
                                                                "example": "ServiceNowBasicAuth",
                                                                "type": "string",
                                                                "x-enum-varnames": [
                                                                    "SERVICENOWBASICAUTH"
                                                                ],
                                                            },
                                                            "username": {
                                                                "description": "The "
                                                                "`ServiceNowBasicAuth` "
                                                                "`username`.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                        },
                                                        "required": [
                                                            "type",
                                                            "instance",
                                                            "username",
                                                            "password",
                                                        ],
                                                        "type": "object",
                                                    }
                                                ],
                                            },
                                            "type": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`ServiceNowIntegrationType` "
                                                "object.",
                                                "enum": ["ServiceNow"],
                                                "example": "ServiceNow",
                                                "type": "string",
                                                "x-enum-varnames": ["SERVICENOW"],
                                            },
                                        },
                                        "required": ["type", "credentials"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "The "
                                        "definition "
                                        "of "
                                        "the "
                                        "`SplitIntegration` "
                                        "object.",
                                        "properties": {
                                            "credentials": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`SplitCredentials` "
                                                "object.",
                                                "oneOf": [
                                                    {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "the "
                                                        "`SplitAPIKey` "
                                                        "object.",
                                                        "properties": {
                                                            "api_key": {
                                                                "description": "The "
                                                                "`SplitAPIKey` "
                                                                "`api_key`.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                            "type": {
                                                                "description": "The "
                                                                "definition "
                                                                "of "
                                                                "the "
                                                                "`SplitAPIKey` "
                                                                "object.",
                                                                "enum": ["SplitAPIKey"],
                                                                "example": "SplitAPIKey",
                                                                "type": "string",
                                                                "x-enum-varnames": ["SPLITAPIKEY"],
                                                            },
                                                        },
                                                        "required": ["type", "api_key"],
                                                        "type": "object",
                                                    }
                                                ],
                                            },
                                            "type": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`SplitIntegrationType` "
                                                "object.",
                                                "enum": ["Split"],
                                                "example": "Split",
                                                "type": "string",
                                                "x-enum-varnames": ["SPLIT"],
                                            },
                                        },
                                        "required": ["type", "credentials"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "The "
                                        "definition "
                                        "of "
                                        "the "
                                        "`StatsigIntegration` "
                                        "object.",
                                        "properties": {
                                            "credentials": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`StatsigCredentials` "
                                                "object.",
                                                "oneOf": [
                                                    {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "the "
                                                        "`StatsigAPIKey` "
                                                        "object.",
                                                        "properties": {
                                                            "api_key": {
                                                                "description": "The "
                                                                "`StatsigAPIKey` "
                                                                "`api_key`.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                            "type": {
                                                                "description": "The "
                                                                "definition "
                                                                "of "
                                                                "the "
                                                                "`StatsigAPIKey` "
                                                                "object.",
                                                                "enum": ["StatsigAPIKey"],
                                                                "example": "StatsigAPIKey",
                                                                "type": "string",
                                                                "x-enum-varnames": [
                                                                    "STATSIGAPIKEY"
                                                                ],
                                                            },
                                                        },
                                                        "required": ["type", "api_key"],
                                                        "type": "object",
                                                    }
                                                ],
                                            },
                                            "type": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`StatsigIntegrationType` "
                                                "object.",
                                                "enum": ["Statsig"],
                                                "example": "Statsig",
                                                "type": "string",
                                                "x-enum-varnames": ["STATSIG"],
                                            },
                                        },
                                        "required": ["type", "credentials"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "The "
                                        "definition "
                                        "of "
                                        "the "
                                        "`VirusTotalIntegration` "
                                        "object.",
                                        "properties": {
                                            "credentials": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`VirusTotalCredentials` "
                                                "object.",
                                                "oneOf": [
                                                    {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "the "
                                                        "`VirusTotalAPIKey` "
                                                        "object.",
                                                        "properties": {
                                                            "api_key": {
                                                                "description": "The "
                                                                "`VirusTotalAPIKey` "
                                                                "`api_key`.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                            "type": {
                                                                "description": "The "
                                                                "definition "
                                                                "of "
                                                                "the "
                                                                "`VirusTotalAPIKey` "
                                                                "object.",
                                                                "enum": ["VirusTotalAPIKey"],
                                                                "example": "VirusTotalAPIKey",
                                                                "type": "string",
                                                                "x-enum-varnames": [
                                                                    "VIRUSTOTALAPIKEY"
                                                                ],
                                                            },
                                                        },
                                                        "required": ["type", "api_key"],
                                                        "type": "object",
                                                    }
                                                ],
                                            },
                                            "type": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`VirusTotalIntegrationType` "
                                                "object.",
                                                "enum": ["VirusTotal"],
                                                "example": "VirusTotal",
                                                "type": "string",
                                                "x-enum-varnames": ["VIRUSTOTAL"],
                                            },
                                        },
                                        "required": ["type", "credentials"],
                                        "type": "object",
                                    },
                                ],
                            },
                            "name": {
                                "description": "Name of the connection",
                                "example": "My AWS Connection",
                                "type": "string",
                            },
                        },
                        "required": ["name", "integration"],
                        "type": "object",
                    },
                    "id": {
                        "description": "The connection identifier",
                        "readOnly": True,
                        "type": "string",
                    },
                    "type": {
                        "description": "The definition of `ActionConnectionDataType` object.",
                        "enum": ["action_connection"],
                        "example": "action_connection",
                        "type": "string",
                        "x-enum-varnames": ["ACTION_CONNECTION"],
                    },
                },
                "required": ["type", "attributes"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "UPDATEACTIONCONNECTION_REQUEST_BODY_SCHEMA": {
        "description": "Request used to update an action connection.",
        "properties": {
            "data": {
                "description": "Data related to the connection update.",
                "properties": {
                    "attributes": {
                        "description": "The definition "
                        "of "
                        "`ActionConnectionAttributesUpdate` "
                        "object.",
                        "properties": {
                            "integration": {
                                "description": "The "
                                "definition "
                                "of "
                                "`ActionConnectionIntegrationUpdate` "
                                "object.",
                                "oneOf": [
                                    {
                                        "description": "The "
                                        "definition "
                                        "of "
                                        "`AWSIntegrationUpdate` "
                                        "object.",
                                        "properties": {
                                            "credentials": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "`AWSCredentialsUpdate` "
                                                "object.",
                                                "oneOf": [
                                                    {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "`AWSAssumeRoleUpdate` "
                                                        "object.",
                                                        "properties": {
                                                            "account_id": {
                                                                "description": "AWS "
                                                                "account "
                                                                "the "
                                                                "connection "
                                                                "is "
                                                                "created "
                                                                "for",
                                                                "example": "111222333444",
                                                                "pattern": "^\\d{12}$",
                                                                "type": "string",
                                                            },
                                                            "generate_new_external_id": {
                                                                "description": "The "
                                                                "`AWSAssumeRoleUpdate` "
                                                                "`generate_new_external_id`.",
                                                                "type": "boolean",
                                                            },
                                                            "role": {
                                                                "description": "Role to assume",
                                                                "example": "my-role",
                                                                "type": "string",
                                                            },
                                                            "type": {
                                                                "description": "The "
                                                                "definition "
                                                                "of "
                                                                "`AWSAssumeRoleType` "
                                                                "object.",
                                                                "enum": ["AWSAssumeRole"],
                                                                "example": "AWSAssumeRole",
                                                                "type": "string",
                                                                "x-enum-varnames": [
                                                                    "AWSASSUMEROLE"
                                                                ],
                                                            },
                                                        },
                                                        "required": ["type"],
                                                        "type": "object",
                                                    }
                                                ],
                                            },
                                            "type": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "`AWSIntegrationType` "
                                                "object.",
                                                "enum": ["AWS"],
                                                "example": "AWS",
                                                "type": "string",
                                                "x-enum-varnames": ["AWS"],
                                            },
                                        },
                                        "required": ["type"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "The "
                                        "definition "
                                        "of "
                                        "the "
                                        "`AnthropicIntegrationUpdate` "
                                        "object.",
                                        "properties": {
                                            "credentials": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`AnthropicCredentialsUpdate` "
                                                "object.",
                                                "oneOf": [
                                                    {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "the "
                                                        "`AnthropicAPIKey` "
                                                        "object.",
                                                        "properties": {
                                                            "api_token": {
                                                                "description": "The "
                                                                "`AnthropicAPIKeyUpdate` "
                                                                "`api_token`.",
                                                                "type": "string",
                                                            },
                                                            "type": {
                                                                "description": "The "
                                                                "definition "
                                                                "of "
                                                                "the "
                                                                "`AnthropicAPIKey` "
                                                                "object.",
                                                                "enum": ["AnthropicAPIKey"],
                                                                "example": "AnthropicAPIKey",
                                                                "type": "string",
                                                                "x-enum-varnames": [
                                                                    "ANTHROPICAPIKEY"
                                                                ],
                                                            },
                                                        },
                                                        "required": ["type"],
                                                        "type": "object",
                                                    }
                                                ],
                                            },
                                            "type": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`AnthropicIntegrationType` "
                                                "object.",
                                                "enum": ["Anthropic"],
                                                "example": "Anthropic",
                                                "type": "string",
                                                "x-enum-varnames": ["ANTHROPIC"],
                                            },
                                        },
                                        "required": ["type"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "The "
                                        "definition "
                                        "of "
                                        "the "
                                        "`AsanaIntegrationUpdate` "
                                        "object.",
                                        "properties": {
                                            "credentials": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`AsanaCredentialsUpdate` "
                                                "object.",
                                                "oneOf": [
                                                    {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "the "
                                                        "`AsanaAccessToken` "
                                                        "object.",
                                                        "properties": {
                                                            "access_token": {
                                                                "description": "The "
                                                                "`AsanaAccessTokenUpdate` "
                                                                "`access_token`.",
                                                                "type": "string",
                                                            },
                                                            "type": {
                                                                "description": "The "
                                                                "definition "
                                                                "of "
                                                                "the "
                                                                "`AsanaAccessToken` "
                                                                "object.",
                                                                "enum": ["AsanaAccessToken"],
                                                                "example": "AsanaAccessToken",
                                                                "type": "string",
                                                                "x-enum-varnames": [
                                                                    "ASANAACCESSTOKEN"
                                                                ],
                                                            },
                                                        },
                                                        "required": ["type"],
                                                        "type": "object",
                                                    }
                                                ],
                                            },
                                            "type": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`AsanaIntegrationType` "
                                                "object.",
                                                "enum": ["Asana"],
                                                "example": "Asana",
                                                "type": "string",
                                                "x-enum-varnames": ["ASANA"],
                                            },
                                        },
                                        "required": ["type"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "The "
                                        "definition "
                                        "of "
                                        "the "
                                        "`AzureIntegrationUpdate` "
                                        "object.",
                                        "properties": {
                                            "credentials": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`AzureCredentialsUpdate` "
                                                "object.",
                                                "oneOf": [
                                                    {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "the "
                                                        "`AzureTenant` "
                                                        "object.",
                                                        "properties": {
                                                            "app_client_id": {
                                                                "description": "The "
                                                                "Client "
                                                                "ID, "
                                                                "also "
                                                                "known "
                                                                "as "
                                                                "the "
                                                                "Application "
                                                                "ID "
                                                                "in "
                                                                "Azure, "
                                                                "is "
                                                                "a "
                                                                "unique "
                                                                "identifier "
                                                                "for "
                                                                "an "
                                                                "application. "
                                                                "It's "
                                                                "used "
                                                                "to "
                                                                "identify "
                                                                "the "
                                                                "application "
                                                                "during "
                                                                "the "
                                                                "authentication "
                                                                "process. "
                                                                "Your "
                                                                "Application "
                                                                "(client) "
                                                                "ID "
                                                                "is "
                                                                "listed "
                                                                "in "
                                                                "the "
                                                                "application's "
                                                                "overview "
                                                                "page. "
                                                                "You "
                                                                "can "
                                                                "navigate "
                                                                "to "
                                                                "your "
                                                                "application "
                                                                "via "
                                                                "the "
                                                                "Azure "
                                                                "Directory. ",
                                                                "type": "string",
                                                            },
                                                            "client_secret": {
                                                                "description": "The "
                                                                "Client "
                                                                "Secret "
                                                                "is "
                                                                "a "
                                                                "confidential "
                                                                "piece "
                                                                "of "
                                                                "information "
                                                                "known "
                                                                "only "
                                                                "to "
                                                                "the "
                                                                "application "
                                                                "and "
                                                                "Azure "
                                                                "AD. "
                                                                "It's "
                                                                "used "
                                                                "to "
                                                                "prove "
                                                                "the "
                                                                "application's "
                                                                "identity. "
                                                                "Your "
                                                                "Client "
                                                                "Secret "
                                                                "is "
                                                                "available "
                                                                "from "
                                                                "the "
                                                                "application’s "
                                                                "secrets "
                                                                "page. "
                                                                "You "
                                                                "can "
                                                                "navigate "
                                                                "to "
                                                                "your "
                                                                "application "
                                                                "via "
                                                                "the "
                                                                "Azure "
                                                                "Directory.",
                                                                "type": "string",
                                                            },
                                                            "custom_scopes": {
                                                                "description": "If "
                                                                "provided, "
                                                                "the "
                                                                "custom "
                                                                "scope "
                                                                "to "
                                                                "be "
                                                                "requested "
                                                                "from "
                                                                "Microsoft "
                                                                "when "
                                                                "acquiring "
                                                                "an "
                                                                "OAuth "
                                                                "2 "
                                                                "access "
                                                                "token. "
                                                                "This "
                                                                "custom "
                                                                "scope "
                                                                "is "
                                                                "used "
                                                                "only "
                                                                "in "
                                                                "conjunction "
                                                                "with "
                                                                "the "
                                                                "HTTP "
                                                                "action. "
                                                                "A "
                                                                "resource's "
                                                                "scope "
                                                                "is "
                                                                "constructed "
                                                                "by "
                                                                "using "
                                                                "the "
                                                                "identifier "
                                                                "URI "
                                                                "for "
                                                                "the "
                                                                "resource "
                                                                "and "
                                                                ".default, "
                                                                "separated "
                                                                "by "
                                                                "a "
                                                                "forward "
                                                                "slash "
                                                                "(/) "
                                                                "as "
                                                                "follows:{identifierURI}/.default.",
                                                                "type": "string",
                                                            },
                                                            "tenant_id": {
                                                                "description": "The "
                                                                "Tenant "
                                                                "ID, "
                                                                "also "
                                                                "known "
                                                                "as "
                                                                "the "
                                                                "Directory "
                                                                "ID "
                                                                "in "
                                                                "Azure, "
                                                                "is "
                                                                "a "
                                                                "unique "
                                                                "identifier "
                                                                "that "
                                                                "represents "
                                                                "an "
                                                                "Azure "
                                                                "AD "
                                                                "instance. "
                                                                "Your "
                                                                "Tenant "
                                                                "ID "
                                                                "(Directory "
                                                                "ID) "
                                                                "is "
                                                                "listed "
                                                                "in "
                                                                "your "
                                                                "Active "
                                                                "Directory "
                                                                "overview "
                                                                "page "
                                                                "under "
                                                                "the "
                                                                "'Tenant "
                                                                "information' "
                                                                "section.",
                                                                "type": "string",
                                                            },
                                                            "type": {
                                                                "description": "The "
                                                                "definition "
                                                                "of "
                                                                "the "
                                                                "`AzureTenant` "
                                                                "object.",
                                                                "enum": ["AzureTenant"],
                                                                "example": "AzureTenant",
                                                                "type": "string",
                                                                "x-enum-varnames": ["AZURETENANT"],
                                                            },
                                                        },
                                                        "required": ["type"],
                                                        "type": "object",
                                                    }
                                                ],
                                            },
                                            "type": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`AzureIntegrationType` "
                                                "object.",
                                                "enum": ["Azure"],
                                                "example": "Azure",
                                                "type": "string",
                                                "x-enum-varnames": ["AZURE"],
                                            },
                                        },
                                        "required": ["type"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "The "
                                        "definition "
                                        "of "
                                        "the "
                                        "`CircleCIIntegrationUpdate` "
                                        "object.",
                                        "properties": {
                                            "credentials": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`CircleCICredentialsUpdate` "
                                                "object.",
                                                "oneOf": [
                                                    {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "the "
                                                        "`CircleCIAPIKey` "
                                                        "object.",
                                                        "properties": {
                                                            "api_token": {
                                                                "description": "The "
                                                                "`CircleCIAPIKeyUpdate` "
                                                                "`api_token`.",
                                                                "type": "string",
                                                            },
                                                            "type": {
                                                                "description": "The "
                                                                "definition "
                                                                "of "
                                                                "the "
                                                                "`CircleCIAPIKey` "
                                                                "object.",
                                                                "enum": ["CircleCIAPIKey"],
                                                                "example": "CircleCIAPIKey",
                                                                "type": "string",
                                                                "x-enum-varnames": [
                                                                    "CIRCLECIAPIKEY"
                                                                ],
                                                            },
                                                        },
                                                        "required": ["type"],
                                                        "type": "object",
                                                    }
                                                ],
                                            },
                                            "type": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`CircleCIIntegrationType` "
                                                "object.",
                                                "enum": ["CircleCI"],
                                                "example": "CircleCI",
                                                "type": "string",
                                                "x-enum-varnames": ["CIRCLECI"],
                                            },
                                        },
                                        "required": ["type"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "The "
                                        "definition "
                                        "of "
                                        "the "
                                        "`ClickupIntegrationUpdate` "
                                        "object.",
                                        "properties": {
                                            "credentials": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`ClickupCredentialsUpdate` "
                                                "object.",
                                                "oneOf": [
                                                    {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "the "
                                                        "`ClickupAPIKey` "
                                                        "object.",
                                                        "properties": {
                                                            "api_token": {
                                                                "description": "The "
                                                                "`ClickupAPIKeyUpdate` "
                                                                "`api_token`.",
                                                                "type": "string",
                                                            },
                                                            "type": {
                                                                "description": "The "
                                                                "definition "
                                                                "of "
                                                                "the "
                                                                "`ClickupAPIKey` "
                                                                "object.",
                                                                "enum": ["ClickupAPIKey"],
                                                                "example": "ClickupAPIKey",
                                                                "type": "string",
                                                                "x-enum-varnames": [
                                                                    "CLICKUPAPIKEY"
                                                                ],
                                                            },
                                                        },
                                                        "required": ["type"],
                                                        "type": "object",
                                                    }
                                                ],
                                            },
                                            "type": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`ClickupIntegrationType` "
                                                "object.",
                                                "enum": ["Clickup"],
                                                "example": "Clickup",
                                                "type": "string",
                                                "x-enum-varnames": ["CLICKUP"],
                                            },
                                        },
                                        "required": ["type"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "The "
                                        "definition "
                                        "of "
                                        "the "
                                        "`CloudflareIntegrationUpdate` "
                                        "object.",
                                        "properties": {
                                            "credentials": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`CloudflareCredentialsUpdate` "
                                                "object.",
                                                "oneOf": [
                                                    {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "the "
                                                        "`CloudflareAPIToken` "
                                                        "object.",
                                                        "properties": {
                                                            "api_token": {
                                                                "description": "The "
                                                                "`CloudflareAPITokenUpdate` "
                                                                "`api_token`.",
                                                                "type": "string",
                                                            },
                                                            "type": {
                                                                "description": "The "
                                                                "definition "
                                                                "of "
                                                                "the "
                                                                "`CloudflareAPIToken` "
                                                                "object.",
                                                                "enum": ["CloudflareAPIToken"],
                                                                "example": "CloudflareAPIToken",
                                                                "type": "string",
                                                                "x-enum-varnames": [
                                                                    "CLOUDFLAREAPITOKEN"
                                                                ],
                                                            },
                                                        },
                                                        "required": ["type"],
                                                        "type": "object",
                                                    },
                                                    {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "the "
                                                        "`CloudflareGlobalAPIToken` "
                                                        "object.",
                                                        "properties": {
                                                            "auth_email": {
                                                                "description": "The "
                                                                "`CloudflareGlobalAPITokenUpdate` "
                                                                "`auth_email`.",
                                                                "type": "string",
                                                            },
                                                            "global_api_key": {
                                                                "description": "The "
                                                                "`CloudflareGlobalAPITokenUpdate` "
                                                                "`global_api_key`.",
                                                                "type": "string",
                                                            },
                                                            "type": {
                                                                "description": "The "
                                                                "definition "
                                                                "of "
                                                                "the "
                                                                "`CloudflareGlobalAPIToken` "
                                                                "object.",
                                                                "enum": [
                                                                    "CloudflareGlobalAPIToken"
                                                                ],
                                                                "example": "CloudflareGlobalAPIToken",
                                                                "type": "string",
                                                                "x-enum-varnames": [
                                                                    "CLOUDFLAREGLOBALAPITOKEN"
                                                                ],
                                                            },
                                                        },
                                                        "required": ["type"],
                                                        "type": "object",
                                                    },
                                                ],
                                            },
                                            "type": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`CloudflareIntegrationType` "
                                                "object.",
                                                "enum": ["Cloudflare"],
                                                "example": "Cloudflare",
                                                "type": "string",
                                                "x-enum-varnames": ["CLOUDFLARE"],
                                            },
                                        },
                                        "required": ["type"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "The "
                                        "definition "
                                        "of "
                                        "the "
                                        "`ConfigCatIntegrationUpdate` "
                                        "object.",
                                        "properties": {
                                            "credentials": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`ConfigCatCredentialsUpdate` "
                                                "object.",
                                                "oneOf": [
                                                    {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "the "
                                                        "`ConfigCatSDKKey` "
                                                        "object.",
                                                        "properties": {
                                                            "api_password": {
                                                                "description": "The "
                                                                "`ConfigCatSDKKeyUpdate` "
                                                                "`api_password`.",
                                                                "type": "string",
                                                            },
                                                            "api_username": {
                                                                "description": "The "
                                                                "`ConfigCatSDKKeyUpdate` "
                                                                "`api_username`.",
                                                                "type": "string",
                                                            },
                                                            "sdk_key": {
                                                                "description": "The "
                                                                "`ConfigCatSDKKeyUpdate` "
                                                                "`sdk_key`.",
                                                                "type": "string",
                                                            },
                                                            "type": {
                                                                "description": "The "
                                                                "definition "
                                                                "of "
                                                                "the "
                                                                "`ConfigCatSDKKey` "
                                                                "object.",
                                                                "enum": ["ConfigCatSDKKey"],
                                                                "example": "ConfigCatSDKKey",
                                                                "type": "string",
                                                                "x-enum-varnames": [
                                                                    "CONFIGCATSDKKEY"
                                                                ],
                                                            },
                                                        },
                                                        "required": ["type"],
                                                        "type": "object",
                                                    }
                                                ],
                                            },
                                            "type": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`ConfigCatIntegrationType` "
                                                "object.",
                                                "enum": ["ConfigCat"],
                                                "example": "ConfigCat",
                                                "type": "string",
                                                "x-enum-varnames": ["CONFIGCAT"],
                                            },
                                        },
                                        "required": ["type"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "The "
                                        "definition "
                                        "of "
                                        "the "
                                        "`DatadogIntegrationUpdate` "
                                        "object.",
                                        "properties": {
                                            "credentials": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`DatadogCredentialsUpdate` "
                                                "object.",
                                                "oneOf": [
                                                    {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "the "
                                                        "`DatadogAPIKey` "
                                                        "object.",
                                                        "properties": {
                                                            "api_key": {
                                                                "description": "The "
                                                                "`DatadogAPIKeyUpdate` "
                                                                "`api_key`.",
                                                                "type": "string",
                                                            },
                                                            "app_key": {
                                                                "description": "The "
                                                                "`DatadogAPIKeyUpdate` "
                                                                "`app_key`.",
                                                                "type": "string",
                                                            },
                                                            "datacenter": {
                                                                "description": "The "
                                                                "`DatadogAPIKeyUpdate` "
                                                                "`datacenter`.",
                                                                "type": "string",
                                                            },
                                                            "subdomain": {
                                                                "description": "Custom "
                                                                "subdomain "
                                                                "used "
                                                                "for "
                                                                "Datadog "
                                                                "URLs "
                                                                "generated "
                                                                "with "
                                                                "this "
                                                                "Connection. "
                                                                "For "
                                                                "example, "
                                                                "if "
                                                                "this "
                                                                "org "
                                                                "uses "
                                                                "`https://acme.datadoghq.com` "
                                                                "to "
                                                                "access "
                                                                "Datadog, "
                                                                "set "
                                                                "this "
                                                                "field "
                                                                "to "
                                                                "`acme`. "
                                                                "If "
                                                                "this "
                                                                "field "
                                                                "is "
                                                                "omitted, "
                                                                "generated "
                                                                "URLs "
                                                                "will "
                                                                "use "
                                                                "the "
                                                                "default "
                                                                "site "
                                                                "URL "
                                                                "for "
                                                                "its "
                                                                "datacenter "
                                                                "(see "
                                                                "[https://docs.datadoghq.com/getting_started/site](https://docs.datadoghq.com/getting_started/site)).",
                                                                "type": "string",
                                                            },
                                                            "type": {
                                                                "description": "The "
                                                                "definition "
                                                                "of "
                                                                "the "
                                                                "`DatadogAPIKey` "
                                                                "object.",
                                                                "enum": ["DatadogAPIKey"],
                                                                "example": "DatadogAPIKey",
                                                                "type": "string",
                                                                "x-enum-varnames": [
                                                                    "DATADOGAPIKEY"
                                                                ],
                                                            },
                                                        },
                                                        "required": ["type"],
                                                        "type": "object",
                                                    }
                                                ],
                                            },
                                            "type": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`DatadogIntegrationType` "
                                                "object.",
                                                "enum": ["Datadog"],
                                                "example": "Datadog",
                                                "type": "string",
                                                "x-enum-varnames": ["DATADOG"],
                                            },
                                        },
                                        "required": ["type"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "The "
                                        "definition "
                                        "of "
                                        "the "
                                        "`FastlyIntegrationUpdate` "
                                        "object.",
                                        "properties": {
                                            "credentials": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`FastlyCredentialsUpdate` "
                                                "object.",
                                                "oneOf": [
                                                    {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "the "
                                                        "`FastlyAPIKey` "
                                                        "object.",
                                                        "properties": {
                                                            "api_key": {
                                                                "description": "The "
                                                                "`FastlyAPIKeyUpdate` "
                                                                "`api_key`.",
                                                                "type": "string",
                                                            },
                                                            "type": {
                                                                "description": "The "
                                                                "definition "
                                                                "of "
                                                                "the "
                                                                "`FastlyAPIKey` "
                                                                "object.",
                                                                "enum": ["FastlyAPIKey"],
                                                                "example": "FastlyAPIKey",
                                                                "type": "string",
                                                                "x-enum-varnames": ["FASTLYAPIKEY"],
                                                            },
                                                        },
                                                        "required": ["type"],
                                                        "type": "object",
                                                    }
                                                ],
                                            },
                                            "type": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`FastlyIntegrationType` "
                                                "object.",
                                                "enum": ["Fastly"],
                                                "example": "Fastly",
                                                "type": "string",
                                                "x-enum-varnames": ["FASTLY"],
                                            },
                                        },
                                        "required": ["type"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "The "
                                        "definition "
                                        "of "
                                        "the "
                                        "`FreshserviceIntegrationUpdate` "
                                        "object.",
                                        "properties": {
                                            "credentials": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`FreshserviceCredentialsUpdate` "
                                                "object.",
                                                "oneOf": [
                                                    {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "the "
                                                        "`FreshserviceAPIKey` "
                                                        "object.",
                                                        "properties": {
                                                            "api_key": {
                                                                "description": "The "
                                                                "`FreshserviceAPIKeyUpdate` "
                                                                "`api_key`.",
                                                                "type": "string",
                                                            },
                                                            "domain": {
                                                                "description": "The "
                                                                "`FreshserviceAPIKeyUpdate` "
                                                                "`domain`.",
                                                                "type": "string",
                                                            },
                                                            "type": {
                                                                "description": "The "
                                                                "definition "
                                                                "of "
                                                                "the "
                                                                "`FreshserviceAPIKey` "
                                                                "object.",
                                                                "enum": ["FreshserviceAPIKey"],
                                                                "example": "FreshserviceAPIKey",
                                                                "type": "string",
                                                                "x-enum-varnames": [
                                                                    "FRESHSERVICEAPIKEY"
                                                                ],
                                                            },
                                                        },
                                                        "required": ["type"],
                                                        "type": "object",
                                                    }
                                                ],
                                            },
                                            "type": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`FreshserviceIntegrationType` "
                                                "object.",
                                                "enum": ["Freshservice"],
                                                "example": "Freshservice",
                                                "type": "string",
                                                "x-enum-varnames": ["FRESHSERVICE"],
                                            },
                                        },
                                        "required": ["type"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "The "
                                        "definition "
                                        "of "
                                        "the "
                                        "`GCPIntegrationUpdate` "
                                        "object.",
                                        "properties": {
                                            "credentials": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`GCPCredentialsUpdate` "
                                                "object.",
                                                "oneOf": [
                                                    {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "the "
                                                        "`GCPServiceAccount` "
                                                        "object.",
                                                        "properties": {
                                                            "private_key": {
                                                                "description": "The "
                                                                "`GCPServiceAccountUpdate` "
                                                                "`private_key`.",
                                                                "type": "string",
                                                            },
                                                            "service_account_email": {
                                                                "description": "The "
                                                                "`GCPServiceAccountUpdate` "
                                                                "`service_account_email`.",
                                                                "type": "string",
                                                            },
                                                            "type": {
                                                                "description": "The "
                                                                "definition "
                                                                "of "
                                                                "the "
                                                                "`GCPServiceAccount` "
                                                                "object.",
                                                                "enum": ["GCPServiceAccount"],
                                                                "example": "GCPServiceAccount",
                                                                "type": "string",
                                                                "x-enum-varnames": [
                                                                    "GCPSERVICEACCOUNT"
                                                                ],
                                                            },
                                                        },
                                                        "required": ["type"],
                                                        "type": "object",
                                                    }
                                                ],
                                            },
                                            "type": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`GCPIntegrationType` "
                                                "object.",
                                                "enum": ["GCP"],
                                                "example": "GCP",
                                                "type": "string",
                                                "x-enum-varnames": ["GCP"],
                                            },
                                        },
                                        "required": ["type"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "The "
                                        "definition "
                                        "of "
                                        "the "
                                        "`GeminiIntegrationUpdate` "
                                        "object.",
                                        "properties": {
                                            "credentials": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`GeminiCredentialsUpdate` "
                                                "object.",
                                                "oneOf": [
                                                    {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "the "
                                                        "`GeminiAPIKey` "
                                                        "object.",
                                                        "properties": {
                                                            "api_key": {
                                                                "description": "The "
                                                                "`GeminiAPIKeyUpdate` "
                                                                "`api_key`.",
                                                                "type": "string",
                                                            },
                                                            "type": {
                                                                "description": "The "
                                                                "definition "
                                                                "of "
                                                                "the "
                                                                "`GeminiAPIKey` "
                                                                "object.",
                                                                "enum": ["GeminiAPIKey"],
                                                                "example": "GeminiAPIKey",
                                                                "type": "string",
                                                                "x-enum-varnames": ["GEMINIAPIKEY"],
                                                            },
                                                        },
                                                        "required": ["type"],
                                                        "type": "object",
                                                    }
                                                ],
                                            },
                                            "type": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`GeminiIntegrationType` "
                                                "object.",
                                                "enum": ["Gemini"],
                                                "example": "Gemini",
                                                "type": "string",
                                                "x-enum-varnames": ["GEMINI"],
                                            },
                                        },
                                        "required": ["type"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "The "
                                        "definition "
                                        "of "
                                        "the "
                                        "`GitlabIntegrationUpdate` "
                                        "object.",
                                        "properties": {
                                            "credentials": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`GitlabCredentialsUpdate` "
                                                "object.",
                                                "oneOf": [
                                                    {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "the "
                                                        "`GitlabAPIKey` "
                                                        "object.",
                                                        "properties": {
                                                            "api_token": {
                                                                "description": "The "
                                                                "`GitlabAPIKeyUpdate` "
                                                                "`api_token`.",
                                                                "type": "string",
                                                            },
                                                            "type": {
                                                                "description": "The "
                                                                "definition "
                                                                "of "
                                                                "the "
                                                                "`GitlabAPIKey` "
                                                                "object.",
                                                                "enum": ["GitlabAPIKey"],
                                                                "example": "GitlabAPIKey",
                                                                "type": "string",
                                                                "x-enum-varnames": ["GITLABAPIKEY"],
                                                            },
                                                        },
                                                        "required": ["type"],
                                                        "type": "object",
                                                    }
                                                ],
                                            },
                                            "type": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`GitlabIntegrationType` "
                                                "object.",
                                                "enum": ["Gitlab"],
                                                "example": "Gitlab",
                                                "type": "string",
                                                "x-enum-varnames": ["GITLAB"],
                                            },
                                        },
                                        "required": ["type"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "The "
                                        "definition "
                                        "of "
                                        "the "
                                        "`GreyNoiseIntegrationUpdate` "
                                        "object.",
                                        "properties": {
                                            "credentials": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`GreyNoiseCredentialsUpdate` "
                                                "object.",
                                                "oneOf": [
                                                    {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "the "
                                                        "`GreyNoiseAPIKey` "
                                                        "object.",
                                                        "properties": {
                                                            "api_key": {
                                                                "description": "The "
                                                                "`GreyNoiseAPIKeyUpdate` "
                                                                "`api_key`.",
                                                                "type": "string",
                                                            },
                                                            "type": {
                                                                "description": "The "
                                                                "definition "
                                                                "of "
                                                                "the "
                                                                "`GreyNoiseAPIKey` "
                                                                "object.",
                                                                "enum": ["GreyNoiseAPIKey"],
                                                                "example": "GreyNoiseAPIKey",
                                                                "type": "string",
                                                                "x-enum-varnames": [
                                                                    "GREYNOISEAPIKEY"
                                                                ],
                                                            },
                                                        },
                                                        "required": ["type"],
                                                        "type": "object",
                                                    }
                                                ],
                                            },
                                            "type": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`GreyNoiseIntegrationType` "
                                                "object.",
                                                "enum": ["GreyNoise"],
                                                "example": "GreyNoise",
                                                "type": "string",
                                                "x-enum-varnames": ["GREYNOISE"],
                                            },
                                        },
                                        "required": ["type"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "The "
                                        "definition "
                                        "of "
                                        "`HTTPIntegrationUpdate` "
                                        "object.",
                                        "properties": {
                                            "base_url": {
                                                "description": "Base HTTP url for the integration",
                                                "example": "http://datadoghq.com",
                                                "type": "string",
                                            },
                                            "credentials": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "`HTTPCredentialsUpdate` "
                                                "object.",
                                                "oneOf": [
                                                    {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "`HTTPTokenAuthUpdate` "
                                                        "object.",
                                                        "properties": {
                                                            "body": {
                                                                "description": "The "
                                                                "definition "
                                                                "of "
                                                                "`HTTPBody` "
                                                                "object.",
                                                                "properties": {
                                                                    "content": {
                                                                        "description": "Serialized "
                                                                        "body "
                                                                        "content",
                                                                        "example": '{"some-json": '
                                                                        '"with-value"}',
                                                                        "type": "string",
                                                                    },
                                                                    "content_type": {
                                                                        "description": "Content "
                                                                        "type "
                                                                        "of "
                                                                        "the "
                                                                        "body",
                                                                        "example": "application/json",
                                                                        "type": "string",
                                                                    },
                                                                },
                                                                "type": "object",
                                                            },
                                                            "headers": {
                                                                "description": "The "
                                                                "`HTTPTokenAuthUpdate` "
                                                                "`headers`.",
                                                                "items": {
                                                                    "description": "The "
                                                                    "definition "
                                                                    "of "
                                                                    "`HTTPHeaderUpdate` "
                                                                    "object.",
                                                                    "properties": {
                                                                        "deleted": {
                                                                            "description": "Should "
                                                                            "the "
                                                                            "header "
                                                                            "be "
                                                                            "deleted.",
                                                                            "type": "boolean",
                                                                        },
                                                                        "name": {
                                                                            "description": "The "
                                                                            "`HTTPHeaderUpdate` "
                                                                            "`name`.",
                                                                            "example": "MyHttpHeader",
                                                                            "pattern": "^[A-Za-z][A-Za-z\\\\d\\\\-\\\\_]*$",
                                                                            "type": "string",
                                                                        },
                                                                        "value": {
                                                                            "description": "The "
                                                                            "`HTTPHeaderUpdate` "
                                                                            "`value`.",
                                                                            "example": "Updated "
                                                                            "Header "
                                                                            "Value",
                                                                            "type": "string",
                                                                        },
                                                                    },
                                                                    "required": ["name"],
                                                                    "type": "object",
                                                                },
                                                                "type": "array",
                                                            },
                                                            "tokens": {
                                                                "description": "The "
                                                                "`HTTPTokenAuthUpdate` "
                                                                "`tokens`.",
                                                                "items": {
                                                                    "description": "The "
                                                                    "definition "
                                                                    "of "
                                                                    "`HTTPTokenUpdate` "
                                                                    "object.",
                                                                    "properties": {
                                                                        "deleted": {
                                                                            "description": "Should "
                                                                            "the "
                                                                            "header "
                                                                            "be "
                                                                            "deleted.",
                                                                            "type": "boolean",
                                                                        },
                                                                        "name": {
                                                                            "description": "The "
                                                                            "`HTTPToken` "
                                                                            "`name`.",
                                                                            "example": "MyToken",
                                                                            "pattern": "^[A-Za-z][A-Za-z\\\\d]*$",
                                                                            "type": "string",
                                                                        },
                                                                        "type": {
                                                                            "description": "The "
                                                                            "definition "
                                                                            "of "
                                                                            "`TokenType` "
                                                                            "object.",
                                                                            "enum": ["SECRET"],
                                                                            "example": "SECRET",
                                                                            "type": "string",
                                                                            "x-enum-varnames": [
                                                                                "SECRET"
                                                                            ],
                                                                        },
                                                                        "value": {
                                                                            "description": "The "
                                                                            "`HTTPToken` "
                                                                            "`value`.",
                                                                            "example": "Some "
                                                                            "Token "
                                                                            "Value",
                                                                            "type": "string",
                                                                        },
                                                                    },
                                                                    "required": [
                                                                        "name",
                                                                        "type",
                                                                        "value",
                                                                    ],
                                                                    "type": "object",
                                                                },
                                                                "type": "array",
                                                            },
                                                            "type": {
                                                                "description": "The "
                                                                "definition "
                                                                "of "
                                                                "`HTTPTokenAuthType` "
                                                                "object.",
                                                                "enum": ["HTTPTokenAuth"],
                                                                "example": "HTTPTokenAuth",
                                                                "type": "string",
                                                                "x-enum-varnames": [
                                                                    "HTTPTOKENAUTH"
                                                                ],
                                                            },
                                                            "url_parameters": {
                                                                "description": "The "
                                                                "`HTTPTokenAuthUpdate` "
                                                                "`url_parameters`.",
                                                                "items": {
                                                                    "description": "The "
                                                                    "definition "
                                                                    "of "
                                                                    "`UrlParamUpdate` "
                                                                    "object.",
                                                                    "properties": {
                                                                        "deleted": {
                                                                            "description": "Should "
                                                                            "the "
                                                                            "header "
                                                                            "be "
                                                                            "deleted.",
                                                                            "type": "boolean",
                                                                        },
                                                                        "name": {
                                                                            "description": "Name "
                                                                            "for "
                                                                            "tokens.",
                                                                            "example": "MyTokenName",
                                                                            "pattern": "^[A-Za-z][A-Za-z\\\\d]*$",
                                                                            "type": "string",
                                                                        },
                                                                        "value": {
                                                                            "description": "The "
                                                                            "`UrlParamUpdate` "
                                                                            "`value`.",
                                                                            "example": "Some "
                                                                            "Url "
                                                                            "Parameter "
                                                                            "value",
                                                                            "type": "string",
                                                                        },
                                                                    },
                                                                    "required": ["name"],
                                                                    "type": "object",
                                                                },
                                                                "type": "array",
                                                            },
                                                        },
                                                        "required": ["type"],
                                                        "type": "object",
                                                    }
                                                ],
                                            },
                                            "type": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "`HTTPIntegrationType` "
                                                "object.",
                                                "enum": ["HTTP"],
                                                "example": "HTTP",
                                                "type": "string",
                                                "x-enum-varnames": ["HTTP"],
                                            },
                                        },
                                        "required": ["type"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "The "
                                        "definition "
                                        "of "
                                        "the "
                                        "`LaunchDarklyIntegrationUpdate` "
                                        "object.",
                                        "properties": {
                                            "credentials": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`LaunchDarklyCredentialsUpdate` "
                                                "object.",
                                                "oneOf": [
                                                    {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "the "
                                                        "`LaunchDarklyAPIKey` "
                                                        "object.",
                                                        "properties": {
                                                            "api_token": {
                                                                "description": "The "
                                                                "`LaunchDarklyAPIKeyUpdate` "
                                                                "`api_token`.",
                                                                "type": "string",
                                                            },
                                                            "type": {
                                                                "description": "The "
                                                                "definition "
                                                                "of "
                                                                "the "
                                                                "`LaunchDarklyAPIKey` "
                                                                "object.",
                                                                "enum": ["LaunchDarklyAPIKey"],
                                                                "example": "LaunchDarklyAPIKey",
                                                                "type": "string",
                                                                "x-enum-varnames": [
                                                                    "LAUNCHDARKLYAPIKEY"
                                                                ],
                                                            },
                                                        },
                                                        "required": ["type"],
                                                        "type": "object",
                                                    }
                                                ],
                                            },
                                            "type": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`LaunchDarklyIntegrationType` "
                                                "object.",
                                                "enum": ["LaunchDarkly"],
                                                "example": "LaunchDarkly",
                                                "type": "string",
                                                "x-enum-varnames": ["LAUNCHDARKLY"],
                                            },
                                        },
                                        "required": ["type"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "The "
                                        "definition "
                                        "of "
                                        "the "
                                        "`NotionIntegrationUpdate` "
                                        "object.",
                                        "properties": {
                                            "credentials": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`NotionCredentialsUpdate` "
                                                "object.",
                                                "oneOf": [
                                                    {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "the "
                                                        "`NotionAPIKey` "
                                                        "object.",
                                                        "properties": {
                                                            "api_token": {
                                                                "description": "The "
                                                                "`NotionAPIKeyUpdate` "
                                                                "`api_token`.",
                                                                "type": "string",
                                                            },
                                                            "type": {
                                                                "description": "The "
                                                                "definition "
                                                                "of "
                                                                "the "
                                                                "`NotionAPIKey` "
                                                                "object.",
                                                                "enum": ["NotionAPIKey"],
                                                                "example": "NotionAPIKey",
                                                                "type": "string",
                                                                "x-enum-varnames": ["NOTIONAPIKEY"],
                                                            },
                                                        },
                                                        "required": ["type"],
                                                        "type": "object",
                                                    }
                                                ],
                                            },
                                            "type": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`NotionIntegrationType` "
                                                "object.",
                                                "enum": ["Notion"],
                                                "example": "Notion",
                                                "type": "string",
                                                "x-enum-varnames": ["NOTION"],
                                            },
                                        },
                                        "required": ["type"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "The "
                                        "definition "
                                        "of "
                                        "the "
                                        "`OktaIntegrationUpdate` "
                                        "object.",
                                        "properties": {
                                            "credentials": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`OktaCredentialsUpdate` "
                                                "object.",
                                                "oneOf": [
                                                    {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "the "
                                                        "`OktaAPIToken` "
                                                        "object.",
                                                        "properties": {
                                                            "api_token": {
                                                                "description": "The "
                                                                "`OktaAPITokenUpdate` "
                                                                "`api_token`.",
                                                                "type": "string",
                                                            },
                                                            "domain": {
                                                                "description": "The "
                                                                "`OktaAPITokenUpdate` "
                                                                "`domain`.",
                                                                "type": "string",
                                                            },
                                                            "type": {
                                                                "description": "The "
                                                                "definition "
                                                                "of "
                                                                "the "
                                                                "`OktaAPIToken` "
                                                                "object.",
                                                                "enum": ["OktaAPIToken"],
                                                                "example": "OktaAPIToken",
                                                                "type": "string",
                                                                "x-enum-varnames": ["OKTAAPITOKEN"],
                                                            },
                                                        },
                                                        "required": ["type"],
                                                        "type": "object",
                                                    }
                                                ],
                                            },
                                            "type": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`OktaIntegrationType` "
                                                "object.",
                                                "enum": ["Okta"],
                                                "example": "Okta",
                                                "type": "string",
                                                "x-enum-varnames": ["OKTA"],
                                            },
                                        },
                                        "required": ["type"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "The "
                                        "definition "
                                        "of "
                                        "the "
                                        "`OpenAIIntegrationUpdate` "
                                        "object.",
                                        "properties": {
                                            "credentials": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`OpenAICredentialsUpdate` "
                                                "object.",
                                                "oneOf": [
                                                    {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "the "
                                                        "`OpenAIAPIKey` "
                                                        "object.",
                                                        "properties": {
                                                            "api_token": {
                                                                "description": "The "
                                                                "`OpenAIAPIKeyUpdate` "
                                                                "`api_token`.",
                                                                "type": "string",
                                                            },
                                                            "type": {
                                                                "description": "The "
                                                                "definition "
                                                                "of "
                                                                "the "
                                                                "`OpenAIAPIKey` "
                                                                "object.",
                                                                "enum": ["OpenAIAPIKey"],
                                                                "example": "OpenAIAPIKey",
                                                                "type": "string",
                                                                "x-enum-varnames": ["OPENAIAPIKEY"],
                                                            },
                                                        },
                                                        "required": ["type"],
                                                        "type": "object",
                                                    }
                                                ],
                                            },
                                            "type": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`OpenAIIntegrationType` "
                                                "object.",
                                                "enum": ["OpenAI"],
                                                "example": "OpenAI",
                                                "type": "string",
                                                "x-enum-varnames": ["OPENAI"],
                                            },
                                        },
                                        "required": ["type"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "The "
                                        "definition "
                                        "of "
                                        "the "
                                        "`ServiceNowIntegrationUpdate` "
                                        "object.",
                                        "properties": {
                                            "credentials": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`ServiceNowCredentialsUpdate` "
                                                "object.",
                                                "oneOf": [
                                                    {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "the "
                                                        "`ServiceNowBasicAuth` "
                                                        "object.",
                                                        "properties": {
                                                            "instance": {
                                                                "description": "The "
                                                                "`ServiceNowBasicAuthUpdate` "
                                                                "`instance`.",
                                                                "type": "string",
                                                            },
                                                            "password": {
                                                                "description": "The "
                                                                "`ServiceNowBasicAuthUpdate` "
                                                                "`password`.",
                                                                "type": "string",
                                                            },
                                                            "type": {
                                                                "description": "The "
                                                                "definition "
                                                                "of "
                                                                "the "
                                                                "`ServiceNowBasicAuth` "
                                                                "object.",
                                                                "enum": ["ServiceNowBasicAuth"],
                                                                "example": "ServiceNowBasicAuth",
                                                                "type": "string",
                                                                "x-enum-varnames": [
                                                                    "SERVICENOWBASICAUTH"
                                                                ],
                                                            },
                                                            "username": {
                                                                "description": "The "
                                                                "`ServiceNowBasicAuthUpdate` "
                                                                "`username`.",
                                                                "type": "string",
                                                            },
                                                        },
                                                        "required": ["type"],
                                                        "type": "object",
                                                    }
                                                ],
                                            },
                                            "type": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`ServiceNowIntegrationType` "
                                                "object.",
                                                "enum": ["ServiceNow"],
                                                "example": "ServiceNow",
                                                "type": "string",
                                                "x-enum-varnames": ["SERVICENOW"],
                                            },
                                        },
                                        "required": ["type"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "The "
                                        "definition "
                                        "of "
                                        "the "
                                        "`SplitIntegrationUpdate` "
                                        "object.",
                                        "properties": {
                                            "credentials": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`SplitCredentialsUpdate` "
                                                "object.",
                                                "oneOf": [
                                                    {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "the "
                                                        "`SplitAPIKey` "
                                                        "object.",
                                                        "properties": {
                                                            "api_key": {
                                                                "description": "The "
                                                                "`SplitAPIKeyUpdate` "
                                                                "`api_key`.",
                                                                "type": "string",
                                                            },
                                                            "type": {
                                                                "description": "The "
                                                                "definition "
                                                                "of "
                                                                "the "
                                                                "`SplitAPIKey` "
                                                                "object.",
                                                                "enum": ["SplitAPIKey"],
                                                                "example": "SplitAPIKey",
                                                                "type": "string",
                                                                "x-enum-varnames": ["SPLITAPIKEY"],
                                                            },
                                                        },
                                                        "required": ["type"],
                                                        "type": "object",
                                                    }
                                                ],
                                            },
                                            "type": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`SplitIntegrationType` "
                                                "object.",
                                                "enum": ["Split"],
                                                "example": "Split",
                                                "type": "string",
                                                "x-enum-varnames": ["SPLIT"],
                                            },
                                        },
                                        "required": ["type"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "The "
                                        "definition "
                                        "of "
                                        "the "
                                        "`StatsigIntegrationUpdate` "
                                        "object.",
                                        "properties": {
                                            "credentials": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`StatsigCredentialsUpdate` "
                                                "object.",
                                                "oneOf": [
                                                    {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "the "
                                                        "`StatsigAPIKey` "
                                                        "object.",
                                                        "properties": {
                                                            "api_key": {
                                                                "description": "The "
                                                                "`StatsigAPIKeyUpdate` "
                                                                "`api_key`.",
                                                                "type": "string",
                                                            },
                                                            "type": {
                                                                "description": "The "
                                                                "definition "
                                                                "of "
                                                                "the "
                                                                "`StatsigAPIKey` "
                                                                "object.",
                                                                "enum": ["StatsigAPIKey"],
                                                                "example": "StatsigAPIKey",
                                                                "type": "string",
                                                                "x-enum-varnames": [
                                                                    "STATSIGAPIKEY"
                                                                ],
                                                            },
                                                        },
                                                        "required": ["type"],
                                                        "type": "object",
                                                    }
                                                ],
                                            },
                                            "type": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`StatsigIntegrationType` "
                                                "object.",
                                                "enum": ["Statsig"],
                                                "example": "Statsig",
                                                "type": "string",
                                                "x-enum-varnames": ["STATSIG"],
                                            },
                                        },
                                        "required": ["type"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "The "
                                        "definition "
                                        "of "
                                        "the "
                                        "`VirusTotalIntegrationUpdate` "
                                        "object.",
                                        "properties": {
                                            "credentials": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`VirusTotalCredentialsUpdate` "
                                                "object.",
                                                "oneOf": [
                                                    {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "the "
                                                        "`VirusTotalAPIKey` "
                                                        "object.",
                                                        "properties": {
                                                            "api_key": {
                                                                "description": "The "
                                                                "`VirusTotalAPIKeyUpdate` "
                                                                "`api_key`.",
                                                                "type": "string",
                                                            },
                                                            "type": {
                                                                "description": "The "
                                                                "definition "
                                                                "of "
                                                                "the "
                                                                "`VirusTotalAPIKey` "
                                                                "object.",
                                                                "enum": ["VirusTotalAPIKey"],
                                                                "example": "VirusTotalAPIKey",
                                                                "type": "string",
                                                                "x-enum-varnames": [
                                                                    "VIRUSTOTALAPIKEY"
                                                                ],
                                                            },
                                                        },
                                                        "required": ["type"],
                                                        "type": "object",
                                                    }
                                                ],
                                            },
                                            "type": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "the "
                                                "`VirusTotalIntegrationType` "
                                                "object.",
                                                "enum": ["VirusTotal"],
                                                "example": "VirusTotal",
                                                "type": "string",
                                                "x-enum-varnames": ["VIRUSTOTAL"],
                                            },
                                        },
                                        "required": ["type"],
                                        "type": "object",
                                    },
                                ],
                            },
                            "name": {
                                "description": "Name of the connection",
                                "example": "My AWS Connection",
                                "type": "string",
                            },
                        },
                        "type": "object",
                    },
                    "type": {
                        "description": "The definition of `ActionConnectionDataType` object.",
                        "enum": ["action_connection"],
                        "example": "action_connection",
                        "type": "string",
                        "x-enum-varnames": ["ACTION_CONNECTION"],
                    },
                },
                "required": ["type", "attributes"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "CREATESPANMETRIC_REQUEST_BODY_SCHEMA": {
        "description": "The new span-based metric body.",
        "properties": {
            "data": {
                "description": "The new span-based metric properties.",
                "properties": {
                    "attributes": {
                        "description": "The object "
                        "describing the "
                        "Datadog "
                        "span-based "
                        "metric to "
                        "create.",
                        "properties": {
                            "compute": {
                                "description": "The compute rule to compute the span-based metric.",
                                "properties": {
                                    "aggregation_type": {
                                        "description": "The type of aggregation to use.",
                                        "enum": ["count", "distribution"],
                                        "example": "distribution",
                                        "type": "string",
                                        "x-enum-varnames": ["COUNT", "DISTRIBUTION"],
                                    },
                                    "include_percentiles": {
                                        "description": "Toggle "
                                        "to "
                                        "include "
                                        "or "
                                        "exclude "
                                        "percentile "
                                        "aggregations "
                                        "for "
                                        "distribution "
                                        "metrics.\n"
                                        "Only "
                                        "present "
                                        "when "
                                        "the "
                                        "`aggregation_type` "
                                        "is "
                                        "`distribution`.",
                                        "example": False,
                                        "type": "boolean",
                                    },
                                    "path": {
                                        "description": "The "
                                        "path "
                                        "to "
                                        "the "
                                        "value "
                                        "the "
                                        "span-based "
                                        "metric "
                                        "will "
                                        "aggregate "
                                        "on "
                                        "(only "
                                        "used "
                                        "if "
                                        "the "
                                        "aggregation "
                                        "type "
                                        "is "
                                        "a "
                                        '"distribution").',
                                        "example": "@duration",
                                        "type": "string",
                                    },
                                },
                                "required": ["aggregation_type"],
                                "type": "object",
                            },
                            "filter": {
                                "description": "The "
                                "span-based "
                                "metric "
                                "filter. "
                                "Spans "
                                "matching "
                                "this "
                                "filter "
                                "will "
                                "be "
                                "aggregated "
                                "in "
                                "this "
                                "metric.",
                                "properties": {
                                    "query": {
                                        "default": "*",
                                        "description": "The "
                                        "search "
                                        "query "
                                        "- "
                                        "following "
                                        "the "
                                        "span "
                                        "search "
                                        "syntax.",
                                        "example": "@http.status_code:200 service:my-service",
                                        "type": "string",
                                    }
                                },
                                "type": "object",
                            },
                            "group_by": {
                                "description": "The rules for the group by.",
                                "items": {
                                    "description": "A group by rule.",
                                    "properties": {
                                        "path": {
                                            "description": "The "
                                            "path "
                                            "to "
                                            "the "
                                            "value "
                                            "the "
                                            "span-based "
                                            "metric "
                                            "will "
                                            "be "
                                            "aggregated "
                                            "over.",
                                            "example": "resource_name",
                                            "type": "string",
                                        },
                                        "tag_name": {
                                            "description": "Eventual "
                                            "name "
                                            "of "
                                            "the "
                                            "tag "
                                            "that "
                                            "gets "
                                            "created. "
                                            "By "
                                            "default, "
                                            "the "
                                            "path "
                                            "attribute "
                                            "is "
                                            "used "
                                            "as "
                                            "the "
                                            "tag "
                                            "name.",
                                            "example": "resource_name",
                                            "type": "string",
                                        },
                                    },
                                    "required": ["path"],
                                    "type": "object",
                                },
                                "type": "array",
                            },
                        },
                        "required": ["compute"],
                        "type": "object",
                    },
                    "id": {
                        "description": "The name of the span-based metric.",
                        "example": "my.metric",
                        "type": "string",
                    },
                    "type": {
                        "default": "spans_metrics",
                        "description": "The type of resource. "
                        "The value should "
                        "always be "
                        "spans_metrics.",
                        "enum": ["spans_metrics"],
                        "example": "spans_metrics",
                        "type": "string",
                        "x-enum-varnames": ["SPANS_METRICS"],
                    },
                },
                "required": ["id", "type", "attributes"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "UPDATESPANMETRIC_REQUEST_BODY_SCHEMA": {
        "description": "The new span-based metric body.",
        "properties": {
            "data": {
                "description": "The new span-based metric properties.",
                "properties": {
                    "attributes": {
                        "description": "The span-based metric properties that will be updated.",
                        "properties": {
                            "compute": {
                                "description": "The compute rule to compute the span-based metric.",
                                "properties": {
                                    "include_percentiles": {
                                        "description": "Toggle "
                                        "to "
                                        "include "
                                        "or "
                                        "exclude "
                                        "percentile "
                                        "aggregations "
                                        "for "
                                        "distribution "
                                        "metrics.\n"
                                        "Only "
                                        "present "
                                        "when "
                                        "the "
                                        "`aggregation_type` "
                                        "is "
                                        "`distribution`.",
                                        "example": False,
                                        "type": "boolean",
                                    }
                                },
                                "type": "object",
                            },
                            "filter": {
                                "description": "The "
                                "span-based "
                                "metric "
                                "filter. "
                                "Spans "
                                "matching "
                                "this "
                                "filter "
                                "will "
                                "be "
                                "aggregated "
                                "in "
                                "this "
                                "metric.",
                                "properties": {
                                    "query": {
                                        "default": "*",
                                        "description": "The "
                                        "search "
                                        "query "
                                        "- "
                                        "following "
                                        "the "
                                        "span "
                                        "search "
                                        "syntax.",
                                        "example": "@http.status_code:200 service:my-service",
                                        "type": "string",
                                    }
                                },
                                "type": "object",
                            },
                            "group_by": {
                                "description": "The rules for the group by.",
                                "items": {
                                    "description": "A group by rule.",
                                    "properties": {
                                        "path": {
                                            "description": "The "
                                            "path "
                                            "to "
                                            "the "
                                            "value "
                                            "the "
                                            "span-based "
                                            "metric "
                                            "will "
                                            "be "
                                            "aggregated "
                                            "over.",
                                            "example": "resource_name",
                                            "type": "string",
                                        },
                                        "tag_name": {
                                            "description": "Eventual "
                                            "name "
                                            "of "
                                            "the "
                                            "tag "
                                            "that "
                                            "gets "
                                            "created. "
                                            "By "
                                            "default, "
                                            "the "
                                            "path "
                                            "attribute "
                                            "is "
                                            "used "
                                            "as "
                                            "the "
                                            "tag "
                                            "name.",
                                            "example": "resource_name",
                                            "type": "string",
                                        },
                                    },
                                    "required": ["path"],
                                    "type": "object",
                                },
                                "type": "array",
                            },
                        },
                        "type": "object",
                    },
                    "type": {
                        "default": "spans_metrics",
                        "description": "The type of resource. "
                        "The value should "
                        "always be "
                        "spans_metrics.",
                        "enum": ["spans_metrics"],
                        "example": "spans_metrics",
                        "type": "string",
                        "x-enum-varnames": ["SPANS_METRICS"],
                    },
                },
                "required": ["type", "attributes"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "REORDERAPMRETENTIONFILTERS_REQUEST_BODY_SCHEMA": {
        "description": "A list of retention filters to reorder.",
        "properties": {
            "data": {
                "description": "A list of retention filters objects.",
                "items": {
                    "description": "The retention filter object .",
                    "properties": {
                        "id": {
                            "description": "The ID of the retention filter.",
                            "example": "7RBOb7dLSYWI01yc3pIH8w",
                            "type": "string",
                        },
                        "type": {
                            "default": "apm_retention_filter",
                            "description": "The type of the resource.",
                            "enum": ["apm_retention_filter"],
                            "example": "apm_retention_filter",
                            "type": "string",
                            "x-enum-varnames": ["apm_retention_filter"],
                        },
                    },
                    "required": ["id", "type"],
                    "type": "object",
                },
                "type": "array",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "DELETEMULTIPLEDATADOGAPPS_REQUEST_BODY_SCHEMA": {
        "description": "A request object for deleting multiple apps by ID.",
        "example": {
            "data": [
                {"id": "aea2ed17-b45f-40d0-ba59-c86b7972c901", "type": "appDefinitions"},
                {"id": "f69bb8be-6168-4fe7-a30d-370256b6504a", "type": "appDefinitions"},
                {"id": "ab1ed73e-13ad-4426-b0df-a0ff8876a088", "type": "appDefinitions"},
            ]
        },
        "properties": {
            "data": {
                "description": "An array of objects containing the IDs of the apps to delete.",
                "items": {
                    "description": "An object containing the ID of an app to delete.",
                    "properties": {
                        "id": {
                            "description": "The ID of the app to delete.",
                            "example": "65bb1f25-52e1-4510-9f8d-22d1516ed693",
                            "format": "uuid",
                            "type": "string",
                        },
                        "type": {
                            "default": "appDefinitions",
                            "description": "The app definition type.",
                            "enum": ["appDefinitions"],
                            "example": "appDefinitions",
                            "type": "string",
                            "x-enum-varnames": ["APPDEFINITIONS"],
                        },
                    },
                    "required": ["id", "type"],
                    "type": "object",
                },
                "type": "array",
            }
        },
        "type": "object",
    },
    "CREATENEWAPP_REQUEST_BODY_SCHEMA": {
        "description": "A request object for creating a new app.",
        "example": {
            "data": {
                "attributes": {
                    "components": [
                        {
                            "events": [],
                            "name": "grid0",
                            "properties": {
                                "children": [
                                    {
                                        "events": [],
                                        "name": "gridCell0",
                                        "properties": {
                                            "children": [
                                                {
                                                    "events": [],
                                                    "name": "calloutValue0",
                                                    "properties": {
                                                        "isDisabled": False,
                                                        "isLoading": False,
                                                        "isVisible": True,
                                                        "label": "CPU Usage",
                                                        "size": "sm",
                                                        "style": "vivid_yellow",
                                                        "unit": "kB",
                                                        "value": "42",
                                                    },
                                                    "type": "calloutValue",
                                                }
                                            ],
                                            "isVisible": "true",
                                            "layout": {
                                                "default": {"height": 8, "width": 2, "x": 0, "y": 0}
                                            },
                                        },
                                        "type": "gridCell",
                                    }
                                ]
                            },
                            "type": "grid",
                        }
                    ],
                    "description": "This is a simple example app",
                    "name": "Example App",
                    "queries": [],
                    "rootInstanceName": "grid0",
                },
                "type": "appDefinitions",
            }
        },
        "properties": {
            "data": {
                "description": "The data object containing the app definition.",
                "properties": {
                    "attributes": {
                        "description": "App definition "
                        "attributes such "
                        "as name, "
                        "description, "
                        "and components.",
                        "properties": {
                            "components": {
                                "description": "The UI components that make up the app.",
                                "items": {
                                    "description": "A "
                                    "grid "
                                    "component. "
                                    "The "
                                    "grid "
                                    "component "
                                    "is "
                                    "the "
                                    "root "
                                    "canvas "
                                    "for "
                                    "an "
                                    "app "
                                    "and "
                                    "contains "
                                    "all "
                                    "other "
                                    "components.",
                                    "properties": {
                                        "events": {
                                            "description": "Events "
                                            "to "
                                            "listen "
                                            "for "
                                            "on "
                                            "the "
                                            "grid "
                                            "component.",
                                            "items": {
                                                "additionalProperties": {},
                                                "description": "An "
                                                "event "
                                                "on "
                                                "a "
                                                "UI "
                                                "component "
                                                "that "
                                                "triggers "
                                                "a "
                                                "response "
                                                "or "
                                                "action "
                                                "in "
                                                "an "
                                                "app.",
                                                "properties": {
                                                    "name": {
                                                        "description": "The "
                                                        "triggering "
                                                        "action "
                                                        "for "
                                                        "the "
                                                        "event.",
                                                        "enum": [
                                                            "pageChange",
                                                            "tableRowClick",
                                                            "_tableRowButtonClick",
                                                            "change",
                                                            "submit",
                                                            "click",
                                                            "toggleOpen",
                                                            "close",
                                                            "open",
                                                            "executionFinished",
                                                        ],
                                                        "example": "click",
                                                        "type": "string",
                                                        "x-enum-varnames": [
                                                            "PAGECHANGE",
                                                            "TABLEROWCLICK",
                                                            "TABLEROWBUTTONCLICK",
                                                            "CHANGE",
                                                            "SUBMIT",
                                                            "CLICK",
                                                            "TOGGLEOPEN",
                                                            "CLOSE",
                                                            "OPEN",
                                                            "EXECUTIONFINISHED",
                                                        ],
                                                    },
                                                    "type": {
                                                        "description": "The response to the event.",
                                                        "enum": [
                                                            "custom",
                                                            "setComponentState",
                                                            "triggerQuery",
                                                            "openModal",
                                                            "closeModal",
                                                            "openUrl",
                                                            "downloadFile",
                                                            "setStateVariableValue",
                                                        ],
                                                        "example": "triggerQuery",
                                                        "type": "string",
                                                        "x-enum-varnames": [
                                                            "CUSTOM",
                                                            "SETCOMPONENTSTATE",
                                                            "TRIGGERQUERY",
                                                            "OPENMODAL",
                                                            "CLOSEMODAL",
                                                            "OPENURL",
                                                            "DOWNLOADFILE",
                                                            "SETSTATEVARIABLEVALUE",
                                                        ],
                                                    },
                                                },
                                                "type": "object",
                                            },
                                            "type": "array",
                                        },
                                        "id": {
                                            "description": "The "
                                            "ID "
                                            "of "
                                            "the "
                                            "grid "
                                            "component. "
                                            "This "
                                            "property "
                                            "is "
                                            "deprecated; "
                                            "use "
                                            "`name` "
                                            "to "
                                            "identify "
                                            "individual "
                                            "components "
                                            "instead.",
                                            "type": "string",
                                        },
                                        "name": {
                                            "description": "A "
                                            "unique "
                                            "identifier "
                                            "for "
                                            "this "
                                            "grid "
                                            "component. "
                                            "This "
                                            "name "
                                            "is "
                                            "also "
                                            "visible "
                                            "in "
                                            "the "
                                            "app "
                                            "editor.",
                                            "example": "",
                                            "type": "string",
                                        },
                                        "properties": {
                                            "description": "Properties of a grid component.",
                                            "properties": {
                                                "backgroundColor": {
                                                    "default": "default",
                                                    "description": "The "
                                                    "background "
                                                    "color "
                                                    "of "
                                                    "the "
                                                    "grid.",
                                                    "type": "string",
                                                },
                                                "children": {
                                                    "description": "The "
                                                    "child "
                                                    "components "
                                                    "of "
                                                    "the "
                                                    "grid.",
                                                    "items": {
                                                        "description": "[Definition "
                                                        "of "
                                                        "a "
                                                        "UI "
                                                        "component "
                                                        "in "
                                                        "the "
                                                        "app](https://docs.datadoghq.com/service_management/app_builder/components/)",
                                                        "properties": {
                                                            "events": {
                                                                "description": "Events "
                                                                "to "
                                                                "listen "
                                                                "for "
                                                                "on "
                                                                "the "
                                                                "UI "
                                                                "component.",
                                                                "items": {
                                                                    "additionalProperties": {},
                                                                    "description": "An "
                                                                    "event "
                                                                    "on "
                                                                    "a "
                                                                    "UI "
                                                                    "component "
                                                                    "that "
                                                                    "triggers "
                                                                    "a "
                                                                    "response "
                                                                    "or "
                                                                    "action "
                                                                    "in "
                                                                    "an "
                                                                    "app.",
                                                                    "properties": {
                                                                        "name": {
                                                                            "description": "The "
                                                                            "triggering "
                                                                            "action "
                                                                            "for "
                                                                            "the "
                                                                            "event.",
                                                                            "enum": [
                                                                                "pageChange",
                                                                                "tableRowClick",
                                                                                "_tableRowButtonClick",
                                                                                "change",
                                                                                "submit",
                                                                                "click",
                                                                                "toggleOpen",
                                                                                "close",
                                                                                "open",
                                                                                "executionFinished",
                                                                            ],
                                                                            "example": "click",
                                                                            "type": "string",
                                                                            "x-enum-varnames": [
                                                                                "PAGECHANGE",
                                                                                "TABLEROWCLICK",
                                                                                "TABLEROWBUTTONCLICK",
                                                                                "CHANGE",
                                                                                "SUBMIT",
                                                                                "CLICK",
                                                                                "TOGGLEOPEN",
                                                                                "CLOSE",
                                                                                "OPEN",
                                                                                "EXECUTIONFINISHED",
                                                                            ],
                                                                        },
                                                                        "type": {
                                                                            "description": "The "
                                                                            "response "
                                                                            "to "
                                                                            "the "
                                                                            "event.",
                                                                            "enum": [
                                                                                "custom",
                                                                                "setComponentState",
                                                                                "triggerQuery",
                                                                                "openModal",
                                                                                "closeModal",
                                                                                "openUrl",
                                                                                "downloadFile",
                                                                                "setStateVariableValue",
                                                                            ],
                                                                            "example": "triggerQuery",
                                                                            "type": "string",
                                                                            "x-enum-varnames": [
                                                                                "CUSTOM",
                                                                                "SETCOMPONENTSTATE",
                                                                                "TRIGGERQUERY",
                                                                                "OPENMODAL",
                                                                                "CLOSEMODAL",
                                                                                "OPENURL",
                                                                                "DOWNLOADFILE",
                                                                                "SETSTATEVARIABLEVALUE",
                                                                            ],
                                                                        },
                                                                    },
                                                                    "type": "object",
                                                                },
                                                                "type": "array",
                                                            },
                                                            "id": {
                                                                "description": "The "
                                                                "ID "
                                                                "of "
                                                                "the "
                                                                "UI "
                                                                "component. "
                                                                "This "
                                                                "property "
                                                                "is "
                                                                "deprecated; "
                                                                "use "
                                                                "`name` "
                                                                "to "
                                                                "identify "
                                                                "individual "
                                                                "components "
                                                                "instead.",
                                                                "nullable": True,
                                                                "type": "string",
                                                            },
                                                            "name": {
                                                                "description": "A "
                                                                "unique "
                                                                "identifier "
                                                                "for "
                                                                "this "
                                                                "UI "
                                                                "component. "
                                                                "This "
                                                                "name "
                                                                "is "
                                                                "also "
                                                                "visible "
                                                                "in "
                                                                "the "
                                                                "app "
                                                                "editor.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                            "properties": {
                                                                "additionalProperties": {},
                                                                "description": "Properties "
                                                                "of "
                                                                "a "
                                                                "UI "
                                                                "component. "
                                                                "Different "
                                                                "component "
                                                                "types "
                                                                "can "
                                                                "have "
                                                                "their "
                                                                "own "
                                                                "additional "
                                                                "unique "
                                                                "properties. "
                                                                "See "
                                                                "the "
                                                                "[components "
                                                                "documentation](https://docs.datadoghq.com/service_management/app_builder/components/) "
                                                                "for "
                                                                "more "
                                                                "detail "
                                                                "on "
                                                                "each "
                                                                "component "
                                                                "type "
                                                                "and "
                                                                "its "
                                                                "properties.",
                                                                "properties": {
                                                                    "children": {
                                                                        "description": "The "
                                                                        "child "
                                                                        "components "
                                                                        "of "
                                                                        "the "
                                                                        "UI "
                                                                        "component.",
                                                                        "items": {
                                                                            "$ref": "#/components/schemas/Component",
                                                                            "has_circular_reference": True,
                                                                        },
                                                                        "type": "array",
                                                                    },
                                                                    "isVisible": {
                                                                        "description": "Whether "
                                                                        "the "
                                                                        "UI "
                                                                        "component "
                                                                        "is "
                                                                        "visible. "
                                                                        "If "
                                                                        "this "
                                                                        "is "
                                                                        "a "
                                                                        "string, "
                                                                        "it "
                                                                        "must "
                                                                        "be "
                                                                        "a "
                                                                        "valid "
                                                                        "JavaScript "
                                                                        "expression "
                                                                        "that "
                                                                        "evaluates "
                                                                        "to "
                                                                        "a "
                                                                        "boolean.",
                                                                        "oneOf": [
                                                                            {"type": "boolean"},
                                                                            {
                                                                                "description": "If "
                                                                                "this "
                                                                                "is "
                                                                                "a "
                                                                                "string, "
                                                                                "it "
                                                                                "must "
                                                                                "be "
                                                                                "a "
                                                                                "valid "
                                                                                "JavaScript "
                                                                                "expression "
                                                                                "that "
                                                                                "evaluates "
                                                                                "to "
                                                                                "a "
                                                                                "boolean.",
                                                                                "example": "${true}",
                                                                                "type": "string",
                                                                            },
                                                                        ],
                                                                    },
                                                                },
                                                                "type": "object",
                                                            },
                                                            "type": {
                                                                "description": "The "
                                                                "UI "
                                                                "component "
                                                                "type.",
                                                                "enum": [
                                                                    "table",
                                                                    "textInput",
                                                                    "textArea",
                                                                    "button",
                                                                    "text",
                                                                    "select",
                                                                    "modal",
                                                                    "schemaForm",
                                                                    "checkbox",
                                                                    "tabs",
                                                                    "vegaChart",
                                                                    "radioButtons",
                                                                    "numberInput",
                                                                    "fileInput",
                                                                    "jsonInput",
                                                                    "gridCell",
                                                                    "dateRangePicker",
                                                                    "search",
                                                                    "container",
                                                                    "calloutValue",
                                                                ],
                                                                "example": "text",
                                                                "type": "string",
                                                                "x-enum-varnames": [
                                                                    "TABLE",
                                                                    "TEXTINPUT",
                                                                    "TEXTAREA",
                                                                    "BUTTON",
                                                                    "TEXT",
                                                                    "SELECT",
                                                                    "MODAL",
                                                                    "SCHEMAFORM",
                                                                    "CHECKBOX",
                                                                    "TABS",
                                                                    "VEGACHART",
                                                                    "RADIOBUTTONS",
                                                                    "NUMBERINPUT",
                                                                    "FILEINPUT",
                                                                    "JSONINPUT",
                                                                    "GRIDCELL",
                                                                    "DATERANGEPICKER",
                                                                    "SEARCH",
                                                                    "CONTAINER",
                                                                    "CALLOUTVALUE",
                                                                ],
                                                            },
                                                        },
                                                        "required": ["name", "type", "properties"],
                                                        "type": "object",
                                                    },
                                                    "type": "array",
                                                },
                                                "isVisible": {
                                                    "description": "Whether "
                                                    "the "
                                                    "grid "
                                                    "component "
                                                    "and "
                                                    "its "
                                                    "children "
                                                    "are "
                                                    "visible. "
                                                    "If "
                                                    "a "
                                                    "string, "
                                                    "it "
                                                    "must "
                                                    "be "
                                                    "a "
                                                    "valid "
                                                    "JavaScript "
                                                    "expression "
                                                    "that "
                                                    "evaluates "
                                                    "to "
                                                    "a "
                                                    "boolean.",
                                                    "oneOf": [
                                                        {"type": "string"},
                                                        {"default": True, "type": "boolean"},
                                                    ],
                                                },
                                            },
                                            "type": "object",
                                        },
                                        "type": {
                                            "default": "grid",
                                            "description": "The grid component type.",
                                            "enum": ["grid"],
                                            "example": "grid",
                                            "type": "string",
                                            "x-enum-varnames": ["GRID"],
                                        },
                                    },
                                    "required": ["name", "type", "properties"],
                                    "type": "object",
                                },
                                "type": "array",
                            },
                            "description": {
                                "description": "A human-readable description for the app.",
                                "type": "string",
                            },
                            "name": {"description": "The name of the app.", "type": "string"},
                            "queries": {
                                "description": "An "
                                "array "
                                "of "
                                "queries, "
                                "such "
                                "as "
                                "external "
                                "actions "
                                "and "
                                "state "
                                "variables, "
                                "that "
                                "the "
                                "app "
                                "uses.",
                                "items": {
                                    "description": "A "
                                    "data "
                                    "query "
                                    "used "
                                    "by "
                                    "an "
                                    "app. "
                                    "This "
                                    "can "
                                    "take "
                                    "the "
                                    "form "
                                    "of "
                                    "an "
                                    "external "
                                    "action, "
                                    "a "
                                    "data "
                                    "transformation, "
                                    "or "
                                    "a "
                                    "state "
                                    "variable.",
                                    "oneOf": [
                                        {
                                            "description": "An "
                                            "action "
                                            "query. "
                                            "This "
                                            "query "
                                            "type "
                                            "is "
                                            "used "
                                            "to "
                                            "trigger "
                                            "an "
                                            "action, "
                                            "such "
                                            "as "
                                            "sending "
                                            "a "
                                            "HTTP "
                                            "request.",
                                            "properties": {
                                                "events": {
                                                    "description": "Events "
                                                    "to "
                                                    "listen "
                                                    "for "
                                                    "downstream "
                                                    "of "
                                                    "the "
                                                    "action "
                                                    "query.",
                                                    "items": {
                                                        "additionalProperties": {},
                                                        "description": "An "
                                                        "event "
                                                        "on "
                                                        "a "
                                                        "UI "
                                                        "component "
                                                        "that "
                                                        "triggers "
                                                        "a "
                                                        "response "
                                                        "or "
                                                        "action "
                                                        "in "
                                                        "an "
                                                        "app.",
                                                        "properties": {
                                                            "name": {
                                                                "description": "The "
                                                                "triggering "
                                                                "action "
                                                                "for "
                                                                "the "
                                                                "event.",
                                                                "enum": [
                                                                    "pageChange",
                                                                    "tableRowClick",
                                                                    "_tableRowButtonClick",
                                                                    "change",
                                                                    "submit",
                                                                    "click",
                                                                    "toggleOpen",
                                                                    "close",
                                                                    "open",
                                                                    "executionFinished",
                                                                ],
                                                                "example": "click",
                                                                "type": "string",
                                                                "x-enum-varnames": [
                                                                    "PAGECHANGE",
                                                                    "TABLEROWCLICK",
                                                                    "TABLEROWBUTTONCLICK",
                                                                    "CHANGE",
                                                                    "SUBMIT",
                                                                    "CLICK",
                                                                    "TOGGLEOPEN",
                                                                    "CLOSE",
                                                                    "OPEN",
                                                                    "EXECUTIONFINISHED",
                                                                ],
                                                            },
                                                            "type": {
                                                                "description": "The "
                                                                "response "
                                                                "to "
                                                                "the "
                                                                "event.",
                                                                "enum": [
                                                                    "custom",
                                                                    "setComponentState",
                                                                    "triggerQuery",
                                                                    "openModal",
                                                                    "closeModal",
                                                                    "openUrl",
                                                                    "downloadFile",
                                                                    "setStateVariableValue",
                                                                ],
                                                                "example": "triggerQuery",
                                                                "type": "string",
                                                                "x-enum-varnames": [
                                                                    "CUSTOM",
                                                                    "SETCOMPONENTSTATE",
                                                                    "TRIGGERQUERY",
                                                                    "OPENMODAL",
                                                                    "CLOSEMODAL",
                                                                    "OPENURL",
                                                                    "DOWNLOADFILE",
                                                                    "SETSTATEVARIABLEVALUE",
                                                                ],
                                                            },
                                                        },
                                                        "type": "object",
                                                    },
                                                    "type": "array",
                                                },
                                                "id": {
                                                    "description": "The ID of the action query.",
                                                    "example": "65bb1f25-52e1-4510-9f8d-22d1516ed693",
                                                    "format": "uuid",
                                                    "type": "string",
                                                },
                                                "name": {
                                                    "description": "A "
                                                    "unique "
                                                    "identifier "
                                                    "for "
                                                    "this "
                                                    "action "
                                                    "query. "
                                                    "This "
                                                    "name "
                                                    "is "
                                                    "also "
                                                    "used "
                                                    "to "
                                                    "access "
                                                    "the "
                                                    "query's "
                                                    "result "
                                                    "throughout "
                                                    "the "
                                                    "app.",
                                                    "example": "fetchPendingOrders",
                                                    "type": "string",
                                                },
                                                "properties": {
                                                    "description": "The "
                                                    "properties "
                                                    "of "
                                                    "the "
                                                    "action "
                                                    "query.",
                                                    "properties": {
                                                        "condition": {
                                                            "description": "Whether "
                                                            "to "
                                                            "run "
                                                            "this "
                                                            "query. "
                                                            "If "
                                                            "specified, "
                                                            "the "
                                                            "query "
                                                            "will "
                                                            "only "
                                                            "run "
                                                            "if "
                                                            "this "
                                                            "condition "
                                                            "evaluates "
                                                            "to "
                                                            "`true` "
                                                            "in "
                                                            "JavaScript "
                                                            "and "
                                                            "all "
                                                            "other "
                                                            "conditions "
                                                            "are "
                                                            "also "
                                                            "met.",
                                                            "oneOf": [
                                                                {"type": "boolean"},
                                                                {
                                                                    "example": "${true}",
                                                                    "type": "string",
                                                                },
                                                            ],
                                                        },
                                                        "debounceInMs": {
                                                            "description": "The "
                                                            "minimum "
                                                            "time "
                                                            "in "
                                                            "milliseconds "
                                                            "that "
                                                            "must "
                                                            "pass "
                                                            "before "
                                                            "the "
                                                            "query "
                                                            "can "
                                                            "be "
                                                            "triggered "
                                                            "again. "
                                                            "This "
                                                            "is "
                                                            "useful "
                                                            "for "
                                                            "preventing "
                                                            "accidental "
                                                            "double-clicks "
                                                            "from "
                                                            "triggering "
                                                            "the "
                                                            "query "
                                                            "multiple "
                                                            "times.",
                                                            "oneOf": [
                                                                {
                                                                    "example": 310.5,
                                                                    "format": "double",
                                                                    "type": "number",
                                                                },
                                                                {
                                                                    "description": "If "
                                                                    "this "
                                                                    "is "
                                                                    "a "
                                                                    "string, "
                                                                    "it "
                                                                    "must "
                                                                    "be "
                                                                    "a "
                                                                    "valid "
                                                                    "JavaScript "
                                                                    "expression "
                                                                    "that "
                                                                    "evaluates "
                                                                    "to "
                                                                    "a "
                                                                    "number.",
                                                                    "example": "${1000}",
                                                                    "type": "string",
                                                                },
                                                            ],
                                                        },
                                                        "mockedOutputs": {
                                                            "description": "The "
                                                            "mocked "
                                                            "outputs "
                                                            "of "
                                                            "the "
                                                            "action "
                                                            "query. "
                                                            "This "
                                                            "is "
                                                            "useful "
                                                            "for "
                                                            "testing "
                                                            "the "
                                                            "app "
                                                            "without "
                                                            "actually "
                                                            "running "
                                                            "the "
                                                            "action.",
                                                            "oneOf": [
                                                                {"type": "string"},
                                                                {
                                                                    "description": "The "
                                                                    "mocked "
                                                                    "outputs "
                                                                    "of "
                                                                    "the "
                                                                    "action "
                                                                    "query.",
                                                                    "properties": {
                                                                        "enabled": {
                                                                            "description": "Whether "
                                                                            "to "
                                                                            "enable "
                                                                            "the "
                                                                            "mocked "
                                                                            "outputs "
                                                                            "for "
                                                                            "testing.",
                                                                            "oneOf": [
                                                                                {"type": "boolean"},
                                                                                {
                                                                                    "description": "If "
                                                                                    "this "
                                                                                    "is "
                                                                                    "a "
                                                                                    "string, "
                                                                                    "it "
                                                                                    "must "
                                                                                    "be "
                                                                                    "a "
                                                                                    "valid "
                                                                                    "JavaScript "
                                                                                    "expression "
                                                                                    "that "
                                                                                    "evaluates "
                                                                                    "to "
                                                                                    "a "
                                                                                    "boolean.",
                                                                                    "example": "${true}",
                                                                                    "type": "string",
                                                                                },
                                                                            ],
                                                                        },
                                                                        "outputs": {
                                                                            "description": "The "
                                                                            "mocked "
                                                                            "outputs "
                                                                            "of "
                                                                            "the "
                                                                            "action "
                                                                            "query, "
                                                                            "serialized "
                                                                            "as "
                                                                            "JSON.",
                                                                            "example": '{"status": '
                                                                            '"success"}',
                                                                            "type": "string",
                                                                        },
                                                                    },
                                                                    "required": ["enabled"],
                                                                    "type": "object",
                                                                },
                                                            ],
                                                        },
                                                        "onlyTriggerManually": {
                                                            "description": "Determines "
                                                            "when "
                                                            "this "
                                                            "query "
                                                            "is "
                                                            "executed. "
                                                            "If "
                                                            "set "
                                                            "to "
                                                            "`false`, "
                                                            "the "
                                                            "query "
                                                            "will "
                                                            "run "
                                                            "when "
                                                            "the "
                                                            "app "
                                                            "loads "
                                                            "and "
                                                            "whenever "
                                                            "any "
                                                            "query "
                                                            "arguments "
                                                            "change. "
                                                            "If "
                                                            "set "
                                                            "to "
                                                            "`true`, "
                                                            "the "
                                                            "query "
                                                            "will "
                                                            "only "
                                                            "run "
                                                            "when "
                                                            "manually "
                                                            "triggered "
                                                            "from "
                                                            "elsewhere "
                                                            "in "
                                                            "the "
                                                            "app.",
                                                            "oneOf": [
                                                                {"type": "boolean"},
                                                                {
                                                                    "description": "If "
                                                                    "this "
                                                                    "is "
                                                                    "a "
                                                                    "string, "
                                                                    "it "
                                                                    "must "
                                                                    "be "
                                                                    "a "
                                                                    "valid "
                                                                    "JavaScript "
                                                                    "expression "
                                                                    "that "
                                                                    "evaluates "
                                                                    "to "
                                                                    "a "
                                                                    "boolean.",
                                                                    "example": "${true}",
                                                                    "type": "string",
                                                                },
                                                            ],
                                                        },
                                                        "outputs": {
                                                            "description": "The "
                                                            "post-query "
                                                            "transformation "
                                                            "function, "
                                                            "which "
                                                            "is "
                                                            "a "
                                                            "JavaScript "
                                                            "function "
                                                            "that "
                                                            "changes "
                                                            "the "
                                                            "query's "
                                                            "`.outputs` "
                                                            "property "
                                                            "after "
                                                            "the "
                                                            "query's "
                                                            "execution.",
                                                            "example": "${((outputs) "
                                                            "=> "
                                                            "{return "
                                                            "outputs.body.data})(self.rawOutputs)}",
                                                            "type": "string",
                                                        },
                                                        "pollingIntervalInMs": {
                                                            "description": "If "
                                                            "specified, "
                                                            "the "
                                                            "app "
                                                            "will "
                                                            "poll "
                                                            "the "
                                                            "query "
                                                            "at "
                                                            "the "
                                                            "specified "
                                                            "interval "
                                                            "in "
                                                            "milliseconds. "
                                                            "The "
                                                            "minimum "
                                                            "polling "
                                                            "interval "
                                                            "is "
                                                            "15 "
                                                            "seconds. "
                                                            "The "
                                                            "query "
                                                            "will "
                                                            "only "
                                                            "poll "
                                                            "when "
                                                            "the "
                                                            "app's "
                                                            "browser "
                                                            "tab "
                                                            "is "
                                                            "active.",
                                                            "oneOf": [
                                                                {
                                                                    "example": 30000.0,
                                                                    "format": "double",
                                                                    "minimum": 15000.0,
                                                                    "type": "number",
                                                                },
                                                                {
                                                                    "description": "If "
                                                                    "this "
                                                                    "is "
                                                                    "a "
                                                                    "string, "
                                                                    "it "
                                                                    "must "
                                                                    "be "
                                                                    "a "
                                                                    "valid "
                                                                    "JavaScript "
                                                                    "expression "
                                                                    "that "
                                                                    "evaluates "
                                                                    "to "
                                                                    "a "
                                                                    "number.",
                                                                    "example": "${15000}",
                                                                    "type": "string",
                                                                },
                                                            ],
                                                        },
                                                        "requiresConfirmation": {
                                                            "description": "Whether "
                                                            "to "
                                                            "prompt "
                                                            "the "
                                                            "user "
                                                            "to "
                                                            "confirm "
                                                            "this "
                                                            "query "
                                                            "before "
                                                            "it "
                                                            "runs.",
                                                            "oneOf": [
                                                                {"type": "boolean"},
                                                                {
                                                                    "description": "If "
                                                                    "this "
                                                                    "is "
                                                                    "a "
                                                                    "string, "
                                                                    "it "
                                                                    "must "
                                                                    "be "
                                                                    "a "
                                                                    "valid "
                                                                    "JavaScript "
                                                                    "expression "
                                                                    "that "
                                                                    "evaluates "
                                                                    "to "
                                                                    "a "
                                                                    "boolean.",
                                                                    "example": "${true}",
                                                                    "type": "string",
                                                                },
                                                            ],
                                                        },
                                                        "showToastOnError": {
                                                            "description": "Whether "
                                                            "to "
                                                            "display "
                                                            "a "
                                                            "toast "
                                                            "to "
                                                            "the "
                                                            "user "
                                                            "when "
                                                            "the "
                                                            "query "
                                                            "returns "
                                                            "an "
                                                            "error.",
                                                            "oneOf": [
                                                                {"type": "boolean"},
                                                                {
                                                                    "description": "If "
                                                                    "this "
                                                                    "is "
                                                                    "a "
                                                                    "string, "
                                                                    "it "
                                                                    "must "
                                                                    "be "
                                                                    "a "
                                                                    "valid "
                                                                    "JavaScript "
                                                                    "expression "
                                                                    "that "
                                                                    "evaluates "
                                                                    "to "
                                                                    "a "
                                                                    "boolean.",
                                                                    "example": "${true}",
                                                                    "type": "string",
                                                                },
                                                            ],
                                                        },
                                                        "spec": {
                                                            "description": "The "
                                                            "definition "
                                                            "of "
                                                            "the "
                                                            "action "
                                                            "query.",
                                                            "oneOf": [
                                                                {"type": "string"},
                                                                {
                                                                    "description": "The "
                                                                    "action "
                                                                    "query "
                                                                    "spec "
                                                                    "object.",
                                                                    "properties": {
                                                                        "connectionGroup": {
                                                                            "description": "The "
                                                                            "connection "
                                                                            "group "
                                                                            "to "
                                                                            "use "
                                                                            "for "
                                                                            "an "
                                                                            "action "
                                                                            "query.",
                                                                            "properties": {
                                                                                "id": {
                                                                                    "description": "The "
                                                                                    "ID "
                                                                                    "of "
                                                                                    "the "
                                                                                    "connection "
                                                                                    "group.",
                                                                                    "example": "65bb1f25-52e1-4510-9f8d-22d1516ed693",
                                                                                    "format": "uuid",
                                                                                    "type": "string",
                                                                                },
                                                                                "tags": {
                                                                                    "description": "The "
                                                                                    "tags "
                                                                                    "of "
                                                                                    "the "
                                                                                    "connection "
                                                                                    "group.",
                                                                                    "items": {
                                                                                        "type": "string"
                                                                                    },
                                                                                    "type": "array",
                                                                                },
                                                                            },
                                                                            "type": "object",
                                                                        },
                                                                        "connectionId": {
                                                                            "description": "The "
                                                                            "ID "
                                                                            "of "
                                                                            "the "
                                                                            "custom "
                                                                            "connection "
                                                                            "to "
                                                                            "use "
                                                                            "for "
                                                                            "this "
                                                                            "action "
                                                                            "query.",
                                                                            "example": "65bb1f25-52e1-4510-9f8d-22d1516ed693",
                                                                            "type": "string",
                                                                        },
                                                                        "fqn": {
                                                                            "description": "The "
                                                                            "fully "
                                                                            "qualified "
                                                                            "name "
                                                                            "of "
                                                                            "the "
                                                                            "action "
                                                                            "type.",
                                                                            "example": "com.datadoghq.http.request",
                                                                            "type": "string",
                                                                        },
                                                                        "inputs": {
                                                                            "description": "The "
                                                                            "inputs "
                                                                            "to "
                                                                            "the "
                                                                            "action "
                                                                            "query. "
                                                                            "These "
                                                                            "are "
                                                                            "the "
                                                                            "values "
                                                                            "that "
                                                                            "are "
                                                                            "passed "
                                                                            "to "
                                                                            "the "
                                                                            "action "
                                                                            "when "
                                                                            "it "
                                                                            "is "
                                                                            "triggered.",
                                                                            "oneOf": [
                                                                                {"type": "string"},
                                                                                {
                                                                                    "additionalProperties": {},
                                                                                    "description": "The "
                                                                                    "inputs "
                                                                                    "to "
                                                                                    "the "
                                                                                    "action "
                                                                                    "query. "
                                                                                    "See "
                                                                                    "the "
                                                                                    "[Actions "
                                                                                    "Catalog](https://docs.datadoghq.com/actions/actions_catalog/) "
                                                                                    "for "
                                                                                    "more "
                                                                                    "detail "
                                                                                    "on "
                                                                                    "each "
                                                                                    "action "
                                                                                    "and "
                                                                                    "its "
                                                                                    "inputs.",
                                                                                    "type": "object",
                                                                                },
                                                                            ],
                                                                        },
                                                                    },
                                                                    "required": ["fqn"],
                                                                    "type": "object",
                                                                },
                                                            ],
                                                        },
                                                    },
                                                    "required": ["spec"],
                                                    "type": "object",
                                                },
                                                "type": {
                                                    "default": "action",
                                                    "description": "The action query type.",
                                                    "enum": ["action"],
                                                    "example": "action",
                                                    "type": "string",
                                                    "x-enum-varnames": ["ACTION"],
                                                },
                                            },
                                            "required": ["id", "name", "type", "properties"],
                                            "type": "object",
                                        },
                                        {
                                            "description": "A "
                                            "data "
                                            "transformer, "
                                            "which "
                                            "is "
                                            "custom "
                                            "JavaScript "
                                            "code "
                                            "that "
                                            "executes "
                                            "and "
                                            "transforms "
                                            "data "
                                            "when "
                                            "its "
                                            "inputs "
                                            "change.",
                                            "properties": {
                                                "id": {
                                                    "description": "The "
                                                    "ID "
                                                    "of "
                                                    "the "
                                                    "data "
                                                    "transformer.",
                                                    "example": "65bb1f25-52e1-4510-9f8d-22d1516ed693",
                                                    "format": "uuid",
                                                    "type": "string",
                                                },
                                                "name": {
                                                    "description": "A "
                                                    "unique "
                                                    "identifier "
                                                    "for "
                                                    "this "
                                                    "data "
                                                    "transformer. "
                                                    "This "
                                                    "name "
                                                    "is "
                                                    "also "
                                                    "used "
                                                    "to "
                                                    "access "
                                                    "the "
                                                    "transformer's "
                                                    "result "
                                                    "throughout "
                                                    "the "
                                                    "app.",
                                                    "example": "combineTwoOrders",
                                                    "type": "string",
                                                },
                                                "properties": {
                                                    "description": "The "
                                                    "properties "
                                                    "of "
                                                    "the "
                                                    "data "
                                                    "transformer.",
                                                    "properties": {
                                                        "outputs": {
                                                            "description": "A "
                                                            "JavaScript "
                                                            "function "
                                                            "that "
                                                            "returns "
                                                            "the "
                                                            "transformed "
                                                            "data.",
                                                            "example": "${(() "
                                                            "=> "
                                                            "{return "
                                                            "{\n"
                                                            "    "
                                                            "allItems: "
                                                            "[...fetchOrder1.outputs.items, "
                                                            "...fetchOrder2.outputs.items],\n"
                                                            "}})()}",
                                                            "type": "string",
                                                        }
                                                    },
                                                    "type": "object",
                                                },
                                                "type": {
                                                    "default": "dataTransform",
                                                    "description": "The data transform type.",
                                                    "enum": ["dataTransform"],
                                                    "example": "dataTransform",
                                                    "type": "string",
                                                    "x-enum-varnames": ["DATATRANSFORM"],
                                                },
                                            },
                                            "required": ["id", "name", "type", "properties"],
                                            "type": "object",
                                        },
                                        {
                                            "description": "A "
                                            "variable, "
                                            "which "
                                            "can "
                                            "be "
                                            "set "
                                            "and "
                                            "read "
                                            "by "
                                            "other "
                                            "components "
                                            "in "
                                            "the "
                                            "app.",
                                            "properties": {
                                                "id": {
                                                    "description": "The ID of the state variable.",
                                                    "example": "65bb1f25-52e1-4510-9f8d-22d1516ed693",
                                                    "format": "uuid",
                                                    "type": "string",
                                                },
                                                "name": {
                                                    "description": "A "
                                                    "unique "
                                                    "identifier "
                                                    "for "
                                                    "this "
                                                    "state "
                                                    "variable. "
                                                    "This "
                                                    "name "
                                                    "is "
                                                    "also "
                                                    "used "
                                                    "to "
                                                    "access "
                                                    "the "
                                                    "variable's "
                                                    "value "
                                                    "throughout "
                                                    "the "
                                                    "app.",
                                                    "example": "ordersToSubmit",
                                                    "type": "string",
                                                },
                                                "properties": {
                                                    "description": "The "
                                                    "properties "
                                                    "of "
                                                    "the "
                                                    "state "
                                                    "variable.",
                                                    "properties": {
                                                        "defaultValue": {
                                                            "description": "The "
                                                            "default "
                                                            "value "
                                                            "of "
                                                            "the "
                                                            "state "
                                                            "variable.",
                                                            "example": "${['order_3145', "
                                                            "'order_4920']}",
                                                        }
                                                    },
                                                    "type": "object",
                                                },
                                                "type": {
                                                    "default": "stateVariable",
                                                    "description": "The state variable type.",
                                                    "enum": ["stateVariable"],
                                                    "example": "stateVariable",
                                                    "type": "string",
                                                    "x-enum-varnames": ["STATEVARIABLE"],
                                                },
                                            },
                                            "required": ["id", "name", "type", "properties"],
                                            "type": "object",
                                        },
                                    ],
                                },
                                "type": "array",
                            },
                            "rootInstanceName": {
                                "description": "The "
                                "name "
                                "of "
                                "the "
                                "root "
                                "component "
                                "of "
                                "the "
                                "app. "
                                "This "
                                "must "
                                "be "
                                "a "
                                "`grid` "
                                "component "
                                "that "
                                "contains "
                                "all "
                                "other "
                                "components.",
                                "type": "string",
                            },
                            "tags": {
                                "description": "A "
                                "list "
                                "of "
                                "tags "
                                "for "
                                "the "
                                "app, "
                                "which "
                                "can "
                                "be "
                                "used "
                                "to "
                                "filter "
                                "apps.",
                                "example": ["service:webshop-backend", "team:webshop"],
                                "items": {
                                    "description": "An individual tag for the app.",
                                    "type": "string",
                                },
                                "type": "array",
                            },
                        },
                        "type": "object",
                    },
                    "type": {
                        "default": "appDefinitions",
                        "description": "The app definition type.",
                        "enum": ["appDefinitions"],
                        "example": "appDefinitions",
                        "type": "string",
                        "x-enum-varnames": ["APPDEFINITIONS"],
                    },
                },
                "required": ["type"],
                "type": "object",
            }
        },
        "type": "object",
    },
    "UPDATEAPPVERSION_REQUEST_BODY_SCHEMA": {
        "description": "A request object for updating an existing app.",
        "example": {
            "data": {
                "attributes": {
                    "components": [
                        {
                            "events": [],
                            "name": "grid0",
                            "properties": {
                                "children": [
                                    {
                                        "events": [],
                                        "name": "gridCell0",
                                        "properties": {
                                            "children": [
                                                {
                                                    "events": [],
                                                    "name": "calloutValue0",
                                                    "properties": {
                                                        "isDisabled": False,
                                                        "isLoading": False,
                                                        "isVisible": True,
                                                        "label": "CPU Usage",
                                                        "size": "sm",
                                                        "style": "vivid_yellow",
                                                        "unit": "kB",
                                                        "value": "42",
                                                    },
                                                    "type": "calloutValue",
                                                }
                                            ],
                                            "isVisible": "true",
                                            "layout": {
                                                "default": {"height": 8, "width": 2, "x": 0, "y": 0}
                                            },
                                        },
                                        "type": "gridCell",
                                    }
                                ]
                            },
                            "type": "grid",
                        }
                    ],
                    "description": "This is a simple example app",
                    "name": "Example App",
                    "queries": [],
                    "rootInstanceName": "grid0",
                },
                "id": "9e20cbaf-68da-45a6-9ccf-54193ac29fa5",
                "type": "appDefinitions",
            }
        },
        "properties": {
            "data": {
                "description": "The data object containing the new app "
                "definition. Any fields not included in the "
                "request remain unchanged.",
                "properties": {
                    "attributes": {
                        "description": "App definition "
                        "attributes to "
                        "be updated, "
                        "such as name, "
                        "description, "
                        "and components.",
                        "properties": {
                            "components": {
                                "description": "The "
                                "new "
                                "UI "
                                "components "
                                "that "
                                "make "
                                "up "
                                "the "
                                "app. "
                                "If "
                                "this "
                                "field "
                                "is "
                                "set, "
                                "all "
                                "existing "
                                "components "
                                "are "
                                "replaced "
                                "with "
                                "the "
                                "new "
                                "components "
                                "under "
                                "this "
                                "field.",
                                "items": {
                                    "description": "A "
                                    "grid "
                                    "component. "
                                    "The "
                                    "grid "
                                    "component "
                                    "is "
                                    "the "
                                    "root "
                                    "canvas "
                                    "for "
                                    "an "
                                    "app "
                                    "and "
                                    "contains "
                                    "all "
                                    "other "
                                    "components.",
                                    "properties": {
                                        "events": {
                                            "description": "Events "
                                            "to "
                                            "listen "
                                            "for "
                                            "on "
                                            "the "
                                            "grid "
                                            "component.",
                                            "items": {
                                                "additionalProperties": {},
                                                "description": "An "
                                                "event "
                                                "on "
                                                "a "
                                                "UI "
                                                "component "
                                                "that "
                                                "triggers "
                                                "a "
                                                "response "
                                                "or "
                                                "action "
                                                "in "
                                                "an "
                                                "app.",
                                                "properties": {
                                                    "name": {
                                                        "description": "The "
                                                        "triggering "
                                                        "action "
                                                        "for "
                                                        "the "
                                                        "event.",
                                                        "enum": [
                                                            "pageChange",
                                                            "tableRowClick",
                                                            "_tableRowButtonClick",
                                                            "change",
                                                            "submit",
                                                            "click",
                                                            "toggleOpen",
                                                            "close",
                                                            "open",
                                                            "executionFinished",
                                                        ],
                                                        "example": "click",
                                                        "type": "string",
                                                        "x-enum-varnames": [
                                                            "PAGECHANGE",
                                                            "TABLEROWCLICK",
                                                            "TABLEROWBUTTONCLICK",
                                                            "CHANGE",
                                                            "SUBMIT",
                                                            "CLICK",
                                                            "TOGGLEOPEN",
                                                            "CLOSE",
                                                            "OPEN",
                                                            "EXECUTIONFINISHED",
                                                        ],
                                                    },
                                                    "type": {
                                                        "description": "The response to the event.",
                                                        "enum": [
                                                            "custom",
                                                            "setComponentState",
                                                            "triggerQuery",
                                                            "openModal",
                                                            "closeModal",
                                                            "openUrl",
                                                            "downloadFile",
                                                            "setStateVariableValue",
                                                        ],
                                                        "example": "triggerQuery",
                                                        "type": "string",
                                                        "x-enum-varnames": [
                                                            "CUSTOM",
                                                            "SETCOMPONENTSTATE",
                                                            "TRIGGERQUERY",
                                                            "OPENMODAL",
                                                            "CLOSEMODAL",
                                                            "OPENURL",
                                                            "DOWNLOADFILE",
                                                            "SETSTATEVARIABLEVALUE",
                                                        ],
                                                    },
                                                },
                                                "type": "object",
                                            },
                                            "type": "array",
                                        },
                                        "id": {
                                            "description": "The "
                                            "ID "
                                            "of "
                                            "the "
                                            "grid "
                                            "component. "
                                            "This "
                                            "property "
                                            "is "
                                            "deprecated; "
                                            "use "
                                            "`name` "
                                            "to "
                                            "identify "
                                            "individual "
                                            "components "
                                            "instead.",
                                            "type": "string",
                                        },
                                        "name": {
                                            "description": "A "
                                            "unique "
                                            "identifier "
                                            "for "
                                            "this "
                                            "grid "
                                            "component. "
                                            "This "
                                            "name "
                                            "is "
                                            "also "
                                            "visible "
                                            "in "
                                            "the "
                                            "app "
                                            "editor.",
                                            "example": "",
                                            "type": "string",
                                        },
                                        "properties": {
                                            "description": "Properties of a grid component.",
                                            "properties": {
                                                "backgroundColor": {
                                                    "default": "default",
                                                    "description": "The "
                                                    "background "
                                                    "color "
                                                    "of "
                                                    "the "
                                                    "grid.",
                                                    "type": "string",
                                                },
                                                "children": {
                                                    "description": "The "
                                                    "child "
                                                    "components "
                                                    "of "
                                                    "the "
                                                    "grid.",
                                                    "items": {
                                                        "description": "[Definition "
                                                        "of "
                                                        "a "
                                                        "UI "
                                                        "component "
                                                        "in "
                                                        "the "
                                                        "app](https://docs.datadoghq.com/service_management/app_builder/components/)",
                                                        "properties": {
                                                            "events": {
                                                                "description": "Events "
                                                                "to "
                                                                "listen "
                                                                "for "
                                                                "on "
                                                                "the "
                                                                "UI "
                                                                "component.",
                                                                "items": {
                                                                    "additionalProperties": {},
                                                                    "description": "An "
                                                                    "event "
                                                                    "on "
                                                                    "a "
                                                                    "UI "
                                                                    "component "
                                                                    "that "
                                                                    "triggers "
                                                                    "a "
                                                                    "response "
                                                                    "or "
                                                                    "action "
                                                                    "in "
                                                                    "an "
                                                                    "app.",
                                                                    "properties": {
                                                                        "name": {
                                                                            "description": "The "
                                                                            "triggering "
                                                                            "action "
                                                                            "for "
                                                                            "the "
                                                                            "event.",
                                                                            "enum": [
                                                                                "pageChange",
                                                                                "tableRowClick",
                                                                                "_tableRowButtonClick",
                                                                                "change",
                                                                                "submit",
                                                                                "click",
                                                                                "toggleOpen",
                                                                                "close",
                                                                                "open",
                                                                                "executionFinished",
                                                                            ],
                                                                            "example": "click",
                                                                            "type": "string",
                                                                            "x-enum-varnames": [
                                                                                "PAGECHANGE",
                                                                                "TABLEROWCLICK",
                                                                                "TABLEROWBUTTONCLICK",
                                                                                "CHANGE",
                                                                                "SUBMIT",
                                                                                "CLICK",
                                                                                "TOGGLEOPEN",
                                                                                "CLOSE",
                                                                                "OPEN",
                                                                                "EXECUTIONFINISHED",
                                                                            ],
                                                                        },
                                                                        "type": {
                                                                            "description": "The "
                                                                            "response "
                                                                            "to "
                                                                            "the "
                                                                            "event.",
                                                                            "enum": [
                                                                                "custom",
                                                                                "setComponentState",
                                                                                "triggerQuery",
                                                                                "openModal",
                                                                                "closeModal",
                                                                                "openUrl",
                                                                                "downloadFile",
                                                                                "setStateVariableValue",
                                                                            ],
                                                                            "example": "triggerQuery",
                                                                            "type": "string",
                                                                            "x-enum-varnames": [
                                                                                "CUSTOM",
                                                                                "SETCOMPONENTSTATE",
                                                                                "TRIGGERQUERY",
                                                                                "OPENMODAL",
                                                                                "CLOSEMODAL",
                                                                                "OPENURL",
                                                                                "DOWNLOADFILE",
                                                                                "SETSTATEVARIABLEVALUE",
                                                                            ],
                                                                        },
                                                                    },
                                                                    "type": "object",
                                                                },
                                                                "type": "array",
                                                            },
                                                            "id": {
                                                                "description": "The "
                                                                "ID "
                                                                "of "
                                                                "the "
                                                                "UI "
                                                                "component. "
                                                                "This "
                                                                "property "
                                                                "is "
                                                                "deprecated; "
                                                                "use "
                                                                "`name` "
                                                                "to "
                                                                "identify "
                                                                "individual "
                                                                "components "
                                                                "instead.",
                                                                "nullable": True,
                                                                "type": "string",
                                                            },
                                                            "name": {
                                                                "description": "A "
                                                                "unique "
                                                                "identifier "
                                                                "for "
                                                                "this "
                                                                "UI "
                                                                "component. "
                                                                "This "
                                                                "name "
                                                                "is "
                                                                "also "
                                                                "visible "
                                                                "in "
                                                                "the "
                                                                "app "
                                                                "editor.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                            "properties": {
                                                                "additionalProperties": {},
                                                                "description": "Properties "
                                                                "of "
                                                                "a "
                                                                "UI "
                                                                "component. "
                                                                "Different "
                                                                "component "
                                                                "types "
                                                                "can "
                                                                "have "
                                                                "their "
                                                                "own "
                                                                "additional "
                                                                "unique "
                                                                "properties. "
                                                                "See "
                                                                "the "
                                                                "[components "
                                                                "documentation](https://docs.datadoghq.com/service_management/app_builder/components/) "
                                                                "for "
                                                                "more "
                                                                "detail "
                                                                "on "
                                                                "each "
                                                                "component "
                                                                "type "
                                                                "and "
                                                                "its "
                                                                "properties.",
                                                                "properties": {
                                                                    "children": {
                                                                        "description": "The "
                                                                        "child "
                                                                        "components "
                                                                        "of "
                                                                        "the "
                                                                        "UI "
                                                                        "component.",
                                                                        "items": {
                                                                            "$ref": "#/components/schemas/Component",
                                                                            "has_circular_reference": True,
                                                                        },
                                                                        "type": "array",
                                                                    },
                                                                    "isVisible": {
                                                                        "description": "Whether "
                                                                        "the "
                                                                        "UI "
                                                                        "component "
                                                                        "is "
                                                                        "visible. "
                                                                        "If "
                                                                        "this "
                                                                        "is "
                                                                        "a "
                                                                        "string, "
                                                                        "it "
                                                                        "must "
                                                                        "be "
                                                                        "a "
                                                                        "valid "
                                                                        "JavaScript "
                                                                        "expression "
                                                                        "that "
                                                                        "evaluates "
                                                                        "to "
                                                                        "a "
                                                                        "boolean.",
                                                                        "oneOf": [
                                                                            {"type": "boolean"},
                                                                            {
                                                                                "description": "If "
                                                                                "this "
                                                                                "is "
                                                                                "a "
                                                                                "string, "
                                                                                "it "
                                                                                "must "
                                                                                "be "
                                                                                "a "
                                                                                "valid "
                                                                                "JavaScript "
                                                                                "expression "
                                                                                "that "
                                                                                "evaluates "
                                                                                "to "
                                                                                "a "
                                                                                "boolean.",
                                                                                "example": "${true}",
                                                                                "type": "string",
                                                                            },
                                                                        ],
                                                                    },
                                                                },
                                                                "type": "object",
                                                            },
                                                            "type": {
                                                                "description": "The "
                                                                "UI "
                                                                "component "
                                                                "type.",
                                                                "enum": [
                                                                    "table",
                                                                    "textInput",
                                                                    "textArea",
                                                                    "button",
                                                                    "text",
                                                                    "select",
                                                                    "modal",
                                                                    "schemaForm",
                                                                    "checkbox",
                                                                    "tabs",
                                                                    "vegaChart",
                                                                    "radioButtons",
                                                                    "numberInput",
                                                                    "fileInput",
                                                                    "jsonInput",
                                                                    "gridCell",
                                                                    "dateRangePicker",
                                                                    "search",
                                                                    "container",
                                                                    "calloutValue",
                                                                ],
                                                                "example": "text",
                                                                "type": "string",
                                                                "x-enum-varnames": [
                                                                    "TABLE",
                                                                    "TEXTINPUT",
                                                                    "TEXTAREA",
                                                                    "BUTTON",
                                                                    "TEXT",
                                                                    "SELECT",
                                                                    "MODAL",
                                                                    "SCHEMAFORM",
                                                                    "CHECKBOX",
                                                                    "TABS",
                                                                    "VEGACHART",
                                                                    "RADIOBUTTONS",
                                                                    "NUMBERINPUT",
                                                                    "FILEINPUT",
                                                                    "JSONINPUT",
                                                                    "GRIDCELL",
                                                                    "DATERANGEPICKER",
                                                                    "SEARCH",
                                                                    "CONTAINER",
                                                                    "CALLOUTVALUE",
                                                                ],
                                                            },
                                                        },
                                                        "required": ["name", "type", "properties"],
                                                        "type": "object",
                                                    },
                                                    "type": "array",
                                                },
                                                "isVisible": {
                                                    "description": "Whether "
                                                    "the "
                                                    "grid "
                                                    "component "
                                                    "and "
                                                    "its "
                                                    "children "
                                                    "are "
                                                    "visible. "
                                                    "If "
                                                    "a "
                                                    "string, "
                                                    "it "
                                                    "must "
                                                    "be "
                                                    "a "
                                                    "valid "
                                                    "JavaScript "
                                                    "expression "
                                                    "that "
                                                    "evaluates "
                                                    "to "
                                                    "a "
                                                    "boolean.",
                                                    "oneOf": [
                                                        {"type": "string"},
                                                        {"default": True, "type": "boolean"},
                                                    ],
                                                },
                                            },
                                            "type": "object",
                                        },
                                        "type": {
                                            "default": "grid",
                                            "description": "The grid component type.",
                                            "enum": ["grid"],
                                            "example": "grid",
                                            "type": "string",
                                            "x-enum-varnames": ["GRID"],
                                        },
                                    },
                                    "required": ["name", "type", "properties"],
                                    "type": "object",
                                },
                                "type": "array",
                            },
                            "description": {
                                "description": "The new human-readable description for the app.",
                                "type": "string",
                            },
                            "name": {"description": "The new name of the app.", "type": "string"},
                            "queries": {
                                "description": "The "
                                "new "
                                "array "
                                "of "
                                "queries, "
                                "such "
                                "as "
                                "external "
                                "actions "
                                "and "
                                "state "
                                "variables, "
                                "that "
                                "the "
                                "app "
                                "uses. "
                                "If "
                                "this "
                                "field "
                                "is "
                                "set, "
                                "all "
                                "existing "
                                "queries "
                                "are "
                                "replaced "
                                "with "
                                "the "
                                "new "
                                "queries "
                                "under "
                                "this "
                                "field.",
                                "items": {
                                    "description": "A "
                                    "data "
                                    "query "
                                    "used "
                                    "by "
                                    "an "
                                    "app. "
                                    "This "
                                    "can "
                                    "take "
                                    "the "
                                    "form "
                                    "of "
                                    "an "
                                    "external "
                                    "action, "
                                    "a "
                                    "data "
                                    "transformation, "
                                    "or "
                                    "a "
                                    "state "
                                    "variable.",
                                    "oneOf": [
                                        {
                                            "description": "An "
                                            "action "
                                            "query. "
                                            "This "
                                            "query "
                                            "type "
                                            "is "
                                            "used "
                                            "to "
                                            "trigger "
                                            "an "
                                            "action, "
                                            "such "
                                            "as "
                                            "sending "
                                            "a "
                                            "HTTP "
                                            "request.",
                                            "properties": {
                                                "events": {
                                                    "description": "Events "
                                                    "to "
                                                    "listen "
                                                    "for "
                                                    "downstream "
                                                    "of "
                                                    "the "
                                                    "action "
                                                    "query.",
                                                    "items": {
                                                        "additionalProperties": {},
                                                        "description": "An "
                                                        "event "
                                                        "on "
                                                        "a "
                                                        "UI "
                                                        "component "
                                                        "that "
                                                        "triggers "
                                                        "a "
                                                        "response "
                                                        "or "
                                                        "action "
                                                        "in "
                                                        "an "
                                                        "app.",
                                                        "properties": {
                                                            "name": {
                                                                "description": "The "
                                                                "triggering "
                                                                "action "
                                                                "for "
                                                                "the "
                                                                "event.",
                                                                "enum": [
                                                                    "pageChange",
                                                                    "tableRowClick",
                                                                    "_tableRowButtonClick",
                                                                    "change",
                                                                    "submit",
                                                                    "click",
                                                                    "toggleOpen",
                                                                    "close",
                                                                    "open",
                                                                    "executionFinished",
                                                                ],
                                                                "example": "click",
                                                                "type": "string",
                                                                "x-enum-varnames": [
                                                                    "PAGECHANGE",
                                                                    "TABLEROWCLICK",
                                                                    "TABLEROWBUTTONCLICK",
                                                                    "CHANGE",
                                                                    "SUBMIT",
                                                                    "CLICK",
                                                                    "TOGGLEOPEN",
                                                                    "CLOSE",
                                                                    "OPEN",
                                                                    "EXECUTIONFINISHED",
                                                                ],
                                                            },
                                                            "type": {
                                                                "description": "The "
                                                                "response "
                                                                "to "
                                                                "the "
                                                                "event.",
                                                                "enum": [
                                                                    "custom",
                                                                    "setComponentState",
                                                                    "triggerQuery",
                                                                    "openModal",
                                                                    "closeModal",
                                                                    "openUrl",
                                                                    "downloadFile",
                                                                    "setStateVariableValue",
                                                                ],
                                                                "example": "triggerQuery",
                                                                "type": "string",
                                                                "x-enum-varnames": [
                                                                    "CUSTOM",
                                                                    "SETCOMPONENTSTATE",
                                                                    "TRIGGERQUERY",
                                                                    "OPENMODAL",
                                                                    "CLOSEMODAL",
                                                                    "OPENURL",
                                                                    "DOWNLOADFILE",
                                                                    "SETSTATEVARIABLEVALUE",
                                                                ],
                                                            },
                                                        },
                                                        "type": "object",
                                                    },
                                                    "type": "array",
                                                },
                                                "id": {
                                                    "description": "The ID of the action query.",
                                                    "example": "65bb1f25-52e1-4510-9f8d-22d1516ed693",
                                                    "format": "uuid",
                                                    "type": "string",
                                                },
                                                "name": {
                                                    "description": "A "
                                                    "unique "
                                                    "identifier "
                                                    "for "
                                                    "this "
                                                    "action "
                                                    "query. "
                                                    "This "
                                                    "name "
                                                    "is "
                                                    "also "
                                                    "used "
                                                    "to "
                                                    "access "
                                                    "the "
                                                    "query's "
                                                    "result "
                                                    "throughout "
                                                    "the "
                                                    "app.",
                                                    "example": "fetchPendingOrders",
                                                    "type": "string",
                                                },
                                                "properties": {
                                                    "description": "The "
                                                    "properties "
                                                    "of "
                                                    "the "
                                                    "action "
                                                    "query.",
                                                    "properties": {
                                                        "condition": {
                                                            "description": "Whether "
                                                            "to "
                                                            "run "
                                                            "this "
                                                            "query. "
                                                            "If "
                                                            "specified, "
                                                            "the "
                                                            "query "
                                                            "will "
                                                            "only "
                                                            "run "
                                                            "if "
                                                            "this "
                                                            "condition "
                                                            "evaluates "
                                                            "to "
                                                            "`true` "
                                                            "in "
                                                            "JavaScript "
                                                            "and "
                                                            "all "
                                                            "other "
                                                            "conditions "
                                                            "are "
                                                            "also "
                                                            "met.",
                                                            "oneOf": [
                                                                {"type": "boolean"},
                                                                {
                                                                    "example": "${true}",
                                                                    "type": "string",
                                                                },
                                                            ],
                                                        },
                                                        "debounceInMs": {
                                                            "description": "The "
                                                            "minimum "
                                                            "time "
                                                            "in "
                                                            "milliseconds "
                                                            "that "
                                                            "must "
                                                            "pass "
                                                            "before "
                                                            "the "
                                                            "query "
                                                            "can "
                                                            "be "
                                                            "triggered "
                                                            "again. "
                                                            "This "
                                                            "is "
                                                            "useful "
                                                            "for "
                                                            "preventing "
                                                            "accidental "
                                                            "double-clicks "
                                                            "from "
                                                            "triggering "
                                                            "the "
                                                            "query "
                                                            "multiple "
                                                            "times.",
                                                            "oneOf": [
                                                                {
                                                                    "example": 310.5,
                                                                    "format": "double",
                                                                    "type": "number",
                                                                },
                                                                {
                                                                    "description": "If "
                                                                    "this "
                                                                    "is "
                                                                    "a "
                                                                    "string, "
                                                                    "it "
                                                                    "must "
                                                                    "be "
                                                                    "a "
                                                                    "valid "
                                                                    "JavaScript "
                                                                    "expression "
                                                                    "that "
                                                                    "evaluates "
                                                                    "to "
                                                                    "a "
                                                                    "number.",
                                                                    "example": "${1000}",
                                                                    "type": "string",
                                                                },
                                                            ],
                                                        },
                                                        "mockedOutputs": {
                                                            "description": "The "
                                                            "mocked "
                                                            "outputs "
                                                            "of "
                                                            "the "
                                                            "action "
                                                            "query. "
                                                            "This "
                                                            "is "
                                                            "useful "
                                                            "for "
                                                            "testing "
                                                            "the "
                                                            "app "
                                                            "without "
                                                            "actually "
                                                            "running "
                                                            "the "
                                                            "action.",
                                                            "oneOf": [
                                                                {"type": "string"},
                                                                {
                                                                    "description": "The "
                                                                    "mocked "
                                                                    "outputs "
                                                                    "of "
                                                                    "the "
                                                                    "action "
                                                                    "query.",
                                                                    "properties": {
                                                                        "enabled": {
                                                                            "description": "Whether "
                                                                            "to "
                                                                            "enable "
                                                                            "the "
                                                                            "mocked "
                                                                            "outputs "
                                                                            "for "
                                                                            "testing.",
                                                                            "oneOf": [
                                                                                {"type": "boolean"},
                                                                                {
                                                                                    "description": "If "
                                                                                    "this "
                                                                                    "is "
                                                                                    "a "
                                                                                    "string, "
                                                                                    "it "
                                                                                    "must "
                                                                                    "be "
                                                                                    "a "
                                                                                    "valid "
                                                                                    "JavaScript "
                                                                                    "expression "
                                                                                    "that "
                                                                                    "evaluates "
                                                                                    "to "
                                                                                    "a "
                                                                                    "boolean.",
                                                                                    "example": "${true}",
                                                                                    "type": "string",
                                                                                },
                                                                            ],
                                                                        },
                                                                        "outputs": {
                                                                            "description": "The "
                                                                            "mocked "
                                                                            "outputs "
                                                                            "of "
                                                                            "the "
                                                                            "action "
                                                                            "query, "
                                                                            "serialized "
                                                                            "as "
                                                                            "JSON.",
                                                                            "example": '{"status": '
                                                                            '"success"}',
                                                                            "type": "string",
                                                                        },
                                                                    },
                                                                    "required": ["enabled"],
                                                                    "type": "object",
                                                                },
                                                            ],
                                                        },
                                                        "onlyTriggerManually": {
                                                            "description": "Determines "
                                                            "when "
                                                            "this "
                                                            "query "
                                                            "is "
                                                            "executed. "
                                                            "If "
                                                            "set "
                                                            "to "
                                                            "`false`, "
                                                            "the "
                                                            "query "
                                                            "will "
                                                            "run "
                                                            "when "
                                                            "the "
                                                            "app "
                                                            "loads "
                                                            "and "
                                                            "whenever "
                                                            "any "
                                                            "query "
                                                            "arguments "
                                                            "change. "
                                                            "If "
                                                            "set "
                                                            "to "
                                                            "`true`, "
                                                            "the "
                                                            "query "
                                                            "will "
                                                            "only "
                                                            "run "
                                                            "when "
                                                            "manually "
                                                            "triggered "
                                                            "from "
                                                            "elsewhere "
                                                            "in "
                                                            "the "
                                                            "app.",
                                                            "oneOf": [
                                                                {"type": "boolean"},
                                                                {
                                                                    "description": "If "
                                                                    "this "
                                                                    "is "
                                                                    "a "
                                                                    "string, "
                                                                    "it "
                                                                    "must "
                                                                    "be "
                                                                    "a "
                                                                    "valid "
                                                                    "JavaScript "
                                                                    "expression "
                                                                    "that "
                                                                    "evaluates "
                                                                    "to "
                                                                    "a "
                                                                    "boolean.",
                                                                    "example": "${true}",
                                                                    "type": "string",
                                                                },
                                                            ],
                                                        },
                                                        "outputs": {
                                                            "description": "The "
                                                            "post-query "
                                                            "transformation "
                                                            "function, "
                                                            "which "
                                                            "is "
                                                            "a "
                                                            "JavaScript "
                                                            "function "
                                                            "that "
                                                            "changes "
                                                            "the "
                                                            "query's "
                                                            "`.outputs` "
                                                            "property "
                                                            "after "
                                                            "the "
                                                            "query's "
                                                            "execution.",
                                                            "example": "${((outputs) "
                                                            "=> "
                                                            "{return "
                                                            "outputs.body.data})(self.rawOutputs)}",
                                                            "type": "string",
                                                        },
                                                        "pollingIntervalInMs": {
                                                            "description": "If "
                                                            "specified, "
                                                            "the "
                                                            "app "
                                                            "will "
                                                            "poll "
                                                            "the "
                                                            "query "
                                                            "at "
                                                            "the "
                                                            "specified "
                                                            "interval "
                                                            "in "
                                                            "milliseconds. "
                                                            "The "
                                                            "minimum "
                                                            "polling "
                                                            "interval "
                                                            "is "
                                                            "15 "
                                                            "seconds. "
                                                            "The "
                                                            "query "
                                                            "will "
                                                            "only "
                                                            "poll "
                                                            "when "
                                                            "the "
                                                            "app's "
                                                            "browser "
                                                            "tab "
                                                            "is "
                                                            "active.",
                                                            "oneOf": [
                                                                {
                                                                    "example": 30000.0,
                                                                    "format": "double",
                                                                    "minimum": 15000.0,
                                                                    "type": "number",
                                                                },
                                                                {
                                                                    "description": "If "
                                                                    "this "
                                                                    "is "
                                                                    "a "
                                                                    "string, "
                                                                    "it "
                                                                    "must "
                                                                    "be "
                                                                    "a "
                                                                    "valid "
                                                                    "JavaScript "
                                                                    "expression "
                                                                    "that "
                                                                    "evaluates "
                                                                    "to "
                                                                    "a "
                                                                    "number.",
                                                                    "example": "${15000}",
                                                                    "type": "string",
                                                                },
                                                            ],
                                                        },
                                                        "requiresConfirmation": {
                                                            "description": "Whether "
                                                            "to "
                                                            "prompt "
                                                            "the "
                                                            "user "
                                                            "to "
                                                            "confirm "
                                                            "this "
                                                            "query "
                                                            "before "
                                                            "it "
                                                            "runs.",
                                                            "oneOf": [
                                                                {"type": "boolean"},
                                                                {
                                                                    "description": "If "
                                                                    "this "
                                                                    "is "
                                                                    "a "
                                                                    "string, "
                                                                    "it "
                                                                    "must "
                                                                    "be "
                                                                    "a "
                                                                    "valid "
                                                                    "JavaScript "
                                                                    "expression "
                                                                    "that "
                                                                    "evaluates "
                                                                    "to "
                                                                    "a "
                                                                    "boolean.",
                                                                    "example": "${true}",
                                                                    "type": "string",
                                                                },
                                                            ],
                                                        },
                                                        "showToastOnError": {
                                                            "description": "Whether "
                                                            "to "
                                                            "display "
                                                            "a "
                                                            "toast "
                                                            "to "
                                                            "the "
                                                            "user "
                                                            "when "
                                                            "the "
                                                            "query "
                                                            "returns "
                                                            "an "
                                                            "error.",
                                                            "oneOf": [
                                                                {"type": "boolean"},
                                                                {
                                                                    "description": "If "
                                                                    "this "
                                                                    "is "
                                                                    "a "
                                                                    "string, "
                                                                    "it "
                                                                    "must "
                                                                    "be "
                                                                    "a "
                                                                    "valid "
                                                                    "JavaScript "
                                                                    "expression "
                                                                    "that "
                                                                    "evaluates "
                                                                    "to "
                                                                    "a "
                                                                    "boolean.",
                                                                    "example": "${true}",
                                                                    "type": "string",
                                                                },
                                                            ],
                                                        },
                                                        "spec": {
                                                            "description": "The "
                                                            "definition "
                                                            "of "
                                                            "the "
                                                            "action "
                                                            "query.",
                                                            "oneOf": [
                                                                {"type": "string"},
                                                                {
                                                                    "description": "The "
                                                                    "action "
                                                                    "query "
                                                                    "spec "
                                                                    "object.",
                                                                    "properties": {
                                                                        "connectionGroup": {
                                                                            "description": "The "
                                                                            "connection "
                                                                            "group "
                                                                            "to "
                                                                            "use "
                                                                            "for "
                                                                            "an "
                                                                            "action "
                                                                            "query.",
                                                                            "properties": {
                                                                                "id": {
                                                                                    "description": "The "
                                                                                    "ID "
                                                                                    "of "
                                                                                    "the "
                                                                                    "connection "
                                                                                    "group.",
                                                                                    "example": "65bb1f25-52e1-4510-9f8d-22d1516ed693",
                                                                                    "format": "uuid",
                                                                                    "type": "string",
                                                                                },
                                                                                "tags": {
                                                                                    "description": "The "
                                                                                    "tags "
                                                                                    "of "
                                                                                    "the "
                                                                                    "connection "
                                                                                    "group.",
                                                                                    "items": {
                                                                                        "type": "string"
                                                                                    },
                                                                                    "type": "array",
                                                                                },
                                                                            },
                                                                            "type": "object",
                                                                        },
                                                                        "connectionId": {
                                                                            "description": "The "
                                                                            "ID "
                                                                            "of "
                                                                            "the "
                                                                            "custom "
                                                                            "connection "
                                                                            "to "
                                                                            "use "
                                                                            "for "
                                                                            "this "
                                                                            "action "
                                                                            "query.",
                                                                            "example": "65bb1f25-52e1-4510-9f8d-22d1516ed693",
                                                                            "type": "string",
                                                                        },
                                                                        "fqn": {
                                                                            "description": "The "
                                                                            "fully "
                                                                            "qualified "
                                                                            "name "
                                                                            "of "
                                                                            "the "
                                                                            "action "
                                                                            "type.",
                                                                            "example": "com.datadoghq.http.request",
                                                                            "type": "string",
                                                                        },
                                                                        "inputs": {
                                                                            "description": "The "
                                                                            "inputs "
                                                                            "to "
                                                                            "the "
                                                                            "action "
                                                                            "query. "
                                                                            "These "
                                                                            "are "
                                                                            "the "
                                                                            "values "
                                                                            "that "
                                                                            "are "
                                                                            "passed "
                                                                            "to "
                                                                            "the "
                                                                            "action "
                                                                            "when "
                                                                            "it "
                                                                            "is "
                                                                            "triggered.",
                                                                            "oneOf": [
                                                                                {"type": "string"},
                                                                                {
                                                                                    "additionalProperties": {},
                                                                                    "description": "The "
                                                                                    "inputs "
                                                                                    "to "
                                                                                    "the "
                                                                                    "action "
                                                                                    "query. "
                                                                                    "See "
                                                                                    "the "
                                                                                    "[Actions "
                                                                                    "Catalog](https://docs.datadoghq.com/actions/actions_catalog/) "
                                                                                    "for "
                                                                                    "more "
                                                                                    "detail "
                                                                                    "on "
                                                                                    "each "
                                                                                    "action "
                                                                                    "and "
                                                                                    "its "
                                                                                    "inputs.",
                                                                                    "type": "object",
                                                                                },
                                                                            ],
                                                                        },
                                                                    },
                                                                    "required": ["fqn"],
                                                                    "type": "object",
                                                                },
                                                            ],
                                                        },
                                                    },
                                                    "required": ["spec"],
                                                    "type": "object",
                                                },
                                                "type": {
                                                    "default": "action",
                                                    "description": "The action query type.",
                                                    "enum": ["action"],
                                                    "example": "action",
                                                    "type": "string",
                                                    "x-enum-varnames": ["ACTION"],
                                                },
                                            },
                                            "required": ["id", "name", "type", "properties"],
                                            "type": "object",
                                        },
                                        {
                                            "description": "A "
                                            "data "
                                            "transformer, "
                                            "which "
                                            "is "
                                            "custom "
                                            "JavaScript "
                                            "code "
                                            "that "
                                            "executes "
                                            "and "
                                            "transforms "
                                            "data "
                                            "when "
                                            "its "
                                            "inputs "
                                            "change.",
                                            "properties": {
                                                "id": {
                                                    "description": "The "
                                                    "ID "
                                                    "of "
                                                    "the "
                                                    "data "
                                                    "transformer.",
                                                    "example": "65bb1f25-52e1-4510-9f8d-22d1516ed693",
                                                    "format": "uuid",
                                                    "type": "string",
                                                },
                                                "name": {
                                                    "description": "A "
                                                    "unique "
                                                    "identifier "
                                                    "for "
                                                    "this "
                                                    "data "
                                                    "transformer. "
                                                    "This "
                                                    "name "
                                                    "is "
                                                    "also "
                                                    "used "
                                                    "to "
                                                    "access "
                                                    "the "
                                                    "transformer's "
                                                    "result "
                                                    "throughout "
                                                    "the "
                                                    "app.",
                                                    "example": "combineTwoOrders",
                                                    "type": "string",
                                                },
                                                "properties": {
                                                    "description": "The "
                                                    "properties "
                                                    "of "
                                                    "the "
                                                    "data "
                                                    "transformer.",
                                                    "properties": {
                                                        "outputs": {
                                                            "description": "A "
                                                            "JavaScript "
                                                            "function "
                                                            "that "
                                                            "returns "
                                                            "the "
                                                            "transformed "
                                                            "data.",
                                                            "example": "${(() "
                                                            "=> "
                                                            "{return "
                                                            "{\n"
                                                            "    "
                                                            "allItems: "
                                                            "[...fetchOrder1.outputs.items, "
                                                            "...fetchOrder2.outputs.items],\n"
                                                            "}})()}",
                                                            "type": "string",
                                                        }
                                                    },
                                                    "type": "object",
                                                },
                                                "type": {
                                                    "default": "dataTransform",
                                                    "description": "The data transform type.",
                                                    "enum": ["dataTransform"],
                                                    "example": "dataTransform",
                                                    "type": "string",
                                                    "x-enum-varnames": ["DATATRANSFORM"],
                                                },
                                            },
                                            "required": ["id", "name", "type", "properties"],
                                            "type": "object",
                                        },
                                        {
                                            "description": "A "
                                            "variable, "
                                            "which "
                                            "can "
                                            "be "
                                            "set "
                                            "and "
                                            "read "
                                            "by "
                                            "other "
                                            "components "
                                            "in "
                                            "the "
                                            "app.",
                                            "properties": {
                                                "id": {
                                                    "description": "The ID of the state variable.",
                                                    "example": "65bb1f25-52e1-4510-9f8d-22d1516ed693",
                                                    "format": "uuid",
                                                    "type": "string",
                                                },
                                                "name": {
                                                    "description": "A "
                                                    "unique "
                                                    "identifier "
                                                    "for "
                                                    "this "
                                                    "state "
                                                    "variable. "
                                                    "This "
                                                    "name "
                                                    "is "
                                                    "also "
                                                    "used "
                                                    "to "
                                                    "access "
                                                    "the "
                                                    "variable's "
                                                    "value "
                                                    "throughout "
                                                    "the "
                                                    "app.",
                                                    "example": "ordersToSubmit",
                                                    "type": "string",
                                                },
                                                "properties": {
                                                    "description": "The "
                                                    "properties "
                                                    "of "
                                                    "the "
                                                    "state "
                                                    "variable.",
                                                    "properties": {
                                                        "defaultValue": {
                                                            "description": "The "
                                                            "default "
                                                            "value "
                                                            "of "
                                                            "the "
                                                            "state "
                                                            "variable.",
                                                            "example": "${['order_3145', "
                                                            "'order_4920']}",
                                                        }
                                                    },
                                                    "type": "object",
                                                },
                                                "type": {
                                                    "default": "stateVariable",
                                                    "description": "The state variable type.",
                                                    "enum": ["stateVariable"],
                                                    "example": "stateVariable",
                                                    "type": "string",
                                                    "x-enum-varnames": ["STATEVARIABLE"],
                                                },
                                            },
                                            "required": ["id", "name", "type", "properties"],
                                            "type": "object",
                                        },
                                    ],
                                },
                                "type": "array",
                            },
                            "rootInstanceName": {
                                "description": "The "
                                "new "
                                "name "
                                "of "
                                "the "
                                "root "
                                "component "
                                "of "
                                "the "
                                "app. "
                                "This "
                                "must "
                                "be "
                                "a "
                                "`grid` "
                                "component "
                                "that "
                                "contains "
                                "all "
                                "other "
                                "components.",
                                "type": "string",
                            },
                            "tags": {
                                "description": "The "
                                "new "
                                "list "
                                "of "
                                "tags "
                                "for "
                                "the "
                                "app, "
                                "which "
                                "can "
                                "be "
                                "used "
                                "to "
                                "filter "
                                "apps. "
                                "If "
                                "this "
                                "field "
                                "is "
                                "set, "
                                "any "
                                "existing "
                                "tags "
                                "not "
                                "included "
                                "in "
                                "the "
                                "request "
                                "are "
                                "removed.",
                                "example": ["service:webshop-backend", "team:webshop"],
                                "items": {
                                    "description": "An individual tag for the app.",
                                    "type": "string",
                                },
                                "type": "array",
                            },
                        },
                        "type": "object",
                    },
                    "id": {
                        "description": "The ID of the app to "
                        "update. The app ID must "
                        "match the ID in the URL "
                        "path.",
                        "example": "65bb1f25-52e1-4510-9f8d-22d1516ed693",
                        "format": "uuid",
                        "type": "string",
                    },
                    "type": {
                        "default": "appDefinitions",
                        "description": "The app definition type.",
                        "enum": ["appDefinitions"],
                        "example": "appDefinitions",
                        "type": "string",
                        "x-enum-varnames": ["APPDEFINITIONS"],
                    },
                },
                "required": ["type"],
                "type": "object",
            }
        },
        "type": "object",
    },
    "CREATEAUTHNMAPPING_REQUEST_BODY_SCHEMA": {
        "description": "Request for creating an AuthN Mapping.",
        "properties": {
            "data": {
                "description": "Data for creating an AuthN Mapping.",
                "properties": {
                    "attributes": {
                        "description": "Key/Value pair of attributes used for create request.",
                        "properties": {
                            "attribute_key": {
                                "description": "Key "
                                "portion "
                                "of "
                                "a "
                                "key/value "
                                "pair "
                                "of "
                                "the "
                                "attribute "
                                "sent "
                                "from "
                                "the "
                                "Identity "
                                "Provider.",
                                "example": "member-of",
                                "type": "string",
                            },
                            "attribute_value": {
                                "description": "Value "
                                "portion "
                                "of "
                                "a "
                                "key/value "
                                "pair "
                                "of "
                                "the "
                                "attribute "
                                "sent "
                                "from "
                                "the "
                                "Identity "
                                "Provider.",
                                "example": "Development",
                                "type": "string",
                            },
                        },
                        "type": "object",
                    },
                    "relationships": {
                        "description": "Relationship "
                        "of AuthN "
                        "Mapping "
                        "create "
                        "object to a "
                        "Role or "
                        "Team.",
                        "oneOf": [
                            {
                                "description": "Relationship of AuthN Mapping to a Role.",
                                "properties": {
                                    "role": {
                                        "description": "Relationship to role.",
                                        "properties": {
                                            "data": {
                                                "description": "Relationship to role object.",
                                                "properties": {
                                                    "id": {
                                                        "description": "The "
                                                        "unique "
                                                        "identifier "
                                                        "of "
                                                        "the "
                                                        "role.",
                                                        "example": "3653d3c6-0c75-11ea-ad28-fb5701eabc7d",
                                                        "type": "string",
                                                    },
                                                    "type": {
                                                        "default": "roles",
                                                        "description": "Roles type.",
                                                        "enum": ["roles"],
                                                        "example": "roles",
                                                        "type": "string",
                                                        "x-enum-varnames": ["ROLES"],
                                                    },
                                                },
                                                "type": "object",
                                            }
                                        },
                                        "type": "object",
                                    }
                                },
                                "required": ["role"],
                                "type": "object",
                            },
                            {
                                "description": "Relationship of AuthN Mapping to a Team.",
                                "properties": {
                                    "team": {
                                        "description": "Relationship to team.",
                                        "properties": {
                                            "data": {
                                                "description": "Relationship to Team object.",
                                                "properties": {
                                                    "id": {
                                                        "description": "The "
                                                        "unique "
                                                        "identifier "
                                                        "of "
                                                        "the "
                                                        "team.",
                                                        "example": "f9bb8444-af7f-11ec-ac2c-da7ad0900001",
                                                        "type": "string",
                                                    },
                                                    "type": {
                                                        "default": "team",
                                                        "description": "Team type",
                                                        "enum": ["team"],
                                                        "example": "team",
                                                        "type": "string",
                                                        "x-enum-varnames": ["TEAM"],
                                                    },
                                                },
                                                "type": "object",
                                            }
                                        },
                                        "type": "object",
                                    }
                                },
                                "required": ["team"],
                                "type": "object",
                            },
                        ],
                    },
                    "type": {
                        "default": "authn_mappings",
                        "description": "AuthN Mappings resource type.",
                        "enum": ["authn_mappings"],
                        "example": "authn_mappings",
                        "type": "string",
                        "x-enum-varnames": ["AUTHN_MAPPINGS"],
                    },
                },
                "required": ["type"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "EDITAUTHNMAPPING_REQUEST_BODY_SCHEMA": {
        "description": "Request to update an AuthN Mapping.",
        "properties": {
            "data": {
                "description": "Data for updating an AuthN Mapping.",
                "properties": {
                    "attributes": {
                        "description": "Key/Value pair of attributes used for update request.",
                        "properties": {
                            "attribute_key": {
                                "description": "Key "
                                "portion "
                                "of "
                                "a "
                                "key/value "
                                "pair "
                                "of "
                                "the "
                                "attribute "
                                "sent "
                                "from "
                                "the "
                                "Identity "
                                "Provider.",
                                "example": "member-of",
                                "type": "string",
                            },
                            "attribute_value": {
                                "description": "Value "
                                "portion "
                                "of "
                                "a "
                                "key/value "
                                "pair "
                                "of "
                                "the "
                                "attribute "
                                "sent "
                                "from "
                                "the "
                                "Identity "
                                "Provider.",
                                "example": "Development",
                                "type": "string",
                            },
                        },
                        "type": "object",
                    },
                    "id": {
                        "description": "ID of the AuthN Mapping.",
                        "example": "3653d3c6-0c75-11ea-ad28-fb5701eabc7d",
                        "type": "string",
                    },
                    "relationships": {
                        "description": "Relationship "
                        "of AuthN "
                        "Mapping "
                        "update "
                        "object to a "
                        "Role or "
                        "Team.",
                        "oneOf": [
                            {
                                "description": "Relationship of AuthN Mapping to a Role.",
                                "properties": {
                                    "role": {
                                        "description": "Relationship to role.",
                                        "properties": {
                                            "data": {
                                                "description": "Relationship to role object.",
                                                "properties": {
                                                    "id": {
                                                        "description": "The "
                                                        "unique "
                                                        "identifier "
                                                        "of "
                                                        "the "
                                                        "role.",
                                                        "example": "3653d3c6-0c75-11ea-ad28-fb5701eabc7d",
                                                        "type": "string",
                                                    },
                                                    "type": {
                                                        "default": "roles",
                                                        "description": "Roles type.",
                                                        "enum": ["roles"],
                                                        "example": "roles",
                                                        "type": "string",
                                                        "x-enum-varnames": ["ROLES"],
                                                    },
                                                },
                                                "type": "object",
                                            }
                                        },
                                        "type": "object",
                                    }
                                },
                                "required": ["role"],
                                "type": "object",
                            },
                            {
                                "description": "Relationship of AuthN Mapping to a Team.",
                                "properties": {
                                    "team": {
                                        "description": "Relationship to team.",
                                        "properties": {
                                            "data": {
                                                "description": "Relationship to Team object.",
                                                "properties": {
                                                    "id": {
                                                        "description": "The "
                                                        "unique "
                                                        "identifier "
                                                        "of "
                                                        "the "
                                                        "team.",
                                                        "example": "f9bb8444-af7f-11ec-ac2c-da7ad0900001",
                                                        "type": "string",
                                                    },
                                                    "type": {
                                                        "default": "team",
                                                        "description": "Team type",
                                                        "enum": ["team"],
                                                        "example": "team",
                                                        "type": "string",
                                                        "x-enum-varnames": ["TEAM"],
                                                    },
                                                },
                                                "type": "object",
                                            }
                                        },
                                        "type": "object",
                                    }
                                },
                                "required": ["team"],
                                "type": "object",
                            },
                        ],
                    },
                    "type": {
                        "default": "authn_mappings",
                        "description": "AuthN Mappings resource type.",
                        "enum": ["authn_mappings"],
                        "example": "authn_mappings",
                        "type": "string",
                        "x-enum-varnames": ["AUTHN_MAPPINGS"],
                    },
                },
                "required": ["id", "type"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "UPDATECASEATTRIBUTES_REQUEST_BODY_SCHEMA": {
        "description": "Case update attributes request",
        "properties": {
            "data": {
                "description": "Case update attributes",
                "properties": {
                    "attributes": {
                        "description": "Case update attributes attributes",
                        "properties": {
                            "attributes": {
                                "additionalProperties": {
                                    "items": {"type": "string"},
                                    "type": "array",
                                },
                                "description": "The definition of `CaseObjectAttributes` object.",
                                "type": "object",
                            }
                        },
                        "required": ["attributes"],
                        "type": "object",
                    },
                    "type": {
                        "default": "case",
                        "description": "Case resource type",
                        "enum": ["case"],
                        "example": "case",
                        "type": "string",
                        "x-enum-varnames": ["CASE"],
                    },
                },
                "required": ["attributes", "type"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "UPDATECASECUSTOMATTRIBUTE_REQUEST_BODY_SCHEMA": {
        "description": "Case update custom attribute request",
        "properties": {
            "data": {
                "description": "Case update custom attribute",
                "properties": {
                    "attributes": {
                        "description": "Custom attribute values",
                        "properties": {
                            "is_multi": {
                                "description": "If true, value must be an array",
                                "example": False,
                                "type": "boolean",
                            },
                            "type": {
                                "description": "Custom attributes type",
                                "enum": ["URL", "TEXT", "NUMBER"],
                                "example": "NUMBER",
                                "type": "string",
                                "x-enum-varnames": ["URL", "TEXT", "NUMBER"],
                            },
                            "value": {
                                "description": "Union of supported value for a custom attribute",
                                "oneOf": [
                                    {
                                        "description": "Value of TEXT/URL custom attribute",
                                        "type": "string",
                                    },
                                    {
                                        "description": "Value of multi TEXT/URL custom attribute",
                                        "items": {
                                            "description": "TEXT/URL Value",
                                            "type": "string",
                                        },
                                        "type": "array",
                                    },
                                    {
                                        "description": "Value of NUMBER custom attribute",
                                        "format": "double",
                                        "type": "number",
                                    },
                                    {
                                        "description": "Values of multi NUMBER custom attribute",
                                        "items": {
                                            "description": "NUMBER value",
                                            "format": "double",
                                            "type": "number",
                                        },
                                        "type": "array",
                                    },
                                ],
                            },
                        },
                        "required": ["type", "is_multi", "value"],
                        "type": "object",
                    },
                    "type": {
                        "default": "case",
                        "description": "Case resource type",
                        "enum": ["case"],
                        "example": "case",
                        "type": "string",
                        "x-enum-varnames": ["CASE"],
                    },
                },
                "required": ["attributes", "type"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "MANAGESOFTWARECATALOGENTITY_REQUEST_BODY_SCHEMA": {
        "description": "Create or update entity request.",
        "oneOf": [
            {
                "description": "Entity schema v3.",
                "oneOf": [
                    {
                        "additionalProperties": False,
                        "description": "Schema for service entities.",
                        "properties": {
                            "apiVersion": {
                                "description": "The version of "
                                "the schema data "
                                "that was used to "
                                "populate this "
                                "entity's data. "
                                "This could be via "
                                "the API, "
                                "Terraform, or "
                                "YAML file in a "
                                "repository. The "
                                "field is known as "
                                "schema-version in "
                                "the previous "
                                "version.",
                                "enum": ["v3", "v2.2", "v2.1", "v2"],
                                "example": "v3",
                                "type": "string",
                                "x-enum-varnames": ["V3", "V2_2", "V2_1", "V2"],
                            },
                            "datadog": {
                                "additionalProperties": False,
                                "description": "Datadog product "
                                "integrations for the "
                                "service entity.",
                                "properties": {
                                    "codeLocations": {
                                        "additionalProperties": False,
                                        "description": "Schema "
                                        "for "
                                        "mapping "
                                        "source "
                                        "code "
                                        "locations "
                                        "to "
                                        "an "
                                        "entity.",
                                        "items": {
                                            "additionalProperties": False,
                                            "description": "Code location item.",
                                            "properties": {
                                                "paths": {
                                                    "description": "The "
                                                    "paths "
                                                    "(glob) "
                                                    "to "
                                                    "the "
                                                    "source "
                                                    "code "
                                                    "of "
                                                    "the "
                                                    "service.",
                                                    "items": {"type": "string"},
                                                    "type": "array",
                                                },
                                                "repositoryURL": {
                                                    "description": "The "
                                                    "repository "
                                                    "path "
                                                    "of "
                                                    "the "
                                                    "source "
                                                    "code "
                                                    "of "
                                                    "the "
                                                    "entity.",
                                                    "type": "string",
                                                },
                                            },
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "events": {
                                        "additionalProperties": False,
                                        "description": "Events associations.",
                                        "items": {
                                            "additionalProperties": False,
                                            "description": "Events association item.",
                                            "properties": {
                                                "name": {
                                                    "description": "The name of the query.",
                                                    "type": "string",
                                                },
                                                "query": {
                                                    "description": "The query to run.",
                                                    "type": "string",
                                                },
                                            },
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "logs": {
                                        "additionalProperties": False,
                                        "description": "Logs association.",
                                        "items": {
                                            "additionalProperties": False,
                                            "description": "Log association item.",
                                            "properties": {
                                                "name": {
                                                    "description": "The name of the query.",
                                                    "type": "string",
                                                },
                                                "query": {
                                                    "description": "The query to run.",
                                                    "type": "string",
                                                },
                                            },
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "performanceData": {
                                        "additionalProperties": False,
                                        "description": "Performance stats association.",
                                        "properties": {
                                            "tags": {
                                                "description": "A "
                                                "list "
                                                "of "
                                                "APM "
                                                "entity "
                                                "tags "
                                                "that "
                                                "associates "
                                                "the "
                                                "APM "
                                                "Stats "
                                                "data "
                                                "with "
                                                "the "
                                                "entity.",
                                                "items": {"type": "string"},
                                                "type": "array",
                                            }
                                        },
                                        "type": "object",
                                    },
                                    "pipelines": {
                                        "additionalProperties": False,
                                        "description": "CI Pipelines association.",
                                        "properties": {
                                            "fingerprints": {
                                                "description": "A "
                                                "list "
                                                "of "
                                                "CI "
                                                "Fingerprints "
                                                "that "
                                                "associate "
                                                "CI "
                                                "Pipelines "
                                                "with "
                                                "the "
                                                "entity.",
                                                "items": {"type": "string"},
                                                "type": "array",
                                            }
                                        },
                                        "type": "object",
                                    },
                                },
                                "type": "object",
                            },
                            "extensions": {
                                "additionalProperties": {},
                                "description": "Custom "
                                "extensions. This "
                                "is the "
                                "free-formed field "
                                "to send "
                                "client-side "
                                "metadata. No "
                                "Datadog features "
                                "are affected by "
                                "this field.",
                                "type": "object",
                            },
                            "integrations": {
                                "additionalProperties": False,
                                "description": "A base schema "
                                "for defining "
                                "third-party "
                                "integrations.",
                                "properties": {
                                    "opsgenie": {
                                        "additionalProperties": False,
                                        "description": "An Opsgenie integration schema.",
                                        "properties": {
                                            "region": {
                                                "description": "The "
                                                "region "
                                                "for "
                                                "the "
                                                "Opsgenie "
                                                "integration.",
                                                "minLength": 1,
                                                "type": "string",
                                            },
                                            "serviceURL": {
                                                "description": "The "
                                                "service "
                                                "URL "
                                                "for "
                                                "the "
                                                "Opsgenie "
                                                "integration.",
                                                "example": "https://www.opsgenie.com/service/shopping-cart",
                                                "minLength": 1,
                                                "type": "string",
                                            },
                                        },
                                        "required": ["serviceURL"],
                                        "type": "object",
                                    },
                                    "pagerduty": {
                                        "additionalProperties": False,
                                        "description": "A PagerDuty integration schema.",
                                        "properties": {
                                            "serviceURL": {
                                                "description": "The "
                                                "service "
                                                "URL "
                                                "for "
                                                "the "
                                                "PagerDuty "
                                                "integration.",
                                                "example": "https://www.pagerduty.com/service-directory/Pshopping-cart",
                                                "minLength": 1,
                                                "type": "string",
                                            }
                                        },
                                        "required": ["serviceURL"],
                                        "type": "object",
                                    },
                                },
                                "type": "object",
                            },
                            "kind": {
                                "description": "The definition of Entity V3 Service Kind object.",
                                "enum": ["service"],
                                "example": "service",
                                "type": "string",
                                "x-enum-varnames": ["SERVICE"],
                            },
                            "metadata": {
                                "additionalProperties": False,
                                "description": "The definition of Entity V3 Metadata object.",
                                "properties": {
                                    "additionalOwners": {
                                        "additionalProperties": False,
                                        "description": "The "
                                        "additional "
                                        "owners "
                                        "of "
                                        "the "
                                        "entity, "
                                        "usually "
                                        "a "
                                        "team.",
                                        "items": {
                                            "description": "The "
                                            "definition "
                                            "of "
                                            "Entity "
                                            "V3 "
                                            "Metadata "
                                            "Additional "
                                            "Owners "
                                            "Items "
                                            "object.",
                                            "properties": {
                                                "name": {
                                                    "description": "Team name.",
                                                    "example": "",
                                                    "type": "string",
                                                },
                                                "type": {
                                                    "description": "Team type.",
                                                    "type": "string",
                                                },
                                            },
                                            "required": ["name"],
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "contacts": {
                                        "additionalProperties": False,
                                        "description": "A list of contacts for the entity.",
                                        "items": {
                                            "additionalProperties": False,
                                            "description": "The "
                                            "definition "
                                            "of "
                                            "Entity "
                                            "V3 "
                                            "Metadata "
                                            "Contacts "
                                            "Items "
                                            "object.",
                                            "properties": {
                                                "contact": {
                                                    "description": "Contact value.",
                                                    "example": "https://slack/",
                                                    "type": "string",
                                                },
                                                "name": {
                                                    "description": "Contact name.",
                                                    "minLength": 2,
                                                    "type": "string",
                                                },
                                                "type": {
                                                    "description": "Contact type.",
                                                    "example": "slack",
                                                    "type": "string",
                                                },
                                            },
                                            "required": ["type", "contact"],
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "description": {
                                        "description": "Short "
                                        "description "
                                        "of "
                                        "the "
                                        "entity. "
                                        "The "
                                        "UI "
                                        "can "
                                        "leverage "
                                        "the "
                                        "description "
                                        "for "
                                        "display.",
                                        "type": "string",
                                    },
                                    "displayName": {
                                        "description": "User "
                                        "friendly "
                                        "name "
                                        "of "
                                        "the "
                                        "entity. "
                                        "The "
                                        "UI "
                                        "can "
                                        "leverage "
                                        "the "
                                        "display "
                                        "name "
                                        "for "
                                        "display.",
                                        "type": "string",
                                    },
                                    "id": {
                                        "description": "A "
                                        "read-only "
                                        "globally "
                                        "unique "
                                        "identifier "
                                        "for "
                                        "the "
                                        "entity "
                                        "generated "
                                        "by "
                                        "Datadog.  "
                                        "User "
                                        "supplied "
                                        "values "
                                        "are "
                                        "ignored.",
                                        "example": "4b163705-23c0-4573-b2fb-f6cea2163fcb",
                                        "minLength": 1,
                                        "type": "string",
                                    },
                                    "inheritFrom": {
                                        "description": "The "
                                        "entity "
                                        "reference "
                                        "from "
                                        "which "
                                        "to "
                                        "inherit "
                                        "metadata",
                                        "example": "application:default/myapp",
                                        "type": "string",
                                    },
                                    "links": {
                                        "additionalProperties": False,
                                        "description": "A list of links for the entity.",
                                        "items": {
                                            "additionalProperties": False,
                                            "description": "The "
                                            "definition "
                                            "of "
                                            "Entity "
                                            "V3 "
                                            "Metadata "
                                            "Links "
                                            "Items "
                                            "object.",
                                            "properties": {
                                                "name": {
                                                    "description": "Link name.",
                                                    "example": "mylink",
                                                    "type": "string",
                                                },
                                                "provider": {
                                                    "description": "Link provider.",
                                                    "type": "string",
                                                },
                                                "type": {
                                                    "default": "other",
                                                    "description": "Link type.",
                                                    "example": "link",
                                                    "type": "string",
                                                },
                                                "url": {
                                                    "description": "Link URL.",
                                                    "example": "https://mylink",
                                                    "type": "string",
                                                },
                                            },
                                            "required": ["name", "type", "url"],
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "managed": {
                                        "additionalProperties": {},
                                        "description": "A "
                                        "read-only "
                                        "set "
                                        "of "
                                        "Datadog "
                                        "managed "
                                        "attributes "
                                        "generated "
                                        "by "
                                        "Datadog.  "
                                        "User "
                                        "supplied "
                                        "values "
                                        "are "
                                        "ignored.",
                                        "type": "object",
                                    },
                                    "name": {
                                        "description": "Unique "
                                        "name "
                                        "given "
                                        "to "
                                        "an "
                                        "entity "
                                        "under "
                                        "the "
                                        "kind/namespace.",
                                        "example": "myService",
                                        "minLength": 1,
                                        "type": "string",
                                    },
                                    "namespace": {
                                        "description": "Namespace "
                                        "is "
                                        "a "
                                        "part "
                                        "of "
                                        "unique "
                                        "identifier. "
                                        "It "
                                        "has "
                                        "a "
                                        "default "
                                        "value "
                                        "of "
                                        "'default'.",
                                        "example": "default",
                                        "minLength": 1,
                                        "type": "string",
                                    },
                                    "owner": {
                                        "description": "The owner of the entity, usually a team.",
                                        "type": "string",
                                    },
                                    "tags": {
                                        "description": "A set of custom tags.",
                                        "example": ["this:tag", "that:tag"],
                                        "items": {"type": "string"},
                                        "type": "array",
                                    },
                                },
                                "required": ["name"],
                                "type": "object",
                            },
                            "spec": {
                                "additionalProperties": False,
                                "description": "The definition of Entity V3 Service Spec object.",
                                "properties": {
                                    "componentOf": {
                                        "description": "A "
                                        "list "
                                        "of "
                                        "components "
                                        "the "
                                        "service "
                                        "is "
                                        "a "
                                        "part "
                                        "of",
                                        "items": {"type": "string"},
                                        "type": "array",
                                    },
                                    "dependsOn": {
                                        "description": "A "
                                        "list "
                                        "of "
                                        "components "
                                        "the "
                                        "service "
                                        "depends "
                                        "on.",
                                        "items": {"type": "string"},
                                        "type": "array",
                                    },
                                    "languages": {
                                        "description": "The service's programming language.",
                                        "items": {"type": "string"},
                                        "type": "array",
                                    },
                                    "lifecycle": {
                                        "description": "The lifecycle state of the component.",
                                        "minLength": 1,
                                        "type": "string",
                                    },
                                    "tier": {
                                        "description": "The importance of the component.",
                                        "minLength": 1,
                                        "type": "string",
                                    },
                                    "type": {
                                        "description": "The type of service.",
                                        "type": "string",
                                    },
                                },
                                "type": "object",
                            },
                        },
                        "required": ["apiVersion", "kind", "metadata"],
                        "type": "object",
                    },
                    {
                        "additionalProperties": False,
                        "description": "Schema for datastore entities.",
                        "properties": {
                            "apiVersion": {
                                "description": "The version of "
                                "the schema data "
                                "that was used to "
                                "populate this "
                                "entity's data. "
                                "This could be via "
                                "the API, "
                                "Terraform, or "
                                "YAML file in a "
                                "repository. The "
                                "field is known as "
                                "schema-version in "
                                "the previous "
                                "version.",
                                "enum": ["v3", "v2.2", "v2.1", "v2"],
                                "example": "v3",
                                "type": "string",
                                "x-enum-varnames": ["V3", "V2_2", "V2_1", "V2"],
                            },
                            "datadog": {
                                "additionalProperties": False,
                                "description": "Datadog product "
                                "integrations for the "
                                "datastore entity.",
                                "properties": {
                                    "events": {
                                        "additionalProperties": False,
                                        "description": "Events associations.",
                                        "items": {
                                            "additionalProperties": False,
                                            "description": "Events association item.",
                                            "properties": {
                                                "name": {
                                                    "description": "The name of the query.",
                                                    "type": "string",
                                                },
                                                "query": {
                                                    "description": "The query to run.",
                                                    "type": "string",
                                                },
                                            },
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "logs": {
                                        "additionalProperties": False,
                                        "description": "Logs association.",
                                        "items": {
                                            "additionalProperties": False,
                                            "description": "Log association item.",
                                            "properties": {
                                                "name": {
                                                    "description": "The name of the query.",
                                                    "type": "string",
                                                },
                                                "query": {
                                                    "description": "The query to run.",
                                                    "type": "string",
                                                },
                                            },
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "performanceData": {
                                        "additionalProperties": False,
                                        "description": "Performance stats association.",
                                        "properties": {
                                            "tags": {
                                                "description": "A "
                                                "list "
                                                "of "
                                                "APM "
                                                "entity "
                                                "tags "
                                                "that "
                                                "associates "
                                                "the "
                                                "APM "
                                                "Stats "
                                                "data "
                                                "with "
                                                "the "
                                                "entity.",
                                                "items": {"type": "string"},
                                                "type": "array",
                                            }
                                        },
                                        "type": "object",
                                    },
                                },
                                "type": "object",
                            },
                            "extensions": {
                                "additionalProperties": {},
                                "description": "Custom "
                                "extensions. This "
                                "is the "
                                "free-formed field "
                                "to send client "
                                "side metadata. No "
                                "Datadog features "
                                "are affected by "
                                "this field.",
                                "type": "object",
                            },
                            "integrations": {
                                "additionalProperties": False,
                                "description": "A base schema "
                                "for defining "
                                "third-party "
                                "integrations.",
                                "properties": {
                                    "opsgenie": {
                                        "additionalProperties": False,
                                        "description": "An Opsgenie integration schema.",
                                        "properties": {
                                            "region": {
                                                "description": "The "
                                                "region "
                                                "for "
                                                "the "
                                                "Opsgenie "
                                                "integration.",
                                                "minLength": 1,
                                                "type": "string",
                                            },
                                            "serviceURL": {
                                                "description": "The "
                                                "service "
                                                "URL "
                                                "for "
                                                "the "
                                                "Opsgenie "
                                                "integration.",
                                                "example": "https://www.opsgenie.com/service/shopping-cart",
                                                "minLength": 1,
                                                "type": "string",
                                            },
                                        },
                                        "required": ["serviceURL"],
                                        "type": "object",
                                    },
                                    "pagerduty": {
                                        "additionalProperties": False,
                                        "description": "A PagerDuty integration schema.",
                                        "properties": {
                                            "serviceURL": {
                                                "description": "The "
                                                "service "
                                                "URL "
                                                "for "
                                                "the "
                                                "PagerDuty "
                                                "integration.",
                                                "example": "https://www.pagerduty.com/service-directory/Pshopping-cart",
                                                "minLength": 1,
                                                "type": "string",
                                            }
                                        },
                                        "required": ["serviceURL"],
                                        "type": "object",
                                    },
                                },
                                "type": "object",
                            },
                            "kind": {
                                "description": "The definition of Entity V3 Datastore Kind object.",
                                "enum": ["datastore"],
                                "example": "datastore",
                                "type": "string",
                                "x-enum-varnames": ["DATASTORE"],
                            },
                            "metadata": {
                                "additionalProperties": False,
                                "description": "The definition of Entity V3 Metadata object.",
                                "properties": {
                                    "additionalOwners": {
                                        "additionalProperties": False,
                                        "description": "The "
                                        "additional "
                                        "owners "
                                        "of "
                                        "the "
                                        "entity, "
                                        "usually "
                                        "a "
                                        "team.",
                                        "items": {
                                            "description": "The "
                                            "definition "
                                            "of "
                                            "Entity "
                                            "V3 "
                                            "Metadata "
                                            "Additional "
                                            "Owners "
                                            "Items "
                                            "object.",
                                            "properties": {
                                                "name": {
                                                    "description": "Team name.",
                                                    "example": "",
                                                    "type": "string",
                                                },
                                                "type": {
                                                    "description": "Team type.",
                                                    "type": "string",
                                                },
                                            },
                                            "required": ["name"],
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "contacts": {
                                        "additionalProperties": False,
                                        "description": "A list of contacts for the entity.",
                                        "items": {
                                            "additionalProperties": False,
                                            "description": "The "
                                            "definition "
                                            "of "
                                            "Entity "
                                            "V3 "
                                            "Metadata "
                                            "Contacts "
                                            "Items "
                                            "object.",
                                            "properties": {
                                                "contact": {
                                                    "description": "Contact value.",
                                                    "example": "https://slack/",
                                                    "type": "string",
                                                },
                                                "name": {
                                                    "description": "Contact name.",
                                                    "minLength": 2,
                                                    "type": "string",
                                                },
                                                "type": {
                                                    "description": "Contact type.",
                                                    "example": "slack",
                                                    "type": "string",
                                                },
                                            },
                                            "required": ["type", "contact"],
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "description": {
                                        "description": "Short "
                                        "description "
                                        "of "
                                        "the "
                                        "entity. "
                                        "The "
                                        "UI "
                                        "can "
                                        "leverage "
                                        "the "
                                        "description "
                                        "for "
                                        "display.",
                                        "type": "string",
                                    },
                                    "displayName": {
                                        "description": "User "
                                        "friendly "
                                        "name "
                                        "of "
                                        "the "
                                        "entity. "
                                        "The "
                                        "UI "
                                        "can "
                                        "leverage "
                                        "the "
                                        "display "
                                        "name "
                                        "for "
                                        "display.",
                                        "type": "string",
                                    },
                                    "id": {
                                        "description": "A "
                                        "read-only "
                                        "globally "
                                        "unique "
                                        "identifier "
                                        "for "
                                        "the "
                                        "entity "
                                        "generated "
                                        "by "
                                        "Datadog.  "
                                        "User "
                                        "supplied "
                                        "values "
                                        "are "
                                        "ignored.",
                                        "example": "4b163705-23c0-4573-b2fb-f6cea2163fcb",
                                        "minLength": 1,
                                        "type": "string",
                                    },
                                    "inheritFrom": {
                                        "description": "The "
                                        "entity "
                                        "reference "
                                        "from "
                                        "which "
                                        "to "
                                        "inherit "
                                        "metadata",
                                        "example": "application:default/myapp",
                                        "type": "string",
                                    },
                                    "links": {
                                        "additionalProperties": False,
                                        "description": "A list of links for the entity.",
                                        "items": {
                                            "additionalProperties": False,
                                            "description": "The "
                                            "definition "
                                            "of "
                                            "Entity "
                                            "V3 "
                                            "Metadata "
                                            "Links "
                                            "Items "
                                            "object.",
                                            "properties": {
                                                "name": {
                                                    "description": "Link name.",
                                                    "example": "mylink",
                                                    "type": "string",
                                                },
                                                "provider": {
                                                    "description": "Link provider.",
                                                    "type": "string",
                                                },
                                                "type": {
                                                    "default": "other",
                                                    "description": "Link type.",
                                                    "example": "link",
                                                    "type": "string",
                                                },
                                                "url": {
                                                    "description": "Link URL.",
                                                    "example": "https://mylink",
                                                    "type": "string",
                                                },
                                            },
                                            "required": ["name", "type", "url"],
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "managed": {
                                        "additionalProperties": {},
                                        "description": "A "
                                        "read-only "
                                        "set "
                                        "of "
                                        "Datadog "
                                        "managed "
                                        "attributes "
                                        "generated "
                                        "by "
                                        "Datadog.  "
                                        "User "
                                        "supplied "
                                        "values "
                                        "are "
                                        "ignored.",
                                        "type": "object",
                                    },
                                    "name": {
                                        "description": "Unique "
                                        "name "
                                        "given "
                                        "to "
                                        "an "
                                        "entity "
                                        "under "
                                        "the "
                                        "kind/namespace.",
                                        "example": "myService",
                                        "minLength": 1,
                                        "type": "string",
                                    },
                                    "namespace": {
                                        "description": "Namespace "
                                        "is "
                                        "a "
                                        "part "
                                        "of "
                                        "unique "
                                        "identifier. "
                                        "It "
                                        "has "
                                        "a "
                                        "default "
                                        "value "
                                        "of "
                                        "'default'.",
                                        "example": "default",
                                        "minLength": 1,
                                        "type": "string",
                                    },
                                    "owner": {
                                        "description": "The owner of the entity, usually a team.",
                                        "type": "string",
                                    },
                                    "tags": {
                                        "description": "A set of custom tags.",
                                        "example": ["this:tag", "that:tag"],
                                        "items": {"type": "string"},
                                        "type": "array",
                                    },
                                },
                                "required": ["name"],
                                "type": "object",
                            },
                            "spec": {
                                "additionalProperties": False,
                                "description": "The definition of Entity V3 Datastore Spec object.",
                                "properties": {
                                    "componentOf": {
                                        "description": "A "
                                        "list "
                                        "of "
                                        "components "
                                        "the "
                                        "datastore "
                                        "is "
                                        "a "
                                        "part "
                                        "of",
                                        "items": {"type": "string"},
                                        "type": "array",
                                    },
                                    "lifecycle": {
                                        "description": "The lifecycle state of the datastore.",
                                        "minLength": 1,
                                        "type": "string",
                                    },
                                    "tier": {
                                        "description": "The importance of the datastore.",
                                        "minLength": 1,
                                        "type": "string",
                                    },
                                    "type": {
                                        "description": "The type of datastore.",
                                        "type": "string",
                                    },
                                },
                                "type": "object",
                            },
                        },
                        "required": ["apiVersion", "kind", "metadata"],
                        "type": "object",
                    },
                    {
                        "additionalProperties": False,
                        "description": "Schema for queue entities.",
                        "properties": {
                            "apiVersion": {
                                "description": "The version of "
                                "the schema data "
                                "that was used to "
                                "populate this "
                                "entity's data. "
                                "This could be via "
                                "the API, "
                                "Terraform, or "
                                "YAML file in a "
                                "repository. The "
                                "field is known as "
                                "schema-version in "
                                "the previous "
                                "version.",
                                "enum": ["v3", "v2.2", "v2.1", "v2"],
                                "example": "v3",
                                "type": "string",
                                "x-enum-varnames": ["V3", "V2_2", "V2_1", "V2"],
                            },
                            "datadog": {
                                "additionalProperties": False,
                                "description": "Datadog product "
                                "integrations for the "
                                "datastore entity.",
                                "properties": {
                                    "events": {
                                        "additionalProperties": False,
                                        "description": "Events associations.",
                                        "items": {
                                            "additionalProperties": False,
                                            "description": "Events association item.",
                                            "properties": {
                                                "name": {
                                                    "description": "The name of the query.",
                                                    "type": "string",
                                                },
                                                "query": {
                                                    "description": "The query to run.",
                                                    "type": "string",
                                                },
                                            },
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "logs": {
                                        "additionalProperties": False,
                                        "description": "Logs association.",
                                        "items": {
                                            "additionalProperties": False,
                                            "description": "Log association item.",
                                            "properties": {
                                                "name": {
                                                    "description": "The name of the query.",
                                                    "type": "string",
                                                },
                                                "query": {
                                                    "description": "The query to run.",
                                                    "type": "string",
                                                },
                                            },
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "performanceData": {
                                        "additionalProperties": False,
                                        "description": "Performance stats association.",
                                        "properties": {
                                            "tags": {
                                                "description": "A "
                                                "list "
                                                "of "
                                                "APM "
                                                "entity "
                                                "tags "
                                                "that "
                                                "associates "
                                                "the "
                                                "APM "
                                                "Stats "
                                                "data "
                                                "with "
                                                "the "
                                                "entity.",
                                                "items": {"type": "string"},
                                                "type": "array",
                                            }
                                        },
                                        "type": "object",
                                    },
                                },
                                "type": "object",
                            },
                            "extensions": {
                                "additionalProperties": {},
                                "description": "Custom "
                                "extensions. This "
                                "is the "
                                "free-formed field "
                                "to send "
                                "client-side "
                                "metadata. No "
                                "Datadog features "
                                "are affected by "
                                "this field.",
                                "type": "object",
                            },
                            "integrations": {
                                "additionalProperties": False,
                                "description": "A base schema "
                                "for defining "
                                "third-party "
                                "integrations.",
                                "properties": {
                                    "opsgenie": {
                                        "additionalProperties": False,
                                        "description": "An Opsgenie integration schema.",
                                        "properties": {
                                            "region": {
                                                "description": "The "
                                                "region "
                                                "for "
                                                "the "
                                                "Opsgenie "
                                                "integration.",
                                                "minLength": 1,
                                                "type": "string",
                                            },
                                            "serviceURL": {
                                                "description": "The "
                                                "service "
                                                "URL "
                                                "for "
                                                "the "
                                                "Opsgenie "
                                                "integration.",
                                                "example": "https://www.opsgenie.com/service/shopping-cart",
                                                "minLength": 1,
                                                "type": "string",
                                            },
                                        },
                                        "required": ["serviceURL"],
                                        "type": "object",
                                    },
                                    "pagerduty": {
                                        "additionalProperties": False,
                                        "description": "A PagerDuty integration schema.",
                                        "properties": {
                                            "serviceURL": {
                                                "description": "The "
                                                "service "
                                                "URL "
                                                "for "
                                                "the "
                                                "PagerDuty "
                                                "integration.",
                                                "example": "https://www.pagerduty.com/service-directory/Pshopping-cart",
                                                "minLength": 1,
                                                "type": "string",
                                            }
                                        },
                                        "required": ["serviceURL"],
                                        "type": "object",
                                    },
                                },
                                "type": "object",
                            },
                            "kind": {
                                "description": "The definition of Entity V3 Queue Kind object.",
                                "enum": ["queue"],
                                "example": "queue",
                                "type": "string",
                                "x-enum-varnames": ["QUEUE"],
                            },
                            "metadata": {
                                "additionalProperties": False,
                                "description": "The definition of Entity V3 Metadata object.",
                                "properties": {
                                    "additionalOwners": {
                                        "additionalProperties": False,
                                        "description": "The "
                                        "additional "
                                        "owners "
                                        "of "
                                        "the "
                                        "entity, "
                                        "usually "
                                        "a "
                                        "team.",
                                        "items": {
                                            "description": "The "
                                            "definition "
                                            "of "
                                            "Entity "
                                            "V3 "
                                            "Metadata "
                                            "Additional "
                                            "Owners "
                                            "Items "
                                            "object.",
                                            "properties": {
                                                "name": {
                                                    "description": "Team name.",
                                                    "example": "",
                                                    "type": "string",
                                                },
                                                "type": {
                                                    "description": "Team type.",
                                                    "type": "string",
                                                },
                                            },
                                            "required": ["name"],
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "contacts": {
                                        "additionalProperties": False,
                                        "description": "A list of contacts for the entity.",
                                        "items": {
                                            "additionalProperties": False,
                                            "description": "The "
                                            "definition "
                                            "of "
                                            "Entity "
                                            "V3 "
                                            "Metadata "
                                            "Contacts "
                                            "Items "
                                            "object.",
                                            "properties": {
                                                "contact": {
                                                    "description": "Contact value.",
                                                    "example": "https://slack/",
                                                    "type": "string",
                                                },
                                                "name": {
                                                    "description": "Contact name.",
                                                    "minLength": 2,
                                                    "type": "string",
                                                },
                                                "type": {
                                                    "description": "Contact type.",
                                                    "example": "slack",
                                                    "type": "string",
                                                },
                                            },
                                            "required": ["type", "contact"],
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "description": {
                                        "description": "Short "
                                        "description "
                                        "of "
                                        "the "
                                        "entity. "
                                        "The "
                                        "UI "
                                        "can "
                                        "leverage "
                                        "the "
                                        "description "
                                        "for "
                                        "display.",
                                        "type": "string",
                                    },
                                    "displayName": {
                                        "description": "User "
                                        "friendly "
                                        "name "
                                        "of "
                                        "the "
                                        "entity. "
                                        "The "
                                        "UI "
                                        "can "
                                        "leverage "
                                        "the "
                                        "display "
                                        "name "
                                        "for "
                                        "display.",
                                        "type": "string",
                                    },
                                    "id": {
                                        "description": "A "
                                        "read-only "
                                        "globally "
                                        "unique "
                                        "identifier "
                                        "for "
                                        "the "
                                        "entity "
                                        "generated "
                                        "by "
                                        "Datadog.  "
                                        "User "
                                        "supplied "
                                        "values "
                                        "are "
                                        "ignored.",
                                        "example": "4b163705-23c0-4573-b2fb-f6cea2163fcb",
                                        "minLength": 1,
                                        "type": "string",
                                    },
                                    "inheritFrom": {
                                        "description": "The "
                                        "entity "
                                        "reference "
                                        "from "
                                        "which "
                                        "to "
                                        "inherit "
                                        "metadata",
                                        "example": "application:default/myapp",
                                        "type": "string",
                                    },
                                    "links": {
                                        "additionalProperties": False,
                                        "description": "A list of links for the entity.",
                                        "items": {
                                            "additionalProperties": False,
                                            "description": "The "
                                            "definition "
                                            "of "
                                            "Entity "
                                            "V3 "
                                            "Metadata "
                                            "Links "
                                            "Items "
                                            "object.",
                                            "properties": {
                                                "name": {
                                                    "description": "Link name.",
                                                    "example": "mylink",
                                                    "type": "string",
                                                },
                                                "provider": {
                                                    "description": "Link provider.",
                                                    "type": "string",
                                                },
                                                "type": {
                                                    "default": "other",
                                                    "description": "Link type.",
                                                    "example": "link",
                                                    "type": "string",
                                                },
                                                "url": {
                                                    "description": "Link URL.",
                                                    "example": "https://mylink",
                                                    "type": "string",
                                                },
                                            },
                                            "required": ["name", "type", "url"],
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "managed": {
                                        "additionalProperties": {},
                                        "description": "A "
                                        "read-only "
                                        "set "
                                        "of "
                                        "Datadog "
                                        "managed "
                                        "attributes "
                                        "generated "
                                        "by "
                                        "Datadog.  "
                                        "User "
                                        "supplied "
                                        "values "
                                        "are "
                                        "ignored.",
                                        "type": "object",
                                    },
                                    "name": {
                                        "description": "Unique "
                                        "name "
                                        "given "
                                        "to "
                                        "an "
                                        "entity "
                                        "under "
                                        "the "
                                        "kind/namespace.",
                                        "example": "myService",
                                        "minLength": 1,
                                        "type": "string",
                                    },
                                    "namespace": {
                                        "description": "Namespace "
                                        "is "
                                        "a "
                                        "part "
                                        "of "
                                        "unique "
                                        "identifier. "
                                        "It "
                                        "has "
                                        "a "
                                        "default "
                                        "value "
                                        "of "
                                        "'default'.",
                                        "example": "default",
                                        "minLength": 1,
                                        "type": "string",
                                    },
                                    "owner": {
                                        "description": "The owner of the entity, usually a team.",
                                        "type": "string",
                                    },
                                    "tags": {
                                        "description": "A set of custom tags.",
                                        "example": ["this:tag", "that:tag"],
                                        "items": {"type": "string"},
                                        "type": "array",
                                    },
                                },
                                "required": ["name"],
                                "type": "object",
                            },
                            "spec": {
                                "additionalProperties": False,
                                "description": "The definition of Entity V3 Queue Spec object.",
                                "properties": {
                                    "componentOf": {
                                        "description": "A "
                                        "list "
                                        "of "
                                        "components "
                                        "the "
                                        "queue "
                                        "is "
                                        "a "
                                        "part "
                                        "of",
                                        "items": {"type": "string"},
                                        "type": "array",
                                    },
                                    "lifecycle": {
                                        "description": "The lifecycle state of the queue.",
                                        "minLength": 1,
                                        "type": "string",
                                    },
                                    "tier": {
                                        "description": "The importance of the queue.",
                                        "minLength": 1,
                                        "type": "string",
                                    },
                                    "type": {"description": "The type of queue.", "type": "string"},
                                },
                                "type": "object",
                            },
                        },
                        "required": ["apiVersion", "kind", "metadata"],
                        "type": "object",
                    },
                    {
                        "additionalProperties": False,
                        "description": "Schema for system entities.",
                        "properties": {
                            "apiVersion": {
                                "description": "The version of "
                                "the schema data "
                                "that was used to "
                                "populate this "
                                "entity's data. "
                                "This could be via "
                                "the API, "
                                "Terraform, or "
                                "YAML file in a "
                                "repository. The "
                                "field is known as "
                                "schema-version in "
                                "the previous "
                                "version.",
                                "enum": ["v3", "v2.2", "v2.1", "v2"],
                                "example": "v3",
                                "type": "string",
                                "x-enum-varnames": ["V3", "V2_2", "V2_1", "V2"],
                            },
                            "datadog": {
                                "additionalProperties": False,
                                "description": "Datadog product "
                                "integrations for the "
                                "service entity.",
                                "properties": {
                                    "events": {
                                        "additionalProperties": False,
                                        "description": "Events associations.",
                                        "items": {
                                            "additionalProperties": False,
                                            "description": "Events association item.",
                                            "properties": {
                                                "name": {
                                                    "description": "The name of the query.",
                                                    "type": "string",
                                                },
                                                "query": {
                                                    "description": "The query to run.",
                                                    "type": "string",
                                                },
                                            },
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "logs": {
                                        "additionalProperties": False,
                                        "description": "Logs association.",
                                        "items": {
                                            "additionalProperties": False,
                                            "description": "Log association item.",
                                            "properties": {
                                                "name": {
                                                    "description": "The name of the query.",
                                                    "type": "string",
                                                },
                                                "query": {
                                                    "description": "The query to run.",
                                                    "type": "string",
                                                },
                                            },
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "performanceData": {
                                        "additionalProperties": False,
                                        "description": "Performance stats association.",
                                        "properties": {
                                            "tags": {
                                                "description": "A "
                                                "list "
                                                "of "
                                                "APM "
                                                "entity "
                                                "tags "
                                                "that "
                                                "associates "
                                                "the "
                                                "APM "
                                                "Stats "
                                                "data "
                                                "with "
                                                "the "
                                                "entity.",
                                                "items": {"type": "string"},
                                                "type": "array",
                                            }
                                        },
                                        "type": "object",
                                    },
                                    "pipelines": {
                                        "additionalProperties": False,
                                        "description": "CI Pipelines association.",
                                        "properties": {
                                            "fingerprints": {
                                                "description": "A "
                                                "list "
                                                "of "
                                                "CI "
                                                "Fingerprints "
                                                "that "
                                                "associate "
                                                "CI "
                                                "Pipelines "
                                                "with "
                                                "the "
                                                "entity.",
                                                "items": {"type": "string"},
                                                "type": "array",
                                            }
                                        },
                                        "type": "object",
                                    },
                                },
                                "type": "object",
                            },
                            "extensions": {
                                "additionalProperties": {},
                                "description": "Custom "
                                "extensions. This "
                                "is the "
                                "free-formed field "
                                "to send "
                                "client-side "
                                "metadata. No "
                                "Datadog features "
                                "are affected by "
                                "this field.",
                                "type": "object",
                            },
                            "integrations": {
                                "additionalProperties": False,
                                "description": "A base schema "
                                "for defining "
                                "third-party "
                                "integrations.",
                                "properties": {
                                    "opsgenie": {
                                        "additionalProperties": False,
                                        "description": "An Opsgenie integration schema.",
                                        "properties": {
                                            "region": {
                                                "description": "The "
                                                "region "
                                                "for "
                                                "the "
                                                "Opsgenie "
                                                "integration.",
                                                "minLength": 1,
                                                "type": "string",
                                            },
                                            "serviceURL": {
                                                "description": "The "
                                                "service "
                                                "URL "
                                                "for "
                                                "the "
                                                "Opsgenie "
                                                "integration.",
                                                "example": "https://www.opsgenie.com/service/shopping-cart",
                                                "minLength": 1,
                                                "type": "string",
                                            },
                                        },
                                        "required": ["serviceURL"],
                                        "type": "object",
                                    },
                                    "pagerduty": {
                                        "additionalProperties": False,
                                        "description": "A PagerDuty integration schema.",
                                        "properties": {
                                            "serviceURL": {
                                                "description": "The "
                                                "service "
                                                "URL "
                                                "for "
                                                "the "
                                                "PagerDuty "
                                                "integration.",
                                                "example": "https://www.pagerduty.com/service-directory/Pshopping-cart",
                                                "minLength": 1,
                                                "type": "string",
                                            }
                                        },
                                        "required": ["serviceURL"],
                                        "type": "object",
                                    },
                                },
                                "type": "object",
                            },
                            "kind": {
                                "description": "The definition of Entity V3 System Kind object.",
                                "enum": ["system"],
                                "example": "system",
                                "type": "string",
                                "x-enum-varnames": ["SYSTEM"],
                            },
                            "metadata": {
                                "additionalProperties": False,
                                "description": "The definition of Entity V3 Metadata object.",
                                "properties": {
                                    "additionalOwners": {
                                        "additionalProperties": False,
                                        "description": "The "
                                        "additional "
                                        "owners "
                                        "of "
                                        "the "
                                        "entity, "
                                        "usually "
                                        "a "
                                        "team.",
                                        "items": {
                                            "description": "The "
                                            "definition "
                                            "of "
                                            "Entity "
                                            "V3 "
                                            "Metadata "
                                            "Additional "
                                            "Owners "
                                            "Items "
                                            "object.",
                                            "properties": {
                                                "name": {
                                                    "description": "Team name.",
                                                    "example": "",
                                                    "type": "string",
                                                },
                                                "type": {
                                                    "description": "Team type.",
                                                    "type": "string",
                                                },
                                            },
                                            "required": ["name"],
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "contacts": {
                                        "additionalProperties": False,
                                        "description": "A list of contacts for the entity.",
                                        "items": {
                                            "additionalProperties": False,
                                            "description": "The "
                                            "definition "
                                            "of "
                                            "Entity "
                                            "V3 "
                                            "Metadata "
                                            "Contacts "
                                            "Items "
                                            "object.",
                                            "properties": {
                                                "contact": {
                                                    "description": "Contact value.",
                                                    "example": "https://slack/",
                                                    "type": "string",
                                                },
                                                "name": {
                                                    "description": "Contact name.",
                                                    "minLength": 2,
                                                    "type": "string",
                                                },
                                                "type": {
                                                    "description": "Contact type.",
                                                    "example": "slack",
                                                    "type": "string",
                                                },
                                            },
                                            "required": ["type", "contact"],
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "description": {
                                        "description": "Short "
                                        "description "
                                        "of "
                                        "the "
                                        "entity. "
                                        "The "
                                        "UI "
                                        "can "
                                        "leverage "
                                        "the "
                                        "description "
                                        "for "
                                        "display.",
                                        "type": "string",
                                    },
                                    "displayName": {
                                        "description": "User "
                                        "friendly "
                                        "name "
                                        "of "
                                        "the "
                                        "entity. "
                                        "The "
                                        "UI "
                                        "can "
                                        "leverage "
                                        "the "
                                        "display "
                                        "name "
                                        "for "
                                        "display.",
                                        "type": "string",
                                    },
                                    "id": {
                                        "description": "A "
                                        "read-only "
                                        "globally "
                                        "unique "
                                        "identifier "
                                        "for "
                                        "the "
                                        "entity "
                                        "generated "
                                        "by "
                                        "Datadog.  "
                                        "User "
                                        "supplied "
                                        "values "
                                        "are "
                                        "ignored.",
                                        "example": "4b163705-23c0-4573-b2fb-f6cea2163fcb",
                                        "minLength": 1,
                                        "type": "string",
                                    },
                                    "inheritFrom": {
                                        "description": "The "
                                        "entity "
                                        "reference "
                                        "from "
                                        "which "
                                        "to "
                                        "inherit "
                                        "metadata",
                                        "example": "application:default/myapp",
                                        "type": "string",
                                    },
                                    "links": {
                                        "additionalProperties": False,
                                        "description": "A list of links for the entity.",
                                        "items": {
                                            "additionalProperties": False,
                                            "description": "The "
                                            "definition "
                                            "of "
                                            "Entity "
                                            "V3 "
                                            "Metadata "
                                            "Links "
                                            "Items "
                                            "object.",
                                            "properties": {
                                                "name": {
                                                    "description": "Link name.",
                                                    "example": "mylink",
                                                    "type": "string",
                                                },
                                                "provider": {
                                                    "description": "Link provider.",
                                                    "type": "string",
                                                },
                                                "type": {
                                                    "default": "other",
                                                    "description": "Link type.",
                                                    "example": "link",
                                                    "type": "string",
                                                },
                                                "url": {
                                                    "description": "Link URL.",
                                                    "example": "https://mylink",
                                                    "type": "string",
                                                },
                                            },
                                            "required": ["name", "type", "url"],
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "managed": {
                                        "additionalProperties": {},
                                        "description": "A "
                                        "read-only "
                                        "set "
                                        "of "
                                        "Datadog "
                                        "managed "
                                        "attributes "
                                        "generated "
                                        "by "
                                        "Datadog.  "
                                        "User "
                                        "supplied "
                                        "values "
                                        "are "
                                        "ignored.",
                                        "type": "object",
                                    },
                                    "name": {
                                        "description": "Unique "
                                        "name "
                                        "given "
                                        "to "
                                        "an "
                                        "entity "
                                        "under "
                                        "the "
                                        "kind/namespace.",
                                        "example": "myService",
                                        "minLength": 1,
                                        "type": "string",
                                    },
                                    "namespace": {
                                        "description": "Namespace "
                                        "is "
                                        "a "
                                        "part "
                                        "of "
                                        "unique "
                                        "identifier. "
                                        "It "
                                        "has "
                                        "a "
                                        "default "
                                        "value "
                                        "of "
                                        "'default'.",
                                        "example": "default",
                                        "minLength": 1,
                                        "type": "string",
                                    },
                                    "owner": {
                                        "description": "The owner of the entity, usually a team.",
                                        "type": "string",
                                    },
                                    "tags": {
                                        "description": "A set of custom tags.",
                                        "example": ["this:tag", "that:tag"],
                                        "items": {"type": "string"},
                                        "type": "array",
                                    },
                                },
                                "required": ["name"],
                                "type": "object",
                            },
                            "spec": {
                                "additionalProperties": False,
                                "description": "The definition of Entity V3 System Spec object.",
                                "properties": {
                                    "components": {
                                        "description": "A "
                                        "list "
                                        "of "
                                        "components "
                                        "belongs "
                                        "to "
                                        "the "
                                        "system.",
                                        "items": {"type": "string"},
                                        "type": "array",
                                    },
                                    "lifecycle": {
                                        "description": "The lifecycle state of the component.",
                                        "minLength": 1,
                                        "type": "string",
                                    },
                                    "tier": {
                                        "description": "An "
                                        "entity "
                                        "reference "
                                        "to "
                                        "the "
                                        "owner "
                                        "of "
                                        "the "
                                        "component.",
                                        "minLength": 1,
                                        "type": "string",
                                    },
                                },
                                "type": "object",
                            },
                        },
                        "required": ["apiVersion", "kind", "metadata"],
                        "type": "object",
                    },
                    {
                        "additionalProperties": False,
                        "description": "Schema for API entities.",
                        "properties": {
                            "apiVersion": {
                                "description": "The version of "
                                "the schema data "
                                "that was used to "
                                "populate this "
                                "entity's data. "
                                "This could be via "
                                "the API, "
                                "Terraform, or "
                                "YAML file in a "
                                "repository. The "
                                "field is known as "
                                "schema-version in "
                                "the previous "
                                "version.",
                                "enum": ["v3", "v2.2", "v2.1", "v2"],
                                "example": "v3",
                                "type": "string",
                                "x-enum-varnames": ["V3", "V2_2", "V2_1", "V2"],
                            },
                            "datadog": {
                                "additionalProperties": False,
                                "description": "Datadog product integrations for the API entity.",
                                "properties": {
                                    "codeLocations": {
                                        "additionalProperties": False,
                                        "description": "Schema "
                                        "for "
                                        "mapping "
                                        "source "
                                        "code "
                                        "locations "
                                        "to "
                                        "an "
                                        "entity.",
                                        "items": {
                                            "additionalProperties": False,
                                            "description": "Code location item.",
                                            "properties": {
                                                "paths": {
                                                    "description": "The "
                                                    "paths "
                                                    "(glob) "
                                                    "to "
                                                    "the "
                                                    "source "
                                                    "code "
                                                    "of "
                                                    "the "
                                                    "service.",
                                                    "items": {"type": "string"},
                                                    "type": "array",
                                                },
                                                "repositoryURL": {
                                                    "description": "The "
                                                    "repository "
                                                    "path "
                                                    "of "
                                                    "the "
                                                    "source "
                                                    "code "
                                                    "of "
                                                    "the "
                                                    "entity.",
                                                    "type": "string",
                                                },
                                            },
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "events": {
                                        "additionalProperties": False,
                                        "description": "Events associations.",
                                        "items": {
                                            "additionalProperties": False,
                                            "description": "Events association item.",
                                            "properties": {
                                                "name": {
                                                    "description": "The name of the query.",
                                                    "type": "string",
                                                },
                                                "query": {
                                                    "description": "The query to run.",
                                                    "type": "string",
                                                },
                                            },
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "logs": {
                                        "additionalProperties": False,
                                        "description": "Logs association.",
                                        "items": {
                                            "additionalProperties": False,
                                            "description": "Log association item.",
                                            "properties": {
                                                "name": {
                                                    "description": "The name of the query.",
                                                    "type": "string",
                                                },
                                                "query": {
                                                    "description": "The query to run.",
                                                    "type": "string",
                                                },
                                            },
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "performanceData": {
                                        "additionalProperties": False,
                                        "description": "Performance stats association.",
                                        "properties": {
                                            "tags": {
                                                "description": "A "
                                                "list "
                                                "of "
                                                "APM "
                                                "entity "
                                                "tags "
                                                "that "
                                                "associates "
                                                "the "
                                                "APM "
                                                "Stats "
                                                "data "
                                                "with "
                                                "the "
                                                "entity.",
                                                "items": {"type": "string"},
                                                "type": "array",
                                            }
                                        },
                                        "type": "object",
                                    },
                                    "pipelines": {
                                        "additionalProperties": False,
                                        "description": "CI Pipelines association.",
                                        "properties": {
                                            "fingerprints": {
                                                "description": "A "
                                                "list "
                                                "of "
                                                "CI "
                                                "Fingerprints "
                                                "that "
                                                "associate "
                                                "CI "
                                                "Pipelines "
                                                "with "
                                                "the "
                                                "entity.",
                                                "items": {"type": "string"},
                                                "type": "array",
                                            }
                                        },
                                        "type": "object",
                                    },
                                },
                                "type": "object",
                            },
                            "extensions": {
                                "additionalProperties": {},
                                "description": "Custom "
                                "extensions. This "
                                "is the "
                                "free-formed field "
                                "to send "
                                "client-side "
                                "metadata. No "
                                "Datadog features "
                                "are affected by "
                                "this field.",
                                "type": "object",
                            },
                            "integrations": {
                                "additionalProperties": False,
                                "description": "A base schema "
                                "for defining "
                                "third-party "
                                "integrations.",
                                "properties": {
                                    "opsgenie": {
                                        "additionalProperties": False,
                                        "description": "An Opsgenie integration schema.",
                                        "properties": {
                                            "region": {
                                                "description": "The "
                                                "region "
                                                "for "
                                                "the "
                                                "Opsgenie "
                                                "integration.",
                                                "minLength": 1,
                                                "type": "string",
                                            },
                                            "serviceURL": {
                                                "description": "The "
                                                "service "
                                                "URL "
                                                "for "
                                                "the "
                                                "Opsgenie "
                                                "integration.",
                                                "example": "https://www.opsgenie.com/service/shopping-cart",
                                                "minLength": 1,
                                                "type": "string",
                                            },
                                        },
                                        "required": ["serviceURL"],
                                        "type": "object",
                                    },
                                    "pagerduty": {
                                        "additionalProperties": False,
                                        "description": "A PagerDuty integration schema.",
                                        "properties": {
                                            "serviceURL": {
                                                "description": "The "
                                                "service "
                                                "URL "
                                                "for "
                                                "the "
                                                "PagerDuty "
                                                "integration.",
                                                "example": "https://www.pagerduty.com/service-directory/Pshopping-cart",
                                                "minLength": 1,
                                                "type": "string",
                                            }
                                        },
                                        "required": ["serviceURL"],
                                        "type": "object",
                                    },
                                },
                                "type": "object",
                            },
                            "kind": {
                                "description": "The definition of Entity V3 API Kind object.",
                                "enum": ["api"],
                                "example": "api",
                                "type": "string",
                                "x-enum-varnames": ["API"],
                            },
                            "metadata": {
                                "additionalProperties": False,
                                "description": "The definition of Entity V3 Metadata object.",
                                "properties": {
                                    "additionalOwners": {
                                        "additionalProperties": False,
                                        "description": "The "
                                        "additional "
                                        "owners "
                                        "of "
                                        "the "
                                        "entity, "
                                        "usually "
                                        "a "
                                        "team.",
                                        "items": {
                                            "description": "The "
                                            "definition "
                                            "of "
                                            "Entity "
                                            "V3 "
                                            "Metadata "
                                            "Additional "
                                            "Owners "
                                            "Items "
                                            "object.",
                                            "properties": {
                                                "name": {
                                                    "description": "Team name.",
                                                    "example": "",
                                                    "type": "string",
                                                },
                                                "type": {
                                                    "description": "Team type.",
                                                    "type": "string",
                                                },
                                            },
                                            "required": ["name"],
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "contacts": {
                                        "additionalProperties": False,
                                        "description": "A list of contacts for the entity.",
                                        "items": {
                                            "additionalProperties": False,
                                            "description": "The "
                                            "definition "
                                            "of "
                                            "Entity "
                                            "V3 "
                                            "Metadata "
                                            "Contacts "
                                            "Items "
                                            "object.",
                                            "properties": {
                                                "contact": {
                                                    "description": "Contact value.",
                                                    "example": "https://slack/",
                                                    "type": "string",
                                                },
                                                "name": {
                                                    "description": "Contact name.",
                                                    "minLength": 2,
                                                    "type": "string",
                                                },
                                                "type": {
                                                    "description": "Contact type.",
                                                    "example": "slack",
                                                    "type": "string",
                                                },
                                            },
                                            "required": ["type", "contact"],
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "description": {
                                        "description": "Short "
                                        "description "
                                        "of "
                                        "the "
                                        "entity. "
                                        "The "
                                        "UI "
                                        "can "
                                        "leverage "
                                        "the "
                                        "description "
                                        "for "
                                        "display.",
                                        "type": "string",
                                    },
                                    "displayName": {
                                        "description": "User "
                                        "friendly "
                                        "name "
                                        "of "
                                        "the "
                                        "entity. "
                                        "The "
                                        "UI "
                                        "can "
                                        "leverage "
                                        "the "
                                        "display "
                                        "name "
                                        "for "
                                        "display.",
                                        "type": "string",
                                    },
                                    "id": {
                                        "description": "A "
                                        "read-only "
                                        "globally "
                                        "unique "
                                        "identifier "
                                        "for "
                                        "the "
                                        "entity "
                                        "generated "
                                        "by "
                                        "Datadog.  "
                                        "User "
                                        "supplied "
                                        "values "
                                        "are "
                                        "ignored.",
                                        "example": "4b163705-23c0-4573-b2fb-f6cea2163fcb",
                                        "minLength": 1,
                                        "type": "string",
                                    },
                                    "inheritFrom": {
                                        "description": "The "
                                        "entity "
                                        "reference "
                                        "from "
                                        "which "
                                        "to "
                                        "inherit "
                                        "metadata",
                                        "example": "application:default/myapp",
                                        "type": "string",
                                    },
                                    "links": {
                                        "additionalProperties": False,
                                        "description": "A list of links for the entity.",
                                        "items": {
                                            "additionalProperties": False,
                                            "description": "The "
                                            "definition "
                                            "of "
                                            "Entity "
                                            "V3 "
                                            "Metadata "
                                            "Links "
                                            "Items "
                                            "object.",
                                            "properties": {
                                                "name": {
                                                    "description": "Link name.",
                                                    "example": "mylink",
                                                    "type": "string",
                                                },
                                                "provider": {
                                                    "description": "Link provider.",
                                                    "type": "string",
                                                },
                                                "type": {
                                                    "default": "other",
                                                    "description": "Link type.",
                                                    "example": "link",
                                                    "type": "string",
                                                },
                                                "url": {
                                                    "description": "Link URL.",
                                                    "example": "https://mylink",
                                                    "type": "string",
                                                },
                                            },
                                            "required": ["name", "type", "url"],
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "managed": {
                                        "additionalProperties": {},
                                        "description": "A "
                                        "read-only "
                                        "set "
                                        "of "
                                        "Datadog "
                                        "managed "
                                        "attributes "
                                        "generated "
                                        "by "
                                        "Datadog.  "
                                        "User "
                                        "supplied "
                                        "values "
                                        "are "
                                        "ignored.",
                                        "type": "object",
                                    },
                                    "name": {
                                        "description": "Unique "
                                        "name "
                                        "given "
                                        "to "
                                        "an "
                                        "entity "
                                        "under "
                                        "the "
                                        "kind/namespace.",
                                        "example": "myService",
                                        "minLength": 1,
                                        "type": "string",
                                    },
                                    "namespace": {
                                        "description": "Namespace "
                                        "is "
                                        "a "
                                        "part "
                                        "of "
                                        "unique "
                                        "identifier. "
                                        "It "
                                        "has "
                                        "a "
                                        "default "
                                        "value "
                                        "of "
                                        "'default'.",
                                        "example": "default",
                                        "minLength": 1,
                                        "type": "string",
                                    },
                                    "owner": {
                                        "description": "The owner of the entity, usually a team.",
                                        "type": "string",
                                    },
                                    "tags": {
                                        "description": "A set of custom tags.",
                                        "example": ["this:tag", "that:tag"],
                                        "items": {"type": "string"},
                                        "type": "array",
                                    },
                                },
                                "required": ["name"],
                                "type": "object",
                            },
                            "spec": {
                                "additionalProperties": False,
                                "description": "The definition of Entity V3 API Spec object.",
                                "properties": {
                                    "implementedBy": {
                                        "description": "Services which implemented the API.",
                                        "items": {"type": "string"},
                                        "type": "array",
                                    },
                                    "interface": {
                                        "additionalProperties": False,
                                        "description": "The API definition.",
                                        "oneOf": [
                                            {
                                                "additionalProperties": False,
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "`EntityV3APISpecInterfaceFileRef` "
                                                "object.",
                                                "properties": {
                                                    "fileRef": {
                                                        "description": "The "
                                                        "reference "
                                                        "to "
                                                        "the "
                                                        "API "
                                                        "definition "
                                                        "file.",
                                                        "type": "string",
                                                    }
                                                },
                                                "type": "object",
                                            },
                                            {
                                                "additionalProperties": False,
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "`EntityV3APISpecInterfaceDefinition` "
                                                "object.",
                                                "properties": {
                                                    "definition": {
                                                        "description": "The API definition.",
                                                        "type": "object",
                                                    }
                                                },
                                                "type": "object",
                                            },
                                        ],
                                    },
                                    "lifecycle": {
                                        "description": "The lifecycle state of the component.",
                                        "minLength": 1,
                                        "type": "string",
                                    },
                                    "tier": {
                                        "description": "The importance of the component.",
                                        "minLength": 1,
                                        "type": "string",
                                    },
                                    "type": {"description": "The type of API.", "type": "string"},
                                },
                                "type": "object",
                            },
                        },
                        "required": ["apiVersion", "kind", "metadata"],
                        "type": "object",
                    },
                ],
            },
            {
                "description": "Entity definition in raw JSON or YAML representation.",
                "example": "apiVersion: v3\nkind: service\nmetadata:\n  name: myservice",
                "type": "string",
            },
        ],
    },
    "UPDATESOFTWARECATALOGKIND_REQUEST_BODY_SCHEMA": {
        "description": "Create or update kind request.",
        "oneOf": [
            {
                "description": "Schema for kind.",
                "properties": {
                    "description": {
                        "description": "Short description of the kind.",
                        "type": "string",
                    },
                    "displayName": {
                        "description": "The display name of the "
                        "kind. Automatically "
                        "generated if not provided.",
                        "type": "string",
                    },
                    "kind": {
                        "description": "The name of the kind to create or "
                        "update. This must be in kebab-case "
                        "format.",
                        "example": "my-job",
                        "type": "string",
                    },
                },
                "required": ["kind"],
                "type": "object",
            },
            {
                "description": "Kind definition in raw JSON or YAML representation.",
                "example": "kind: service\n"
                "displayName: Service\n"
                "description: A service entity in the catalog.",
                "type": "string",
            },
        ],
    },
    "AGGREGATEPIPELINEEVENTS_REQUEST_BODY_SCHEMA": {
        "description": "The object sent with the request to retrieve aggregation buckets of "
        "pipeline events from your organization.",
        "properties": {
            "compute": {
                "description": "The list of metrics or timeseries to "
                "compute for the retrieved buckets.",
                "items": {
                    "description": "A compute rule to compute metrics or timeseries.",
                    "properties": {
                        "aggregation": {
                            "description": "An aggregation function.",
                            "enum": [
                                "count",
                                "cardinality",
                                "pc75",
                                "pc90",
                                "pc95",
                                "pc98",
                                "pc99",
                                "sum",
                                "min",
                                "max",
                                "avg",
                                "median",
                                "latest",
                                "earliest",
                                "most_frequent",
                                "delta",
                            ],
                            "example": "pc90",
                            "type": "string",
                            "x-enum-varnames": [
                                "COUNT",
                                "CARDINALITY",
                                "PERCENTILE_75",
                                "PERCENTILE_90",
                                "PERCENTILE_95",
                                "PERCENTILE_98",
                                "PERCENTILE_99",
                                "SUM",
                                "MIN",
                                "MAX",
                                "AVG",
                                "MEDIAN",
                                "LATEST",
                                "EARLIEST",
                                "MOST_FREQUENT",
                                "DELTA",
                            ],
                        },
                        "interval": {
                            "description": "The "
                            "time "
                            "buckets' "
                            "size "
                            "(only "
                            "used "
                            "for "
                            "type=timeseries)\n"
                            "Defaults "
                            "to a "
                            "resolution "
                            "of "
                            "150 "
                            "points.",
                            "example": "5m",
                            "type": "string",
                        },
                        "metric": {
                            "description": "The metric to use.",
                            "example": "@duration",
                            "type": "string",
                        },
                        "type": {
                            "default": "total",
                            "description": "The type of compute.",
                            "enum": ["timeseries", "total"],
                            "type": "string",
                            "x-enum-varnames": ["TIMESERIES", "TOTAL"],
                        },
                    },
                    "required": ["aggregation"],
                    "type": "object",
                },
                "type": "array",
            },
            "filter": {
                "description": "The search and filter query settings.",
                "properties": {
                    "from": {
                        "default": "now-15m",
                        "description": "The minimum time "
                        "for the requested "
                        "events; supports "
                        "date, math, and "
                        "regular timestamps "
                        "(in milliseconds).",
                        "example": "now-15m",
                        "type": "string",
                    },
                    "query": {
                        "default": "*",
                        "description": "The search query "
                        "following the CI "
                        "Visibility "
                        "Explorer search "
                        "syntax.",
                        "example": "@ci.provider.name:github AND @ci.status:error",
                        "type": "string",
                    },
                    "to": {
                        "default": "now",
                        "description": "The maximum time for "
                        "the requested events, "
                        "supports date, math, "
                        "and regular "
                        "timestamps (in "
                        "milliseconds).",
                        "example": "now",
                        "type": "string",
                    },
                },
                "type": "object",
            },
            "group_by": {
                "description": "The rules for the group-by.",
                "items": {
                    "description": "A group-by rule.",
                    "properties": {
                        "facet": {
                            "description": "The name of the facet to use (required).",
                            "example": "@ci.status",
                            "type": "string",
                        },
                        "histogram": {
                            "description": "Used "
                            "to "
                            "perform "
                            "a "
                            "histogram "
                            "computation "
                            "(only "
                            "for "
                            "measure "
                            "facets).\n"
                            "At "
                            "most, "
                            "100 "
                            "buckets "
                            "are "
                            "allowed, "
                            "the "
                            "number "
                            "of "
                            "buckets "
                            "is "
                            "`(max "
                            "- "
                            "min)/interval`.",
                            "properties": {
                                "interval": {
                                    "description": "The bin size of the histogram buckets.",
                                    "example": 10,
                                    "format": "double",
                                    "type": "number",
                                },
                                "max": {
                                    "description": "The "
                                    "maximum "
                                    "value "
                                    "for "
                                    "the "
                                    "measure "
                                    "used "
                                    "in "
                                    "the "
                                    "histogram\n"
                                    "(values "
                                    "greater "
                                    "than "
                                    "this "
                                    "one "
                                    "are "
                                    "filtered "
                                    "out).",
                                    "example": 100,
                                    "format": "double",
                                    "type": "number",
                                },
                                "min": {
                                    "description": "The "
                                    "minimum "
                                    "value "
                                    "for "
                                    "the "
                                    "measure "
                                    "used "
                                    "in "
                                    "the "
                                    "histogram\n"
                                    "(values "
                                    "smaller "
                                    "than "
                                    "this "
                                    "one "
                                    "are "
                                    "filtered "
                                    "out).",
                                    "example": 50,
                                    "format": "double",
                                    "type": "number",
                                },
                            },
                            "required": ["interval", "min", "max"],
                            "type": "object",
                        },
                        "limit": {
                            "default": 10,
                            "description": "The maximum buckets to return for this group-by.",
                            "format": "int64",
                            "type": "integer",
                        },
                        "missing": {
                            "description": "The "
                            "value "
                            "to "
                            "use "
                            "for "
                            "logs "
                            "that "
                            "don't "
                            "have "
                            "the "
                            "facet "
                            "used "
                            "to "
                            "group-by.",
                            "oneOf": [
                                {
                                    "description": "The "
                                    "missing "
                                    "value "
                                    "to "
                                    "use "
                                    "if "
                                    "there "
                                    "is "
                                    "a "
                                    "string "
                                    "valued "
                                    "facet.",
                                    "type": "string",
                                },
                                {
                                    "description": "The "
                                    "missing "
                                    "value "
                                    "to "
                                    "use "
                                    "if "
                                    "there "
                                    "is "
                                    "a "
                                    "number "
                                    "valued "
                                    "facet.",
                                    "format": "double",
                                    "type": "number",
                                },
                            ],
                        },
                        "sort": {
                            "description": "A sort "
                            "rule. "
                            "The "
                            "`aggregation` "
                            "field "
                            "is "
                            "required "
                            "when "
                            "`type` "
                            "is "
                            "`measure`.",
                            "example": {"aggregation": "count", "order": "asc"},
                            "properties": {
                                "aggregation": {
                                    "description": "An aggregation function.",
                                    "enum": [
                                        "count",
                                        "cardinality",
                                        "pc75",
                                        "pc90",
                                        "pc95",
                                        "pc98",
                                        "pc99",
                                        "sum",
                                        "min",
                                        "max",
                                        "avg",
                                        "median",
                                        "latest",
                                        "earliest",
                                        "most_frequent",
                                        "delta",
                                    ],
                                    "example": "pc90",
                                    "type": "string",
                                    "x-enum-varnames": [
                                        "COUNT",
                                        "CARDINALITY",
                                        "PERCENTILE_75",
                                        "PERCENTILE_90",
                                        "PERCENTILE_95",
                                        "PERCENTILE_98",
                                        "PERCENTILE_99",
                                        "SUM",
                                        "MIN",
                                        "MAX",
                                        "AVG",
                                        "MEDIAN",
                                        "LATEST",
                                        "EARLIEST",
                                        "MOST_FREQUENT",
                                        "DELTA",
                                    ],
                                },
                                "metric": {
                                    "description": "The "
                                    "metric "
                                    "to "
                                    "sort "
                                    "by "
                                    "(only "
                                    "used "
                                    "for "
                                    "`type=measure`).",
                                    "example": "@duration",
                                    "type": "string",
                                },
                                "order": {
                                    "description": "The order to use, ascending or descending.",
                                    "enum": ["asc", "desc"],
                                    "example": "asc",
                                    "type": "string",
                                    "x-enum-varnames": ["ASCENDING", "DESCENDING"],
                                },
                                "type": {
                                    "default": "alphabetical",
                                    "description": "The type of sorting algorithm.",
                                    "enum": ["alphabetical", "measure"],
                                    "type": "string",
                                    "x-enum-varnames": ["ALPHABETICAL", "MEASURE"],
                                },
                            },
                            "type": "object",
                        },
                        "total": {
                            "default": False,
                            "description": "A "
                            "resulting "
                            "object "
                            "to put "
                            "the "
                            "given "
                            "computes "
                            "in "
                            "over "
                            "all "
                            "the "
                            "matching "
                            "records.",
                            "oneOf": [
                                {
                                    "description": "If "
                                    "set "
                                    "to "
                                    "true, "
                                    "creates "
                                    "an "
                                    "additional "
                                    "bucket "
                                    "labeled "
                                    '"$facet_total".',
                                    "type": "boolean",
                                },
                                {
                                    "description": "A "
                                    "string "
                                    "to "
                                    "use "
                                    "as "
                                    "the "
                                    "key "
                                    "value "
                                    "for "
                                    "the "
                                    "total "
                                    "bucket.",
                                    "type": "string",
                                },
                                {
                                    "description": "A "
                                    "number "
                                    "to "
                                    "use "
                                    "as "
                                    "the "
                                    "key "
                                    "value "
                                    "for "
                                    "the "
                                    "total "
                                    "bucket.",
                                    "format": "double",
                                    "type": "number",
                                },
                            ],
                        },
                    },
                    "required": ["facet"],
                    "type": "object",
                },
                "type": "array",
            },
            "options": {
                "description": "Global query options that are used during "
                "the query.\n"
                "Only supply timezone or time offset, not "
                "both. Otherwise, the query fails.",
                "properties": {
                    "time_offset": {
                        "description": "The time offset (in seconds) to apply to the query.",
                        "format": "int64",
                        "type": "integer",
                    },
                    "timezone": {
                        "default": "UTC",
                        "description": "The timezone "
                        "can be "
                        "specified as "
                        "GMT, UTC, an "
                        "offset from "
                        "UTC (like "
                        "UTC+1), or as "
                        "a Timezone "
                        "Database "
                        "identifier "
                        "(like "
                        "America/New_York).",
                        "example": "GMT",
                        "type": "string",
                    },
                },
                "type": "object",
            },
        },
        "type": "object",
    },
    "AGGREGATETESTMETRICS_REQUEST_BODY_SCHEMA": {
        "description": "The object sent with the request to retrieve aggregation buckets of "
        "test events from your organization.",
        "properties": {
            "compute": {
                "description": "The list of metrics or timeseries to "
                "compute for the retrieved buckets.",
                "items": {
                    "description": "A compute rule to compute metrics or timeseries.",
                    "properties": {
                        "aggregation": {
                            "description": "An aggregation function.",
                            "enum": [
                                "count",
                                "cardinality",
                                "pc75",
                                "pc90",
                                "pc95",
                                "pc98",
                                "pc99",
                                "sum",
                                "min",
                                "max",
                                "avg",
                                "median",
                                "latest",
                                "earliest",
                                "most_frequent",
                                "delta",
                            ],
                            "example": "pc90",
                            "type": "string",
                            "x-enum-varnames": [
                                "COUNT",
                                "CARDINALITY",
                                "PERCENTILE_75",
                                "PERCENTILE_90",
                                "PERCENTILE_95",
                                "PERCENTILE_98",
                                "PERCENTILE_99",
                                "SUM",
                                "MIN",
                                "MAX",
                                "AVG",
                                "MEDIAN",
                                "LATEST",
                                "EARLIEST",
                                "MOST_FREQUENT",
                                "DELTA",
                            ],
                        },
                        "interval": {
                            "description": "The "
                            "time "
                            "buckets' "
                            "size "
                            "(only "
                            "used "
                            "for "
                            "type=timeseries)\n"
                            "Defaults "
                            "to a "
                            "resolution "
                            "of "
                            "150 "
                            "points.",
                            "example": "5m",
                            "type": "string",
                        },
                        "metric": {
                            "description": "The metric to use.",
                            "example": "@duration",
                            "type": "string",
                        },
                        "type": {
                            "default": "total",
                            "description": "The type of compute.",
                            "enum": ["timeseries", "total"],
                            "type": "string",
                            "x-enum-varnames": ["TIMESERIES", "TOTAL"],
                        },
                    },
                    "required": ["aggregation"],
                    "type": "object",
                },
                "type": "array",
            },
            "filter": {
                "description": "The search and filter query settings.",
                "properties": {
                    "from": {
                        "default": "now-15m",
                        "description": "The minimum time "
                        "for the requested "
                        "events; supports "
                        "date, math, and "
                        "regular timestamps "
                        "(in milliseconds).",
                        "example": "now-15m",
                        "type": "string",
                    },
                    "query": {
                        "default": "*",
                        "description": "The search query "
                        "following the CI "
                        "Visibility "
                        "Explorer search "
                        "syntax.",
                        "example": "@test.service:web-ui-tests AND @test.status:fail",
                        "type": "string",
                    },
                    "to": {
                        "default": "now",
                        "description": "The maximum time for "
                        "the requested events, "
                        "supports date, math, "
                        "and regular "
                        "timestamps (in "
                        "milliseconds).",
                        "example": "now",
                        "type": "string",
                    },
                },
                "type": "object",
            },
            "group_by": {
                "description": "The rules for the group-by.",
                "items": {
                    "description": "A group-by rule.",
                    "properties": {
                        "facet": {
                            "description": "The name of the facet to use (required).",
                            "example": "@test.service",
                            "type": "string",
                        },
                        "histogram": {
                            "description": "Used "
                            "to "
                            "perform "
                            "a "
                            "histogram "
                            "computation "
                            "(only "
                            "for "
                            "measure "
                            "facets).\n"
                            "At "
                            "most, "
                            "100 "
                            "buckets "
                            "are "
                            "allowed, "
                            "the "
                            "number "
                            "of "
                            "buckets "
                            "is "
                            "`(max "
                            "- "
                            "min)/interval`.",
                            "properties": {
                                "interval": {
                                    "description": "The bin size of the histogram buckets.",
                                    "example": 10,
                                    "format": "double",
                                    "type": "number",
                                },
                                "max": {
                                    "description": "The "
                                    "maximum "
                                    "value "
                                    "for "
                                    "the "
                                    "measure "
                                    "used "
                                    "in "
                                    "the "
                                    "histogram\n"
                                    "(values "
                                    "greater "
                                    "than "
                                    "this "
                                    "one "
                                    "are "
                                    "filtered "
                                    "out).",
                                    "example": 100,
                                    "format": "double",
                                    "type": "number",
                                },
                                "min": {
                                    "description": "The "
                                    "minimum "
                                    "value "
                                    "for "
                                    "the "
                                    "measure "
                                    "used "
                                    "in "
                                    "the "
                                    "histogram\n"
                                    "(values "
                                    "smaller "
                                    "than "
                                    "this "
                                    "one "
                                    "are "
                                    "filtered "
                                    "out).",
                                    "example": 50,
                                    "format": "double",
                                    "type": "number",
                                },
                            },
                            "required": ["interval", "min", "max"],
                            "type": "object",
                        },
                        "limit": {
                            "default": 10,
                            "description": "The maximum buckets to return for this group-by.",
                            "format": "int64",
                            "type": "integer",
                        },
                        "missing": {
                            "description": "The "
                            "value "
                            "to "
                            "use "
                            "for "
                            "logs "
                            "that "
                            "don't "
                            "have "
                            "the "
                            "facet "
                            "used "
                            "to "
                            "group-by.",
                            "oneOf": [
                                {
                                    "description": "The "
                                    "missing "
                                    "value "
                                    "to "
                                    "use "
                                    "if "
                                    "there "
                                    "is "
                                    "a "
                                    "string "
                                    "valued "
                                    "facet.",
                                    "type": "string",
                                },
                                {
                                    "description": "The "
                                    "missing "
                                    "value "
                                    "to "
                                    "use "
                                    "if "
                                    "there "
                                    "is "
                                    "a "
                                    "number "
                                    "valued "
                                    "facet.",
                                    "format": "double",
                                    "type": "number",
                                },
                            ],
                        },
                        "sort": {
                            "description": "A sort "
                            "rule. "
                            "The "
                            "`aggregation` "
                            "field "
                            "is "
                            "required "
                            "when "
                            "`type` "
                            "is "
                            "`measure`.",
                            "example": {"aggregation": "count", "order": "asc"},
                            "properties": {
                                "aggregation": {
                                    "description": "An aggregation function.",
                                    "enum": [
                                        "count",
                                        "cardinality",
                                        "pc75",
                                        "pc90",
                                        "pc95",
                                        "pc98",
                                        "pc99",
                                        "sum",
                                        "min",
                                        "max",
                                        "avg",
                                        "median",
                                        "latest",
                                        "earliest",
                                        "most_frequent",
                                        "delta",
                                    ],
                                    "example": "pc90",
                                    "type": "string",
                                    "x-enum-varnames": [
                                        "COUNT",
                                        "CARDINALITY",
                                        "PERCENTILE_75",
                                        "PERCENTILE_90",
                                        "PERCENTILE_95",
                                        "PERCENTILE_98",
                                        "PERCENTILE_99",
                                        "SUM",
                                        "MIN",
                                        "MAX",
                                        "AVG",
                                        "MEDIAN",
                                        "LATEST",
                                        "EARLIEST",
                                        "MOST_FREQUENT",
                                        "DELTA",
                                    ],
                                },
                                "metric": {
                                    "description": "The "
                                    "metric "
                                    "to "
                                    "sort "
                                    "by "
                                    "(only "
                                    "used "
                                    "for "
                                    "`type=measure`).",
                                    "example": "@duration",
                                    "type": "string",
                                },
                                "order": {
                                    "description": "The order to use, ascending or descending.",
                                    "enum": ["asc", "desc"],
                                    "example": "asc",
                                    "type": "string",
                                    "x-enum-varnames": ["ASCENDING", "DESCENDING"],
                                },
                                "type": {
                                    "default": "alphabetical",
                                    "description": "The type of sorting algorithm.",
                                    "enum": ["alphabetical", "measure"],
                                    "type": "string",
                                    "x-enum-varnames": ["ALPHABETICAL", "MEASURE"],
                                },
                            },
                            "type": "object",
                        },
                        "total": {
                            "default": False,
                            "description": "A "
                            "resulting "
                            "object "
                            "to put "
                            "the "
                            "given "
                            "computes "
                            "in "
                            "over "
                            "all "
                            "the "
                            "matching "
                            "records.",
                            "oneOf": [
                                {
                                    "description": "If "
                                    "set "
                                    "to "
                                    "true, "
                                    "creates "
                                    "an "
                                    "additional "
                                    "bucket "
                                    "labeled "
                                    '"$facet_total".',
                                    "type": "boolean",
                                },
                                {
                                    "description": "A "
                                    "string "
                                    "to "
                                    "use "
                                    "as "
                                    "the "
                                    "key "
                                    "value "
                                    "for "
                                    "the "
                                    "total "
                                    "bucket.",
                                    "type": "string",
                                },
                                {
                                    "description": "A "
                                    "number "
                                    "to "
                                    "use "
                                    "as "
                                    "the "
                                    "key "
                                    "value "
                                    "for "
                                    "the "
                                    "total "
                                    "bucket.",
                                    "format": "double",
                                    "type": "number",
                                },
                            ],
                        },
                    },
                    "required": ["facet"],
                    "type": "object",
                },
                "type": "array",
            },
            "options": {
                "description": "Global query options that are used during "
                "the query.\n"
                "Only supply timezone or time offset, not "
                "both. Otherwise, the query fails.",
                "properties": {
                    "time_offset": {
                        "description": "The time offset (in seconds) to apply to the query.",
                        "format": "int64",
                        "type": "integer",
                    },
                    "timezone": {
                        "default": "UTC",
                        "description": "The timezone "
                        "can be "
                        "specified as "
                        "GMT, UTC, an "
                        "offset from "
                        "UTC (like "
                        "UTC+1), or as "
                        "a Timezone "
                        "Database "
                        "identifier "
                        "(like "
                        "America/New_York).",
                        "example": "GMT",
                        "type": "string",
                    },
                },
                "type": "object",
            },
        },
        "type": "object",
    },
    "CREATECUSTOMSECURITYFRAMEWORK_REQUEST_BODY_SCHEMA": {
        "description": "Request object to create a custom framework.",
        "properties": {
            "data": {
                "description": "Contains type and attributes for custom frameworks.",
                "properties": {
                    "attributes": {
                        "description": "Framework Data Attributes.",
                        "properties": {
                            "description": {
                                "description": "Framework Description",
                                "type": "string",
                            },
                            "handle": {
                                "description": "Framework Handle",
                                "example": "sec2",
                                "type": "string",
                            },
                            "icon_url": {"description": "Framework Icon URL", "type": "string"},
                            "name": {
                                "description": "Framework Name",
                                "example": "security-framework",
                                "type": "string",
                            },
                            "requirements": {
                                "description": "Framework Requirements",
                                "items": {
                                    "description": "Framework Requirement.",
                                    "properties": {
                                        "controls": {
                                            "description": "Requirement Controls.",
                                            "items": {
                                                "description": "Framework Control.",
                                                "properties": {
                                                    "name": {
                                                        "description": "Control Name.",
                                                        "example": "A1.2",
                                                        "type": "string",
                                                    },
                                                    "rules_id": {
                                                        "description": "Rule IDs.",
                                                        "example": ['["def-000-abc"]'],
                                                        "items": {"type": "string"},
                                                        "type": "array",
                                                    },
                                                },
                                                "required": ["name", "rules_id"],
                                                "type": "object",
                                            },
                                            "type": "array",
                                        },
                                        "name": {
                                            "description": "Requirement Name.",
                                            "example": "criteria",
                                            "type": "string",
                                        },
                                    },
                                    "required": ["name", "controls"],
                                    "type": "object",
                                },
                                "type": "array",
                            },
                            "version": {
                                "description": "Framework Version",
                                "example": "2",
                                "type": "string",
                            },
                        },
                        "required": ["handle", "version", "name", "requirements"],
                        "type": "object",
                    },
                    "type": {
                        "default": "custom_framework",
                        "description": "The type of the "
                        "resource. The value "
                        "must be "
                        "`custom_framework`.",
                        "enum": ["custom_framework"],
                        "example": "custom_framework",
                        "type": "string",
                        "x-enum-varnames": ["CUSTOM_FRAMEWORK"],
                    },
                },
                "required": ["type", "attributes"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "UPDATECUSTOMFRAMEWORK_REQUEST_BODY_SCHEMA": {
        "description": "Request object to update a custom framework.",
        "properties": {
            "data": {
                "description": "Contains type and attributes for custom frameworks.",
                "properties": {
                    "attributes": {
                        "description": "Framework Data Attributes.",
                        "properties": {
                            "description": {
                                "description": "Framework Description",
                                "type": "string",
                            },
                            "handle": {
                                "description": "Framework Handle",
                                "example": "sec2",
                                "type": "string",
                            },
                            "icon_url": {"description": "Framework Icon URL", "type": "string"},
                            "name": {
                                "description": "Framework Name",
                                "example": "security-framework",
                                "type": "string",
                            },
                            "requirements": {
                                "description": "Framework Requirements",
                                "items": {
                                    "description": "Framework Requirement.",
                                    "properties": {
                                        "controls": {
                                            "description": "Requirement Controls.",
                                            "items": {
                                                "description": "Framework Control.",
                                                "properties": {
                                                    "name": {
                                                        "description": "Control Name.",
                                                        "example": "A1.2",
                                                        "type": "string",
                                                    },
                                                    "rules_id": {
                                                        "description": "Rule IDs.",
                                                        "example": ['["def-000-abc"]'],
                                                        "items": {"type": "string"},
                                                        "type": "array",
                                                    },
                                                },
                                                "required": ["name", "rules_id"],
                                                "type": "object",
                                            },
                                            "type": "array",
                                        },
                                        "name": {
                                            "description": "Requirement Name.",
                                            "example": "criteria",
                                            "type": "string",
                                        },
                                    },
                                    "required": ["name", "controls"],
                                    "type": "object",
                                },
                                "type": "array",
                            },
                            "version": {
                                "description": "Framework Version",
                                "example": "2",
                                "type": "string",
                            },
                        },
                        "required": ["handle", "version", "name", "requirements"],
                        "type": "object",
                    },
                    "type": {
                        "default": "custom_framework",
                        "description": "The type of the "
                        "resource. The value "
                        "must be "
                        "`custom_framework`.",
                        "enum": ["custom_framework"],
                        "example": "custom_framework",
                        "type": "string",
                        "x-enum-varnames": ["CUSTOM_FRAMEWORK"],
                    },
                },
                "required": ["type", "attributes"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "UPDATERESOURCEFILTERS_REQUEST_BODY_SCHEMA": {
        "description": "Request object to update a resource filter.",
        "properties": {
            "data": {
                "description": "The definition of `UpdateResourceFilterRequestData` object.",
                "properties": {
                    "attributes": {
                        "description": "Attributes of a resource filter.",
                        "example": {
                            "aws": {"123456789": ["environment:production", "team:devops"]},
                            "azure": {"sub-001": ["app:frontend"]},
                            "gcp": {"project-abc": ["region:us-central1"]},
                        },
                        "properties": {
                            "cloud_provider": {
                                "additionalProperties": {
                                    "additionalProperties": {
                                        "items": {
                                            "description": 'Tag filter in format "key:value"',
                                            "example": "environment:production",
                                            "type": "string",
                                        },
                                        "type": "array",
                                    },
                                    "type": "object",
                                },
                                "description": "A "
                                "map "
                                "of "
                                "cloud "
                                "provider "
                                "names "
                                "(e.g., "
                                '"aws", '
                                '"gcp", '
                                '"azure") '
                                "to "
                                "a "
                                "map "
                                "of "
                                "account/resource "
                                "IDs "
                                "and "
                                "their "
                                "associated "
                                "tag "
                                "filters.",
                                "type": "object",
                            },
                            "uuid": {
                                "description": "The UUID of the resource filter.",
                                "type": "string",
                            },
                        },
                        "required": ["cloud_provider"],
                        "type": "object",
                    },
                    "id": {
                        "description": "The `UpdateResourceEvaluationFiltersRequestData` `id`.",
                        "example": "csm_resource_filter",
                        "type": "string",
                    },
                    "type": {
                        "description": "Constant string to identify the request type.",
                        "enum": ["csm_resource_filter"],
                        "example": "csm_resource_filter",
                        "type": "string",
                        "x-enum-varnames": ["CSM_RESOURCE_FILTER"],
                    },
                },
                "required": ["attributes", "type"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "CREATECUSTOMALLOCATIONRULE_REQUEST_BODY_SCHEMA": {
        "description": "The definition of `ArbitraryCostUpsertRequest` object.",
        "example": {
            "data": {
                "attributes": {
                    "costs_to_allocate": [
                        {
                            "condition": "is",
                            "tag": "account_id",
                            "value": "123456789",
                            "values": None,
                        },
                        {
                            "condition": "in",
                            "tag": "environment",
                            "value": "",
                            "values": ["production", "staging"],
                        },
                    ],
                    "enabled": True,
                    "order_id": 1,
                    "provider": ["aws", "gcp"],
                    "rule_name": "example-arbitrary-cost-rule",
                    "strategy": {
                        "allocated_by_tag_keys": ["team", "environment"],
                        "based_on_costs": [
                            {
                                "condition": "is",
                                "tag": "service",
                                "value": "web-api",
                                "values": None,
                            },
                            {
                                "condition": "not in",
                                "tag": "team",
                                "value": "",
                                "values": ["legacy", "deprecated"],
                            },
                        ],
                        "granularity": "daily",
                        "method": "proportional",
                    },
                    "type": "shared",
                },
                "type": "upsert_arbitrary_rule",
            }
        },
        "properties": {
            "data": {
                "description": "The definition of `ArbitraryCostUpsertRequestData` object.",
                "properties": {
                    "attributes": {
                        "description": "The definition "
                        "of "
                        "`ArbitraryCostUpsertRequestDataAttributes` "
                        "object.",
                        "properties": {
                            "costs_to_allocate": {
                                "description": "The `attributes` `costs_to_allocate`.",
                                "items": {
                                    "description": "The "
                                    "definition "
                                    "of "
                                    "`ArbitraryCostUpsertRequestDataAttributesCostsToAllocateItems` "
                                    "object.",
                                    "properties": {
                                        "condition": {
                                            "description": "The `items` `condition`.",
                                            "example": "",
                                            "type": "string",
                                        },
                                        "tag": {
                                            "description": "The `items` `tag`.",
                                            "example": "",
                                            "type": "string",
                                        },
                                        "value": {
                                            "description": "The `items` `value`.",
                                            "type": "string",
                                        },
                                        "values": {
                                            "description": "The `items` `values`.",
                                            "items": {"type": "string"},
                                            "nullable": True,
                                            "type": "array",
                                        },
                                    },
                                    "required": ["condition", "tag"],
                                    "type": "object",
                                },
                                "type": "array",
                            },
                            "enabled": {
                                "description": "The `attributes` `enabled`.",
                                "type": "boolean",
                            },
                            "order_id": {
                                "description": "The `attributes` `order_id`.",
                                "format": "int64",
                                "type": "integer",
                            },
                            "provider": {
                                "description": "The `attributes` `provider`.",
                                "example": [""],
                                "items": {"type": "string"},
                                "type": "array",
                            },
                            "rejected": {
                                "description": "The `attributes` `rejected`.",
                                "type": "boolean",
                            },
                            "rule_name": {
                                "description": "The `attributes` `rule_name`.",
                                "example": "",
                                "type": "string",
                            },
                            "strategy": {
                                "description": "The "
                                "definition "
                                "of "
                                "`ArbitraryCostUpsertRequestDataAttributesStrategy` "
                                "object.",
                                "properties": {
                                    "allocated_by": {
                                        "description": "The `strategy` `allocated_by`.",
                                        "items": {
                                            "description": "The "
                                            "definition "
                                            "of "
                                            "`ArbitraryCostUpsertRequestDataAttributesStrategyAllocatedByItems` "
                                            "object.",
                                            "properties": {
                                                "allocated_tags": {
                                                    "description": "The `items` `allocated_tags`.",
                                                    "items": {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "`ArbitraryCostUpsertRequestDataAttributesStrategyAllocatedByItemsAllocatedTagsItems` "
                                                        "object.",
                                                        "properties": {
                                                            "key": {
                                                                "description": "The `items` `key`.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                            "value": {
                                                                "description": "The "
                                                                "`items` "
                                                                "`value`.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                        },
                                                        "required": ["key", "value"],
                                                        "type": "object",
                                                    },
                                                    "type": "array",
                                                },
                                                "percentage": {
                                                    "description": "The "
                                                    "`items` "
                                                    "`percentage`. "
                                                    "The "
                                                    "numeric "
                                                    "value "
                                                    "format "
                                                    "should "
                                                    "be "
                                                    "a "
                                                    "32bit "
                                                    "float "
                                                    "value.",
                                                    "example": 0.0,
                                                    "format": "double",
                                                    "type": "number",
                                                },
                                            },
                                            "required": ["allocated_tags", "percentage"],
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "allocated_by_filters": {
                                        "description": "The `strategy` `allocated_by_filters`.",
                                        "items": {
                                            "description": "The "
                                            "definition "
                                            "of "
                                            "`ArbitraryCostUpsertRequestDataAttributesStrategyAllocatedByFiltersItems` "
                                            "object.",
                                            "properties": {
                                                "condition": {
                                                    "description": "The `items` `condition`.",
                                                    "example": "",
                                                    "type": "string",
                                                },
                                                "tag": {
                                                    "description": "The `items` `tag`.",
                                                    "example": "",
                                                    "type": "string",
                                                },
                                                "value": {
                                                    "description": "The `items` `value`.",
                                                    "type": "string",
                                                },
                                                "values": {
                                                    "description": "The `items` `values`.",
                                                    "items": {"type": "string"},
                                                    "nullable": True,
                                                    "type": "array",
                                                },
                                            },
                                            "required": ["condition", "tag"],
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "allocated_by_tag_keys": {
                                        "description": "The `strategy` `allocated_by_tag_keys`.",
                                        "items": {"type": "string"},
                                        "type": "array",
                                    },
                                    "based_on_costs": {
                                        "description": "The `strategy` `based_on_costs`.",
                                        "items": {
                                            "description": "The "
                                            "definition "
                                            "of "
                                            "`ArbitraryCostUpsertRequestDataAttributesStrategyBasedOnCostsItems` "
                                            "object.",
                                            "properties": {
                                                "condition": {
                                                    "description": "The `items` `condition`.",
                                                    "example": "",
                                                    "type": "string",
                                                },
                                                "tag": {
                                                    "description": "The `items` `tag`.",
                                                    "example": "",
                                                    "type": "string",
                                                },
                                                "value": {
                                                    "description": "The `items` `value`.",
                                                    "type": "string",
                                                },
                                                "values": {
                                                    "description": "The `items` `values`.",
                                                    "items": {"type": "string"},
                                                    "nullable": True,
                                                    "type": "array",
                                                },
                                            },
                                            "required": ["condition", "tag"],
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "based_on_timeseries": {
                                        "additionalProperties": {},
                                        "description": "The `strategy` `based_on_timeseries`.",
                                        "type": "object",
                                    },
                                    "evaluate_grouped_by_filters": {
                                        "description": "The "
                                        "`strategy` "
                                        "`evaluate_grouped_by_filters`.",
                                        "items": {
                                            "description": "The "
                                            "definition "
                                            "of "
                                            "`ArbitraryCostUpsertRequestDataAttributesStrategyEvaluateGroupedByFiltersItems` "
                                            "object.",
                                            "properties": {
                                                "condition": {
                                                    "description": "The `items` `condition`.",
                                                    "example": "",
                                                    "type": "string",
                                                },
                                                "tag": {
                                                    "description": "The `items` `tag`.",
                                                    "example": "",
                                                    "type": "string",
                                                },
                                                "value": {
                                                    "description": "The `items` `value`.",
                                                    "type": "string",
                                                },
                                                "values": {
                                                    "description": "The `items` `values`.",
                                                    "items": {"type": "string"},
                                                    "nullable": True,
                                                    "type": "array",
                                                },
                                            },
                                            "required": ["condition", "tag"],
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "evaluate_grouped_by_tag_keys": {
                                        "description": "The "
                                        "`strategy` "
                                        "`evaluate_grouped_by_tag_keys`.",
                                        "items": {"type": "string"},
                                        "type": "array",
                                    },
                                    "granularity": {
                                        "description": "The `strategy` `granularity`.",
                                        "type": "string",
                                    },
                                    "method": {
                                        "description": "The `strategy` `method`.",
                                        "example": "",
                                        "type": "string",
                                    },
                                },
                                "required": ["method"],
                                "type": "object",
                            },
                            "type": {
                                "description": "The `attributes` `type`.",
                                "example": "",
                                "type": "string",
                            },
                        },
                        "required": [
                            "costs_to_allocate",
                            "provider",
                            "rule_name",
                            "strategy",
                            "type",
                        ],
                        "type": "object",
                    },
                    "id": {
                        "description": "The `ArbitraryCostUpsertRequestData` `id`.",
                        "type": "string",
                    },
                    "type": {
                        "default": "upsert_arbitrary_rule",
                        "description": "Upsert arbitrary rule resource type.",
                        "enum": ["upsert_arbitrary_rule"],
                        "example": "upsert_arbitrary_rule",
                        "type": "string",
                        "x-enum-varnames": ["UPSERT_ARBITRARY_RULE"],
                    },
                },
                "required": ["type"],
                "type": "object",
            }
        },
        "type": "object",
    },
    "REORDERCUSTOMALLOCATIONRULES_REQUEST_BODY_SCHEMA": {
        "description": "The definition of `ReorderRuleResourceArray` object.",
        "example": {
            "data": [
                {"id": "456", "type": "arbitrary_rule"},
                {"id": "123", "type": "arbitrary_rule"},
                {"id": "789", "type": "arbitrary_rule"},
            ]
        },
        "properties": {
            "data": {
                "description": "The `ReorderRuleResourceArray` `data`.",
                "items": {
                    "description": "The definition of `ReorderRuleResourceData` object.",
                    "properties": {
                        "id": {
                            "description": "The `ReorderRuleResourceData` `id`.",
                            "type": "string",
                        },
                        "type": {
                            "default": "arbitrary_rule",
                            "description": "Arbitrary rule resource type.",
                            "enum": ["arbitrary_rule"],
                            "example": "arbitrary_rule",
                            "type": "string",
                            "x-enum-varnames": ["ARBITRARY_RULE"],
                        },
                    },
                    "required": ["type"],
                    "type": "object",
                },
                "type": "array",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "UPDATECUSTOMALLOCATIONRULE_REQUEST_BODY_SCHEMA": {
        "description": "The definition of `ArbitraryCostUpsertRequest` object.",
        "example": {
            "data": {
                "attributes": {
                    "costs_to_allocate": [
                        {
                            "condition": "is",
                            "tag": "account_id",
                            "value": "123456789",
                            "values": None,
                        },
                        {
                            "condition": "in",
                            "tag": "environment",
                            "value": "",
                            "values": ["production", "staging"],
                        },
                    ],
                    "enabled": True,
                    "order_id": 1,
                    "provider": ["aws", "gcp"],
                    "rule_name": "example-arbitrary-cost-rule",
                    "strategy": {
                        "allocated_by_tag_keys": ["team", "environment"],
                        "based_on_costs": [
                            {
                                "condition": "is",
                                "tag": "service",
                                "value": "web-api",
                                "values": None,
                            },
                            {
                                "condition": "not in",
                                "tag": "team",
                                "value": "",
                                "values": ["legacy", "deprecated"],
                            },
                        ],
                        "granularity": "daily",
                        "method": "proportional",
                    },
                    "type": "shared",
                },
                "type": "upsert_arbitrary_rule",
            }
        },
        "properties": {
            "data": {
                "description": "The definition of `ArbitraryCostUpsertRequestData` object.",
                "properties": {
                    "attributes": {
                        "description": "The definition "
                        "of "
                        "`ArbitraryCostUpsertRequestDataAttributes` "
                        "object.",
                        "properties": {
                            "costs_to_allocate": {
                                "description": "The `attributes` `costs_to_allocate`.",
                                "items": {
                                    "description": "The "
                                    "definition "
                                    "of "
                                    "`ArbitraryCostUpsertRequestDataAttributesCostsToAllocateItems` "
                                    "object.",
                                    "properties": {
                                        "condition": {
                                            "description": "The `items` `condition`.",
                                            "example": "",
                                            "type": "string",
                                        },
                                        "tag": {
                                            "description": "The `items` `tag`.",
                                            "example": "",
                                            "type": "string",
                                        },
                                        "value": {
                                            "description": "The `items` `value`.",
                                            "type": "string",
                                        },
                                        "values": {
                                            "description": "The `items` `values`.",
                                            "items": {"type": "string"},
                                            "nullable": True,
                                            "type": "array",
                                        },
                                    },
                                    "required": ["condition", "tag"],
                                    "type": "object",
                                },
                                "type": "array",
                            },
                            "enabled": {
                                "description": "The `attributes` `enabled`.",
                                "type": "boolean",
                            },
                            "order_id": {
                                "description": "The `attributes` `order_id`.",
                                "format": "int64",
                                "type": "integer",
                            },
                            "provider": {
                                "description": "The `attributes` `provider`.",
                                "example": [""],
                                "items": {"type": "string"},
                                "type": "array",
                            },
                            "rejected": {
                                "description": "The `attributes` `rejected`.",
                                "type": "boolean",
                            },
                            "rule_name": {
                                "description": "The `attributes` `rule_name`.",
                                "example": "",
                                "type": "string",
                            },
                            "strategy": {
                                "description": "The "
                                "definition "
                                "of "
                                "`ArbitraryCostUpsertRequestDataAttributesStrategy` "
                                "object.",
                                "properties": {
                                    "allocated_by": {
                                        "description": "The `strategy` `allocated_by`.",
                                        "items": {
                                            "description": "The "
                                            "definition "
                                            "of "
                                            "`ArbitraryCostUpsertRequestDataAttributesStrategyAllocatedByItems` "
                                            "object.",
                                            "properties": {
                                                "allocated_tags": {
                                                    "description": "The `items` `allocated_tags`.",
                                                    "items": {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "`ArbitraryCostUpsertRequestDataAttributesStrategyAllocatedByItemsAllocatedTagsItems` "
                                                        "object.",
                                                        "properties": {
                                                            "key": {
                                                                "description": "The `items` `key`.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                            "value": {
                                                                "description": "The "
                                                                "`items` "
                                                                "`value`.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                        },
                                                        "required": ["key", "value"],
                                                        "type": "object",
                                                    },
                                                    "type": "array",
                                                },
                                                "percentage": {
                                                    "description": "The "
                                                    "`items` "
                                                    "`percentage`. "
                                                    "The "
                                                    "numeric "
                                                    "value "
                                                    "format "
                                                    "should "
                                                    "be "
                                                    "a "
                                                    "32bit "
                                                    "float "
                                                    "value.",
                                                    "example": 0.0,
                                                    "format": "double",
                                                    "type": "number",
                                                },
                                            },
                                            "required": ["allocated_tags", "percentage"],
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "allocated_by_filters": {
                                        "description": "The `strategy` `allocated_by_filters`.",
                                        "items": {
                                            "description": "The "
                                            "definition "
                                            "of "
                                            "`ArbitraryCostUpsertRequestDataAttributesStrategyAllocatedByFiltersItems` "
                                            "object.",
                                            "properties": {
                                                "condition": {
                                                    "description": "The `items` `condition`.",
                                                    "example": "",
                                                    "type": "string",
                                                },
                                                "tag": {
                                                    "description": "The `items` `tag`.",
                                                    "example": "",
                                                    "type": "string",
                                                },
                                                "value": {
                                                    "description": "The `items` `value`.",
                                                    "type": "string",
                                                },
                                                "values": {
                                                    "description": "The `items` `values`.",
                                                    "items": {"type": "string"},
                                                    "nullable": True,
                                                    "type": "array",
                                                },
                                            },
                                            "required": ["condition", "tag"],
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "allocated_by_tag_keys": {
                                        "description": "The `strategy` `allocated_by_tag_keys`.",
                                        "items": {"type": "string"},
                                        "type": "array",
                                    },
                                    "based_on_costs": {
                                        "description": "The `strategy` `based_on_costs`.",
                                        "items": {
                                            "description": "The "
                                            "definition "
                                            "of "
                                            "`ArbitraryCostUpsertRequestDataAttributesStrategyBasedOnCostsItems` "
                                            "object.",
                                            "properties": {
                                                "condition": {
                                                    "description": "The `items` `condition`.",
                                                    "example": "",
                                                    "type": "string",
                                                },
                                                "tag": {
                                                    "description": "The `items` `tag`.",
                                                    "example": "",
                                                    "type": "string",
                                                },
                                                "value": {
                                                    "description": "The `items` `value`.",
                                                    "type": "string",
                                                },
                                                "values": {
                                                    "description": "The `items` `values`.",
                                                    "items": {"type": "string"},
                                                    "nullable": True,
                                                    "type": "array",
                                                },
                                            },
                                            "required": ["condition", "tag"],
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "based_on_timeseries": {
                                        "additionalProperties": {},
                                        "description": "The `strategy` `based_on_timeseries`.",
                                        "type": "object",
                                    },
                                    "evaluate_grouped_by_filters": {
                                        "description": "The "
                                        "`strategy` "
                                        "`evaluate_grouped_by_filters`.",
                                        "items": {
                                            "description": "The "
                                            "definition "
                                            "of "
                                            "`ArbitraryCostUpsertRequestDataAttributesStrategyEvaluateGroupedByFiltersItems` "
                                            "object.",
                                            "properties": {
                                                "condition": {
                                                    "description": "The `items` `condition`.",
                                                    "example": "",
                                                    "type": "string",
                                                },
                                                "tag": {
                                                    "description": "The `items` `tag`.",
                                                    "example": "",
                                                    "type": "string",
                                                },
                                                "value": {
                                                    "description": "The `items` `value`.",
                                                    "type": "string",
                                                },
                                                "values": {
                                                    "description": "The `items` `values`.",
                                                    "items": {"type": "string"},
                                                    "nullable": True,
                                                    "type": "array",
                                                },
                                            },
                                            "required": ["condition", "tag"],
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "evaluate_grouped_by_tag_keys": {
                                        "description": "The "
                                        "`strategy` "
                                        "`evaluate_grouped_by_tag_keys`.",
                                        "items": {"type": "string"},
                                        "type": "array",
                                    },
                                    "granularity": {
                                        "description": "The `strategy` `granularity`.",
                                        "type": "string",
                                    },
                                    "method": {
                                        "description": "The `strategy` `method`.",
                                        "example": "",
                                        "type": "string",
                                    },
                                },
                                "required": ["method"],
                                "type": "object",
                            },
                            "type": {
                                "description": "The `attributes` `type`.",
                                "example": "",
                                "type": "string",
                            },
                        },
                        "required": [
                            "costs_to_allocate",
                            "provider",
                            "rule_name",
                            "strategy",
                            "type",
                        ],
                        "type": "object",
                    },
                    "id": {
                        "description": "The `ArbitraryCostUpsertRequestData` `id`.",
                        "type": "string",
                    },
                    "type": {
                        "default": "upsert_arbitrary_rule",
                        "description": "Upsert arbitrary rule resource type.",
                        "enum": ["upsert_arbitrary_rule"],
                        "example": "upsert_arbitrary_rule",
                        "type": "string",
                        "x-enum-varnames": ["UPSERT_ARBITRARY_RULE"],
                    },
                },
                "required": ["type"],
                "type": "object",
            }
        },
        "type": "object",
    },
    "CREATEAZURECOSTMANAGEMENTACCOUNT_REQUEST_BODY_SCHEMA": {
        "description": "Azure config Post Request.",
        "properties": {
            "data": {
                "description": "Azure config Post data.",
                "properties": {
                    "attributes": {
                        "description": "Attributes for Azure config Post Request.",
                        "properties": {
                            "account_id": {
                                "description": "The tenant ID of the Azure account.",
                                "example": "1234abcd-1234-abcd-1234-1234abcd1234",
                                "type": "string",
                            },
                            "actual_bill_config": {
                                "description": "Bill config.",
                                "properties": {
                                    "export_name": {
                                        "description": "The name of the configured Azure Export.",
                                        "example": "dd-actual-export",
                                        "type": "string",
                                    },
                                    "export_path": {
                                        "description": "The path where the Azure Export is saved.",
                                        "example": "dd-export-path",
                                        "type": "string",
                                    },
                                    "storage_account": {
                                        "description": "The "
                                        "name "
                                        "of "
                                        "the "
                                        "storage "
                                        "account "
                                        "where "
                                        "the "
                                        "Azure "
                                        "Export "
                                        "is "
                                        "saved.",
                                        "example": "dd-storage-account",
                                        "type": "string",
                                    },
                                    "storage_container": {
                                        "description": "The "
                                        "name "
                                        "of "
                                        "the "
                                        "storage "
                                        "container "
                                        "where "
                                        "the "
                                        "Azure "
                                        "Export "
                                        "is "
                                        "saved.",
                                        "example": "dd-storage-container",
                                        "type": "string",
                                    },
                                },
                                "required": [
                                    "export_name",
                                    "export_path",
                                    "storage_account",
                                    "storage_container",
                                ],
                                "type": "object",
                            },
                            "amortized_bill_config": {
                                "description": "Bill config.",
                                "properties": {
                                    "export_name": {
                                        "description": "The name of the configured Azure Export.",
                                        "example": "dd-actual-export",
                                        "type": "string",
                                    },
                                    "export_path": {
                                        "description": "The path where the Azure Export is saved.",
                                        "example": "dd-export-path",
                                        "type": "string",
                                    },
                                    "storage_account": {
                                        "description": "The "
                                        "name "
                                        "of "
                                        "the "
                                        "storage "
                                        "account "
                                        "where "
                                        "the "
                                        "Azure "
                                        "Export "
                                        "is "
                                        "saved.",
                                        "example": "dd-storage-account",
                                        "type": "string",
                                    },
                                    "storage_container": {
                                        "description": "The "
                                        "name "
                                        "of "
                                        "the "
                                        "storage "
                                        "container "
                                        "where "
                                        "the "
                                        "Azure "
                                        "Export "
                                        "is "
                                        "saved.",
                                        "example": "dd-storage-container",
                                        "type": "string",
                                    },
                                },
                                "required": [
                                    "export_name",
                                    "export_path",
                                    "storage_account",
                                    "storage_container",
                                ],
                                "type": "object",
                            },
                            "client_id": {
                                "description": "The client ID of the Azure account.",
                                "example": "1234abcd-1234-abcd-1234-1234abcd1234",
                                "type": "string",
                            },
                            "scope": {
                                "description": "The scope of your observed subscription.",
                                "example": "/subscriptions/1234abcd-1234-abcd-1234-1234abcd1234",
                                "type": "string",
                            },
                        },
                        "required": [
                            "account_id",
                            "actual_bill_config",
                            "amortized_bill_config",
                            "client_id",
                            "scope",
                        ],
                        "type": "object",
                    },
                    "type": {
                        "default": "azure_uc_config_post_request",
                        "description": "Type of Azure config Post Request.",
                        "enum": ["azure_uc_config_post_request"],
                        "example": "azure_uc_config_post_request",
                        "type": "string",
                        "x-enum-varnames": ["AZURE_UC_CONFIG_POST_REQUEST"],
                    },
                },
                "required": ["type"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "MANAGEBUDGET_REQUEST_BODY_SCHEMA": {
        "description": "The definition of the `BudgetWithEntries` object.",
        "properties": {
            "data": {
                "description": "A budget and all its entries.",
                "properties": {
                    "attributes": {
                        "description": "The attributes of a budget.",
                        "properties": {
                            "created_at": {
                                "description": "The timestamp when the budget was created.",
                                "example": 1738258683590,
                                "format": "int64",
                                "type": "integer",
                            },
                            "created_by": {
                                "description": "The id of the user that created the budget.",
                                "example": "00000000-0a0a-0a0a-aaa0-00000000000a",
                                "type": "string",
                            },
                            "end_month": {
                                "description": "The month when the budget ends.",
                                "example": 202502,
                                "format": "int64",
                                "type": "integer",
                            },
                            "entries": {
                                "description": "The entries of the budget.",
                                "items": {
                                    "description": "The entry of a budget.",
                                    "properties": {
                                        "amount": {
                                            "description": "The `amount` of the budget entry.",
                                            "example": 500,
                                            "format": "double",
                                            "type": "number",
                                        },
                                        "month": {
                                            "description": "The `month` of the budget entry.",
                                            "example": 202501,
                                            "format": "int64",
                                            "type": "integer",
                                        },
                                        "tag_filters": {
                                            "description": "The `tag_filters` of the budget entry.",
                                            "items": {
                                                "description": "Tag "
                                                "filter "
                                                "for "
                                                "the "
                                                "budget's "
                                                "entries.",
                                                "properties": {
                                                    "tag_key": {
                                                        "description": "The key of the tag.",
                                                        "example": "service",
                                                        "type": "string",
                                                    },
                                                    "tag_value": {
                                                        "description": "The value of the tag.",
                                                        "example": "ec2",
                                                        "type": "string",
                                                    },
                                                },
                                                "type": "object",
                                            },
                                            "type": "array",
                                        },
                                    },
                                    "type": "object",
                                },
                                "type": "array",
                            },
                            "metrics_query": {
                                "description": "The cost query used to track against the budget.",
                                "example": "aws.cost.amortized{service:ec2} by {service}",
                                "type": "string",
                            },
                            "name": {
                                "description": "The name of the budget.",
                                "example": "my budget",
                                "type": "string",
                            },
                            "org_id": {
                                "description": "The id of the org the budget belongs to.",
                                "example": 123,
                                "format": "int64",
                                "type": "integer",
                            },
                            "start_month": {
                                "description": "The month when the budget starts.",
                                "example": 202501,
                                "format": "int64",
                                "type": "integer",
                            },
                            "total_amount": {
                                "description": "The sum of all budget entries' amounts.",
                                "example": 1000,
                                "format": "double",
                                "type": "number",
                            },
                            "updated_at": {
                                "description": "The timestamp when the budget was last updated.",
                                "example": 1738258683590,
                                "format": "int64",
                                "type": "integer",
                            },
                            "updated_by": {
                                "description": "The id of the user that created the budget.",
                                "example": "00000000-0a0a-0a0a-aaa0-00000000000a",
                                "type": "string",
                            },
                        },
                        "type": "object",
                    },
                    "id": {
                        "description": "The `BudgetWithEntriesData` `id`.",
                        "example": "00000000-0a0a-0a0a-aaa0-00000000000a",
                        "type": "string",
                    },
                    "type": {
                        "description": "The type of the object, must be `budget`.",
                        "type": "string",
                    },
                },
                "type": "object",
            }
        },
        "type": "object",
    },
    "UPLOADCUSTOMCOSTSFILE_REQUEST_BODY_SCHEMA": {
        "description": "Request for uploading a Custom Costs file.",
        "items": {
            "description": "Line item details from a Custom Costs file.",
            "properties": {
                "BilledCost": {
                    "description": "Total cost in the cost file.",
                    "example": 100.5,
                    "format": "double",
                    "type": "number",
                },
                "BillingCurrency": {
                    "description": "Currency used in the Custom Costs file.",
                    "example": "USD",
                    "type": "string",
                },
                "ChargeDescription": {
                    "description": "Description for the line item cost.",
                    "example": "Monthly usage charge for my service",
                    "type": "string",
                },
                "ChargePeriodEnd": {
                    "description": "End date of the usage charge.",
                    "example": "2023-02-28",
                    "pattern": "^\\d{4}-\\d{2}-\\d{2}$",
                    "type": "string",
                },
                "ChargePeriodStart": {
                    "description": "Start date of the usage charge.",
                    "example": "2023-02-01",
                    "pattern": "^\\d{4}-\\d{2}-\\d{2}$",
                    "type": "string",
                },
                "ProviderName": {
                    "description": "Name of the provider for the line item.",
                    "type": "string",
                },
                "Tags": {
                    "additionalProperties": {"type": "string"},
                    "description": "Additional tags for the line item.",
                    "type": "object",
                },
            },
            "type": "object",
        },
        "type": "array",
    },
    "DELETEDASHBOARDFROMLIST_REQUEST_BODY_SCHEMA": {
        "description": "Request containing a list of dashboards to delete.",
        "properties": {
            "dashboards": {
                "description": "List of dashboards to delete from the dashboard list.",
                "items": {
                    "description": "A dashboard within a list.",
                    "properties": {
                        "id": {
                            "description": "ID of the dashboard.",
                            "example": "q5j-nti-fv6",
                            "type": "string",
                        },
                        "type": {
                            "description": "The type of the dashboard.",
                            "enum": [
                                "custom_timeboard",
                                "custom_screenboard",
                                "integration_screenboard",
                                "integration_timeboard",
                                "host_timeboard",
                            ],
                            "example": "host_timeboard",
                            "type": "string",
                            "x-enum-varnames": [
                                "CUSTOM_TIMEBOARD",
                                "CUSTOM_SCREENBOARD",
                                "INTEGRATION_SCREENBOARD",
                                "INTEGRATION_TIMEBOARD",
                                "HOST_TIMEBOARD",
                            ],
                        },
                    },
                    "required": ["type", "id"],
                    "type": "object",
                },
                "type": "array",
            }
        },
        "type": "object",
    },
    "ADDDASHBOARDSTOLIST_REQUEST_BODY_SCHEMA": {
        "description": "Request containing a list of dashboards to add.",
        "properties": {
            "dashboards": {
                "description": "List of dashboards to add the dashboard list.",
                "items": {
                    "description": "A dashboard within a list.",
                    "properties": {
                        "id": {
                            "description": "ID of the dashboard.",
                            "example": "q5j-nti-fv6",
                            "type": "string",
                        },
                        "type": {
                            "description": "The type of the dashboard.",
                            "enum": [
                                "custom_timeboard",
                                "custom_screenboard",
                                "integration_screenboard",
                                "integration_timeboard",
                                "host_timeboard",
                            ],
                            "example": "host_timeboard",
                            "type": "string",
                            "x-enum-varnames": [
                                "CUSTOM_TIMEBOARD",
                                "CUSTOM_SCREENBOARD",
                                "INTEGRATION_SCREENBOARD",
                                "INTEGRATION_TIMEBOARD",
                                "HOST_TIMEBOARD",
                            ],
                        },
                    },
                    "required": ["type", "id"],
                    "type": "object",
                },
                "type": "array",
            }
        },
        "type": "object",
    },
    "UPDATEDASHBOARDLISTITEMS_REQUEST_BODY_SCHEMA": {
        "description": "Request containing the list of dashboards to update to.",
        "properties": {
            "dashboards": {
                "description": "List of dashboards to update the dashboard list to.",
                "items": {
                    "description": "A dashboard within a list.",
                    "properties": {
                        "id": {
                            "description": "ID of the dashboard.",
                            "example": "q5j-nti-fv6",
                            "type": "string",
                        },
                        "type": {
                            "description": "The type of the dashboard.",
                            "enum": [
                                "custom_timeboard",
                                "custom_screenboard",
                                "integration_screenboard",
                                "integration_timeboard",
                                "host_timeboard",
                            ],
                            "example": "host_timeboard",
                            "type": "string",
                            "x-enum-varnames": [
                                "CUSTOM_TIMEBOARD",
                                "CUSTOM_SCREENBOARD",
                                "INTEGRATION_SCREENBOARD",
                                "INTEGRATION_TIMEBOARD",
                                "HOST_TIMEBOARD",
                            ],
                        },
                    },
                    "required": ["type", "id"],
                    "type": "object",
                },
                "type": "array",
            }
        },
        "type": "object",
    },
    "CREATEDATASET_REQUEST_BODY_SCHEMA": {
        "description": "Create request for a dataset.",
        "properties": {
            "data": {
                "description": "**Datasets Object Constraints**\n"
                "- **Tag limit per dataset**:\n"
                "  - Each restricted dataset supports a "
                "maximum of 10 key:value pairs per product.\n"
                "\n"
                "- **Tag key rules per telemetry type**:\n"
                "  - Only one tag key or attribute may be used "
                "to define access within a single telemetry "
                "type.\n"
                "  - The same or different tag key may be used "
                "across different telemetry types.\n"
                "\n"
                "- **Tag value uniqueness**:\n"
                "  - Tag values must be unique within a single "
                "dataset.\n"
                "  - A tag value used in one dataset cannot be "
                "reused in another dataset of the same "
                "telemetry type.",
                "properties": {
                    "attributes": {
                        "description": "Dataset metadata and configurations.",
                        "properties": {
                            "name": {
                                "description": "Name of the dataset.",
                                "example": "Security Audit Dataset",
                                "type": "string",
                            },
                            "principals": {
                                "description": "List "
                                "of "
                                "access "
                                "principals, "
                                "formatted "
                                "as "
                                "`principal_type:id`. "
                                "Principal "
                                "can "
                                "be "
                                "'team' "
                                "or "
                                "'role'.",
                                "example": ["role:94172442-be03-11e9-a77a-3b7612558ac1"],
                                "items": {
                                    "example": "role:94172442-be03-11e9-a77a-3b7612558ac1",
                                    "type": "string",
                                },
                                "type": "array",
                            },
                            "product_filters": {
                                "description": "List of product-specific filters.",
                                "items": {
                                    "description": "Product-specific filters for the dataset.",
                                    "properties": {
                                        "filters": {
                                            "description": "Defines "
                                            "the "
                                            "list "
                                            "of "
                                            "tag-based "
                                            "filters "
                                            "used "
                                            "to "
                                            "restrict "
                                            "access "
                                            "to "
                                            "telemetry "
                                            "data "
                                            "for "
                                            "a "
                                            "specific "
                                            "product.\n"
                                            "These "
                                            "filters "
                                            "act "
                                            "as "
                                            "access "
                                            "control "
                                            "rules. "
                                            "Each "
                                            "filter "
                                            "must "
                                            "follow "
                                            "the "
                                            "tag "
                                            "query "
                                            "syntax "
                                            "used "
                                            "by\n"
                                            "Datadog "
                                            "(such "
                                            "as "
                                            "`@tag.key:value`), "
                                            "and "
                                            "only "
                                            "one "
                                            "tag "
                                            "or "
                                            "attribute "
                                            "may "
                                            "be "
                                            "used "
                                            "to "
                                            "define "
                                            "the "
                                            "access "
                                            "strategy\n"
                                            "per "
                                            "telemetry "
                                            "type.",
                                            "example": ["@application.id:ABCD"],
                                            "items": {
                                                "example": "@application.id:ABCD",
                                                "type": "string",
                                            },
                                            "type": "array",
                                        },
                                        "product": {
                                            "description": "Name "
                                            "of "
                                            "the "
                                            "product "
                                            "the "
                                            "dataset "
                                            "is "
                                            "for. "
                                            "Possible "
                                            "values "
                                            "are "
                                            "'apm', "
                                            "'rum',\n"
                                            "'metrics', "
                                            "'logs', "
                                            "'error_tracking', "
                                            "and "
                                            "'cloud_cost'.",
                                            "example": "logs",
                                            "type": "string",
                                        },
                                    },
                                    "required": ["product", "filters"],
                                    "type": "object",
                                },
                                "type": "array",
                            },
                        },
                        "required": ["name", "product_filters", "principals"],
                        "type": "object",
                    },
                    "type": {
                        "default": "dataset",
                        "description": "Resource type, always set to `dataset`.",
                        "enum": ["dataset"],
                        "example": "dataset",
                        "type": "string",
                        "x-enum-varnames": ["DATASET"],
                    },
                },
                "required": ["type", "attributes"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "EDITDATASET_REQUEST_BODY_SCHEMA": {
        "description": "Edit request for a dataset.",
        "properties": {
            "data": {
                "description": "**Datasets Object Constraints**\n"
                "- **Tag limit per dataset**:\n"
                "  - Each restricted dataset supports a "
                "maximum of 10 key:value pairs per product.\n"
                "\n"
                "- **Tag key rules per telemetry type**:\n"
                "  - Only one tag key or attribute may be used "
                "to define access within a single telemetry "
                "type.\n"
                "  - The same or different tag key may be used "
                "across different telemetry types.\n"
                "\n"
                "- **Tag value uniqueness**:\n"
                "  - Tag values must be unique within a single "
                "dataset.\n"
                "  - A tag value used in one dataset cannot be "
                "reused in another dataset of the same "
                "telemetry type.",
                "properties": {
                    "attributes": {
                        "description": "Dataset metadata and configurations.",
                        "properties": {
                            "name": {
                                "description": "Name of the dataset.",
                                "example": "Security Audit Dataset",
                                "type": "string",
                            },
                            "principals": {
                                "description": "List "
                                "of "
                                "access "
                                "principals, "
                                "formatted "
                                "as "
                                "`principal_type:id`. "
                                "Principal "
                                "can "
                                "be "
                                "'team' "
                                "or "
                                "'role'.",
                                "example": ["role:94172442-be03-11e9-a77a-3b7612558ac1"],
                                "items": {
                                    "example": "role:94172442-be03-11e9-a77a-3b7612558ac1",
                                    "type": "string",
                                },
                                "type": "array",
                            },
                            "product_filters": {
                                "description": "List of product-specific filters.",
                                "items": {
                                    "description": "Product-specific filters for the dataset.",
                                    "properties": {
                                        "filters": {
                                            "description": "Defines "
                                            "the "
                                            "list "
                                            "of "
                                            "tag-based "
                                            "filters "
                                            "used "
                                            "to "
                                            "restrict "
                                            "access "
                                            "to "
                                            "telemetry "
                                            "data "
                                            "for "
                                            "a "
                                            "specific "
                                            "product.\n"
                                            "These "
                                            "filters "
                                            "act "
                                            "as "
                                            "access "
                                            "control "
                                            "rules. "
                                            "Each "
                                            "filter "
                                            "must "
                                            "follow "
                                            "the "
                                            "tag "
                                            "query "
                                            "syntax "
                                            "used "
                                            "by\n"
                                            "Datadog "
                                            "(such "
                                            "as "
                                            "`@tag.key:value`), "
                                            "and "
                                            "only "
                                            "one "
                                            "tag "
                                            "or "
                                            "attribute "
                                            "may "
                                            "be "
                                            "used "
                                            "to "
                                            "define "
                                            "the "
                                            "access "
                                            "strategy\n"
                                            "per "
                                            "telemetry "
                                            "type.",
                                            "example": ["@application.id:ABCD"],
                                            "items": {
                                                "example": "@application.id:ABCD",
                                                "type": "string",
                                            },
                                            "type": "array",
                                        },
                                        "product": {
                                            "description": "Name "
                                            "of "
                                            "the "
                                            "product "
                                            "the "
                                            "dataset "
                                            "is "
                                            "for. "
                                            "Possible "
                                            "values "
                                            "are "
                                            "'apm', "
                                            "'rum',\n"
                                            "'metrics', "
                                            "'logs', "
                                            "'error_tracking', "
                                            "and "
                                            "'cloud_cost'.",
                                            "example": "logs",
                                            "type": "string",
                                        },
                                    },
                                    "required": ["product", "filters"],
                                    "type": "object",
                                },
                                "type": "array",
                            },
                        },
                        "required": ["name", "product_filters", "principals"],
                        "type": "object",
                    },
                    "type": {
                        "default": "dataset",
                        "description": "Resource type, always set to `dataset`.",
                        "enum": ["dataset"],
                        "example": "dataset",
                        "type": "string",
                        "x-enum-varnames": ["DATASET"],
                    },
                },
                "required": ["type", "attributes"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "SCHEDULEDOWNTIME_REQUEST_BODY_SCHEMA": {
        "description": "Request for creating a downtime.",
        "properties": {
            "data": {
                "description": "Object to create a downtime.",
                "properties": {
                    "attributes": {
                        "description": "Downtime details.",
                        "properties": {
                            "display_timezone": {
                                "default": "UTC",
                                "description": "The "
                                "timezone "
                                "in "
                                "which "
                                "to "
                                "display "
                                "the "
                                "downtime's "
                                "start "
                                "and "
                                "end "
                                "times "
                                "in "
                                "Datadog "
                                "applications. "
                                "This "
                                "is "
                                "not "
                                "used\n"
                                "as "
                                "an "
                                "offset "
                                "for "
                                "scheduling.",
                                "example": "America/New_York",
                                "nullable": True,
                                "type": "string",
                            },
                            "message": {
                                "description": "A "
                                "message "
                                "to "
                                "include "
                                "with "
                                "notifications "
                                "for "
                                "this "
                                "downtime. "
                                "Email "
                                "notifications "
                                "can "
                                "be "
                                "sent "
                                "to "
                                "specific "
                                "users\n"
                                "by "
                                "using "
                                "the "
                                "same "
                                "`@username` "
                                "notation "
                                "as "
                                "events.",
                                "example": "Message about the downtime",
                                "nullable": True,
                                "type": "string",
                            },
                            "monitor_identifier": {
                                "description": "Monitor identifier for the downtime.",
                                "oneOf": [
                                    {
                                        "additionalProperties": {},
                                        "description": "Object of the monitor identifier.",
                                        "properties": {
                                            "monitor_id": {
                                                "description": "ID "
                                                "of "
                                                "the "
                                                "monitor "
                                                "to "
                                                "prevent "
                                                "notifications.",
                                                "example": 123,
                                                "format": "int64",
                                                "type": "integer",
                                            }
                                        },
                                        "required": ["monitor_id"],
                                        "type": "object",
                                    },
                                    {
                                        "additionalProperties": {},
                                        "description": "Object of the monitor tags.",
                                        "properties": {
                                            "monitor_tags": {
                                                "description": "A "
                                                "list "
                                                "of "
                                                "monitor "
                                                "tags. "
                                                "For "
                                                "example, "
                                                "tags "
                                                "that "
                                                "are "
                                                "applied "
                                                "directly "
                                                "to "
                                                "monitors,\n"
                                                "not "
                                                "tags "
                                                "that "
                                                "are "
                                                "used "
                                                "in "
                                                "monitor "
                                                "queries "
                                                "(which "
                                                "are "
                                                "filtered "
                                                "by "
                                                "the "
                                                "scope "
                                                "parameter), "
                                                "to "
                                                "which "
                                                "the "
                                                "downtime "
                                                "applies.\n"
                                                "The "
                                                "resulting "
                                                "downtime "
                                                "applies "
                                                "to "
                                                "monitors "
                                                "that "
                                                "match "
                                                "**all** "
                                                "provided "
                                                "monitor "
                                                "tags. "
                                                "Setting "
                                                "`monitor_tags`\n"
                                                "to "
                                                "`[*]` "
                                                "configures "
                                                "the "
                                                "downtime "
                                                "to "
                                                "mute "
                                                "all "
                                                "monitors "
                                                "for "
                                                "the "
                                                "given "
                                                "scope.",
                                                "example": ["service:postgres", "team:frontend"],
                                                "items": {
                                                    "description": "A list of monitor tags.",
                                                    "example": "service:postgres",
                                                    "type": "string",
                                                },
                                                "minItems": 1,
                                                "type": "array",
                                            }
                                        },
                                        "required": ["monitor_tags"],
                                        "type": "object",
                                    },
                                ],
                            },
                            "mute_first_recovery_notification": {
                                "description": "If "
                                "the "
                                "first "
                                "recovery "
                                "notification "
                                "during "
                                "a "
                                "downtime "
                                "should "
                                "be "
                                "muted.",
                                "example": False,
                                "type": "boolean",
                            },
                            "notify_end_states": {
                                "description": "States "
                                "that "
                                "will "
                                "trigger "
                                "a "
                                "monitor "
                                "notification "
                                "when "
                                "the "
                                "`notify_end_types` "
                                "action "
                                "occurs.",
                                "example": ["alert", "warn"],
                                "items": {
                                    "description": "State "
                                    "that "
                                    "will "
                                    "trigger "
                                    "a "
                                    "monitor "
                                    "notification "
                                    "when "
                                    "the "
                                    "`notify_end_types` "
                                    "action "
                                    "occurs.",
                                    "enum": ["alert", "no data", "warn"],
                                    "example": "alert",
                                    "type": "string",
                                    "x-enum-varnames": ["ALERT", "NO_DATA", "WARN"],
                                },
                                "type": "array",
                            },
                            "notify_end_types": {
                                "description": "Actions "
                                "that "
                                "will "
                                "trigger "
                                "a "
                                "monitor "
                                "notification "
                                "if "
                                "the "
                                "downtime "
                                "is "
                                "in "
                                "the "
                                "`notify_end_types` "
                                "state.",
                                "example": ["canceled", "expired"],
                                "items": {
                                    "description": "Action "
                                    "that "
                                    "will "
                                    "trigger "
                                    "a "
                                    "monitor "
                                    "notification "
                                    "if "
                                    "the "
                                    "downtime "
                                    "is "
                                    "in "
                                    "the "
                                    "`notify_end_types` "
                                    "state.",
                                    "enum": ["canceled", "expired"],
                                    "example": "canceled",
                                    "type": "string",
                                    "x-enum-varnames": ["CANCELED", "EXPIRED"],
                                },
                                "type": "array",
                            },
                            "schedule": {
                                "description": "Schedule for the downtime.",
                                "oneOf": [
                                    {
                                        "description": "A recurring downtime schedule definition.",
                                        "properties": {
                                            "recurrences": {
                                                "description": "A list of downtime recurrences.",
                                                "items": {
                                                    "additionalProperties": {},
                                                    "description": "An "
                                                    "object "
                                                    "defining "
                                                    "the "
                                                    "recurrence "
                                                    "of "
                                                    "the "
                                                    "downtime.",
                                                    "properties": {
                                                        "duration": {
                                                            "description": "The "
                                                            "length "
                                                            "of "
                                                            "the "
                                                            "downtime. "
                                                            "Must "
                                                            "begin "
                                                            "with "
                                                            "an "
                                                            "integer "
                                                            "and "
                                                            "end "
                                                            "with "
                                                            "one "
                                                            "of "
                                                            "'m', "
                                                            "'h', "
                                                            "d', "
                                                            "or "
                                                            "'w'.",
                                                            "example": "123d",
                                                            "type": "string",
                                                        },
                                                        "rrule": {
                                                            "description": "The "
                                                            "`RRULE` "
                                                            "standard "
                                                            "for "
                                                            "defining "
                                                            "recurring "
                                                            "events.\n"
                                                            "For "
                                                            "example, "
                                                            "to "
                                                            "have "
                                                            "a "
                                                            "recurring "
                                                            "event "
                                                            "on "
                                                            "the "
                                                            "first "
                                                            "day "
                                                            "of "
                                                            "each "
                                                            "month, "
                                                            "set "
                                                            "the "
                                                            "type "
                                                            "to "
                                                            "`rrule` "
                                                            "and "
                                                            "set "
                                                            "the "
                                                            "`FREQ` "
                                                            "to "
                                                            "`MONTHLY` "
                                                            "and "
                                                            "`BYMONTHDAY` "
                                                            "to "
                                                            "`1`.\n"
                                                            "Most "
                                                            "common "
                                                            "`rrule` "
                                                            "options "
                                                            "from "
                                                            "the "
                                                            "[iCalendar "
                                                            "Spec](https://tools.ietf.org/html/rfc5545) "
                                                            "are "
                                                            "supported.\n"
                                                            "\n"
                                                            "**Note**: "
                                                            "Attributes "
                                                            "specifying "
                                                            "the "
                                                            "duration "
                                                            "in "
                                                            "`RRULE` "
                                                            "are "
                                                            "not "
                                                            "supported "
                                                            "(for "
                                                            "example, "
                                                            "`DTSTART`, "
                                                            "`DTEND`, "
                                                            "`DURATION`).\n"
                                                            "More "
                                                            "examples "
                                                            "available "
                                                            "in "
                                                            "this "
                                                            "[downtime "
                                                            "guide](https://docs.datadoghq.com/monitors/guide/suppress-alert-with-downtimes/?tab=api).",
                                                            "example": "FREQ=MONTHLY;BYSETPOS=3;BYDAY=WE;INTERVAL=1",
                                                            "type": "string",
                                                        },
                                                        "start": {
                                                            "description": "ISO-8601 "
                                                            "Datetime "
                                                            "to "
                                                            "start "
                                                            "the "
                                                            "downtime. "
                                                            "Must "
                                                            "not "
                                                            "include "
                                                            "a "
                                                            "UTC "
                                                            "offset. "
                                                            "If "
                                                            "not "
                                                            "provided, "
                                                            "the\n"
                                                            "downtime "
                                                            "starts "
                                                            "the "
                                                            "moment "
                                                            "it "
                                                            "is "
                                                            "created.",
                                                            "example": "2020-01-02T03:04",
                                                            "nullable": True,
                                                            "type": "string",
                                                        },
                                                    },
                                                    "required": ["duration", "rrule"],
                                                    "type": "object",
                                                },
                                                "type": "array",
                                            },
                                            "timezone": {
                                                "default": "UTC",
                                                "description": "The "
                                                "timezone "
                                                "in "
                                                "which "
                                                "to "
                                                "schedule "
                                                "the "
                                                "downtime.",
                                                "example": "America/New_York",
                                                "type": "string",
                                            },
                                        },
                                        "required": ["recurrences"],
                                        "type": "object",
                                    },
                                    {
                                        "additionalProperties": False,
                                        "description": "A one-time downtime definition.",
                                        "properties": {
                                            "end": {
                                                "description": "ISO-8601 "
                                                "Datetime "
                                                "to "
                                                "end "
                                                "the "
                                                "downtime. "
                                                "Must "
                                                "include "
                                                "a "
                                                "UTC "
                                                "offset "
                                                "of "
                                                "zero. "
                                                "If "
                                                "not "
                                                "provided, "
                                                "the\n"
                                                "downtime "
                                                "continues "
                                                "forever.",
                                                "example": "2020-01-02T03:04:00+00:00",
                                                "format": "date-time",
                                                "nullable": True,
                                                "type": "string",
                                            },
                                            "start": {
                                                "description": "ISO-8601 "
                                                "Datetime "
                                                "to "
                                                "start "
                                                "the "
                                                "downtime. "
                                                "Must "
                                                "include "
                                                "a "
                                                "UTC "
                                                "offset "
                                                "of "
                                                "zero. "
                                                "If "
                                                "not "
                                                "provided, "
                                                "the\n"
                                                "downtime "
                                                "starts "
                                                "the "
                                                "moment "
                                                "it "
                                                "is "
                                                "created.",
                                                "example": "2020-01-02T03:04:00+00:00",
                                                "format": "date-time",
                                                "nullable": True,
                                                "type": "string",
                                            },
                                        },
                                        "type": "object",
                                    },
                                ],
                            },
                            "scope": {
                                "description": "The "
                                "scope "
                                "to "
                                "which "
                                "the "
                                "downtime "
                                "applies. "
                                "Must "
                                "follow "
                                "the "
                                "[common "
                                "search "
                                "syntax](https://docs.datadoghq.com/logs/explorer/search_syntax/).",
                                "example": "env:(staging OR prod) AND datacenter:us-east-1",
                                "type": "string",
                            },
                        },
                        "required": ["scope", "monitor_identifier"],
                        "type": "object",
                    },
                    "type": {
                        "default": "downtime",
                        "description": "Downtime resource type.",
                        "enum": ["downtime"],
                        "example": "downtime",
                        "type": "string",
                        "x-enum-varnames": ["DOWNTIME"],
                    },
                },
                "required": ["type", "attributes"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "UPDATEDOWNTIME_REQUEST_BODY_SCHEMA": {
        "description": "Request for editing a downtime.",
        "properties": {
            "data": {
                "description": "Object to update a downtime.",
                "properties": {
                    "attributes": {
                        "description": "Attributes of the downtime to update.",
                        "properties": {
                            "display_timezone": {
                                "default": "UTC",
                                "description": "The "
                                "timezone "
                                "in "
                                "which "
                                "to "
                                "display "
                                "the "
                                "downtime's "
                                "start "
                                "and "
                                "end "
                                "times "
                                "in "
                                "Datadog "
                                "applications. "
                                "This "
                                "is "
                                "not "
                                "used\n"
                                "as "
                                "an "
                                "offset "
                                "for "
                                "scheduling.",
                                "example": "America/New_York",
                                "nullable": True,
                                "type": "string",
                            },
                            "message": {
                                "description": "A "
                                "message "
                                "to "
                                "include "
                                "with "
                                "notifications "
                                "for "
                                "this "
                                "downtime. "
                                "Email "
                                "notifications "
                                "can "
                                "be "
                                "sent "
                                "to "
                                "specific "
                                "users\n"
                                "by "
                                "using "
                                "the "
                                "same "
                                "`@username` "
                                "notation "
                                "as "
                                "events.",
                                "example": "Message about the downtime",
                                "nullable": True,
                                "type": "string",
                            },
                            "monitor_identifier": {
                                "description": "Monitor identifier for the downtime.",
                                "oneOf": [
                                    {
                                        "additionalProperties": {},
                                        "description": "Object of the monitor identifier.",
                                        "properties": {
                                            "monitor_id": {
                                                "description": "ID "
                                                "of "
                                                "the "
                                                "monitor "
                                                "to "
                                                "prevent "
                                                "notifications.",
                                                "example": 123,
                                                "format": "int64",
                                                "type": "integer",
                                            }
                                        },
                                        "required": ["monitor_id"],
                                        "type": "object",
                                    },
                                    {
                                        "additionalProperties": {},
                                        "description": "Object of the monitor tags.",
                                        "properties": {
                                            "monitor_tags": {
                                                "description": "A "
                                                "list "
                                                "of "
                                                "monitor "
                                                "tags. "
                                                "For "
                                                "example, "
                                                "tags "
                                                "that "
                                                "are "
                                                "applied "
                                                "directly "
                                                "to "
                                                "monitors,\n"
                                                "not "
                                                "tags "
                                                "that "
                                                "are "
                                                "used "
                                                "in "
                                                "monitor "
                                                "queries "
                                                "(which "
                                                "are "
                                                "filtered "
                                                "by "
                                                "the "
                                                "scope "
                                                "parameter), "
                                                "to "
                                                "which "
                                                "the "
                                                "downtime "
                                                "applies.\n"
                                                "The "
                                                "resulting "
                                                "downtime "
                                                "applies "
                                                "to "
                                                "monitors "
                                                "that "
                                                "match "
                                                "**all** "
                                                "provided "
                                                "monitor "
                                                "tags. "
                                                "Setting "
                                                "`monitor_tags`\n"
                                                "to "
                                                "`[*]` "
                                                "configures "
                                                "the "
                                                "downtime "
                                                "to "
                                                "mute "
                                                "all "
                                                "monitors "
                                                "for "
                                                "the "
                                                "given "
                                                "scope.",
                                                "example": ["service:postgres", "team:frontend"],
                                                "items": {
                                                    "description": "A list of monitor tags.",
                                                    "example": "service:postgres",
                                                    "type": "string",
                                                },
                                                "minItems": 1,
                                                "type": "array",
                                            }
                                        },
                                        "required": ["monitor_tags"],
                                        "type": "object",
                                    },
                                ],
                            },
                            "mute_first_recovery_notification": {
                                "description": "If "
                                "the "
                                "first "
                                "recovery "
                                "notification "
                                "during "
                                "a "
                                "downtime "
                                "should "
                                "be "
                                "muted.",
                                "example": False,
                                "type": "boolean",
                            },
                            "notify_end_states": {
                                "description": "States "
                                "that "
                                "will "
                                "trigger "
                                "a "
                                "monitor "
                                "notification "
                                "when "
                                "the "
                                "`notify_end_types` "
                                "action "
                                "occurs.",
                                "example": ["alert", "warn"],
                                "items": {
                                    "description": "State "
                                    "that "
                                    "will "
                                    "trigger "
                                    "a "
                                    "monitor "
                                    "notification "
                                    "when "
                                    "the "
                                    "`notify_end_types` "
                                    "action "
                                    "occurs.",
                                    "enum": ["alert", "no data", "warn"],
                                    "example": "alert",
                                    "type": "string",
                                    "x-enum-varnames": ["ALERT", "NO_DATA", "WARN"],
                                },
                                "type": "array",
                            },
                            "notify_end_types": {
                                "description": "Actions "
                                "that "
                                "will "
                                "trigger "
                                "a "
                                "monitor "
                                "notification "
                                "if "
                                "the "
                                "downtime "
                                "is "
                                "in "
                                "the "
                                "`notify_end_types` "
                                "state.",
                                "example": ["canceled", "expired"],
                                "items": {
                                    "description": "Action "
                                    "that "
                                    "will "
                                    "trigger "
                                    "a "
                                    "monitor "
                                    "notification "
                                    "if "
                                    "the "
                                    "downtime "
                                    "is "
                                    "in "
                                    "the "
                                    "`notify_end_types` "
                                    "state.",
                                    "enum": ["canceled", "expired"],
                                    "example": "canceled",
                                    "type": "string",
                                    "x-enum-varnames": ["CANCELED", "EXPIRED"],
                                },
                                "type": "array",
                            },
                            "schedule": {
                                "description": "Schedule for the downtime.",
                                "oneOf": [
                                    {
                                        "additionalProperties": False,
                                        "description": "A recurring downtime schedule definition.",
                                        "properties": {
                                            "recurrences": {
                                                "description": "A list of downtime recurrences.",
                                                "items": {
                                                    "additionalProperties": {},
                                                    "description": "An "
                                                    "object "
                                                    "defining "
                                                    "the "
                                                    "recurrence "
                                                    "of "
                                                    "the "
                                                    "downtime.",
                                                    "properties": {
                                                        "duration": {
                                                            "description": "The "
                                                            "length "
                                                            "of "
                                                            "the "
                                                            "downtime. "
                                                            "Must "
                                                            "begin "
                                                            "with "
                                                            "an "
                                                            "integer "
                                                            "and "
                                                            "end "
                                                            "with "
                                                            "one "
                                                            "of "
                                                            "'m', "
                                                            "'h', "
                                                            "d', "
                                                            "or "
                                                            "'w'.",
                                                            "example": "123d",
                                                            "type": "string",
                                                        },
                                                        "rrule": {
                                                            "description": "The "
                                                            "`RRULE` "
                                                            "standard "
                                                            "for "
                                                            "defining "
                                                            "recurring "
                                                            "events.\n"
                                                            "For "
                                                            "example, "
                                                            "to "
                                                            "have "
                                                            "a "
                                                            "recurring "
                                                            "event "
                                                            "on "
                                                            "the "
                                                            "first "
                                                            "day "
                                                            "of "
                                                            "each "
                                                            "month, "
                                                            "set "
                                                            "the "
                                                            "type "
                                                            "to "
                                                            "`rrule` "
                                                            "and "
                                                            "set "
                                                            "the "
                                                            "`FREQ` "
                                                            "to "
                                                            "`MONTHLY` "
                                                            "and "
                                                            "`BYMONTHDAY` "
                                                            "to "
                                                            "`1`.\n"
                                                            "Most "
                                                            "common "
                                                            "`rrule` "
                                                            "options "
                                                            "from "
                                                            "the "
                                                            "[iCalendar "
                                                            "Spec](https://tools.ietf.org/html/rfc5545) "
                                                            "are "
                                                            "supported.\n"
                                                            "\n"
                                                            "**Note**: "
                                                            "Attributes "
                                                            "specifying "
                                                            "the "
                                                            "duration "
                                                            "in "
                                                            "`RRULE` "
                                                            "are "
                                                            "not "
                                                            "supported "
                                                            "(for "
                                                            "example, "
                                                            "`DTSTART`, "
                                                            "`DTEND`, "
                                                            "`DURATION`).\n"
                                                            "More "
                                                            "examples "
                                                            "available "
                                                            "in "
                                                            "this "
                                                            "[downtime "
                                                            "guide](https://docs.datadoghq.com/monitors/guide/suppress-alert-with-downtimes/?tab=api).",
                                                            "example": "FREQ=MONTHLY;BYSETPOS=3;BYDAY=WE;INTERVAL=1",
                                                            "type": "string",
                                                        },
                                                        "start": {
                                                            "description": "ISO-8601 "
                                                            "Datetime "
                                                            "to "
                                                            "start "
                                                            "the "
                                                            "downtime. "
                                                            "Must "
                                                            "not "
                                                            "include "
                                                            "a "
                                                            "UTC "
                                                            "offset. "
                                                            "If "
                                                            "not "
                                                            "provided, "
                                                            "the\n"
                                                            "downtime "
                                                            "starts "
                                                            "the "
                                                            "moment "
                                                            "it "
                                                            "is "
                                                            "created.",
                                                            "example": "2020-01-02T03:04",
                                                            "nullable": True,
                                                            "type": "string",
                                                        },
                                                    },
                                                    "required": ["duration", "rrule"],
                                                    "type": "object",
                                                },
                                                "type": "array",
                                            },
                                            "timezone": {
                                                "default": "UTC",
                                                "description": "The "
                                                "timezone "
                                                "in "
                                                "which "
                                                "to "
                                                "schedule "
                                                "the "
                                                "downtime.",
                                                "example": "America/New_York",
                                                "type": "string",
                                            },
                                        },
                                        "type": "object",
                                    },
                                    {
                                        "additionalProperties": False,
                                        "description": "A one-time downtime definition.",
                                        "properties": {
                                            "end": {
                                                "description": "ISO-8601 "
                                                "Datetime "
                                                "to "
                                                "end "
                                                "the "
                                                "downtime. "
                                                "Must "
                                                "include "
                                                "a "
                                                "UTC "
                                                "offset "
                                                "of "
                                                "zero. "
                                                "If "
                                                "not "
                                                "provided, "
                                                "the\n"
                                                "downtime "
                                                "continues "
                                                "forever.",
                                                "example": "2020-01-02T03:04:00+00:00",
                                                "format": "date-time",
                                                "nullable": True,
                                                "type": "string",
                                            },
                                            "start": {
                                                "description": "ISO-8601 "
                                                "Datetime "
                                                "to "
                                                "start "
                                                "the "
                                                "downtime. "
                                                "Must "
                                                "include "
                                                "a "
                                                "UTC "
                                                "offset "
                                                "of "
                                                "zero. "
                                                "If "
                                                "not "
                                                "provided, "
                                                "the\n"
                                                "downtime "
                                                "starts "
                                                "the "
                                                "moment "
                                                "it "
                                                "is "
                                                "created.",
                                                "example": "2020-01-02T03:04:00+00:00",
                                                "format": "date-time",
                                                "nullable": True,
                                                "type": "string",
                                            },
                                        },
                                        "type": "object",
                                    },
                                ],
                            },
                            "scope": {
                                "description": "The "
                                "scope "
                                "to "
                                "which "
                                "the "
                                "downtime "
                                "applies. "
                                "Must "
                                "follow "
                                "the "
                                "[common "
                                "search "
                                "syntax](https://docs.datadoghq.com/logs/explorer/search_syntax/).",
                                "example": "env:(staging OR prod) AND datacenter:us-east-1",
                                "type": "string",
                            },
                        },
                        "type": "object",
                    },
                    "id": {
                        "description": "ID of this downtime.",
                        "example": "00000000-0000-1234-0000-000000000000",
                        "type": "string",
                    },
                    "type": {
                        "default": "downtime",
                        "description": "Downtime resource type.",
                        "enum": ["downtime"],
                        "example": "downtime",
                        "type": "string",
                        "x-enum-varnames": ["DOWNTIME"],
                    },
                },
                "required": ["id", "type", "attributes"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "CREATEINCIDENT_REQUEST_BODY_SCHEMA": {
        "description": "Create request for an incident.",
        "properties": {
            "data": {
                "description": "Incident data for a create request.",
                "properties": {
                    "attributes": {
                        "description": "The incident's attributes for a create request.",
                        "properties": {
                            "customer_impact_scope": {
                                "description": "Required "
                                "if "
                                '`customer_impacted:"true"`. '
                                "A "
                                "summary "
                                "of "
                                "the "
                                "impact "
                                "customers "
                                "experienced "
                                "during "
                                "the "
                                "incident.",
                                "example": "Example customer impact scope",
                                "type": "string",
                            },
                            "customer_impacted": {
                                "description": "A "
                                "flag "
                                "indicating "
                                "whether "
                                "the "
                                "incident "
                                "caused "
                                "customer "
                                "impact.",
                                "example": False,
                                "type": "boolean",
                            },
                            "fields": {
                                "additionalProperties": {
                                    "description": "Dynamic "
                                    "fields "
                                    "for "
                                    "which "
                                    "selections "
                                    "can "
                                    "be "
                                    "made, "
                                    "with "
                                    "field "
                                    "names "
                                    "as "
                                    "keys.",
                                    "oneOf": [
                                        {
                                            "description": "A field with a single value selected.",
                                            "properties": {
                                                "type": {
                                                    "default": "dropdown",
                                                    "description": "Type "
                                                    "of "
                                                    "the "
                                                    "single "
                                                    "value "
                                                    "field "
                                                    "definitions.",
                                                    "enum": ["dropdown", "textbox"],
                                                    "example": "dropdown",
                                                    "type": "string",
                                                    "x-enum-varnames": ["DROPDOWN", "TEXTBOX"],
                                                },
                                                "value": {
                                                    "description": "The "
                                                    "single "
                                                    "value "
                                                    "selected "
                                                    "for "
                                                    "this "
                                                    "field.",
                                                    "example": "SEV-1",
                                                    "nullable": True,
                                                    "type": "string",
                                                },
                                            },
                                            "type": "object",
                                        },
                                        {
                                            "description": "A "
                                            "field "
                                            "with "
                                            "potentially "
                                            "multiple "
                                            "values "
                                            "selected.",
                                            "properties": {
                                                "type": {
                                                    "default": "multiselect",
                                                    "description": "Type "
                                                    "of "
                                                    "the "
                                                    "multiple "
                                                    "value "
                                                    "field "
                                                    "definitions.",
                                                    "enum": [
                                                        "multiselect",
                                                        "textarray",
                                                        "metrictag",
                                                        "autocomplete",
                                                    ],
                                                    "example": "multiselect",
                                                    "type": "string",
                                                    "x-enum-varnames": [
                                                        "MULTISELECT",
                                                        "TEXTARRAY",
                                                        "METRICTAG",
                                                        "AUTOCOMPLETE",
                                                    ],
                                                },
                                                "value": {
                                                    "description": "The "
                                                    "multiple "
                                                    "values "
                                                    "selected "
                                                    "for "
                                                    "this "
                                                    "field.",
                                                    "example": ["1.0", "1.1"],
                                                    "items": {
                                                        "description": "A "
                                                        "value "
                                                        "which "
                                                        "has "
                                                        "been "
                                                        "selected "
                                                        "for "
                                                        "the "
                                                        "parent "
                                                        "field.",
                                                        "example": "1.1",
                                                        "type": "string",
                                                    },
                                                    "nullable": True,
                                                    "type": "array",
                                                },
                                            },
                                            "type": "object",
                                        },
                                    ],
                                },
                                "description": "A "
                                "condensed "
                                "view "
                                "of "
                                "the "
                                "user-defined "
                                "fields "
                                "for "
                                "which "
                                "to "
                                "create "
                                "initial "
                                "selections.",
                                "example": {"severity": {"type": "dropdown", "value": "SEV-5"}},
                                "type": "object",
                            },
                            "incident_type_uuid": {
                                "description": "A "
                                "unique "
                                "identifier "
                                "that "
                                "represents "
                                "an "
                                "incident "
                                "type. "
                                "The "
                                "default "
                                "incident "
                                "type "
                                "will "
                                "be "
                                "used "
                                "if "
                                "this "
                                "property "
                                "is "
                                "not "
                                "provided.",
                                "example": "00000000-0000-0000-0000-000000000000",
                                "type": "string",
                            },
                            "initial_cells": {
                                "description": "An "
                                "array "
                                "of "
                                "initial "
                                "timeline "
                                "cells "
                                "to "
                                "be "
                                "placed "
                                "at "
                                "the "
                                "beginning "
                                "of "
                                "the "
                                "incident "
                                "timeline.",
                                "items": {
                                    "description": "The "
                                    "timeline "
                                    "cell's "
                                    "attributes "
                                    "for "
                                    "a "
                                    "create "
                                    "request.",
                                    "oneOf": [
                                        {
                                            "description": "Timeline "
                                            "cell "
                                            "data "
                                            "for "
                                            "Markdown "
                                            "timeline "
                                            "cells "
                                            "for "
                                            "a "
                                            "create "
                                            "request.",
                                            "properties": {
                                                "cell_type": {
                                                    "default": "markdown",
                                                    "description": "Type "
                                                    "of "
                                                    "the "
                                                    "Markdown "
                                                    "timeline "
                                                    "cell.",
                                                    "enum": ["markdown"],
                                                    "example": "markdown",
                                                    "type": "string",
                                                    "x-enum-varnames": ["MARKDOWN"],
                                                },
                                                "content": {
                                                    "description": "The "
                                                    "Markdown "
                                                    "timeline "
                                                    "cell "
                                                    "contents.",
                                                    "properties": {
                                                        "content": {
                                                            "description": "The "
                                                            "Markdown "
                                                            "content "
                                                            "of "
                                                            "the "
                                                            "cell.",
                                                            "example": "An "
                                                            "example "
                                                            "timeline "
                                                            "cell "
                                                            "message.",
                                                            "nullable": False,
                                                            "type": "string",
                                                        }
                                                    },
                                                    "type": "object",
                                                },
                                                "important": {
                                                    "default": False,
                                                    "description": "A "
                                                    "flag "
                                                    "indicating "
                                                    "whether "
                                                    "the "
                                                    "timeline "
                                                    "cell "
                                                    "is "
                                                    "important "
                                                    "and "
                                                    "should "
                                                    "be "
                                                    "highlighted.",
                                                    "example": False,
                                                    "type": "boolean",
                                                },
                                            },
                                            "required": ["content", "cell_type"],
                                            "type": "object",
                                        }
                                    ],
                                },
                                "type": "array",
                            },
                            "is_test": {
                                "description": "A "
                                "flag "
                                "indicating "
                                "whether "
                                "the "
                                "incident "
                                "is "
                                "a "
                                "test "
                                "incident.",
                                "example": False,
                                "type": "boolean",
                            },
                            "notification_handles": {
                                "description": "Notification "
                                "handles "
                                "that "
                                "will "
                                "be "
                                "notified "
                                "of "
                                "the "
                                "incident "
                                "at "
                                "creation.",
                                "example": [
                                    {"display_name": "Jane Doe", "handle": "@user@email.com"},
                                    {"display_name": "Slack Channel", "handle": "@slack-channel"},
                                    {
                                        "display_name": "Incident Workflow",
                                        "handle": "@workflow-from-incident",
                                    },
                                ],
                                "items": {
                                    "description": "A "
                                    "notification "
                                    "handle "
                                    "that "
                                    "will "
                                    "be "
                                    "notified "
                                    "at "
                                    "incident "
                                    "creation.",
                                    "properties": {
                                        "display_name": {
                                            "description": "The name of the notified handle.",
                                            "example": "Jane Doe",
                                            "type": "string",
                                        },
                                        "handle": {
                                            "description": "The "
                                            "handle "
                                            "used "
                                            "for "
                                            "the "
                                            "notification. "
                                            "This "
                                            "includes "
                                            "an "
                                            "email "
                                            "address, "
                                            "Slack "
                                            "channel, "
                                            "or "
                                            "workflow.",
                                            "example": "@test.user@test.com",
                                            "type": "string",
                                        },
                                    },
                                    "type": "object",
                                },
                                "type": "array",
                            },
                            "title": {
                                "description": "The "
                                "title "
                                "of "
                                "the "
                                "incident, "
                                "which "
                                "summarizes "
                                "what "
                                "happened.",
                                "example": "A test incident title",
                                "type": "string",
                            },
                        },
                        "required": ["title", "customer_impacted"],
                        "type": "object",
                    },
                    "relationships": {
                        "description": "The "
                        "relationships "
                        "the incident "
                        "will have "
                        "with other "
                        "resources "
                        "once "
                        "created.",
                        "properties": {
                            "commander_user": {
                                "description": "Relationship to user.",
                                "nullable": True,
                                "properties": {
                                    "data": {
                                        "description": "Relationship to user object.",
                                        "nullable": True,
                                        "properties": {
                                            "id": {
                                                "description": "A "
                                                "unique "
                                                "identifier "
                                                "that "
                                                "represents "
                                                "the "
                                                "user.",
                                                "example": "00000000-0000-0000-0000-000000000000",
                                                "type": "string",
                                            },
                                            "type": {
                                                "default": "users",
                                                "description": "Users resource type.",
                                                "enum": ["users"],
                                                "example": "users",
                                                "type": "string",
                                                "x-enum-varnames": ["USERS"],
                                            },
                                        },
                                        "required": ["id", "type"],
                                        "type": "object",
                                    }
                                },
                                "required": ["data"],
                                "type": "object",
                            }
                        },
                        "required": ["commander_user"],
                        "type": "object",
                    },
                    "type": {
                        "default": "incidents",
                        "description": "Incident resource type.",
                        "enum": ["incidents"],
                        "example": "incidents",
                        "type": "string",
                        "x-enum-varnames": ["INCIDENTS"],
                    },
                },
                "required": ["type", "attributes"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "CREATEINCIDENTNOTIFICATIONRULE_REQUEST_BODY_SCHEMA": {
        "description": "Create request for a notification rule.",
        "properties": {
            "data": {
                "description": "Notification rule data for a create request.",
                "properties": {
                    "attributes": {
                        "description": "The attributes for creating a notification rule.",
                        "properties": {
                            "conditions": {
                                "description": "The "
                                "conditions "
                                "that "
                                "trigger "
                                "this "
                                "notification "
                                "rule.",
                                "example": [{"field": "severity", "values": ["SEV-1", "SEV-2"]}],
                                "items": {
                                    "description": "A "
                                    "condition "
                                    "that "
                                    "must "
                                    "be "
                                    "met "
                                    "to "
                                    "trigger "
                                    "the "
                                    "notification "
                                    "rule.",
                                    "properties": {
                                        "field": {
                                            "description": "The incident field to evaluate",
                                            "example": "severity",
                                            "type": "string",
                                        },
                                        "values": {
                                            "description": "The "
                                            "value(s) "
                                            "to "
                                            "compare "
                                            "against. "
                                            "Multiple "
                                            "values "
                                            "are "
                                            "`ORed` "
                                            "together.",
                                            "example": ["SEV-1", "SEV-2"],
                                            "items": {"type": "string"},
                                            "type": "array",
                                        },
                                    },
                                    "required": ["field", "values"],
                                    "type": "object",
                                },
                                "type": "array",
                            },
                            "enabled": {
                                "default": False,
                                "description": "Whether the notification rule is enabled.",
                                "example": True,
                                "type": "boolean",
                            },
                            "handles": {
                                "description": "The notification handles (targets) for this rule.",
                                "example": ["@team-email@company.com", "@slack-channel"],
                                "items": {
                                    "description": "A "
                                    "notification "
                                    "handle "
                                    "(email, "
                                    "Slack "
                                    "channel, "
                                    "etc.).",
                                    "type": "string",
                                },
                                "type": "array",
                            },
                            "renotify_on": {
                                "description": "List "
                                "of "
                                "incident "
                                "fields "
                                "that "
                                "trigger "
                                "re-notification "
                                "when "
                                "changed.",
                                "example": ["status", "severity"],
                                "items": {
                                    "description": "An incident field name.",
                                    "type": "string",
                                },
                                "type": "array",
                            },
                            "trigger": {
                                "description": "The trigger event for this notification rule.",
                                "example": "incident_created_trigger",
                                "type": "string",
                            },
                            "visibility": {
                                "description": "The visibility of the notification rule.",
                                "enum": ["all", "organization", "private"],
                                "example": "organization",
                                "type": "string",
                                "x-enum-varnames": ["ALL", "ORGANIZATION", "PRIVATE"],
                            },
                        },
                        "required": ["conditions", "handles", "trigger"],
                        "type": "object",
                    },
                    "relationships": {
                        "description": "The "
                        "definition "
                        "of "
                        "`NotificationRuleCreateDataRelationships` "
                        "object.",
                        "properties": {
                            "incident_type": {
                                "description": "Relationship to an incident type.",
                                "properties": {
                                    "data": {
                                        "description": "Relationship to incident type object.",
                                        "properties": {
                                            "id": {
                                                "description": "The incident type's ID.",
                                                "example": "00000000-0000-0000-0000-000000000000",
                                                "type": "string",
                                            },
                                            "type": {
                                                "default": "incident_types",
                                                "description": "Incident type resource type.",
                                                "enum": ["incident_types"],
                                                "example": "incident_types",
                                                "type": "string",
                                                "x-enum-varnames": ["INCIDENT_TYPES"],
                                            },
                                        },
                                        "required": ["id", "type"],
                                        "type": "object",
                                    }
                                },
                                "required": ["data"],
                                "type": "object",
                            },
                            "notification_template": {
                                "description": "A "
                                "relationship "
                                "reference "
                                "to "
                                "a "
                                "notification "
                                "template.",
                                "properties": {
                                    "data": {
                                        "description": "The "
                                        "notification "
                                        "template "
                                        "relationship "
                                        "data.",
                                        "properties": {
                                            "id": {
                                                "description": "The "
                                                "unique "
                                                "identifier "
                                                "of "
                                                "the "
                                                "notification "
                                                "template.",
                                                "example": "00000000-0000-0000-0000-000000000001",
                                                "format": "uuid",
                                                "type": "string",
                                            },
                                            "type": {
                                                "description": "Notification "
                                                "templates "
                                                "resource "
                                                "type.",
                                                "enum": ["notification_templates"],
                                                "example": "notification_templates",
                                                "type": "string",
                                                "x-enum-varnames": ["NOTIFICATION_TEMPLATES"],
                                            },
                                        },
                                        "required": ["id", "type"],
                                        "type": "object",
                                    }
                                },
                                "required": ["data"],
                                "type": "object",
                            },
                        },
                        "type": "object",
                    },
                    "type": {
                        "description": "Notification rules resource type.",
                        "enum": ["incident_notification_rules"],
                        "example": "incident_notification_rules",
                        "type": "string",
                        "x-enum-varnames": ["INCIDENT_NOTIFICATION_RULES"],
                    },
                },
                "required": ["type", "attributes"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "UPDATEINCIDENTNOTIFICATIONRULE_REQUEST_BODY_SCHEMA": {
        "description": "Put request for a notification rule.",
        "properties": {
            "data": {
                "description": "Notification rule data for an update request.",
                "properties": {
                    "attributes": {
                        "description": "The attributes for creating a notification rule.",
                        "properties": {
                            "conditions": {
                                "description": "The "
                                "conditions "
                                "that "
                                "trigger "
                                "this "
                                "notification "
                                "rule.",
                                "example": [{"field": "severity", "values": ["SEV-1", "SEV-2"]}],
                                "items": {
                                    "description": "A "
                                    "condition "
                                    "that "
                                    "must "
                                    "be "
                                    "met "
                                    "to "
                                    "trigger "
                                    "the "
                                    "notification "
                                    "rule.",
                                    "properties": {
                                        "field": {
                                            "description": "The incident field to evaluate",
                                            "example": "severity",
                                            "type": "string",
                                        },
                                        "values": {
                                            "description": "The "
                                            "value(s) "
                                            "to "
                                            "compare "
                                            "against. "
                                            "Multiple "
                                            "values "
                                            "are "
                                            "`ORed` "
                                            "together.",
                                            "example": ["SEV-1", "SEV-2"],
                                            "items": {"type": "string"},
                                            "type": "array",
                                        },
                                    },
                                    "required": ["field", "values"],
                                    "type": "object",
                                },
                                "type": "array",
                            },
                            "enabled": {
                                "default": False,
                                "description": "Whether the notification rule is enabled.",
                                "example": True,
                                "type": "boolean",
                            },
                            "handles": {
                                "description": "The notification handles (targets) for this rule.",
                                "example": ["@team-email@company.com", "@slack-channel"],
                                "items": {
                                    "description": "A "
                                    "notification "
                                    "handle "
                                    "(email, "
                                    "Slack "
                                    "channel, "
                                    "etc.).",
                                    "type": "string",
                                },
                                "type": "array",
                            },
                            "renotify_on": {
                                "description": "List "
                                "of "
                                "incident "
                                "fields "
                                "that "
                                "trigger "
                                "re-notification "
                                "when "
                                "changed.",
                                "example": ["status", "severity"],
                                "items": {
                                    "description": "An incident field name.",
                                    "type": "string",
                                },
                                "type": "array",
                            },
                            "trigger": {
                                "description": "The trigger event for this notification rule.",
                                "example": "incident_created_trigger",
                                "type": "string",
                            },
                            "visibility": {
                                "description": "The visibility of the notification rule.",
                                "enum": ["all", "organization", "private"],
                                "example": "organization",
                                "type": "string",
                                "x-enum-varnames": ["ALL", "ORGANIZATION", "PRIVATE"],
                            },
                        },
                        "required": ["conditions", "handles", "trigger"],
                        "type": "object",
                    },
                    "id": {
                        "description": "The unique identifier of the notification rule.",
                        "example": "00000000-0000-0000-0000-000000000001",
                        "format": "uuid",
                        "type": "string",
                    },
                    "relationships": {
                        "description": "The "
                        "definition "
                        "of "
                        "`NotificationRuleCreateDataRelationships` "
                        "object.",
                        "properties": {
                            "incident_type": {
                                "description": "Relationship to an incident type.",
                                "properties": {
                                    "data": {
                                        "description": "Relationship to incident type object.",
                                        "properties": {
                                            "id": {
                                                "description": "The incident type's ID.",
                                                "example": "00000000-0000-0000-0000-000000000000",
                                                "type": "string",
                                            },
                                            "type": {
                                                "default": "incident_types",
                                                "description": "Incident type resource type.",
                                                "enum": ["incident_types"],
                                                "example": "incident_types",
                                                "type": "string",
                                                "x-enum-varnames": ["INCIDENT_TYPES"],
                                            },
                                        },
                                        "required": ["id", "type"],
                                        "type": "object",
                                    }
                                },
                                "required": ["data"],
                                "type": "object",
                            },
                            "notification_template": {
                                "description": "A "
                                "relationship "
                                "reference "
                                "to "
                                "a "
                                "notification "
                                "template.",
                                "properties": {
                                    "data": {
                                        "description": "The "
                                        "notification "
                                        "template "
                                        "relationship "
                                        "data.",
                                        "properties": {
                                            "id": {
                                                "description": "The "
                                                "unique "
                                                "identifier "
                                                "of "
                                                "the "
                                                "notification "
                                                "template.",
                                                "example": "00000000-0000-0000-0000-000000000001",
                                                "format": "uuid",
                                                "type": "string",
                                            },
                                            "type": {
                                                "description": "Notification "
                                                "templates "
                                                "resource "
                                                "type.",
                                                "enum": ["notification_templates"],
                                                "example": "notification_templates",
                                                "type": "string",
                                                "x-enum-varnames": ["NOTIFICATION_TEMPLATES"],
                                            },
                                        },
                                        "required": ["id", "type"],
                                        "type": "object",
                                    }
                                },
                                "required": ["data"],
                                "type": "object",
                            },
                        },
                        "type": "object",
                    },
                    "type": {
                        "description": "Notification rules resource type.",
                        "enum": ["incident_notification_rules"],
                        "example": "incident_notification_rules",
                        "type": "string",
                        "x-enum-varnames": ["INCIDENT_NOTIFICATION_RULES"],
                    },
                },
                "required": ["id", "type", "attributes"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "UPDATEINCIDENTTYPE_REQUEST_BODY_SCHEMA": {
        "description": "Patch request for an incident type.",
        "properties": {
            "data": {
                "description": "Incident type data for a patch request.",
                "properties": {
                    "attributes": {
                        "description": "Incident type's attributes for updates.",
                        "properties": {
                            "createdAt": {
                                "description": "Timestamp when the incident type was created.",
                                "format": "date-time",
                                "readOnly": True,
                                "type": "string",
                            },
                            "createdBy": {
                                "description": "A "
                                "unique "
                                "identifier "
                                "that "
                                "represents "
                                "the "
                                "user "
                                "that "
                                "created "
                                "the "
                                "incident "
                                "type.",
                                "example": "00000000-0000-0000-0000-000000000000",
                                "readOnly": True,
                                "type": "string",
                            },
                            "description": {
                                "description": "Text that describes the incident type.",
                                "example": "Any "
                                "incidents "
                                "that "
                                "harm "
                                "(or "
                                "have "
                                "the "
                                "potential "
                                "to) "
                                "the "
                                "confidentiality, "
                                "integrity, "
                                "or "
                                "availability "
                                "of "
                                "our "
                                "data. "
                                "Note: "
                                "This "
                                "will "
                                "notify "
                                "the "
                                "security "
                                "team.",
                                "type": "string",
                            },
                            "is_default": {
                                "description": "When "
                                "true, "
                                "this "
                                "incident "
                                "type "
                                "will "
                                "be "
                                "used "
                                "as "
                                "the "
                                "default "
                                "type "
                                "when "
                                "an "
                                "incident "
                                "type "
                                "is "
                                "not "
                                "specified.",
                                "example": False,
                                "type": "boolean",
                            },
                            "lastModifiedBy": {
                                "description": "A "
                                "unique "
                                "identifier "
                                "that "
                                "represents "
                                "the "
                                "user "
                                "that "
                                "last "
                                "modified "
                                "the "
                                "incident "
                                "type.",
                                "example": "00000000-0000-0000-0000-000000000000",
                                "readOnly": True,
                                "type": "string",
                            },
                            "modifiedAt": {
                                "description": "Timestamp "
                                "when "
                                "the "
                                "incident "
                                "type "
                                "was "
                                "last "
                                "modified.",
                                "format": "date-time",
                                "readOnly": True,
                                "type": "string",
                            },
                            "name": {
                                "description": "The name of the incident type.",
                                "example": "Security Incident",
                                "type": "string",
                            },
                            "prefix": {
                                "description": "The "
                                "string "
                                "that "
                                "will "
                                "be "
                                "prepended "
                                "to "
                                "the "
                                "incident "
                                "title "
                                "across "
                                "the "
                                "Datadog "
                                "app.",
                                "example": "IR",
                                "readOnly": True,
                                "type": "string",
                            },
                        },
                        "type": "object",
                    },
                    "id": {
                        "description": "The incident type's ID.",
                        "example": "00000000-0000-0000-0000-000000000000",
                        "type": "string",
                    },
                    "type": {
                        "default": "incident_types",
                        "description": "Incident type resource type.",
                        "enum": ["incident_types"],
                        "example": "incident_types",
                        "type": "string",
                        "x-enum-varnames": ["INCIDENT_TYPES"],
                    },
                },
                "required": ["id", "type", "attributes"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "UPDATEINCIDENT_REQUEST_BODY_SCHEMA": {
        "description": "Update request for an incident.",
        "properties": {
            "data": {
                "description": "Incident data for an update request.",
                "properties": {
                    "attributes": {
                        "description": "The incident's attributes for an update request.",
                        "properties": {
                            "customer_impact_end": {
                                "description": "Timestamp "
                                "when "
                                "customers "
                                "were "
                                "no "
                                "longer "
                                "impacted "
                                "by "
                                "the "
                                "incident.",
                                "format": "date-time",
                                "nullable": True,
                                "type": "string",
                            },
                            "customer_impact_scope": {
                                "description": "A "
                                "summary "
                                "of "
                                "the "
                                "impact "
                                "customers "
                                "experienced "
                                "during "
                                "the "
                                "incident.",
                                "example": "Example customer impact scope",
                                "type": "string",
                            },
                            "customer_impact_start": {
                                "description": "Timestamp "
                                "when "
                                "customers "
                                "began "
                                "being "
                                "impacted "
                                "by "
                                "the "
                                "incident.",
                                "format": "date-time",
                                "nullable": True,
                                "type": "string",
                            },
                            "customer_impacted": {
                                "description": "A "
                                "flag "
                                "indicating "
                                "whether "
                                "the "
                                "incident "
                                "caused "
                                "customer "
                                "impact.",
                                "example": False,
                                "type": "boolean",
                            },
                            "detected": {
                                "description": "Timestamp when the incident was detected.",
                                "format": "date-time",
                                "nullable": True,
                                "type": "string",
                            },
                            "fields": {
                                "additionalProperties": {
                                    "description": "Dynamic "
                                    "fields "
                                    "for "
                                    "which "
                                    "selections "
                                    "can "
                                    "be "
                                    "made, "
                                    "with "
                                    "field "
                                    "names "
                                    "as "
                                    "keys.",
                                    "oneOf": [
                                        {
                                            "description": "A field with a single value selected.",
                                            "properties": {
                                                "type": {
                                                    "default": "dropdown",
                                                    "description": "Type "
                                                    "of "
                                                    "the "
                                                    "single "
                                                    "value "
                                                    "field "
                                                    "definitions.",
                                                    "enum": ["dropdown", "textbox"],
                                                    "example": "dropdown",
                                                    "type": "string",
                                                    "x-enum-varnames": ["DROPDOWN", "TEXTBOX"],
                                                },
                                                "value": {
                                                    "description": "The "
                                                    "single "
                                                    "value "
                                                    "selected "
                                                    "for "
                                                    "this "
                                                    "field.",
                                                    "example": "SEV-1",
                                                    "nullable": True,
                                                    "type": "string",
                                                },
                                            },
                                            "type": "object",
                                        },
                                        {
                                            "description": "A "
                                            "field "
                                            "with "
                                            "potentially "
                                            "multiple "
                                            "values "
                                            "selected.",
                                            "properties": {
                                                "type": {
                                                    "default": "multiselect",
                                                    "description": "Type "
                                                    "of "
                                                    "the "
                                                    "multiple "
                                                    "value "
                                                    "field "
                                                    "definitions.",
                                                    "enum": [
                                                        "multiselect",
                                                        "textarray",
                                                        "metrictag",
                                                        "autocomplete",
                                                    ],
                                                    "example": "multiselect",
                                                    "type": "string",
                                                    "x-enum-varnames": [
                                                        "MULTISELECT",
                                                        "TEXTARRAY",
                                                        "METRICTAG",
                                                        "AUTOCOMPLETE",
                                                    ],
                                                },
                                                "value": {
                                                    "description": "The "
                                                    "multiple "
                                                    "values "
                                                    "selected "
                                                    "for "
                                                    "this "
                                                    "field.",
                                                    "example": ["1.0", "1.1"],
                                                    "items": {
                                                        "description": "A "
                                                        "value "
                                                        "which "
                                                        "has "
                                                        "been "
                                                        "selected "
                                                        "for "
                                                        "the "
                                                        "parent "
                                                        "field.",
                                                        "example": "1.1",
                                                        "type": "string",
                                                    },
                                                    "nullable": True,
                                                    "type": "array",
                                                },
                                            },
                                            "type": "object",
                                        },
                                    ],
                                },
                                "description": "A "
                                "condensed "
                                "view "
                                "of "
                                "the "
                                "user-defined "
                                "fields "
                                "for "
                                "which "
                                "to "
                                "update "
                                "selections.",
                                "example": {"severity": {"type": "dropdown", "value": "SEV-5"}},
                                "type": "object",
                            },
                            "notification_handles": {
                                "description": "Notification "
                                "handles "
                                "that "
                                "will "
                                "be "
                                "notified "
                                "of "
                                "the "
                                "incident "
                                "during "
                                "update.",
                                "example": [
                                    {"display_name": "Jane Doe", "handle": "@user@email.com"},
                                    {"display_name": "Slack Channel", "handle": "@slack-channel"},
                                    {
                                        "display_name": "Incident Workflow",
                                        "handle": "@workflow-from-incident",
                                    },
                                ],
                                "items": {
                                    "description": "A "
                                    "notification "
                                    "handle "
                                    "that "
                                    "will "
                                    "be "
                                    "notified "
                                    "at "
                                    "incident "
                                    "creation.",
                                    "properties": {
                                        "display_name": {
                                            "description": "The name of the notified handle.",
                                            "example": "Jane Doe",
                                            "type": "string",
                                        },
                                        "handle": {
                                            "description": "The "
                                            "handle "
                                            "used "
                                            "for "
                                            "the "
                                            "notification. "
                                            "This "
                                            "includes "
                                            "an "
                                            "email "
                                            "address, "
                                            "Slack "
                                            "channel, "
                                            "or "
                                            "workflow.",
                                            "example": "@test.user@test.com",
                                            "type": "string",
                                        },
                                    },
                                    "type": "object",
                                },
                                "type": "array",
                            },
                            "title": {
                                "description": "The "
                                "title "
                                "of "
                                "the "
                                "incident, "
                                "which "
                                "summarizes "
                                "what "
                                "happened.",
                                "example": "A test incident title",
                                "type": "string",
                            },
                        },
                        "type": "object",
                    },
                    "id": {
                        "description": "The incident's ID.",
                        "example": "00000000-0000-0000-4567-000000000000",
                        "type": "string",
                    },
                    "relationships": {
                        "description": "The incident's relationships for an update request.",
                        "properties": {
                            "commander_user": {
                                "description": "Relationship to user.",
                                "nullable": True,
                                "properties": {
                                    "data": {
                                        "description": "Relationship to user object.",
                                        "nullable": True,
                                        "properties": {
                                            "id": {
                                                "description": "A "
                                                "unique "
                                                "identifier "
                                                "that "
                                                "represents "
                                                "the "
                                                "user.",
                                                "example": "00000000-0000-0000-0000-000000000000",
                                                "type": "string",
                                            },
                                            "type": {
                                                "default": "users",
                                                "description": "Users resource type.",
                                                "enum": ["users"],
                                                "example": "users",
                                                "type": "string",
                                                "x-enum-varnames": ["USERS"],
                                            },
                                        },
                                        "required": ["id", "type"],
                                        "type": "object",
                                    }
                                },
                                "required": ["data"],
                                "type": "object",
                            },
                            "integrations": {
                                "description": "A "
                                "relationship "
                                "reference "
                                "for "
                                "multiple "
                                "integration "
                                "metadata "
                                "objects.",
                                "example": {
                                    "data": [
                                        {
                                            "id": "00000000-abcd-0005-0000-000000000000",
                                            "type": "incident_integrations",
                                        },
                                        {
                                            "id": "00000000-abcd-0006-0000-000000000000",
                                            "type": "incident_integrations",
                                        },
                                    ]
                                },
                                "properties": {
                                    "data": {
                                        "description": "Integration metadata relationship array",
                                        "example": [
                                            {
                                                "id": "00000000-abcd-0003-0000-000000000000",
                                                "type": "incident_integrations",
                                            },
                                            {
                                                "id": "00000000-abcd-0004-0000-000000000000",
                                                "type": "incident_integrations",
                                            },
                                        ],
                                        "items": {
                                            "description": "A "
                                            "relationship "
                                            "reference "
                                            "for "
                                            "an "
                                            "integration "
                                            "metadata "
                                            "object.",
                                            "example": {
                                                "id": "00000000-abcd-0002-0000-000000000000",
                                                "type": "incident_integrations",
                                            },
                                            "properties": {
                                                "id": {
                                                    "description": "A "
                                                    "unique "
                                                    "identifier "
                                                    "that "
                                                    "represents "
                                                    "the "
                                                    "integration "
                                                    "metadata.",
                                                    "example": "00000000-abcd-0001-0000-000000000000",
                                                    "type": "string",
                                                },
                                                "type": {
                                                    "default": "incident_integrations",
                                                    "description": "Integration "
                                                    "metadata "
                                                    "resource "
                                                    "type.",
                                                    "enum": ["incident_integrations"],
                                                    "example": "incident_integrations",
                                                    "type": "string",
                                                    "x-enum-varnames": ["INCIDENT_INTEGRATIONS"],
                                                },
                                            },
                                            "required": ["id", "type"],
                                            "type": "object",
                                        },
                                        "type": "array",
                                    }
                                },
                                "required": ["data"],
                                "type": "object",
                            },
                            "postmortem": {
                                "description": "A relationship reference for postmortems.",
                                "example": {
                                    "data": {
                                        "id": "00000000-0000-abcd-3000-000000000000",
                                        "type": "incident_postmortems",
                                    }
                                },
                                "properties": {
                                    "data": {
                                        "description": "The postmortem relationship data.",
                                        "example": {
                                            "id": "00000000-0000-abcd-2000-000000000000",
                                            "type": "incident_postmortems",
                                        },
                                        "properties": {
                                            "id": {
                                                "description": "A "
                                                "unique "
                                                "identifier "
                                                "that "
                                                "represents "
                                                "the "
                                                "postmortem.",
                                                "example": "00000000-0000-abcd-1000-000000000000",
                                                "type": "string",
                                            },
                                            "type": {
                                                "default": "incident_postmortems",
                                                "description": "Incident postmortem resource type.",
                                                "enum": ["incident_postmortems"],
                                                "example": "incident_postmortems",
                                                "type": "string",
                                                "x-enum-varnames": ["INCIDENT_POSTMORTEMS"],
                                            },
                                        },
                                        "required": ["id", "type"],
                                        "type": "object",
                                    }
                                },
                                "required": ["data"],
                                "type": "object",
                            },
                        },
                        "type": "object",
                    },
                    "type": {
                        "default": "incidents",
                        "description": "Incident resource type.",
                        "enum": ["incidents"],
                        "example": "incidents",
                        "type": "string",
                        "x-enum-varnames": ["INCIDENTS"],
                    },
                },
                "required": ["id", "type"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "MANAGEINCIDENTATTACHMENTS_REQUEST_BODY_SCHEMA": {
        "description": "The update request for an incident's attachments.",
        "properties": {
            "data": {
                "description": "An array of incident attachments. An "
                'attachment object without an "id" key '
                "indicates that you want to\n"
                "create that attachment. An attachment object "
                'without an "attributes" key indicates that '
                "you want to\n"
                "delete that attachment. An attachment object "
                'with both the "id" key and a populated '
                '"attributes" object\n'
                "indicates that you want to update that "
                "attachment.",
                "example": [
                    {
                        "attributes": {
                            "attachment": {
                                "documentUrl": "https://app.datadoghq.com/notebook/123",
                                "title": "Postmortem IR-123",
                            },
                            "attachment_type": "postmortem",
                        },
                        "id": "00000000-abcd-0002-0000-000000000000",
                        "type": "incident_attachments",
                    },
                    {
                        "attributes": {
                            "attachment": {
                                "documentUrl": "https://www.example.com/webstore-failure-runbook",
                                "title": "Runbook for webstore service failures",
                            },
                            "attachment_type": "link",
                        },
                        "type": "incident_attachments",
                    },
                    {"id": "00000000-abcd-0003-0000-000000000000", "type": "incident_attachments"},
                ],
                "items": {
                    "description": "A single incident attachment.",
                    "properties": {
                        "attributes": {
                            "description": "Incident attachment attributes.",
                            "oneOf": [
                                {
                                    "description": "The "
                                    "attributes "
                                    "object "
                                    "for "
                                    "a "
                                    "postmortem "
                                    "attachment.",
                                    "properties": {
                                        "attachment": {
                                            "description": "The postmortem attachment.",
                                            "properties": {
                                                "documentUrl": {
                                                    "description": "The "
                                                    "URL "
                                                    "of "
                                                    "this "
                                                    "notebook "
                                                    "attachment.",
                                                    "example": "https://app.datadoghq.com/notebook/123",
                                                    "type": "string",
                                                },
                                                "title": {
                                                    "description": "The "
                                                    "title "
                                                    "of "
                                                    "this "
                                                    "postmortem "
                                                    "attachment.",
                                                    "example": "Postmortem IR-123",
                                                    "type": "string",
                                                },
                                            },
                                            "required": ["documentUrl", "title"],
                                            "type": "object",
                                        },
                                        "attachment_type": {
                                            "default": "postmortem",
                                            "description": "The "
                                            "type "
                                            "of "
                                            "postmortem "
                                            "attachment "
                                            "attributes.",
                                            "enum": ["postmortem"],
                                            "example": "postmortem",
                                            "type": "string",
                                            "x-enum-varnames": ["POSTMORTEM"],
                                        },
                                    },
                                    "required": ["attachment_type", "attachment"],
                                    "type": "object",
                                },
                                {
                                    "description": "The attributes object for a link attachment.",
                                    "properties": {
                                        "attachment": {
                                            "description": "The link attachment.",
                                            "properties": {
                                                "documentUrl": {
                                                    "description": "The "
                                                    "URL "
                                                    "of "
                                                    "this "
                                                    "link "
                                                    "attachment.",
                                                    "example": "https://www.example.com/webstore-failure-runbook",
                                                    "type": "string",
                                                },
                                                "title": {
                                                    "description": "The "
                                                    "title "
                                                    "of "
                                                    "this "
                                                    "link "
                                                    "attachment.",
                                                    "example": "Runbook "
                                                    "for "
                                                    "webstore "
                                                    "service "
                                                    "failures",
                                                    "type": "string",
                                                },
                                            },
                                            "required": ["documentUrl", "title"],
                                            "type": "object",
                                        },
                                        "attachment_type": {
                                            "default": "link",
                                            "description": "The "
                                            "type "
                                            "of "
                                            "link "
                                            "attachment "
                                            "attributes.",
                                            "enum": ["link"],
                                            "example": "link",
                                            "type": "string",
                                            "x-enum-varnames": ["LINK"],
                                        },
                                        "modified": {
                                            "description": "Timestamp "
                                            "when "
                                            "the "
                                            "incident "
                                            "attachment "
                                            "link "
                                            "was "
                                            "last "
                                            "modified.",
                                            "format": "date-time",
                                            "readOnly": True,
                                            "type": "string",
                                        },
                                    },
                                    "required": ["attachment_type", "attachment"],
                                    "type": "object",
                                },
                            ],
                        },
                        "id": {
                            "description": "A unique "
                            "identifier "
                            "that "
                            "represents "
                            "the incident "
                            "attachment.",
                            "example": "00000000-abcd-0001-0000-000000000000",
                            "type": "string",
                        },
                        "type": {
                            "default": "incident_attachments",
                            "description": "The incident attachment resource type.",
                            "enum": ["incident_attachments"],
                            "example": "incident_attachments",
                            "type": "string",
                            "x-enum-varnames": ["INCIDENT_ATTACHMENTS"],
                        },
                    },
                    "required": ["type"],
                    "type": "object",
                },
                "type": "array",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "CREATEINCIDENTIMPACT_REQUEST_BODY_SCHEMA": {
        "description": "Create request for an incident impact.",
        "properties": {
            "data": {
                "description": "Incident impact data for a create request.",
                "properties": {
                    "attributes": {
                        "description": "The incident impact's attributes for a create request.",
                        "properties": {
                            "description": {
                                "description": "Description of the impact.",
                                "example": "Service was unavailable for external users",
                                "type": "string",
                            },
                            "end_at": {
                                "description": "Timestamp when the impact ended.",
                                "example": "2025-08-29T13:17:00Z",
                                "format": "date-time",
                                "nullable": True,
                                "type": "string",
                            },
                            "fields": {
                                "additionalProperties": {},
                                "description": "An "
                                "object "
                                "mapping "
                                "impact "
                                "field "
                                "names "
                                "to "
                                "field "
                                "values.",
                                "example": {
                                    "customers_impacted": "all",
                                    "products_impacted": ["shopping", "marketing"],
                                },
                                "nullable": True,
                                "type": "object",
                            },
                            "start_at": {
                                "description": "Timestamp when the impact started.",
                                "example": "2025-08-28T13:17:00Z",
                                "format": "date-time",
                                "type": "string",
                            },
                        },
                        "required": ["description", "start_at"],
                        "type": "object",
                    },
                    "type": {
                        "default": "incident_impacts",
                        "description": "Incident impact resource type.",
                        "enum": ["incident_impacts"],
                        "example": "incident_impacts",
                        "type": "string",
                        "x-enum-varnames": ["INCIDENT_IMPACTS"],
                    },
                },
                "required": ["type", "attributes"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "CREATEINCIDENTINTEGRATION_REQUEST_BODY_SCHEMA": {
        "description": "Create request for an incident integration metadata.",
        "properties": {
            "data": {
                "description": "Incident integration metadata data for a create request.",
                "properties": {
                    "attributes": {
                        "description": "Incident "
                        "integration "
                        "metadata's "
                        "attributes for "
                        "a create "
                        "request.",
                        "properties": {
                            "created": {
                                "description": "Timestamp when the incident todo was created.",
                                "format": "date-time",
                                "readOnly": True,
                                "type": "string",
                            },
                            "incident_id": {
                                "description": "UUID "
                                "of "
                                "the "
                                "incident "
                                "this "
                                "integration "
                                "metadata "
                                "is "
                                "connected "
                                "to.",
                                "example": "00000000-aaaa-0000-0000-000000000000",
                                "type": "string",
                            },
                            "integration_type": {
                                "description": "A "
                                "number "
                                "indicating "
                                "the "
                                "type "
                                "of "
                                "integration "
                                "this "
                                "metadata "
                                "is "
                                "for. "
                                "1 "
                                "indicates "
                                "Slack;\n"
                                "8 "
                                "indicates "
                                "Jira.",
                                "example": 1,
                                "format": "int32",
                                "maximum": 9,
                                "type": "integer",
                            },
                            "metadata": {
                                "description": "Incident "
                                "integration "
                                "metadata's "
                                "metadata "
                                "attribute.",
                                "oneOf": [
                                    {
                                        "description": "Incident "
                                        "integration "
                                        "metadata "
                                        "for "
                                        "the "
                                        "Slack "
                                        "integration.",
                                        "properties": {
                                            "channels": {
                                                "description": "Array "
                                                "of "
                                                "Slack "
                                                "channels "
                                                "in "
                                                "this "
                                                "integration "
                                                "metadata.",
                                                "example": [],
                                                "items": {
                                                    "description": "Item "
                                                    "in "
                                                    "the "
                                                    "Slack "
                                                    "integration "
                                                    "metadata "
                                                    "channel "
                                                    "array.",
                                                    "properties": {
                                                        "channel_id": {
                                                            "description": "Slack channel ID.",
                                                            "example": "C0123456789",
                                                            "type": "string",
                                                        },
                                                        "channel_name": {
                                                            "description": "Name "
                                                            "of "
                                                            "the "
                                                            "Slack "
                                                            "channel.",
                                                            "example": "#example-channel-name",
                                                            "type": "string",
                                                        },
                                                        "redirect_url": {
                                                            "description": "URL "
                                                            "redirecting "
                                                            "to "
                                                            "the "
                                                            "Slack "
                                                            "channel.",
                                                            "example": "https://slack.com/app_redirect?channel=C0123456789&team=T01234567",
                                                            "type": "string",
                                                        },
                                                        "team_id": {
                                                            "description": "Slack team ID.",
                                                            "example": "T01234567",
                                                            "type": "string",
                                                        },
                                                    },
                                                    "required": [
                                                        "channel_id",
                                                        "channel_name",
                                                        "redirect_url",
                                                    ],
                                                    "type": "object",
                                                },
                                                "type": "array",
                                            }
                                        },
                                        "required": ["channels"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "Incident "
                                        "integration "
                                        "metadata "
                                        "for "
                                        "the "
                                        "Jira "
                                        "integration.",
                                        "properties": {
                                            "issues": {
                                                "description": "Array "
                                                "of "
                                                "Jira "
                                                "issues "
                                                "in "
                                                "this "
                                                "integration "
                                                "metadata.",
                                                "example": [],
                                                "items": {
                                                    "description": "Item "
                                                    "in "
                                                    "the "
                                                    "Jira "
                                                    "integration "
                                                    "metadata "
                                                    "issue "
                                                    "array.",
                                                    "properties": {
                                                        "account": {
                                                            "description": "URL "
                                                            "of "
                                                            "issue's "
                                                            "Jira "
                                                            "account.",
                                                            "example": "https://example.atlassian.net",
                                                            "type": "string",
                                                        },
                                                        "issue_key": {
                                                            "description": "Jira "
                                                            "issue's "
                                                            "issue "
                                                            "key.",
                                                            "example": "PROJ-123",
                                                            "type": "string",
                                                        },
                                                        "issuetype_id": {
                                                            "description": "Jira "
                                                            "issue's "
                                                            "issue "
                                                            "type.",
                                                            "example": "1000",
                                                            "type": "string",
                                                        },
                                                        "project_key": {
                                                            "description": "Jira "
                                                            "issue's "
                                                            "project "
                                                            "keys.",
                                                            "example": "PROJ",
                                                            "type": "string",
                                                        },
                                                        "redirect_url": {
                                                            "description": "URL "
                                                            "redirecting "
                                                            "to "
                                                            "the "
                                                            "Jira "
                                                            "issue.",
                                                            "example": "https://example.atlassian.net/browse/PROJ-123",
                                                            "type": "string",
                                                        },
                                                    },
                                                    "required": ["project_key", "account"],
                                                    "type": "object",
                                                },
                                                "type": "array",
                                            }
                                        },
                                        "required": ["issues"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "Incident "
                                        "integration "
                                        "metadata "
                                        "for "
                                        "the "
                                        "Microsoft "
                                        "Teams "
                                        "integration.",
                                        "properties": {
                                            "teams": {
                                                "description": "Array "
                                                "of "
                                                "Microsoft "
                                                "Teams "
                                                "in "
                                                "this "
                                                "integration "
                                                "metadata.",
                                                "example": [],
                                                "items": {
                                                    "description": "Item "
                                                    "in "
                                                    "the "
                                                    "Microsoft "
                                                    "Teams "
                                                    "integration "
                                                    "metadata "
                                                    "teams "
                                                    "array.",
                                                    "properties": {
                                                        "ms_channel_id": {
                                                            "description": "Microsoft "
                                                            "Teams "
                                                            "channel "
                                                            "ID.",
                                                            "example": "19:abc00abcdef00a0abcdef0abcdef0a@thread.tacv2",
                                                            "type": "string",
                                                        },
                                                        "ms_channel_name": {
                                                            "description": "Microsoft "
                                                            "Teams "
                                                            "channel "
                                                            "name.",
                                                            "example": "incident-0001-example",
                                                            "type": "string",
                                                        },
                                                        "ms_tenant_id": {
                                                            "description": "Microsoft "
                                                            "Teams "
                                                            "tenant "
                                                            "ID.",
                                                            "example": "00000000-abcd-0005-0000-000000000000",
                                                            "type": "string",
                                                        },
                                                        "redirect_url": {
                                                            "description": "URL "
                                                            "redirecting "
                                                            "to "
                                                            "the "
                                                            "Microsoft "
                                                            "Teams "
                                                            "channel.",
                                                            "example": "https://teams.microsoft.com/l/channel/19%3Aabc00abcdef00a0abcdef0abcdef0a%40thread.tacv2/conversations?groupId=12345678-abcd-dcba-abcd-1234567890ab&tenantId=00000000-abcd-0005-0000-000000000000",
                                                            "type": "string",
                                                        },
                                                    },
                                                    "required": [
                                                        "ms_tenant_id",
                                                        "ms_channel_id",
                                                        "ms_channel_name",
                                                        "redirect_url",
                                                    ],
                                                    "type": "object",
                                                },
                                                "type": "array",
                                            }
                                        },
                                        "required": ["teams"],
                                        "type": "object",
                                    },
                                ],
                            },
                            "modified": {
                                "description": "Timestamp "
                                "when "
                                "the "
                                "incident "
                                "todo "
                                "was "
                                "last "
                                "modified.",
                                "format": "date-time",
                                "readOnly": True,
                                "type": "string",
                            },
                            "status": {
                                "description": "A "
                                "number "
                                "indicating "
                                "the "
                                "status "
                                "of "
                                "this "
                                "integration "
                                "metadata. "
                                "0 "
                                "indicates "
                                "unknown;\n"
                                "1 "
                                "indicates "
                                "pending; "
                                "2 "
                                "indicates "
                                "complete; "
                                "3 "
                                "indicates "
                                "manually "
                                "created;\n"
                                "4 "
                                "indicates "
                                "manually "
                                "updated; "
                                "5 "
                                "indicates "
                                "failed.",
                                "format": "int32",
                                "maximum": 5,
                                "type": "integer",
                            },
                        },
                        "required": ["integration_type", "metadata"],
                        "type": "object",
                    },
                    "type": {
                        "default": "incident_integrations",
                        "description": "Integration metadata resource type.",
                        "enum": ["incident_integrations"],
                        "example": "incident_integrations",
                        "type": "string",
                        "x-enum-varnames": ["INCIDENT_INTEGRATIONS"],
                    },
                },
                "required": ["type", "attributes"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "UPDATEINCIDENTINTEGRATION_REQUEST_BODY_SCHEMA": {
        "description": "Patch request for an incident integration metadata.",
        "properties": {
            "data": {
                "description": "Incident integration metadata data for a patch request.",
                "properties": {
                    "attributes": {
                        "description": "Incident "
                        "integration "
                        "metadata's "
                        "attributes for "
                        "a create "
                        "request.",
                        "properties": {
                            "created": {
                                "description": "Timestamp when the incident todo was created.",
                                "format": "date-time",
                                "readOnly": True,
                                "type": "string",
                            },
                            "incident_id": {
                                "description": "UUID "
                                "of "
                                "the "
                                "incident "
                                "this "
                                "integration "
                                "metadata "
                                "is "
                                "connected "
                                "to.",
                                "example": "00000000-aaaa-0000-0000-000000000000",
                                "type": "string",
                            },
                            "integration_type": {
                                "description": "A "
                                "number "
                                "indicating "
                                "the "
                                "type "
                                "of "
                                "integration "
                                "this "
                                "metadata "
                                "is "
                                "for. "
                                "1 "
                                "indicates "
                                "Slack;\n"
                                "8 "
                                "indicates "
                                "Jira.",
                                "example": 1,
                                "format": "int32",
                                "maximum": 9,
                                "type": "integer",
                            },
                            "metadata": {
                                "description": "Incident "
                                "integration "
                                "metadata's "
                                "metadata "
                                "attribute.",
                                "oneOf": [
                                    {
                                        "description": "Incident "
                                        "integration "
                                        "metadata "
                                        "for "
                                        "the "
                                        "Slack "
                                        "integration.",
                                        "properties": {
                                            "channels": {
                                                "description": "Array "
                                                "of "
                                                "Slack "
                                                "channels "
                                                "in "
                                                "this "
                                                "integration "
                                                "metadata.",
                                                "example": [],
                                                "items": {
                                                    "description": "Item "
                                                    "in "
                                                    "the "
                                                    "Slack "
                                                    "integration "
                                                    "metadata "
                                                    "channel "
                                                    "array.",
                                                    "properties": {
                                                        "channel_id": {
                                                            "description": "Slack channel ID.",
                                                            "example": "C0123456789",
                                                            "type": "string",
                                                        },
                                                        "channel_name": {
                                                            "description": "Name "
                                                            "of "
                                                            "the "
                                                            "Slack "
                                                            "channel.",
                                                            "example": "#example-channel-name",
                                                            "type": "string",
                                                        },
                                                        "redirect_url": {
                                                            "description": "URL "
                                                            "redirecting "
                                                            "to "
                                                            "the "
                                                            "Slack "
                                                            "channel.",
                                                            "example": "https://slack.com/app_redirect?channel=C0123456789&team=T01234567",
                                                            "type": "string",
                                                        },
                                                        "team_id": {
                                                            "description": "Slack team ID.",
                                                            "example": "T01234567",
                                                            "type": "string",
                                                        },
                                                    },
                                                    "required": [
                                                        "channel_id",
                                                        "channel_name",
                                                        "redirect_url",
                                                    ],
                                                    "type": "object",
                                                },
                                                "type": "array",
                                            }
                                        },
                                        "required": ["channels"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "Incident "
                                        "integration "
                                        "metadata "
                                        "for "
                                        "the "
                                        "Jira "
                                        "integration.",
                                        "properties": {
                                            "issues": {
                                                "description": "Array "
                                                "of "
                                                "Jira "
                                                "issues "
                                                "in "
                                                "this "
                                                "integration "
                                                "metadata.",
                                                "example": [],
                                                "items": {
                                                    "description": "Item "
                                                    "in "
                                                    "the "
                                                    "Jira "
                                                    "integration "
                                                    "metadata "
                                                    "issue "
                                                    "array.",
                                                    "properties": {
                                                        "account": {
                                                            "description": "URL "
                                                            "of "
                                                            "issue's "
                                                            "Jira "
                                                            "account.",
                                                            "example": "https://example.atlassian.net",
                                                            "type": "string",
                                                        },
                                                        "issue_key": {
                                                            "description": "Jira "
                                                            "issue's "
                                                            "issue "
                                                            "key.",
                                                            "example": "PROJ-123",
                                                            "type": "string",
                                                        },
                                                        "issuetype_id": {
                                                            "description": "Jira "
                                                            "issue's "
                                                            "issue "
                                                            "type.",
                                                            "example": "1000",
                                                            "type": "string",
                                                        },
                                                        "project_key": {
                                                            "description": "Jira "
                                                            "issue's "
                                                            "project "
                                                            "keys.",
                                                            "example": "PROJ",
                                                            "type": "string",
                                                        },
                                                        "redirect_url": {
                                                            "description": "URL "
                                                            "redirecting "
                                                            "to "
                                                            "the "
                                                            "Jira "
                                                            "issue.",
                                                            "example": "https://example.atlassian.net/browse/PROJ-123",
                                                            "type": "string",
                                                        },
                                                    },
                                                    "required": ["project_key", "account"],
                                                    "type": "object",
                                                },
                                                "type": "array",
                                            }
                                        },
                                        "required": ["issues"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "Incident "
                                        "integration "
                                        "metadata "
                                        "for "
                                        "the "
                                        "Microsoft "
                                        "Teams "
                                        "integration.",
                                        "properties": {
                                            "teams": {
                                                "description": "Array "
                                                "of "
                                                "Microsoft "
                                                "Teams "
                                                "in "
                                                "this "
                                                "integration "
                                                "metadata.",
                                                "example": [],
                                                "items": {
                                                    "description": "Item "
                                                    "in "
                                                    "the "
                                                    "Microsoft "
                                                    "Teams "
                                                    "integration "
                                                    "metadata "
                                                    "teams "
                                                    "array.",
                                                    "properties": {
                                                        "ms_channel_id": {
                                                            "description": "Microsoft "
                                                            "Teams "
                                                            "channel "
                                                            "ID.",
                                                            "example": "19:abc00abcdef00a0abcdef0abcdef0a@thread.tacv2",
                                                            "type": "string",
                                                        },
                                                        "ms_channel_name": {
                                                            "description": "Microsoft "
                                                            "Teams "
                                                            "channel "
                                                            "name.",
                                                            "example": "incident-0001-example",
                                                            "type": "string",
                                                        },
                                                        "ms_tenant_id": {
                                                            "description": "Microsoft "
                                                            "Teams "
                                                            "tenant "
                                                            "ID.",
                                                            "example": "00000000-abcd-0005-0000-000000000000",
                                                            "type": "string",
                                                        },
                                                        "redirect_url": {
                                                            "description": "URL "
                                                            "redirecting "
                                                            "to "
                                                            "the "
                                                            "Microsoft "
                                                            "Teams "
                                                            "channel.",
                                                            "example": "https://teams.microsoft.com/l/channel/19%3Aabc00abcdef00a0abcdef0abcdef0a%40thread.tacv2/conversations?groupId=12345678-abcd-dcba-abcd-1234567890ab&tenantId=00000000-abcd-0005-0000-000000000000",
                                                            "type": "string",
                                                        },
                                                    },
                                                    "required": [
                                                        "ms_tenant_id",
                                                        "ms_channel_id",
                                                        "ms_channel_name",
                                                        "redirect_url",
                                                    ],
                                                    "type": "object",
                                                },
                                                "type": "array",
                                            }
                                        },
                                        "required": ["teams"],
                                        "type": "object",
                                    },
                                ],
                            },
                            "modified": {
                                "description": "Timestamp "
                                "when "
                                "the "
                                "incident "
                                "todo "
                                "was "
                                "last "
                                "modified.",
                                "format": "date-time",
                                "readOnly": True,
                                "type": "string",
                            },
                            "status": {
                                "description": "A "
                                "number "
                                "indicating "
                                "the "
                                "status "
                                "of "
                                "this "
                                "integration "
                                "metadata. "
                                "0 "
                                "indicates "
                                "unknown;\n"
                                "1 "
                                "indicates "
                                "pending; "
                                "2 "
                                "indicates "
                                "complete; "
                                "3 "
                                "indicates "
                                "manually "
                                "created;\n"
                                "4 "
                                "indicates "
                                "manually "
                                "updated; "
                                "5 "
                                "indicates "
                                "failed.",
                                "format": "int32",
                                "maximum": 5,
                                "type": "integer",
                            },
                        },
                        "required": ["integration_type", "metadata"],
                        "type": "object",
                    },
                    "type": {
                        "default": "incident_integrations",
                        "description": "Integration metadata resource type.",
                        "enum": ["incident_integrations"],
                        "example": "incident_integrations",
                        "type": "string",
                        "x-enum-varnames": ["INCIDENT_INTEGRATIONS"],
                    },
                },
                "required": ["type", "attributes"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "CREATEINCIDENTTODO_REQUEST_BODY_SCHEMA": {
        "description": "Create request for an incident todo.",
        "properties": {
            "data": {
                "description": "Incident todo data for a create request.",
                "properties": {
                    "attributes": {
                        "description": "Incident todo's attributes.",
                        "properties": {
                            "assignees": {
                                "description": "Array of todo assignees.",
                                "example": ["@test.user@test.com"],
                                "items": {
                                    "description": "A todo assignee.",
                                    "example": "@test.user@test.com",
                                    "oneOf": [
                                        {
                                            "description": "Assignee's @-handle.",
                                            "example": "@test.user@test.com",
                                            "type": "string",
                                        },
                                        {
                                            "description": "Anonymous assignee entity.",
                                            "properties": {
                                                "icon": {
                                                    "description": "URL for assignee's icon.",
                                                    "example": "https://a.slack-edge.com/80588/img/slackbot_48.png",
                                                    "type": "string",
                                                },
                                                "id": {
                                                    "description": "Anonymous assignee's ID.",
                                                    "example": "USLACKBOT",
                                                    "type": "string",
                                                },
                                                "name": {
                                                    "description": "Assignee's name.",
                                                    "example": "Slackbot",
                                                    "type": "string",
                                                },
                                                "source": {
                                                    "default": "slack",
                                                    "description": "The "
                                                    "source "
                                                    "of "
                                                    "the "
                                                    "anonymous "
                                                    "assignee.",
                                                    "enum": ["slack", "microsoft_teams"],
                                                    "example": "slack",
                                                    "type": "string",
                                                    "x-enum-varnames": ["SLACK", "MICROSOFT_TEAMS"],
                                                },
                                            },
                                            "required": ["id", "icon", "name", "source"],
                                            "type": "object",
                                        },
                                    ],
                                },
                                "type": "array",
                            },
                            "completed": {
                                "description": "Timestamp when the todo was completed.",
                                "example": "2023-03-06T22:00:00.000000+00:00",
                                "nullable": True,
                                "type": "string",
                            },
                            "content": {
                                "description": "The follow-up task's content.",
                                "example": "Restore lost data.",
                                "type": "string",
                            },
                            "created": {
                                "description": "Timestamp when the incident todo was created.",
                                "format": "date-time",
                                "readOnly": True,
                                "type": "string",
                            },
                            "due_date": {
                                "description": "Timestamp when the todo should be completed by.",
                                "example": "2023-07-10T05:00:00.000000+00:00",
                                "nullable": True,
                                "type": "string",
                            },
                            "incident_id": {
                                "description": "UUID of the incident this todo is connected to.",
                                "example": "00000000-aaaa-0000-0000-000000000000",
                                "type": "string",
                            },
                            "modified": {
                                "description": "Timestamp "
                                "when "
                                "the "
                                "incident "
                                "todo "
                                "was "
                                "last "
                                "modified.",
                                "format": "date-time",
                                "readOnly": True,
                                "type": "string",
                            },
                        },
                        "required": ["content", "assignees"],
                        "type": "object",
                    },
                    "type": {
                        "default": "incident_todos",
                        "description": "Todo resource type.",
                        "enum": ["incident_todos"],
                        "example": "incident_todos",
                        "type": "string",
                        "x-enum-varnames": ["INCIDENT_TODOS"],
                    },
                },
                "required": ["type", "attributes"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "UPDATEINCIDENTTODO_REQUEST_BODY_SCHEMA": {
        "description": "Patch request for an incident todo.",
        "properties": {
            "data": {
                "description": "Incident todo data for a patch request.",
                "properties": {
                    "attributes": {
                        "description": "Incident todo's attributes.",
                        "properties": {
                            "assignees": {
                                "description": "Array of todo assignees.",
                                "example": ["@test.user@test.com"],
                                "items": {
                                    "description": "A todo assignee.",
                                    "example": "@test.user@test.com",
                                    "oneOf": [
                                        {
                                            "description": "Assignee's @-handle.",
                                            "example": "@test.user@test.com",
                                            "type": "string",
                                        },
                                        {
                                            "description": "Anonymous assignee entity.",
                                            "properties": {
                                                "icon": {
                                                    "description": "URL for assignee's icon.",
                                                    "example": "https://a.slack-edge.com/80588/img/slackbot_48.png",
                                                    "type": "string",
                                                },
                                                "id": {
                                                    "description": "Anonymous assignee's ID.",
                                                    "example": "USLACKBOT",
                                                    "type": "string",
                                                },
                                                "name": {
                                                    "description": "Assignee's name.",
                                                    "example": "Slackbot",
                                                    "type": "string",
                                                },
                                                "source": {
                                                    "default": "slack",
                                                    "description": "The "
                                                    "source "
                                                    "of "
                                                    "the "
                                                    "anonymous "
                                                    "assignee.",
                                                    "enum": ["slack", "microsoft_teams"],
                                                    "example": "slack",
                                                    "type": "string",
                                                    "x-enum-varnames": ["SLACK", "MICROSOFT_TEAMS"],
                                                },
                                            },
                                            "required": ["id", "icon", "name", "source"],
                                            "type": "object",
                                        },
                                    ],
                                },
                                "type": "array",
                            },
                            "completed": {
                                "description": "Timestamp when the todo was completed.",
                                "example": "2023-03-06T22:00:00.000000+00:00",
                                "nullable": True,
                                "type": "string",
                            },
                            "content": {
                                "description": "The follow-up task's content.",
                                "example": "Restore lost data.",
                                "type": "string",
                            },
                            "created": {
                                "description": "Timestamp when the incident todo was created.",
                                "format": "date-time",
                                "readOnly": True,
                                "type": "string",
                            },
                            "due_date": {
                                "description": "Timestamp when the todo should be completed by.",
                                "example": "2023-07-10T05:00:00.000000+00:00",
                                "nullable": True,
                                "type": "string",
                            },
                            "incident_id": {
                                "description": "UUID of the incident this todo is connected to.",
                                "example": "00000000-aaaa-0000-0000-000000000000",
                                "type": "string",
                            },
                            "modified": {
                                "description": "Timestamp "
                                "when "
                                "the "
                                "incident "
                                "todo "
                                "was "
                                "last "
                                "modified.",
                                "format": "date-time",
                                "readOnly": True,
                                "type": "string",
                            },
                        },
                        "required": ["content", "assignees"],
                        "type": "object",
                    },
                    "type": {
                        "default": "incident_todos",
                        "description": "Todo resource type.",
                        "enum": ["incident_todos"],
                        "example": "incident_todos",
                        "type": "string",
                        "x-enum-varnames": ["INCIDENT_TODOS"],
                    },
                },
                "required": ["type", "attributes"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "CREATEAWSACCOUNTINTEGRATION_REQUEST_BODY_SCHEMA": {
        "description": "AWS Account Create Request body.",
        "properties": {
            "data": {
                "description": "AWS Account Create Request data.",
                "properties": {
                    "attributes": {
                        "description": "The AWS Account Integration Config to be created.",
                        "properties": {
                            "account_tags": {
                                "description": "Tags "
                                "to "
                                "apply "
                                "to "
                                "all "
                                "hosts "
                                "and "
                                "metrics "
                                "reporting "
                                "for "
                                "this "
                                "account. "
                                "Defaults "
                                "to "
                                "`[]`.",
                                "items": {
                                    "description": "Tag in the form `key:value`.",
                                    "example": "env:prod",
                                    "type": "string",
                                },
                                "nullable": True,
                                "type": "array",
                            },
                            "auth_config": {
                                "description": "AWS Authentication config.",
                                "oneOf": [
                                    {
                                        "description": "AWS "
                                        "Authentication "
                                        "config "
                                        "to "
                                        "integrate "
                                        "your "
                                        "account "
                                        "using "
                                        "an "
                                        "access "
                                        "key "
                                        "pair.",
                                        "properties": {
                                            "access_key_id": {
                                                "description": "AWS Access Key ID.",
                                                "example": "AKIAIOSFODNN7EXAMPLE",
                                                "type": "string",
                                            },
                                            "secret_access_key": {
                                                "description": "AWS Secret Access Key.",
                                                "example": "wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMPLEKEY",
                                                "minLength": 1,
                                                "type": "string",
                                                "writeOnly": True,
                                            },
                                        },
                                        "required": ["access_key_id"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "AWS "
                                        "Authentication "
                                        "config "
                                        "to "
                                        "integrate "
                                        "your "
                                        "account "
                                        "using "
                                        "an "
                                        "IAM "
                                        "role.",
                                        "properties": {
                                            "external_id": {
                                                "description": "AWS "
                                                "IAM "
                                                "External "
                                                "ID "
                                                "for "
                                                "associated "
                                                "role.",
                                                "type": "string",
                                            },
                                            "role_name": {
                                                "description": "AWS IAM Role name.",
                                                "example": "DatadogIntegrationRole",
                                                "maxLength": 576,
                                                "minLength": 1,
                                                "type": "string",
                                            },
                                        },
                                        "required": ["role_name"],
                                        "type": "object",
                                    },
                                ],
                            },
                            "aws_account_id": {
                                "description": "AWS Account ID.",
                                "example": "123456789012",
                                "type": "string",
                            },
                            "aws_partition": {
                                "description": "AWS "
                                "partition "
                                "your "
                                "AWS "
                                "account "
                                "is "
                                "scoped "
                                "to. "
                                "Defaults "
                                "to "
                                "`aws`.\n"
                                "See "
                                "[Partitions](https://docs.aws.amazon.com/whitepapers/latest/aws-fault-isolation-boundaries/partitions.html) "
                                "in "
                                "the "
                                "AWS "
                                "documentation "
                                "for "
                                "more "
                                "information.",
                                "enum": ["aws", "aws-cn", "aws-us-gov"],
                                "example": "aws",
                                "type": "string",
                                "x-enum-varnames": ["AWS", "AWS_CN", "AWS_US_GOV"],
                            },
                            "aws_regions": {
                                "description": "AWS "
                                "Regions "
                                "to "
                                "collect "
                                "data "
                                "from. "
                                "Defaults "
                                "to "
                                "`include_all`.",
                                "oneOf": [
                                    {
                                        "description": "Include all regions. Defaults to `true`.",
                                        "properties": {
                                            "include_all": {
                                                "description": "Include all regions.",
                                                "example": True,
                                                "type": "boolean",
                                            }
                                        },
                                        "required": ["include_all"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "Include only these regions.",
                                        "properties": {
                                            "include_only": {
                                                "description": "Include only these regions.",
                                                "example": ["us-east-1"],
                                                "items": {"example": "us-east-1", "type": "string"},
                                                "type": "array",
                                            }
                                        },
                                        "required": ["include_only"],
                                        "type": "object",
                                    },
                                ],
                            },
                            "logs_config": {
                                "description": "AWS Logs Collection config.",
                                "properties": {
                                    "lambda_forwarder": {
                                        "description": "Log "
                                        "Autosubscription "
                                        "configuration "
                                        "for "
                                        "Datadog "
                                        "Forwarder "
                                        "Lambda "
                                        "functions. "
                                        "Automatically "
                                        "set "
                                        "up "
                                        "triggers "
                                        "for "
                                        "existing\n"
                                        "and "
                                        "new "
                                        "logs "
                                        "for "
                                        "some "
                                        "services, "
                                        "ensuring "
                                        "no "
                                        "logs "
                                        "from "
                                        "new "
                                        "resources "
                                        "are "
                                        "missed "
                                        "and "
                                        "saving "
                                        "time "
                                        "spent "
                                        "on "
                                        "manual "
                                        "configuration.",
                                        "properties": {
                                            "lambdas": {
                                                "description": "List "
                                                "of "
                                                "Datadog "
                                                "Lambda "
                                                "Log "
                                                "Forwarder "
                                                "ARNs "
                                                "in "
                                                "your "
                                                "AWS "
                                                "account. "
                                                "Defaults "
                                                "to "
                                                "`[]`.",
                                                "items": {
                                                    "example": "arn:aws:lambda:us-east-1:123456789012:function:DatadogLambdaLogForwarder",
                                                    "type": "string",
                                                },
                                                "type": "array",
                                            },
                                            "log_source_config": {
                                                "description": "Log source configuration.",
                                                "properties": {
                                                    "tag_filters": {
                                                        "description": "List "
                                                        "of "
                                                        "AWS "
                                                        "log "
                                                        "source "
                                                        "tag "
                                                        "filters. "
                                                        "Defaults "
                                                        "to "
                                                        "`[]`.",
                                                        "items": {
                                                            "description": "AWS "
                                                            "log "
                                                            "source "
                                                            "tag "
                                                            "filter "
                                                            "list. "
                                                            "Defaults "
                                                            "to "
                                                            "`[]`.\n"
                                                            "Array "
                                                            "of "
                                                            "log "
                                                            "source "
                                                            "to "
                                                            "AWS "
                                                            "resource "
                                                            "tag "
                                                            "mappings. "
                                                            "Each "
                                                            "mapping "
                                                            "contains "
                                                            "a "
                                                            "log "
                                                            "source "
                                                            "and "
                                                            "its "
                                                            "associated "
                                                            "AWS "
                                                            "resource "
                                                            "tags "
                                                            "(in "
                                                            "`key:value` "
                                                            "format) "
                                                            "used "
                                                            "to "
                                                            "filter "
                                                            "logs "
                                                            "submitted "
                                                            "to "
                                                            "Datadog.\n"
                                                            "Tag "
                                                            "filters "
                                                            "are "
                                                            "applied "
                                                            "for "
                                                            "tags "
                                                            "on "
                                                            "the "
                                                            "AWS "
                                                            "resource "
                                                            "emitting "
                                                            "logs; "
                                                            "tags "
                                                            "associated "
                                                            "with "
                                                            "the "
                                                            "log "
                                                            "storage "
                                                            "entity "
                                                            "(such "
                                                            "as "
                                                            "a "
                                                            "CloudWatch "
                                                            "Log "
                                                            "Group "
                                                            "or "
                                                            "S3 "
                                                            "Bucket) "
                                                            "are "
                                                            "not "
                                                            "considered.\n"
                                                            "For "
                                                            "more "
                                                            "information "
                                                            "on "
                                                            "resource "
                                                            "tag "
                                                            "filter "
                                                            "syntax, "
                                                            "[see "
                                                            "AWS "
                                                            "resource "
                                                            "exclusion](https://docs.datadoghq.com/account_management/billing/aws/#aws-resource-exclusion) "
                                                            "in "
                                                            "the "
                                                            "AWS "
                                                            "integration "
                                                            "billing "
                                                            "page.",
                                                            "properties": {
                                                                "source": {
                                                                    "description": "The "
                                                                    "AWS "
                                                                    "log "
                                                                    "source "
                                                                    "to "
                                                                    "which "
                                                                    "the "
                                                                    "tag "
                                                                    "filters "
                                                                    "defined "
                                                                    "in "
                                                                    "`tags` "
                                                                    "are "
                                                                    "applied.",
                                                                    "example": "s3",
                                                                    "type": "string",
                                                                },
                                                                "tags": {
                                                                    "description": "The "
                                                                    "AWS "
                                                                    "resource "
                                                                    "tags "
                                                                    "to "
                                                                    "filter "
                                                                    "on "
                                                                    "for "
                                                                    "the "
                                                                    "log "
                                                                    "source "
                                                                    "specified "
                                                                    "by "
                                                                    "`source`.",
                                                                    "items": {
                                                                        "description": "Tag "
                                                                        "in "
                                                                        "the "
                                                                        "form "
                                                                        "`key:value`.",
                                                                        "example": "env:prod",
                                                                        "type": "string",
                                                                    },
                                                                    "nullable": True,
                                                                    "type": "array",
                                                                },
                                                            },
                                                            "type": "object",
                                                        },
                                                        "type": "array",
                                                    }
                                                },
                                                "type": "object",
                                            },
                                            "sources": {
                                                "description": "List "
                                                "of "
                                                "service "
                                                "IDs "
                                                "set "
                                                "to "
                                                "enable "
                                                "automatic "
                                                "log "
                                                "collection. "
                                                "Discover "
                                                "the "
                                                "list "
                                                "of "
                                                "available "
                                                "services "
                                                "with "
                                                "the\n"
                                                "[Get "
                                                "list "
                                                "of "
                                                "AWS "
                                                "log "
                                                "ready "
                                                "services](https://docs.datadoghq.com/api/latest/aws-logs-integration/#get-list-of-aws-log-ready-services) "
                                                "endpoint.",
                                                "items": {"example": "s3", "type": "string"},
                                                "type": "array",
                                            },
                                        },
                                        "type": "object",
                                    }
                                },
                                "type": "object",
                            },
                            "metrics_config": {
                                "description": "AWS Metrics Collection config.",
                                "properties": {
                                    "automute_enabled": {
                                        "description": "Enable "
                                        "EC2 "
                                        "automute "
                                        "for "
                                        "AWS "
                                        "metrics. "
                                        "Defaults "
                                        "to "
                                        "`true`.",
                                        "example": True,
                                        "type": "boolean",
                                    },
                                    "collect_cloudwatch_alarms": {
                                        "description": "Enable "
                                        "CloudWatch "
                                        "alarms "
                                        "collection. "
                                        "Defaults "
                                        "to "
                                        "`false`.",
                                        "example": False,
                                        "type": "boolean",
                                    },
                                    "collect_custom_metrics": {
                                        "description": "Enable "
                                        "custom "
                                        "metrics "
                                        "collection. "
                                        "Defaults "
                                        "to "
                                        "`false`.",
                                        "example": False,
                                        "type": "boolean",
                                    },
                                    "enabled": {
                                        "description": "Enable "
                                        "AWS "
                                        "metrics "
                                        "collection. "
                                        "Defaults "
                                        "to "
                                        "`true`.",
                                        "example": True,
                                        "type": "boolean",
                                    },
                                    "namespace_filters": {
                                        "description": "AWS "
                                        "Metrics "
                                        "namespace "
                                        "filters. "
                                        "Defaults "
                                        "to "
                                        "`exclude_only`.",
                                        "oneOf": [
                                            {
                                                "description": "Exclude "
                                                "only "
                                                "these "
                                                "namespaces "
                                                "from "
                                                "metrics "
                                                "collection. "
                                                "Defaults "
                                                "to "
                                                '`["AWS/SQS", '
                                                '"AWS/ElasticMapReduce", '
                                                '"AWS/Usage"]`.\n'
                                                "`AWS/SQS`, "
                                                "`AWS/ElasticMapReduce`, "
                                                "and "
                                                "`AWS/Usage` "
                                                "are "
                                                "excluded "
                                                "by "
                                                "default "
                                                "to "
                                                "reduce "
                                                "your "
                                                "AWS "
                                                "CloudWatch "
                                                "costs "
                                                "from "
                                                "`GetMetricData` "
                                                "API "
                                                "calls.",
                                                "properties": {
                                                    "exclude_only": {
                                                        "description": "Exclude "
                                                        "only "
                                                        "these "
                                                        "namespaces "
                                                        "from "
                                                        "metrics "
                                                        "collection. "
                                                        "Defaults "
                                                        "to "
                                                        '`["AWS/SQS", '
                                                        '"AWS/ElasticMapReduce", '
                                                        '"AWS/Usage"]`.\n'
                                                        "`AWS/SQS`, "
                                                        "`AWS/ElasticMapReduce`, "
                                                        "and "
                                                        "`AWS/Usage` "
                                                        "are "
                                                        "excluded "
                                                        "by "
                                                        "default "
                                                        "to "
                                                        "reduce "
                                                        "your "
                                                        "AWS "
                                                        "CloudWatch "
                                                        "costs "
                                                        "from "
                                                        "`GetMetricData` "
                                                        "API "
                                                        "calls.",
                                                        "example": [
                                                            "AWS/SQS",
                                                            "AWS/ElasticMapReduce",
                                                            "AWS/Usage",
                                                        ],
                                                        "items": {
                                                            "example": "AWS/SQS",
                                                            "type": "string",
                                                        },
                                                        "type": "array",
                                                    }
                                                },
                                                "required": ["exclude_only"],
                                                "type": "object",
                                            },
                                            {
                                                "description": "Include only these namespaces.",
                                                "properties": {
                                                    "include_only": {
                                                        "description": "Include "
                                                        "only "
                                                        "these "
                                                        "namespaces.",
                                                        "example": ["AWS/EC2"],
                                                        "items": {
                                                            "example": "AWS/EC2",
                                                            "type": "string",
                                                        },
                                                        "type": "array",
                                                    }
                                                },
                                                "required": ["include_only"],
                                                "type": "object",
                                            },
                                        ],
                                    },
                                    "tag_filters": {
                                        "description": "AWS "
                                        "Metrics "
                                        "collection "
                                        "tag "
                                        "filters "
                                        "list. "
                                        "Defaults "
                                        "to "
                                        "`[]`.",
                                        "items": {
                                            "description": "AWS "
                                            "Metrics "
                                            "Collection "
                                            "tag "
                                            "filters "
                                            "list. "
                                            "Defaults "
                                            "to "
                                            "`[]`.\n"
                                            "The "
                                            "array "
                                            "of "
                                            "custom "
                                            "AWS "
                                            "resource "
                                            "tags "
                                            "(in "
                                            "the "
                                            "form "
                                            "`key:value`) "
                                            "defines "
                                            "a "
                                            "filter "
                                            "that "
                                            "Datadog "
                                            "uses "
                                            "when "
                                            "collecting "
                                            "metrics "
                                            "from "
                                            "a "
                                            "specified "
                                            "service.\n"
                                            "Wildcards, "
                                            "such "
                                            "as "
                                            "`?` "
                                            "(match "
                                            "a "
                                            "single "
                                            "character) "
                                            "and "
                                            "`*` "
                                            "(match "
                                            "multiple "
                                            "characters), "
                                            "and "
                                            "exclusion "
                                            "using "
                                            "`!` "
                                            "before "
                                            "the "
                                            "tag "
                                            "are "
                                            "supported.\n"
                                            "For "
                                            "EC2, "
                                            "only "
                                            "hosts "
                                            "that "
                                            "match "
                                            "one "
                                            "of "
                                            "the "
                                            "defined "
                                            "tags "
                                            "will "
                                            "be "
                                            "imported "
                                            "into "
                                            "Datadog. "
                                            "The "
                                            "rest "
                                            "will "
                                            "be "
                                            "ignored.\n"
                                            "For "
                                            "example, "
                                            "`env:production,instance-type:c?.*,!region:us-east-1`.",
                                            "properties": {
                                                "namespace": {
                                                    "description": "The "
                                                    "AWS "
                                                    "service "
                                                    "for "
                                                    "which "
                                                    "the "
                                                    "tag "
                                                    "filters "
                                                    "defined "
                                                    "in "
                                                    "`tags` "
                                                    "will "
                                                    "be "
                                                    "applied.",
                                                    "example": "AWS/EC2",
                                                    "type": "string",
                                                },
                                                "tags": {
                                                    "description": "The "
                                                    "AWS "
                                                    "resource "
                                                    "tags "
                                                    "to "
                                                    "filter "
                                                    "on "
                                                    "for "
                                                    "the "
                                                    "service "
                                                    "specified "
                                                    "by "
                                                    "`namespace`.",
                                                    "items": {
                                                        "description": "Tag "
                                                        "in "
                                                        "the "
                                                        "form "
                                                        "`key:value`.",
                                                        "example": "datadog:true",
                                                        "type": "string",
                                                    },
                                                    "nullable": True,
                                                    "type": "array",
                                                },
                                            },
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                },
                                "type": "object",
                            },
                            "resources_config": {
                                "description": "AWS Resources Collection config.",
                                "properties": {
                                    "cloud_security_posture_management_collection": {
                                        "description": "Enable "
                                        "Cloud "
                                        "Security "
                                        "Management "
                                        "to "
                                        "scan "
                                        "AWS "
                                        "resources "
                                        "for "
                                        "vulnerabilities, "
                                        "misconfigurations, "
                                        "identity "
                                        "risks, "
                                        "and "
                                        "compliance "
                                        "violations. "
                                        "Defaults "
                                        "to "
                                        "`false`. "
                                        "Requires "
                                        "`extended_collection` "
                                        "to "
                                        "be "
                                        "set "
                                        "to "
                                        "`true`.",
                                        "example": False,
                                        "type": "boolean",
                                    },
                                    "extended_collection": {
                                        "description": "Whether "
                                        "Datadog "
                                        "collects "
                                        "additional "
                                        "attributes "
                                        "and "
                                        "configuration "
                                        "information "
                                        "about "
                                        "the "
                                        "resources "
                                        "in "
                                        "your "
                                        "AWS "
                                        "account. "
                                        "Defaults "
                                        "to "
                                        "`true`. "
                                        "Required "
                                        "for "
                                        "`cloud_security_posture_management_collection`.",
                                        "example": True,
                                        "type": "boolean",
                                    },
                                },
                                "type": "object",
                            },
                            "traces_config": {
                                "description": "AWS Traces Collection config.",
                                "properties": {
                                    "xray_services": {
                                        "description": "AWS "
                                        "X-Ray "
                                        "services "
                                        "to "
                                        "collect "
                                        "traces "
                                        "from. "
                                        "Defaults "
                                        "to "
                                        "`include_only`.",
                                        "oneOf": [
                                            {
                                                "description": "Include all services.",
                                                "properties": {
                                                    "include_all": {
                                                        "description": "Include all services.",
                                                        "example": False,
                                                        "type": "boolean",
                                                    }
                                                },
                                                "required": ["include_all"],
                                                "type": "object",
                                            },
                                            {
                                                "description": "Include "
                                                "only "
                                                "these "
                                                "services. "
                                                "Defaults "
                                                "to "
                                                "`[]`.",
                                                "nullable": True,
                                                "properties": {
                                                    "include_only": {
                                                        "description": "Include "
                                                        "only "
                                                        "these "
                                                        "services.",
                                                        "example": ["AWS/AppSync"],
                                                        "items": {
                                                            "example": "AWS/AppSync",
                                                            "type": "string",
                                                        },
                                                        "type": "array",
                                                    }
                                                },
                                                "required": ["include_only"],
                                                "type": "object",
                                            },
                                        ],
                                    }
                                },
                                "type": "object",
                            },
                        },
                        "required": ["aws_account_id", "aws_partition", "auth_config"],
                        "type": "object",
                    },
                    "type": {
                        "default": "account",
                        "description": "AWS Account resource type.",
                        "enum": ["account"],
                        "example": "account",
                        "type": "string",
                        "x-enum-varnames": ["ACCOUNT"],
                    },
                },
                "required": ["attributes", "type"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "UPDATEAWSACCOUNTINTEGRATION_REQUEST_BODY_SCHEMA": {
        "description": "AWS Account Update Request body.",
        "properties": {
            "data": {
                "description": "AWS Account Update Request data.",
                "properties": {
                    "attributes": {
                        "description": "The AWS Account Integration Config to be updated.",
                        "properties": {
                            "account_tags": {
                                "description": "Tags "
                                "to "
                                "apply "
                                "to "
                                "all "
                                "hosts "
                                "and "
                                "metrics "
                                "reporting "
                                "for "
                                "this "
                                "account. "
                                "Defaults "
                                "to "
                                "`[]`.",
                                "items": {
                                    "description": "Tag in the form `key:value`.",
                                    "example": "env:prod",
                                    "type": "string",
                                },
                                "nullable": True,
                                "type": "array",
                            },
                            "auth_config": {
                                "description": "AWS Authentication config.",
                                "oneOf": [
                                    {
                                        "description": "AWS "
                                        "Authentication "
                                        "config "
                                        "to "
                                        "integrate "
                                        "your "
                                        "account "
                                        "using "
                                        "an "
                                        "access "
                                        "key "
                                        "pair.",
                                        "properties": {
                                            "access_key_id": {
                                                "description": "AWS Access Key ID.",
                                                "example": "AKIAIOSFODNN7EXAMPLE",
                                                "type": "string",
                                            },
                                            "secret_access_key": {
                                                "description": "AWS Secret Access Key.",
                                                "example": "wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMPLEKEY",
                                                "minLength": 1,
                                                "type": "string",
                                                "writeOnly": True,
                                            },
                                        },
                                        "required": ["access_key_id"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "AWS "
                                        "Authentication "
                                        "config "
                                        "to "
                                        "integrate "
                                        "your "
                                        "account "
                                        "using "
                                        "an "
                                        "IAM "
                                        "role.",
                                        "properties": {
                                            "external_id": {
                                                "description": "AWS "
                                                "IAM "
                                                "External "
                                                "ID "
                                                "for "
                                                "associated "
                                                "role.",
                                                "type": "string",
                                            },
                                            "role_name": {
                                                "description": "AWS IAM Role name.",
                                                "example": "DatadogIntegrationRole",
                                                "maxLength": 576,
                                                "minLength": 1,
                                                "type": "string",
                                            },
                                        },
                                        "required": ["role_name"],
                                        "type": "object",
                                    },
                                ],
                            },
                            "aws_account_id": {
                                "description": "AWS Account ID.",
                                "example": "123456789012",
                                "type": "string",
                            },
                            "aws_partition": {
                                "description": "AWS "
                                "partition "
                                "your "
                                "AWS "
                                "account "
                                "is "
                                "scoped "
                                "to. "
                                "Defaults "
                                "to "
                                "`aws`.\n"
                                "See "
                                "[Partitions](https://docs.aws.amazon.com/whitepapers/latest/aws-fault-isolation-boundaries/partitions.html) "
                                "in "
                                "the "
                                "AWS "
                                "documentation "
                                "for "
                                "more "
                                "information.",
                                "enum": ["aws", "aws-cn", "aws-us-gov"],
                                "example": "aws",
                                "type": "string",
                                "x-enum-varnames": ["AWS", "AWS_CN", "AWS_US_GOV"],
                            },
                            "aws_regions": {
                                "description": "AWS "
                                "Regions "
                                "to "
                                "collect "
                                "data "
                                "from. "
                                "Defaults "
                                "to "
                                "`include_all`.",
                                "oneOf": [
                                    {
                                        "description": "Include all regions. Defaults to `true`.",
                                        "properties": {
                                            "include_all": {
                                                "description": "Include all regions.",
                                                "example": True,
                                                "type": "boolean",
                                            }
                                        },
                                        "required": ["include_all"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "Include only these regions.",
                                        "properties": {
                                            "include_only": {
                                                "description": "Include only these regions.",
                                                "example": ["us-east-1"],
                                                "items": {"example": "us-east-1", "type": "string"},
                                                "type": "array",
                                            }
                                        },
                                        "required": ["include_only"],
                                        "type": "object",
                                    },
                                ],
                            },
                            "logs_config": {
                                "description": "AWS Logs Collection config.",
                                "properties": {
                                    "lambda_forwarder": {
                                        "description": "Log "
                                        "Autosubscription "
                                        "configuration "
                                        "for "
                                        "Datadog "
                                        "Forwarder "
                                        "Lambda "
                                        "functions. "
                                        "Automatically "
                                        "set "
                                        "up "
                                        "triggers "
                                        "for "
                                        "existing\n"
                                        "and "
                                        "new "
                                        "logs "
                                        "for "
                                        "some "
                                        "services, "
                                        "ensuring "
                                        "no "
                                        "logs "
                                        "from "
                                        "new "
                                        "resources "
                                        "are "
                                        "missed "
                                        "and "
                                        "saving "
                                        "time "
                                        "spent "
                                        "on "
                                        "manual "
                                        "configuration.",
                                        "properties": {
                                            "lambdas": {
                                                "description": "List "
                                                "of "
                                                "Datadog "
                                                "Lambda "
                                                "Log "
                                                "Forwarder "
                                                "ARNs "
                                                "in "
                                                "your "
                                                "AWS "
                                                "account. "
                                                "Defaults "
                                                "to "
                                                "`[]`.",
                                                "items": {
                                                    "example": "arn:aws:lambda:us-east-1:123456789012:function:DatadogLambdaLogForwarder",
                                                    "type": "string",
                                                },
                                                "type": "array",
                                            },
                                            "log_source_config": {
                                                "description": "Log source configuration.",
                                                "properties": {
                                                    "tag_filters": {
                                                        "description": "List "
                                                        "of "
                                                        "AWS "
                                                        "log "
                                                        "source "
                                                        "tag "
                                                        "filters. "
                                                        "Defaults "
                                                        "to "
                                                        "`[]`.",
                                                        "items": {
                                                            "description": "AWS "
                                                            "log "
                                                            "source "
                                                            "tag "
                                                            "filter "
                                                            "list. "
                                                            "Defaults "
                                                            "to "
                                                            "`[]`.\n"
                                                            "Array "
                                                            "of "
                                                            "log "
                                                            "source "
                                                            "to "
                                                            "AWS "
                                                            "resource "
                                                            "tag "
                                                            "mappings. "
                                                            "Each "
                                                            "mapping "
                                                            "contains "
                                                            "a "
                                                            "log "
                                                            "source "
                                                            "and "
                                                            "its "
                                                            "associated "
                                                            "AWS "
                                                            "resource "
                                                            "tags "
                                                            "(in "
                                                            "`key:value` "
                                                            "format) "
                                                            "used "
                                                            "to "
                                                            "filter "
                                                            "logs "
                                                            "submitted "
                                                            "to "
                                                            "Datadog.\n"
                                                            "Tag "
                                                            "filters "
                                                            "are "
                                                            "applied "
                                                            "for "
                                                            "tags "
                                                            "on "
                                                            "the "
                                                            "AWS "
                                                            "resource "
                                                            "emitting "
                                                            "logs; "
                                                            "tags "
                                                            "associated "
                                                            "with "
                                                            "the "
                                                            "log "
                                                            "storage "
                                                            "entity "
                                                            "(such "
                                                            "as "
                                                            "a "
                                                            "CloudWatch "
                                                            "Log "
                                                            "Group "
                                                            "or "
                                                            "S3 "
                                                            "Bucket) "
                                                            "are "
                                                            "not "
                                                            "considered.\n"
                                                            "For "
                                                            "more "
                                                            "information "
                                                            "on "
                                                            "resource "
                                                            "tag "
                                                            "filter "
                                                            "syntax, "
                                                            "[see "
                                                            "AWS "
                                                            "resource "
                                                            "exclusion](https://docs.datadoghq.com/account_management/billing/aws/#aws-resource-exclusion) "
                                                            "in "
                                                            "the "
                                                            "AWS "
                                                            "integration "
                                                            "billing "
                                                            "page.",
                                                            "properties": {
                                                                "source": {
                                                                    "description": "The "
                                                                    "AWS "
                                                                    "log "
                                                                    "source "
                                                                    "to "
                                                                    "which "
                                                                    "the "
                                                                    "tag "
                                                                    "filters "
                                                                    "defined "
                                                                    "in "
                                                                    "`tags` "
                                                                    "are "
                                                                    "applied.",
                                                                    "example": "s3",
                                                                    "type": "string",
                                                                },
                                                                "tags": {
                                                                    "description": "The "
                                                                    "AWS "
                                                                    "resource "
                                                                    "tags "
                                                                    "to "
                                                                    "filter "
                                                                    "on "
                                                                    "for "
                                                                    "the "
                                                                    "log "
                                                                    "source "
                                                                    "specified "
                                                                    "by "
                                                                    "`source`.",
                                                                    "items": {
                                                                        "description": "Tag "
                                                                        "in "
                                                                        "the "
                                                                        "form "
                                                                        "`key:value`.",
                                                                        "example": "env:prod",
                                                                        "type": "string",
                                                                    },
                                                                    "nullable": True,
                                                                    "type": "array",
                                                                },
                                                            },
                                                            "type": "object",
                                                        },
                                                        "type": "array",
                                                    }
                                                },
                                                "type": "object",
                                            },
                                            "sources": {
                                                "description": "List "
                                                "of "
                                                "service "
                                                "IDs "
                                                "set "
                                                "to "
                                                "enable "
                                                "automatic "
                                                "log "
                                                "collection. "
                                                "Discover "
                                                "the "
                                                "list "
                                                "of "
                                                "available "
                                                "services "
                                                "with "
                                                "the\n"
                                                "[Get "
                                                "list "
                                                "of "
                                                "AWS "
                                                "log "
                                                "ready "
                                                "services](https://docs.datadoghq.com/api/latest/aws-logs-integration/#get-list-of-aws-log-ready-services) "
                                                "endpoint.",
                                                "items": {"example": "s3", "type": "string"},
                                                "type": "array",
                                            },
                                        },
                                        "type": "object",
                                    }
                                },
                                "type": "object",
                            },
                            "metrics_config": {
                                "description": "AWS Metrics Collection config.",
                                "properties": {
                                    "automute_enabled": {
                                        "description": "Enable "
                                        "EC2 "
                                        "automute "
                                        "for "
                                        "AWS "
                                        "metrics. "
                                        "Defaults "
                                        "to "
                                        "`true`.",
                                        "example": True,
                                        "type": "boolean",
                                    },
                                    "collect_cloudwatch_alarms": {
                                        "description": "Enable "
                                        "CloudWatch "
                                        "alarms "
                                        "collection. "
                                        "Defaults "
                                        "to "
                                        "`false`.",
                                        "example": False,
                                        "type": "boolean",
                                    },
                                    "collect_custom_metrics": {
                                        "description": "Enable "
                                        "custom "
                                        "metrics "
                                        "collection. "
                                        "Defaults "
                                        "to "
                                        "`false`.",
                                        "example": False,
                                        "type": "boolean",
                                    },
                                    "enabled": {
                                        "description": "Enable "
                                        "AWS "
                                        "metrics "
                                        "collection. "
                                        "Defaults "
                                        "to "
                                        "`true`.",
                                        "example": True,
                                        "type": "boolean",
                                    },
                                    "namespace_filters": {
                                        "description": "AWS "
                                        "Metrics "
                                        "namespace "
                                        "filters. "
                                        "Defaults "
                                        "to "
                                        "`exclude_only`.",
                                        "oneOf": [
                                            {
                                                "description": "Exclude "
                                                "only "
                                                "these "
                                                "namespaces "
                                                "from "
                                                "metrics "
                                                "collection. "
                                                "Defaults "
                                                "to "
                                                '`["AWS/SQS", '
                                                '"AWS/ElasticMapReduce", '
                                                '"AWS/Usage"]`.\n'
                                                "`AWS/SQS`, "
                                                "`AWS/ElasticMapReduce`, "
                                                "and "
                                                "`AWS/Usage` "
                                                "are "
                                                "excluded "
                                                "by "
                                                "default "
                                                "to "
                                                "reduce "
                                                "your "
                                                "AWS "
                                                "CloudWatch "
                                                "costs "
                                                "from "
                                                "`GetMetricData` "
                                                "API "
                                                "calls.",
                                                "properties": {
                                                    "exclude_only": {
                                                        "description": "Exclude "
                                                        "only "
                                                        "these "
                                                        "namespaces "
                                                        "from "
                                                        "metrics "
                                                        "collection. "
                                                        "Defaults "
                                                        "to "
                                                        '`["AWS/SQS", '
                                                        '"AWS/ElasticMapReduce", '
                                                        '"AWS/Usage"]`.\n'
                                                        "`AWS/SQS`, "
                                                        "`AWS/ElasticMapReduce`, "
                                                        "and "
                                                        "`AWS/Usage` "
                                                        "are "
                                                        "excluded "
                                                        "by "
                                                        "default "
                                                        "to "
                                                        "reduce "
                                                        "your "
                                                        "AWS "
                                                        "CloudWatch "
                                                        "costs "
                                                        "from "
                                                        "`GetMetricData` "
                                                        "API "
                                                        "calls.",
                                                        "example": [
                                                            "AWS/SQS",
                                                            "AWS/ElasticMapReduce",
                                                            "AWS/Usage",
                                                        ],
                                                        "items": {
                                                            "example": "AWS/SQS",
                                                            "type": "string",
                                                        },
                                                        "type": "array",
                                                    }
                                                },
                                                "required": ["exclude_only"],
                                                "type": "object",
                                            },
                                            {
                                                "description": "Include only these namespaces.",
                                                "properties": {
                                                    "include_only": {
                                                        "description": "Include "
                                                        "only "
                                                        "these "
                                                        "namespaces.",
                                                        "example": ["AWS/EC2"],
                                                        "items": {
                                                            "example": "AWS/EC2",
                                                            "type": "string",
                                                        },
                                                        "type": "array",
                                                    }
                                                },
                                                "required": ["include_only"],
                                                "type": "object",
                                            },
                                        ],
                                    },
                                    "tag_filters": {
                                        "description": "AWS "
                                        "Metrics "
                                        "collection "
                                        "tag "
                                        "filters "
                                        "list. "
                                        "Defaults "
                                        "to "
                                        "`[]`.",
                                        "items": {
                                            "description": "AWS "
                                            "Metrics "
                                            "Collection "
                                            "tag "
                                            "filters "
                                            "list. "
                                            "Defaults "
                                            "to "
                                            "`[]`.\n"
                                            "The "
                                            "array "
                                            "of "
                                            "custom "
                                            "AWS "
                                            "resource "
                                            "tags "
                                            "(in "
                                            "the "
                                            "form "
                                            "`key:value`) "
                                            "defines "
                                            "a "
                                            "filter "
                                            "that "
                                            "Datadog "
                                            "uses "
                                            "when "
                                            "collecting "
                                            "metrics "
                                            "from "
                                            "a "
                                            "specified "
                                            "service.\n"
                                            "Wildcards, "
                                            "such "
                                            "as "
                                            "`?` "
                                            "(match "
                                            "a "
                                            "single "
                                            "character) "
                                            "and "
                                            "`*` "
                                            "(match "
                                            "multiple "
                                            "characters), "
                                            "and "
                                            "exclusion "
                                            "using "
                                            "`!` "
                                            "before "
                                            "the "
                                            "tag "
                                            "are "
                                            "supported.\n"
                                            "For "
                                            "EC2, "
                                            "only "
                                            "hosts "
                                            "that "
                                            "match "
                                            "one "
                                            "of "
                                            "the "
                                            "defined "
                                            "tags "
                                            "will "
                                            "be "
                                            "imported "
                                            "into "
                                            "Datadog. "
                                            "The "
                                            "rest "
                                            "will "
                                            "be "
                                            "ignored.\n"
                                            "For "
                                            "example, "
                                            "`env:production,instance-type:c?.*,!region:us-east-1`.",
                                            "properties": {
                                                "namespace": {
                                                    "description": "The "
                                                    "AWS "
                                                    "service "
                                                    "for "
                                                    "which "
                                                    "the "
                                                    "tag "
                                                    "filters "
                                                    "defined "
                                                    "in "
                                                    "`tags` "
                                                    "will "
                                                    "be "
                                                    "applied.",
                                                    "example": "AWS/EC2",
                                                    "type": "string",
                                                },
                                                "tags": {
                                                    "description": "The "
                                                    "AWS "
                                                    "resource "
                                                    "tags "
                                                    "to "
                                                    "filter "
                                                    "on "
                                                    "for "
                                                    "the "
                                                    "service "
                                                    "specified "
                                                    "by "
                                                    "`namespace`.",
                                                    "items": {
                                                        "description": "Tag "
                                                        "in "
                                                        "the "
                                                        "form "
                                                        "`key:value`.",
                                                        "example": "datadog:true",
                                                        "type": "string",
                                                    },
                                                    "nullable": True,
                                                    "type": "array",
                                                },
                                            },
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                },
                                "type": "object",
                            },
                            "resources_config": {
                                "description": "AWS Resources Collection config.",
                                "properties": {
                                    "cloud_security_posture_management_collection": {
                                        "description": "Enable "
                                        "Cloud "
                                        "Security "
                                        "Management "
                                        "to "
                                        "scan "
                                        "AWS "
                                        "resources "
                                        "for "
                                        "vulnerabilities, "
                                        "misconfigurations, "
                                        "identity "
                                        "risks, "
                                        "and "
                                        "compliance "
                                        "violations. "
                                        "Defaults "
                                        "to "
                                        "`false`. "
                                        "Requires "
                                        "`extended_collection` "
                                        "to "
                                        "be "
                                        "set "
                                        "to "
                                        "`true`.",
                                        "example": False,
                                        "type": "boolean",
                                    },
                                    "extended_collection": {
                                        "description": "Whether "
                                        "Datadog "
                                        "collects "
                                        "additional "
                                        "attributes "
                                        "and "
                                        "configuration "
                                        "information "
                                        "about "
                                        "the "
                                        "resources "
                                        "in "
                                        "your "
                                        "AWS "
                                        "account. "
                                        "Defaults "
                                        "to "
                                        "`true`. "
                                        "Required "
                                        "for "
                                        "`cloud_security_posture_management_collection`.",
                                        "example": True,
                                        "type": "boolean",
                                    },
                                },
                                "type": "object",
                            },
                            "traces_config": {
                                "description": "AWS Traces Collection config.",
                                "properties": {
                                    "xray_services": {
                                        "description": "AWS "
                                        "X-Ray "
                                        "services "
                                        "to "
                                        "collect "
                                        "traces "
                                        "from. "
                                        "Defaults "
                                        "to "
                                        "`include_only`.",
                                        "oneOf": [
                                            {
                                                "description": "Include all services.",
                                                "properties": {
                                                    "include_all": {
                                                        "description": "Include all services.",
                                                        "example": False,
                                                        "type": "boolean",
                                                    }
                                                },
                                                "required": ["include_all"],
                                                "type": "object",
                                            },
                                            {
                                                "description": "Include "
                                                "only "
                                                "these "
                                                "services. "
                                                "Defaults "
                                                "to "
                                                "`[]`.",
                                                "nullable": True,
                                                "properties": {
                                                    "include_only": {
                                                        "description": "Include "
                                                        "only "
                                                        "these "
                                                        "services.",
                                                        "example": ["AWS/AppSync"],
                                                        "items": {
                                                            "example": "AWS/AppSync",
                                                            "type": "string",
                                                        },
                                                        "type": "array",
                                                    }
                                                },
                                                "required": ["include_only"],
                                                "type": "object",
                                            },
                                        ],
                                    }
                                },
                                "type": "object",
                            },
                        },
                        "required": ["aws_account_id"],
                        "type": "object",
                    },
                    "id": {
                        "description": "Unique Datadog ID of "
                        "the AWS Account "
                        "Integration Config.\n"
                        "To get the config ID "
                        "for an account, use the "
                        "[List all AWS "
                        "integrations](https://docs.datadoghq.com/api/latest/aws-integration/#list-all-aws-integrations)\n"
                        "endpoint and query by "
                        "AWS Account ID.",
                        "example": "00000000-abcd-0001-0000-000000000000",
                        "type": "string",
                    },
                    "type": {
                        "default": "account",
                        "description": "AWS Account resource type.",
                        "enum": ["account"],
                        "example": "account",
                        "type": "string",
                        "x-enum-varnames": ["ACCOUNT"],
                    },
                },
                "required": ["attributes", "type"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "CREATEGCPSTSACCOUNT_REQUEST_BODY_SCHEMA": {
        "description": "Data on your newly generated service account.",
        "properties": {
            "data": {
                "description": "Additional metadata on your generated service account.",
                "properties": {
                    "attributes": {
                        "description": "Attributes associated with your service account.",
                        "properties": {
                            "account_tags": {
                                "description": "Tags "
                                "to "
                                "be "
                                "associated "
                                "with "
                                "GCP "
                                "metrics "
                                "and "
                                "service "
                                "checks "
                                "from "
                                "your "
                                "account.",
                                "items": {"description": "Account Level Tag", "type": "string"},
                                "type": "array",
                            },
                            "automute": {
                                "description": "Silence "
                                "monitors "
                                "for "
                                "expected "
                                "GCE "
                                "instance "
                                "shutdowns.",
                                "type": "boolean",
                            },
                            "client_email": {
                                "description": "Your service account email address.",
                                "example": "datadog-service-account@test-project.iam.gserviceaccount.com",
                                "type": "string",
                            },
                            "cloud_run_revision_filters": {
                                "deprecated": True,
                                "description": "List "
                                "of "
                                "filters "
                                "to "
                                "limit "
                                "the "
                                "Cloud "
                                "Run "
                                "revisions "
                                "that "
                                "are "
                                "pulled "
                                "into "
                                "Datadog "
                                "by "
                                "using "
                                "tags.\n"
                                "Only "
                                "Cloud "
                                "Run "
                                "revision "
                                "resources "
                                "that "
                                "apply "
                                "to "
                                "specified "
                                "filters "
                                "are "
                                "imported "
                                "into "
                                "Datadog.\n"
                                "**Note:** "
                                "This "
                                "field "
                                "is "
                                "deprecated. "
                                "Instead, "
                                "use "
                                "`monitored_resource_configs` "
                                "with "
                                "`type=cloud_run_revision`",
                                "example": ["$KEY:$VALUE"],
                                "items": {
                                    "description": "Cloud Run revision filters",
                                    "type": "string",
                                },
                                "type": "array",
                            },
                            "host_filters": {
                                "deprecated": True,
                                "description": "List "
                                "of "
                                "filters "
                                "to "
                                "limit "
                                "the "
                                "VM "
                                "instances "
                                "that "
                                "are "
                                "pulled "
                                "into "
                                "Datadog "
                                "by "
                                "using "
                                "tags.\n"
                                "Only "
                                "VM "
                                "instance "
                                "resources "
                                "that "
                                "apply "
                                "to "
                                "specified "
                                "filters "
                                "are "
                                "imported "
                                "into "
                                "Datadog.\n"
                                "**Note:** "
                                "This "
                                "field "
                                "is "
                                "deprecated. "
                                "Instead, "
                                "use "
                                "`monitored_resource_configs` "
                                "with "
                                "`type=gce_instance`",
                                "example": ["$KEY:$VALUE"],
                                "items": {"description": "VM instance filters", "type": "string"},
                                "type": "array",
                            },
                            "is_cspm_enabled": {
                                "description": "When "
                                "enabled, "
                                "Datadog "
                                "will "
                                "activate "
                                "the "
                                "Cloud "
                                "Security "
                                "Monitoring "
                                "product "
                                "for "
                                "this "
                                "service "
                                "account. "
                                "Note: "
                                "This "
                                "requires "
                                "resource_collection_enabled "
                                "to "
                                "be "
                                "set "
                                "to "
                                "true.",
                                "type": "boolean",
                            },
                            "is_per_project_quota_enabled": {
                                "default": False,
                                "description": "When "
                                "enabled, "
                                "Datadog "
                                "applies "
                                "the "
                                "`X-Goog-User-Project` "
                                "header, "
                                "attributing "
                                "Google "
                                "Cloud "
                                "billing "
                                "and "
                                "quota "
                                "usage "
                                "to "
                                "the "
                                "project "
                                "being "
                                "monitored "
                                "rather "
                                "than "
                                "the "
                                "default "
                                "service "
                                "account "
                                "project.",
                                "example": True,
                                "type": "boolean",
                            },
                            "is_resource_change_collection_enabled": {
                                "default": False,
                                "description": "When "
                                "enabled, "
                                "Datadog "
                                "scans "
                                "for "
                                "all "
                                "resource "
                                "change "
                                "data "
                                "in "
                                "your "
                                "Google "
                                "Cloud "
                                "environment.",
                                "example": True,
                                "type": "boolean",
                            },
                            "is_security_command_center_enabled": {
                                "default": False,
                                "description": "When "
                                "enabled, "
                                "Datadog "
                                "will "
                                "attempt "
                                "to "
                                "collect "
                                "Security "
                                "Command "
                                "Center "
                                "Findings. "
                                "Note: "
                                "This "
                                "requires "
                                "additional "
                                "permissions "
                                "on "
                                "the "
                                "service "
                                "account.",
                                "example": True,
                                "type": "boolean",
                            },
                            "metric_namespace_configs": {
                                "description": "Configurations for GCP metric namespaces.",
                                "example": [{"disabled": True, "id": "aiplatform"}],
                                "items": {
                                    "description": "Configuration for a GCP metric namespace.",
                                    "properties": {
                                        "disabled": {
                                            "default": False,
                                            "description": "When "
                                            "disabled, "
                                            "Datadog "
                                            "does "
                                            "not "
                                            "collect "
                                            "metrics "
                                            "that "
                                            "are "
                                            "related "
                                            "to "
                                            "this "
                                            "GCP "
                                            "metric "
                                            "namespace.",
                                            "example": True,
                                            "type": "boolean",
                                        },
                                        "id": {
                                            "description": "The id of the GCP metric namespace.",
                                            "example": "aiplatform",
                                            "type": "string",
                                        },
                                    },
                                    "type": "object",
                                },
                                "type": "array",
                            },
                            "monitored_resource_configs": {
                                "description": "Configurations for GCP monitored resources.",
                                "example": [{"filters": ["$KEY:$VALUE"], "type": "gce_instance"}],
                                "items": {
                                    "description": "Configuration for a GCP monitored resource.",
                                    "properties": {
                                        "filters": {
                                            "description": "List "
                                            "of "
                                            "filters "
                                            "to "
                                            "limit "
                                            "the "
                                            "monitored "
                                            "resources "
                                            "that "
                                            "are "
                                            "pulled "
                                            "into "
                                            "Datadog "
                                            "by "
                                            "using "
                                            "tags.\n"
                                            "Only "
                                            "monitored "
                                            "resources "
                                            "that "
                                            "apply "
                                            "to "
                                            "specified "
                                            "filters "
                                            "are "
                                            "imported "
                                            "into "
                                            "Datadog.",
                                            "example": ["$KEY:$VALUE"],
                                            "items": {
                                                "description": "A monitored resource filter",
                                                "type": "string",
                                            },
                                            "type": "array",
                                        },
                                        "type": {
                                            "description": "The "
                                            "GCP "
                                            "monitored "
                                            "resource "
                                            "type. "
                                            "Only "
                                            "a "
                                            "subset "
                                            "of "
                                            "resource "
                                            "types "
                                            "are "
                                            "supported.",
                                            "enum": [
                                                "cloud_function",
                                                "cloud_run_revision",
                                                "gce_instance",
                                            ],
                                            "example": "gce_instance",
                                            "type": "string",
                                            "x-enum-varnames": [
                                                "CLOUD_FUNCTION",
                                                "CLOUD_RUN_REVISION",
                                                "GCE_INSTANCE",
                                            ],
                                        },
                                    },
                                    "type": "object",
                                },
                                "type": "array",
                            },
                            "resource_collection_enabled": {
                                "description": "When "
                                "enabled, "
                                "Datadog "
                                "scans "
                                "for "
                                "all "
                                "resources "
                                "in "
                                "your "
                                "GCP "
                                "environment.",
                                "type": "boolean",
                            },
                        },
                        "type": "object",
                    },
                    "type": {
                        "default": "gcp_service_account",
                        "description": "The type of account.",
                        "enum": ["gcp_service_account"],
                        "example": "gcp_service_account",
                        "type": "string",
                        "x-enum-varnames": ["GCP_SERVICE_ACCOUNT"],
                    },
                },
                "type": "object",
            }
        },
        "type": "object",
    },
    "UPDATEGCPSTSACCOUNT_REQUEST_BODY_SCHEMA": {
        "description": "Service account info.",
        "properties": {
            "data": {
                "description": "Data on your service account.",
                "properties": {
                    "attributes": {
                        "description": "Attributes associated with your service account.",
                        "properties": {
                            "account_tags": {
                                "description": "Tags "
                                "to "
                                "be "
                                "associated "
                                "with "
                                "GCP "
                                "metrics "
                                "and "
                                "service "
                                "checks "
                                "from "
                                "your "
                                "account.",
                                "items": {"description": "Account Level Tag", "type": "string"},
                                "type": "array",
                            },
                            "automute": {
                                "description": "Silence "
                                "monitors "
                                "for "
                                "expected "
                                "GCE "
                                "instance "
                                "shutdowns.",
                                "type": "boolean",
                            },
                            "client_email": {
                                "description": "Your service account email address.",
                                "example": "datadog-service-account@test-project.iam.gserviceaccount.com",
                                "type": "string",
                            },
                            "cloud_run_revision_filters": {
                                "deprecated": True,
                                "description": "List "
                                "of "
                                "filters "
                                "to "
                                "limit "
                                "the "
                                "Cloud "
                                "Run "
                                "revisions "
                                "that "
                                "are "
                                "pulled "
                                "into "
                                "Datadog "
                                "by "
                                "using "
                                "tags.\n"
                                "Only "
                                "Cloud "
                                "Run "
                                "revision "
                                "resources "
                                "that "
                                "apply "
                                "to "
                                "specified "
                                "filters "
                                "are "
                                "imported "
                                "into "
                                "Datadog.\n"
                                "**Note:** "
                                "This "
                                "field "
                                "is "
                                "deprecated. "
                                "Instead, "
                                "use "
                                "`monitored_resource_configs` "
                                "with "
                                "`type=cloud_run_revision`",
                                "example": ["$KEY:$VALUE"],
                                "items": {
                                    "description": "Cloud Run revision filters",
                                    "type": "string",
                                },
                                "type": "array",
                            },
                            "host_filters": {
                                "deprecated": True,
                                "description": "List "
                                "of "
                                "filters "
                                "to "
                                "limit "
                                "the "
                                "VM "
                                "instances "
                                "that "
                                "are "
                                "pulled "
                                "into "
                                "Datadog "
                                "by "
                                "using "
                                "tags.\n"
                                "Only "
                                "VM "
                                "instance "
                                "resources "
                                "that "
                                "apply "
                                "to "
                                "specified "
                                "filters "
                                "are "
                                "imported "
                                "into "
                                "Datadog.\n"
                                "**Note:** "
                                "This "
                                "field "
                                "is "
                                "deprecated. "
                                "Instead, "
                                "use "
                                "`monitored_resource_configs` "
                                "with "
                                "`type=gce_instance`",
                                "example": ["$KEY:$VALUE"],
                                "items": {"description": "VM instance filters", "type": "string"},
                                "type": "array",
                            },
                            "is_cspm_enabled": {
                                "description": "When "
                                "enabled, "
                                "Datadog "
                                "will "
                                "activate "
                                "the "
                                "Cloud "
                                "Security "
                                "Monitoring "
                                "product "
                                "for "
                                "this "
                                "service "
                                "account. "
                                "Note: "
                                "This "
                                "requires "
                                "resource_collection_enabled "
                                "to "
                                "be "
                                "set "
                                "to "
                                "true.",
                                "type": "boolean",
                            },
                            "is_per_project_quota_enabled": {
                                "default": False,
                                "description": "When "
                                "enabled, "
                                "Datadog "
                                "applies "
                                "the "
                                "`X-Goog-User-Project` "
                                "header, "
                                "attributing "
                                "Google "
                                "Cloud "
                                "billing "
                                "and "
                                "quota "
                                "usage "
                                "to "
                                "the "
                                "project "
                                "being "
                                "monitored "
                                "rather "
                                "than "
                                "the "
                                "default "
                                "service "
                                "account "
                                "project.",
                                "example": True,
                                "type": "boolean",
                            },
                            "is_resource_change_collection_enabled": {
                                "default": False,
                                "description": "When "
                                "enabled, "
                                "Datadog "
                                "scans "
                                "for "
                                "all "
                                "resource "
                                "change "
                                "data "
                                "in "
                                "your "
                                "Google "
                                "Cloud "
                                "environment.",
                                "example": True,
                                "type": "boolean",
                            },
                            "is_security_command_center_enabled": {
                                "default": False,
                                "description": "When "
                                "enabled, "
                                "Datadog "
                                "will "
                                "attempt "
                                "to "
                                "collect "
                                "Security "
                                "Command "
                                "Center "
                                "Findings. "
                                "Note: "
                                "This "
                                "requires "
                                "additional "
                                "permissions "
                                "on "
                                "the "
                                "service "
                                "account.",
                                "example": True,
                                "type": "boolean",
                            },
                            "metric_namespace_configs": {
                                "description": "Configurations for GCP metric namespaces.",
                                "example": [{"disabled": True, "id": "aiplatform"}],
                                "items": {
                                    "description": "Configuration for a GCP metric namespace.",
                                    "properties": {
                                        "disabled": {
                                            "default": False,
                                            "description": "When "
                                            "disabled, "
                                            "Datadog "
                                            "does "
                                            "not "
                                            "collect "
                                            "metrics "
                                            "that "
                                            "are "
                                            "related "
                                            "to "
                                            "this "
                                            "GCP "
                                            "metric "
                                            "namespace.",
                                            "example": True,
                                            "type": "boolean",
                                        },
                                        "id": {
                                            "description": "The id of the GCP metric namespace.",
                                            "example": "aiplatform",
                                            "type": "string",
                                        },
                                    },
                                    "type": "object",
                                },
                                "type": "array",
                            },
                            "monitored_resource_configs": {
                                "description": "Configurations for GCP monitored resources.",
                                "example": [{"filters": ["$KEY:$VALUE"], "type": "gce_instance"}],
                                "items": {
                                    "description": "Configuration for a GCP monitored resource.",
                                    "properties": {
                                        "filters": {
                                            "description": "List "
                                            "of "
                                            "filters "
                                            "to "
                                            "limit "
                                            "the "
                                            "monitored "
                                            "resources "
                                            "that "
                                            "are "
                                            "pulled "
                                            "into "
                                            "Datadog "
                                            "by "
                                            "using "
                                            "tags.\n"
                                            "Only "
                                            "monitored "
                                            "resources "
                                            "that "
                                            "apply "
                                            "to "
                                            "specified "
                                            "filters "
                                            "are "
                                            "imported "
                                            "into "
                                            "Datadog.",
                                            "example": ["$KEY:$VALUE"],
                                            "items": {
                                                "description": "A monitored resource filter",
                                                "type": "string",
                                            },
                                            "type": "array",
                                        },
                                        "type": {
                                            "description": "The "
                                            "GCP "
                                            "monitored "
                                            "resource "
                                            "type. "
                                            "Only "
                                            "a "
                                            "subset "
                                            "of "
                                            "resource "
                                            "types "
                                            "are "
                                            "supported.",
                                            "enum": [
                                                "cloud_function",
                                                "cloud_run_revision",
                                                "gce_instance",
                                            ],
                                            "example": "gce_instance",
                                            "type": "string",
                                            "x-enum-varnames": [
                                                "CLOUD_FUNCTION",
                                                "CLOUD_RUN_REVISION",
                                                "GCE_INSTANCE",
                                            ],
                                        },
                                    },
                                    "type": "object",
                                },
                                "type": "array",
                            },
                            "resource_collection_enabled": {
                                "description": "When "
                                "enabled, "
                                "Datadog "
                                "scans "
                                "for "
                                "all "
                                "resources "
                                "in "
                                "your "
                                "GCP "
                                "environment.",
                                "type": "boolean",
                            },
                        },
                        "type": "object",
                    },
                    "id": {
                        "description": "Your service account's unique ID.",
                        "example": "d291291f-12c2-22g4-j290-123456678897",
                        "type": "string",
                    },
                    "type": {
                        "default": "gcp_service_account",
                        "description": "The type of account.",
                        "enum": ["gcp_service_account"],
                        "example": "gcp_service_account",
                        "type": "string",
                        "x-enum-varnames": ["GCP_SERVICE_ACCOUNT"],
                    },
                },
                "type": "object",
            }
        },
        "type": "object",
    },
    "CREATECONFLUENTACCOUNT_REQUEST_BODY_SCHEMA": {
        "description": "Payload schema when adding a Confluent account.",
        "properties": {
            "data": {
                "description": "The data body for adding a Confluent account.",
                "properties": {
                    "attributes": {
                        "description": "Attributes associated with the account creation request.",
                        "properties": {
                            "api_key": {
                                "description": "The "
                                "API "
                                "key "
                                "associated "
                                "with "
                                "your "
                                "Confluent "
                                "account.",
                                "example": "TESTAPIKEY123",
                                "type": "string",
                            },
                            "api_secret": {
                                "description": "The "
                                "API "
                                "secret "
                                "associated "
                                "with "
                                "your "
                                "Confluent "
                                "account.",
                                "example": "test-api-secret-123",
                                "type": "string",
                            },
                            "resources": {
                                "description": "A "
                                "list "
                                "of "
                                "Confluent "
                                "resources "
                                "associated "
                                "with "
                                "the "
                                "Confluent "
                                "account.",
                                "items": {
                                    "description": "Attributes "
                                    "object "
                                    "for "
                                    "updating "
                                    "a "
                                    "Confluent "
                                    "resource.",
                                    "properties": {
                                        "enable_custom_metrics": {
                                            "default": False,
                                            "description": "Enable "
                                            "the "
                                            "`custom.consumer_lag_offset` "
                                            "metric, "
                                            "which "
                                            "contains "
                                            "extra "
                                            "metric "
                                            "tags.",
                                            "example": False,
                                            "type": "boolean",
                                        },
                                        "id": {
                                            "description": "The "
                                            "ID "
                                            "associated "
                                            "with "
                                            "a "
                                            "Confluent "
                                            "resource.",
                                            "example": "resource-id-123",
                                            "type": "string",
                                        },
                                        "resource_type": {
                                            "description": "The "
                                            "resource "
                                            "type "
                                            "of "
                                            "the "
                                            "Resource. "
                                            "Can "
                                            "be "
                                            "`kafka`, "
                                            "`connector`, "
                                            "`ksql`, "
                                            "or "
                                            "`schema_registry`.",
                                            "example": "kafka",
                                            "type": "string",
                                        },
                                        "tags": {
                                            "description": "A "
                                            "list "
                                            "of "
                                            "strings "
                                            "representing "
                                            "tags. "
                                            "Can "
                                            "be "
                                            "a "
                                            "single "
                                            "key, "
                                            "or "
                                            "key-value "
                                            "pairs "
                                            "separated "
                                            "by "
                                            "a "
                                            "colon.",
                                            "example": ["myTag", "myTag2:myValue"],
                                            "items": {"type": "string"},
                                            "type": "array",
                                        },
                                    },
                                    "required": ["resource_type"],
                                    "type": "object",
                                },
                                "type": "array",
                            },
                            "tags": {
                                "description": "A "
                                "list "
                                "of "
                                "strings "
                                "representing "
                                "tags. "
                                "Can "
                                "be "
                                "a "
                                "single "
                                "key, "
                                "or "
                                "key-value "
                                "pairs "
                                "separated "
                                "by "
                                "a "
                                "colon.",
                                "example": ["myTag", "myTag2:myValue"],
                                "items": {"type": "string"},
                                "type": "array",
                            },
                        },
                        "required": ["api_key", "api_secret"],
                        "type": "object",
                    },
                    "type": {
                        "default": "confluent-cloud-accounts",
                        "description": "The JSON:API type for "
                        "this API. Should "
                        "always be "
                        "`confluent-cloud-accounts`.",
                        "enum": ["confluent-cloud-accounts"],
                        "example": "confluent-cloud-accounts",
                        "type": "string",
                        "x-enum-varnames": ["CONFLUENT_CLOUD_ACCOUNTS"],
                    },
                },
                "required": ["attributes", "type"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "CREATEFASTLYACCOUNT_REQUEST_BODY_SCHEMA": {
        "description": "Payload schema when adding a Fastly account.",
        "properties": {
            "data": {
                "description": "Data object for creating a Fastly account.",
                "properties": {
                    "attributes": {
                        "description": "Attributes object for creating a Fastly account.",
                        "properties": {
                            "api_key": {
                                "description": "The API key for the Fastly account.",
                                "example": "ABCDEFG123",
                                "type": "string",
                            },
                            "name": {
                                "description": "The name of the Fastly account.",
                                "example": "test-name",
                                "type": "string",
                            },
                            "services": {
                                "description": "A "
                                "list "
                                "of "
                                "services "
                                "belonging "
                                "to "
                                "the "
                                "parent "
                                "account.",
                                "items": {
                                    "description": "The schema representation of a Fastly service.",
                                    "properties": {
                                        "id": {
                                            "description": "The ID of the Fastly service",
                                            "example": "6abc7de6893AbcDe9fghIj",
                                            "type": "string",
                                        },
                                        "tags": {
                                            "description": "A list of tags for the Fastly service.",
                                            "example": ["myTag", "myTag2:myValue"],
                                            "items": {"type": "string"},
                                            "type": "array",
                                        },
                                    },
                                    "required": ["id"],
                                    "type": "object",
                                },
                                "type": "array",
                            },
                        },
                        "required": ["api_key", "name"],
                        "type": "object",
                    },
                    "type": {
                        "default": "fastly-accounts",
                        "description": "The JSON:API type for "
                        "this API. Should "
                        "always be "
                        "`fastly-accounts`.",
                        "enum": ["fastly-accounts"],
                        "example": "fastly-accounts",
                        "type": "string",
                        "x-enum-varnames": ["FASTLY_ACCOUNTS"],
                    },
                },
                "required": ["attributes", "type"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "UPDATEIPALLOWLIST_REQUEST_BODY_SCHEMA": {
        "description": "Update the IP allowlist.",
        "properties": {
            "data": {
                "description": "IP allowlist data.",
                "properties": {
                    "attributes": {
                        "description": "Attributes of the IP allowlist.",
                        "properties": {
                            "enabled": {
                                "description": "Whether the IP allowlist logic is enabled or not.",
                                "type": "boolean",
                            },
                            "entries": {
                                "description": "Array of entries in the IP allowlist.",
                                "items": {
                                    "description": "IP allowlist entry object.",
                                    "properties": {
                                        "data": {
                                            "description": "Data of the IP allowlist entry object.",
                                            "properties": {
                                                "attributes": {
                                                    "description": "Attributes "
                                                    "of "
                                                    "the "
                                                    "IP "
                                                    "allowlist "
                                                    "entry.",
                                                    "properties": {
                                                        "cidr_block": {
                                                            "description": "The "
                                                            "CIDR "
                                                            "block "
                                                            "describing "
                                                            "the "
                                                            "IP "
                                                            "range "
                                                            "of "
                                                            "the "
                                                            "entry.",
                                                            "type": "string",
                                                        },
                                                        "created_at": {
                                                            "description": "Creation "
                                                            "time "
                                                            "of "
                                                            "the "
                                                            "entry.",
                                                            "format": "date-time",
                                                            "readOnly": True,
                                                            "type": "string",
                                                        },
                                                        "modified_at": {
                                                            "description": "Time "
                                                            "of "
                                                            "last "
                                                            "entry "
                                                            "modification.",
                                                            "format": "date-time",
                                                            "readOnly": True,
                                                            "type": "string",
                                                        },
                                                        "note": {
                                                            "description": "A "
                                                            "note "
                                                            "describing "
                                                            "the "
                                                            "IP "
                                                            "allowlist "
                                                            "entry.",
                                                            "type": "string",
                                                        },
                                                    },
                                                    "type": "object",
                                                },
                                                "id": {
                                                    "description": "The "
                                                    "unique "
                                                    "identifier "
                                                    "of "
                                                    "the "
                                                    "IP "
                                                    "allowlist "
                                                    "entry.",
                                                    "type": "string",
                                                },
                                                "type": {
                                                    "default": "ip_allowlist_entry",
                                                    "description": "IP allowlist Entry type.",
                                                    "enum": ["ip_allowlist_entry"],
                                                    "example": "ip_allowlist_entry",
                                                    "type": "string",
                                                    "x-enum-varnames": ["IP_ALLOWLIST_ENTRY"],
                                                },
                                            },
                                            "required": ["type"],
                                            "type": "object",
                                        }
                                    },
                                    "required": ["data"],
                                    "type": "object",
                                },
                                "type": "array",
                            },
                        },
                        "type": "object",
                    },
                    "id": {"description": "The unique identifier of the org.", "type": "string"},
                    "type": {
                        "default": "ip_allowlist",
                        "description": "IP allowlist type.",
                        "enum": ["ip_allowlist"],
                        "example": "ip_allowlist",
                        "type": "string",
                        "x-enum-varnames": ["IP_ALLOWLIST"],
                    },
                },
                "required": ["type"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "AGGREGATELOGS_REQUEST_BODY_SCHEMA": {
        "description": "The object sent with the request to retrieve a list of logs from your "
        "organization.",
        "properties": {
            "compute": {
                "description": "The list of metrics or timeseries to "
                "compute for the retrieved buckets.",
                "items": {
                    "description": "A compute rule to compute metrics or timeseries",
                    "properties": {
                        "aggregation": {
                            "description": "An aggregation function",
                            "enum": [
                                "count",
                                "cardinality",
                                "pc75",
                                "pc90",
                                "pc95",
                                "pc98",
                                "pc99",
                                "sum",
                                "min",
                                "max",
                                "avg",
                                "median",
                            ],
                            "example": "pc90",
                            "type": "string",
                            "x-enum-varnames": [
                                "COUNT",
                                "CARDINALITY",
                                "PERCENTILE_75",
                                "PERCENTILE_90",
                                "PERCENTILE_95",
                                "PERCENTILE_98",
                                "PERCENTILE_99",
                                "SUM",
                                "MIN",
                                "MAX",
                                "AVG",
                                "MEDIAN",
                            ],
                        },
                        "interval": {
                            "description": "The "
                            "time "
                            "buckets' "
                            "size "
                            "(only "
                            "used "
                            "for "
                            "type=timeseries)\n"
                            "Defaults "
                            "to a "
                            "resolution "
                            "of "
                            "150 "
                            "points",
                            "example": "5m",
                            "type": "string",
                        },
                        "metric": {
                            "description": "The metric to use",
                            "example": "@duration",
                            "type": "string",
                        },
                        "type": {
                            "default": "total",
                            "description": "The type of compute",
                            "enum": ["timeseries", "total"],
                            "type": "string",
                            "x-enum-varnames": ["TIMESERIES", "TOTAL"],
                        },
                    },
                    "required": ["aggregation"],
                    "type": "object",
                },
                "type": "array",
            },
            "filter": {
                "description": "The search and filter query settings",
                "properties": {
                    "from": {
                        "default": "now-15m",
                        "description": "The minimum time "
                        "for the requested "
                        "logs, supports date "
                        "math and regular "
                        "timestamps "
                        "(milliseconds).",
                        "example": "now-15m",
                        "type": "string",
                    },
                    "indexes": {
                        "default": ["*"],
                        "description": "For customers "
                        "with multiple "
                        "indexes, the "
                        "indexes to "
                        "search. Defaults "
                        "to ['*'] which "
                        "means all "
                        "indexes.",
                        "example": ["main", "web"],
                        "items": {"description": "The name of a log index.", "type": "string"},
                        "type": "array",
                    },
                    "query": {
                        "default": "*",
                        "description": "The search query - following the log search syntax.",
                        "example": "service:web* AND @http.status_code:[200 TO 299]",
                        "type": "string",
                    },
                    "storage_tier": {
                        "default": "indexes",
                        "description": "Specifies storage type as indexes, online-archives or flex",
                        "enum": ["indexes", "online-archives", "flex"],
                        "example": "indexes",
                        "type": "string",
                        "x-enum-varnames": ["INDEXES", "ONLINE_ARCHIVES", "FLEX"],
                    },
                    "to": {
                        "default": "now",
                        "description": "The maximum time for "
                        "the requested logs, "
                        "supports date math "
                        "and regular "
                        "timestamps "
                        "(milliseconds).",
                        "example": "now",
                        "type": "string",
                    },
                },
                "type": "object",
            },
            "group_by": {
                "description": "The rules for the group by",
                "items": {
                    "description": "A group by rule",
                    "properties": {
                        "facet": {
                            "description": "The name of the facet to use (required)",
                            "example": "host",
                            "type": "string",
                        },
                        "histogram": {
                            "description": "Used "
                            "to "
                            "perform "
                            "a "
                            "histogram "
                            "computation "
                            "(only "
                            "for "
                            "measure "
                            "facets).\n"
                            "Note: "
                            "at "
                            "most "
                            "100 "
                            "buckets "
                            "are "
                            "allowed, "
                            "the "
                            "number "
                            "of "
                            "buckets "
                            "is "
                            "(max "
                            "- "
                            "min)/interval.",
                            "properties": {
                                "interval": {
                                    "description": "The bin size of the histogram buckets",
                                    "example": 10,
                                    "format": "double",
                                    "type": "number",
                                },
                                "max": {
                                    "description": "The "
                                    "maximum "
                                    "value "
                                    "for "
                                    "the "
                                    "measure "
                                    "used "
                                    "in "
                                    "the "
                                    "histogram\n"
                                    "(values "
                                    "greater "
                                    "than "
                                    "this "
                                    "one "
                                    "are "
                                    "filtered "
                                    "out)",
                                    "example": 100,
                                    "format": "double",
                                    "type": "number",
                                },
                                "min": {
                                    "description": "The "
                                    "minimum "
                                    "value "
                                    "for "
                                    "the "
                                    "measure "
                                    "used "
                                    "in "
                                    "the "
                                    "histogram\n"
                                    "(values "
                                    "smaller "
                                    "than "
                                    "this "
                                    "one "
                                    "are "
                                    "filtered "
                                    "out)",
                                    "example": 50,
                                    "format": "double",
                                    "type": "number",
                                },
                            },
                            "required": ["interval", "min", "max"],
                            "type": "object",
                        },
                        "limit": {
                            "default": 10,
                            "description": "The "
                            "maximum "
                            "buckets "
                            "to "
                            "return "
                            "for "
                            "this "
                            "group "
                            "by. "
                            "Note: "
                            "at "
                            "most "
                            "10000 "
                            "buckets "
                            "are "
                            "allowed.\n"
                            "If "
                            "grouping "
                            "by "
                            "multiple "
                            "facets, "
                            "the "
                            "product "
                            "of "
                            "limits "
                            "must "
                            "not "
                            "exceed "
                            "10000.",
                            "format": "int64",
                            "type": "integer",
                        },
                        "missing": {
                            "description": "The "
                            "value "
                            "to "
                            "use "
                            "for "
                            "logs "
                            "that "
                            "don't "
                            "have "
                            "the "
                            "facet "
                            "used "
                            "to "
                            "group "
                            "by",
                            "oneOf": [
                                {
                                    "description": "The "
                                    "missing "
                                    "value "
                                    "to "
                                    "use "
                                    "if "
                                    "there "
                                    "is "
                                    "string "
                                    "valued "
                                    "facet.",
                                    "type": "string",
                                },
                                {
                                    "description": "The "
                                    "missing "
                                    "value "
                                    "to "
                                    "use "
                                    "if "
                                    "there "
                                    "is "
                                    "a "
                                    "number "
                                    "valued "
                                    "facet.",
                                    "format": "double",
                                    "type": "number",
                                },
                            ],
                        },
                        "sort": {
                            "description": "A sort rule",
                            "example": {"aggregation": "count", "order": "asc"},
                            "properties": {
                                "aggregation": {
                                    "description": "An aggregation function",
                                    "enum": [
                                        "count",
                                        "cardinality",
                                        "pc75",
                                        "pc90",
                                        "pc95",
                                        "pc98",
                                        "pc99",
                                        "sum",
                                        "min",
                                        "max",
                                        "avg",
                                        "median",
                                    ],
                                    "example": "pc90",
                                    "type": "string",
                                    "x-enum-varnames": [
                                        "COUNT",
                                        "CARDINALITY",
                                        "PERCENTILE_75",
                                        "PERCENTILE_90",
                                        "PERCENTILE_95",
                                        "PERCENTILE_98",
                                        "PERCENTILE_99",
                                        "SUM",
                                        "MIN",
                                        "MAX",
                                        "AVG",
                                        "MEDIAN",
                                    ],
                                },
                                "metric": {
                                    "description": "The "
                                    "metric "
                                    "to "
                                    "sort "
                                    "by "
                                    "(only "
                                    "used "
                                    "for "
                                    "`type=measure`)",
                                    "example": "@duration",
                                    "type": "string",
                                },
                                "order": {
                                    "description": "The order to use, ascending or descending",
                                    "enum": ["asc", "desc"],
                                    "example": "asc",
                                    "type": "string",
                                    "x-enum-varnames": ["ASCENDING", "DESCENDING"],
                                },
                                "type": {
                                    "default": "alphabetical",
                                    "description": "The type of sorting algorithm",
                                    "enum": ["alphabetical", "measure"],
                                    "type": "string",
                                    "x-enum-varnames": ["ALPHABETICAL", "MEASURE"],
                                },
                            },
                            "type": "object",
                        },
                        "total": {
                            "default": False,
                            "description": "A "
                            "resulting "
                            "object "
                            "to put "
                            "the "
                            "given "
                            "computes "
                            "in "
                            "over "
                            "all "
                            "the "
                            "matching "
                            "records.",
                            "oneOf": [
                                {
                                    "description": "If "
                                    "set "
                                    "to "
                                    "true, "
                                    "creates "
                                    "an "
                                    "additional "
                                    "bucket "
                                    "labeled "
                                    '"$facet_total"',
                                    "type": "boolean",
                                },
                                {
                                    "description": "A "
                                    "string "
                                    "to "
                                    "use "
                                    "as "
                                    "the "
                                    "key "
                                    "value "
                                    "for "
                                    "the "
                                    "total "
                                    "bucket",
                                    "type": "string",
                                },
                                {
                                    "description": "A "
                                    "number "
                                    "to "
                                    "use "
                                    "as "
                                    "the "
                                    "key "
                                    "value "
                                    "for "
                                    "the "
                                    "total "
                                    "bucket",
                                    "format": "double",
                                    "type": "number",
                                },
                            ],
                        },
                    },
                    "required": ["facet"],
                    "type": "object",
                },
                "type": "array",
            },
            "options": {
                "deprecated": True,
                "description": "Global query options that are used during "
                "the query.\n"
                "Note: These fields are currently "
                "deprecated and do not affect the query "
                "results.",
                "properties": {
                    "timeOffset": {
                        "description": "The time offset (in seconds) to apply to the query.",
                        "format": "int64",
                        "type": "integer",
                    },
                    "timezone": {
                        "default": "UTC",
                        "description": "The timezone "
                        "can be "
                        "specified as "
                        "GMT, UTC, an "
                        "offset from "
                        "UTC (like "
                        "UTC+1), or as "
                        "a Timezone "
                        "Database "
                        "identifier "
                        "(like "
                        "America/New_York).",
                        "example": "GMT",
                        "type": "string",
                    },
                },
                "type": "object",
            },
            "page": {
                "description": "Paging settings",
                "properties": {
                    "cursor": {
                        "description": "The returned paging "
                        "point to use to get "
                        "the next results. "
                        "Note: at most 1000 "
                        "results can be "
                        "paged.",
                        "example": "eyJzdGFydEF0IjoiQVFBQUFYS2tMS3pPbm40NGV3QUFBQUJCV0V0clRFdDZVbG8zY3pCRmNsbHJiVmxDWlEifQ==",
                        "type": "string",
                    }
                },
                "type": "object",
            },
        },
        "type": "object",
    },
    "CREATELOGSARCHIVE_REQUEST_BODY_SCHEMA": {
        "description": "The logs archive.",
        "properties": {
            "data": {
                "description": "The definition of an archive.",
                "properties": {
                    "attributes": {
                        "description": "The attributes associated with the archive.",
                        "properties": {
                            "destination": {
                                "description": "An archive's destination.",
                                "oneOf": [
                                    {
                                        "description": "The Azure archive destination.",
                                        "properties": {
                                            "container": {
                                                "description": "The "
                                                "container "
                                                "where "
                                                "the "
                                                "archive "
                                                "will "
                                                "be "
                                                "stored.",
                                                "example": "container-name",
                                                "type": "string",
                                            },
                                            "integration": {
                                                "description": "The "
                                                "Azure "
                                                "archive's "
                                                "integration "
                                                "destination.",
                                                "properties": {
                                                    "client_id": {
                                                        "description": "A client ID.",
                                                        "example": "aaaaaaaa-1a1a-1a1a-1a1a-aaaaaaaaaaaa",
                                                        "type": "string",
                                                    },
                                                    "tenant_id": {
                                                        "description": "A tenant ID.",
                                                        "example": "aaaaaaaa-1a1a-1a1a-1a1a-aaaaaaaaaaaa",
                                                        "type": "string",
                                                    },
                                                },
                                                "required": ["tenant_id", "client_id"],
                                                "type": "object",
                                            },
                                            "path": {
                                                "description": "The archive path.",
                                                "type": "string",
                                            },
                                            "region": {
                                                "description": "The "
                                                "region "
                                                "where "
                                                "the "
                                                "archive "
                                                "will "
                                                "be "
                                                "stored.",
                                                "type": "string",
                                            },
                                            "storage_account": {
                                                "description": "The associated storage account.",
                                                "example": "account-name",
                                                "type": "string",
                                            },
                                            "type": {
                                                "default": "azure",
                                                "description": "Type "
                                                "of "
                                                "the "
                                                "Azure "
                                                "archive "
                                                "destination.",
                                                "enum": ["azure"],
                                                "example": "azure",
                                                "type": "string",
                                                "x-enum-varnames": ["AZURE"],
                                            },
                                        },
                                        "required": [
                                            "storage_account",
                                            "container",
                                            "integration",
                                            "type",
                                        ],
                                        "type": "object",
                                    },
                                    {
                                        "description": "The GCS archive destination.",
                                        "properties": {
                                            "bucket": {
                                                "description": "The "
                                                "bucket "
                                                "where "
                                                "the "
                                                "archive "
                                                "will "
                                                "be "
                                                "stored.",
                                                "example": "bucket-name",
                                                "type": "string",
                                            },
                                            "integration": {
                                                "description": "The "
                                                "GCS "
                                                "archive's "
                                                "integration "
                                                "destination.",
                                                "properties": {
                                                    "client_email": {
                                                        "description": "A client email.",
                                                        "example": "youremail@example.com",
                                                        "type": "string",
                                                    },
                                                    "project_id": {
                                                        "description": "A project ID.",
                                                        "example": "project-id",
                                                        "type": "string",
                                                    },
                                                },
                                                "required": ["client_email"],
                                                "type": "object",
                                            },
                                            "path": {
                                                "description": "The archive path.",
                                                "type": "string",
                                            },
                                            "type": {
                                                "default": "gcs",
                                                "description": "Type "
                                                "of "
                                                "the "
                                                "GCS "
                                                "archive "
                                                "destination.",
                                                "enum": ["gcs"],
                                                "example": "gcs",
                                                "type": "string",
                                                "x-enum-varnames": ["GCS"],
                                            },
                                        },
                                        "required": ["bucket", "integration", "type"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "The S3 archive destination.",
                                        "properties": {
                                            "bucket": {
                                                "description": "The "
                                                "bucket "
                                                "where "
                                                "the "
                                                "archive "
                                                "will "
                                                "be "
                                                "stored.",
                                                "example": "bucket-name",
                                                "type": "string",
                                            },
                                            "encryption": {
                                                "description": "The S3 encryption settings.",
                                                "properties": {
                                                    "key": {
                                                        "description": "An "
                                                        "Amazon "
                                                        "Resource "
                                                        "Name "
                                                        "(ARN) "
                                                        "used "
                                                        "to "
                                                        "identify "
                                                        "an "
                                                        "AWS "
                                                        "KMS "
                                                        "key.",
                                                        "example": "arn:aws:kms:us-east-1:012345678901:key/DatadogIntegrationRoleKms",
                                                        "type": "string",
                                                    },
                                                    "type": {
                                                        "description": "Type "
                                                        "of "
                                                        "S3 "
                                                        "encryption "
                                                        "for "
                                                        "a "
                                                        "destination.",
                                                        "enum": [
                                                            "NO_OVERRIDE",
                                                            "SSE_S3",
                                                            "SSE_KMS",
                                                        ],
                                                        "example": "SSE_S3",
                                                        "type": "string",
                                                        "x-enum-varnames": [
                                                            "NO_OVERRIDE",
                                                            "SSE_S3",
                                                            "SSE_KMS",
                                                        ],
                                                    },
                                                },
                                                "required": ["type"],
                                                "type": "object",
                                            },
                                            "integration": {
                                                "description": "The "
                                                "S3 "
                                                "Archive's "
                                                "integration "
                                                "destination.",
                                                "properties": {
                                                    "account_id": {
                                                        "description": "The "
                                                        "account "
                                                        "ID "
                                                        "for "
                                                        "the "
                                                        "integration.",
                                                        "example": "123456789012",
                                                        "type": "string",
                                                    },
                                                    "role_name": {
                                                        "description": "The "
                                                        "path "
                                                        "of "
                                                        "the "
                                                        "integration.",
                                                        "example": "role-name",
                                                        "type": "string",
                                                    },
                                                },
                                                "required": ["role_name", "account_id"],
                                                "type": "object",
                                            },
                                            "path": {
                                                "description": "The archive path.",
                                                "type": "string",
                                            },
                                            "storage_class": {
                                                "default": "STANDARD",
                                                "description": "The "
                                                "storage "
                                                "class "
                                                "where "
                                                "the "
                                                "archive "
                                                "will "
                                                "be "
                                                "stored.",
                                                "enum": [
                                                    "STANDARD",
                                                    "STANDARD_IA",
                                                    "ONEZONE_IA",
                                                    "INTELLIGENT_TIERING",
                                                    "GLACIER_IR",
                                                ],
                                                "example": "STANDARD",
                                                "type": "string",
                                                "x-enum-varnames": [
                                                    "STANDARD",
                                                    "STANDARD_IA",
                                                    "ONEZONE_IA",
                                                    "INTELLIGENT_TIERING",
                                                    "GLACIER_IR",
                                                ],
                                            },
                                            "type": {
                                                "default": "s3",
                                                "description": "Type "
                                                "of "
                                                "the "
                                                "S3 "
                                                "archive "
                                                "destination.",
                                                "enum": ["s3"],
                                                "example": "s3",
                                                "type": "string",
                                                "x-enum-varnames": ["S3"],
                                            },
                                        },
                                        "required": ["bucket", "integration", "type"],
                                        "type": "object",
                                    },
                                ],
                            },
                            "include_tags": {
                                "default": False,
                                "description": "To "
                                "store "
                                "the "
                                "tags "
                                "in "
                                "the "
                                "archive, "
                                "set "
                                "the "
                                "value "
                                '"true".\n'
                                "If "
                                "it "
                                "is "
                                "set "
                                "to "
                                '"false", '
                                "the "
                                "tags "
                                "will "
                                "be "
                                "deleted "
                                "when "
                                "the "
                                "logs "
                                "are "
                                "sent "
                                "to "
                                "the "
                                "archive.",
                                "example": False,
                                "type": "boolean",
                            },
                            "name": {
                                "description": "The archive name.",
                                "example": "Nginx Archive",
                                "type": "string",
                            },
                            "query": {
                                "description": "The "
                                "archive "
                                "query/filter. "
                                "Logs "
                                "matching "
                                "this "
                                "query "
                                "are "
                                "included "
                                "in "
                                "the "
                                "archive.",
                                "example": "source:nginx",
                                "type": "string",
                            },
                            "rehydration_max_scan_size_in_gb": {
                                "description": "Maximum "
                                "scan "
                                "size "
                                "for "
                                "rehydration "
                                "from "
                                "this "
                                "archive.",
                                "example": 100,
                                "format": "int64",
                                "nullable": True,
                                "type": "integer",
                            },
                            "rehydration_tags": {
                                "description": "An "
                                "array "
                                "of "
                                "tags "
                                "to "
                                "add "
                                "to "
                                "rehydrated "
                                "logs "
                                "from "
                                "an "
                                "archive.",
                                "example": ["team:intake", "team:app"],
                                "items": {
                                    "description": "A given tag in the `<KEY>:<VALUE>` format.",
                                    "type": "string",
                                },
                                "type": "array",
                            },
                        },
                        "required": ["name", "query", "destination"],
                        "type": "object",
                    },
                    "type": {
                        "default": "archives",
                        "description": "The type of the "
                        "resource. The value "
                        "should always be "
                        "archives.",
                        "example": "archives",
                        "type": "string",
                    },
                },
                "required": ["type"],
                "type": "object",
            }
        },
        "type": "object",
    },
    "UPDATEARCHIVECONFIGURATION_REQUEST_BODY_SCHEMA": {
        "description": "The logs archive.",
        "properties": {
            "data": {
                "description": "The definition of an archive.",
                "properties": {
                    "attributes": {
                        "description": "The attributes associated with the archive.",
                        "properties": {
                            "destination": {
                                "description": "An archive's destination.",
                                "oneOf": [
                                    {
                                        "description": "The Azure archive destination.",
                                        "properties": {
                                            "container": {
                                                "description": "The "
                                                "container "
                                                "where "
                                                "the "
                                                "archive "
                                                "will "
                                                "be "
                                                "stored.",
                                                "example": "container-name",
                                                "type": "string",
                                            },
                                            "integration": {
                                                "description": "The "
                                                "Azure "
                                                "archive's "
                                                "integration "
                                                "destination.",
                                                "properties": {
                                                    "client_id": {
                                                        "description": "A client ID.",
                                                        "example": "aaaaaaaa-1a1a-1a1a-1a1a-aaaaaaaaaaaa",
                                                        "type": "string",
                                                    },
                                                    "tenant_id": {
                                                        "description": "A tenant ID.",
                                                        "example": "aaaaaaaa-1a1a-1a1a-1a1a-aaaaaaaaaaaa",
                                                        "type": "string",
                                                    },
                                                },
                                                "required": ["tenant_id", "client_id"],
                                                "type": "object",
                                            },
                                            "path": {
                                                "description": "The archive path.",
                                                "type": "string",
                                            },
                                            "region": {
                                                "description": "The "
                                                "region "
                                                "where "
                                                "the "
                                                "archive "
                                                "will "
                                                "be "
                                                "stored.",
                                                "type": "string",
                                            },
                                            "storage_account": {
                                                "description": "The associated storage account.",
                                                "example": "account-name",
                                                "type": "string",
                                            },
                                            "type": {
                                                "default": "azure",
                                                "description": "Type "
                                                "of "
                                                "the "
                                                "Azure "
                                                "archive "
                                                "destination.",
                                                "enum": ["azure"],
                                                "example": "azure",
                                                "type": "string",
                                                "x-enum-varnames": ["AZURE"],
                                            },
                                        },
                                        "required": [
                                            "storage_account",
                                            "container",
                                            "integration",
                                            "type",
                                        ],
                                        "type": "object",
                                    },
                                    {
                                        "description": "The GCS archive destination.",
                                        "properties": {
                                            "bucket": {
                                                "description": "The "
                                                "bucket "
                                                "where "
                                                "the "
                                                "archive "
                                                "will "
                                                "be "
                                                "stored.",
                                                "example": "bucket-name",
                                                "type": "string",
                                            },
                                            "integration": {
                                                "description": "The "
                                                "GCS "
                                                "archive's "
                                                "integration "
                                                "destination.",
                                                "properties": {
                                                    "client_email": {
                                                        "description": "A client email.",
                                                        "example": "youremail@example.com",
                                                        "type": "string",
                                                    },
                                                    "project_id": {
                                                        "description": "A project ID.",
                                                        "example": "project-id",
                                                        "type": "string",
                                                    },
                                                },
                                                "required": ["client_email"],
                                                "type": "object",
                                            },
                                            "path": {
                                                "description": "The archive path.",
                                                "type": "string",
                                            },
                                            "type": {
                                                "default": "gcs",
                                                "description": "Type "
                                                "of "
                                                "the "
                                                "GCS "
                                                "archive "
                                                "destination.",
                                                "enum": ["gcs"],
                                                "example": "gcs",
                                                "type": "string",
                                                "x-enum-varnames": ["GCS"],
                                            },
                                        },
                                        "required": ["bucket", "integration", "type"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "The S3 archive destination.",
                                        "properties": {
                                            "bucket": {
                                                "description": "The "
                                                "bucket "
                                                "where "
                                                "the "
                                                "archive "
                                                "will "
                                                "be "
                                                "stored.",
                                                "example": "bucket-name",
                                                "type": "string",
                                            },
                                            "encryption": {
                                                "description": "The S3 encryption settings.",
                                                "properties": {
                                                    "key": {
                                                        "description": "An "
                                                        "Amazon "
                                                        "Resource "
                                                        "Name "
                                                        "(ARN) "
                                                        "used "
                                                        "to "
                                                        "identify "
                                                        "an "
                                                        "AWS "
                                                        "KMS "
                                                        "key.",
                                                        "example": "arn:aws:kms:us-east-1:012345678901:key/DatadogIntegrationRoleKms",
                                                        "type": "string",
                                                    },
                                                    "type": {
                                                        "description": "Type "
                                                        "of "
                                                        "S3 "
                                                        "encryption "
                                                        "for "
                                                        "a "
                                                        "destination.",
                                                        "enum": [
                                                            "NO_OVERRIDE",
                                                            "SSE_S3",
                                                            "SSE_KMS",
                                                        ],
                                                        "example": "SSE_S3",
                                                        "type": "string",
                                                        "x-enum-varnames": [
                                                            "NO_OVERRIDE",
                                                            "SSE_S3",
                                                            "SSE_KMS",
                                                        ],
                                                    },
                                                },
                                                "required": ["type"],
                                                "type": "object",
                                            },
                                            "integration": {
                                                "description": "The "
                                                "S3 "
                                                "Archive's "
                                                "integration "
                                                "destination.",
                                                "properties": {
                                                    "account_id": {
                                                        "description": "The "
                                                        "account "
                                                        "ID "
                                                        "for "
                                                        "the "
                                                        "integration.",
                                                        "example": "123456789012",
                                                        "type": "string",
                                                    },
                                                    "role_name": {
                                                        "description": "The "
                                                        "path "
                                                        "of "
                                                        "the "
                                                        "integration.",
                                                        "example": "role-name",
                                                        "type": "string",
                                                    },
                                                },
                                                "required": ["role_name", "account_id"],
                                                "type": "object",
                                            },
                                            "path": {
                                                "description": "The archive path.",
                                                "type": "string",
                                            },
                                            "storage_class": {
                                                "default": "STANDARD",
                                                "description": "The "
                                                "storage "
                                                "class "
                                                "where "
                                                "the "
                                                "archive "
                                                "will "
                                                "be "
                                                "stored.",
                                                "enum": [
                                                    "STANDARD",
                                                    "STANDARD_IA",
                                                    "ONEZONE_IA",
                                                    "INTELLIGENT_TIERING",
                                                    "GLACIER_IR",
                                                ],
                                                "example": "STANDARD",
                                                "type": "string",
                                                "x-enum-varnames": [
                                                    "STANDARD",
                                                    "STANDARD_IA",
                                                    "ONEZONE_IA",
                                                    "INTELLIGENT_TIERING",
                                                    "GLACIER_IR",
                                                ],
                                            },
                                            "type": {
                                                "default": "s3",
                                                "description": "Type "
                                                "of "
                                                "the "
                                                "S3 "
                                                "archive "
                                                "destination.",
                                                "enum": ["s3"],
                                                "example": "s3",
                                                "type": "string",
                                                "x-enum-varnames": ["S3"],
                                            },
                                        },
                                        "required": ["bucket", "integration", "type"],
                                        "type": "object",
                                    },
                                ],
                            },
                            "include_tags": {
                                "default": False,
                                "description": "To "
                                "store "
                                "the "
                                "tags "
                                "in "
                                "the "
                                "archive, "
                                "set "
                                "the "
                                "value "
                                '"true".\n'
                                "If "
                                "it "
                                "is "
                                "set "
                                "to "
                                '"false", '
                                "the "
                                "tags "
                                "will "
                                "be "
                                "deleted "
                                "when "
                                "the "
                                "logs "
                                "are "
                                "sent "
                                "to "
                                "the "
                                "archive.",
                                "example": False,
                                "type": "boolean",
                            },
                            "name": {
                                "description": "The archive name.",
                                "example": "Nginx Archive",
                                "type": "string",
                            },
                            "query": {
                                "description": "The "
                                "archive "
                                "query/filter. "
                                "Logs "
                                "matching "
                                "this "
                                "query "
                                "are "
                                "included "
                                "in "
                                "the "
                                "archive.",
                                "example": "source:nginx",
                                "type": "string",
                            },
                            "rehydration_max_scan_size_in_gb": {
                                "description": "Maximum "
                                "scan "
                                "size "
                                "for "
                                "rehydration "
                                "from "
                                "this "
                                "archive.",
                                "example": 100,
                                "format": "int64",
                                "nullable": True,
                                "type": "integer",
                            },
                            "rehydration_tags": {
                                "description": "An "
                                "array "
                                "of "
                                "tags "
                                "to "
                                "add "
                                "to "
                                "rehydrated "
                                "logs "
                                "from "
                                "an "
                                "archive.",
                                "example": ["team:intake", "team:app"],
                                "items": {
                                    "description": "A given tag in the `<KEY>:<VALUE>` format.",
                                    "type": "string",
                                },
                                "type": "array",
                            },
                        },
                        "required": ["name", "query", "destination"],
                        "type": "object",
                    },
                    "type": {
                        "default": "archives",
                        "description": "The type of the "
                        "resource. The value "
                        "should always be "
                        "archives.",
                        "example": "archives",
                        "type": "string",
                    },
                },
                "required": ["type"],
                "type": "object",
            }
        },
        "type": "object",
    },
    "CREATECUSTOMLOGDESTINATION_REQUEST_BODY_SCHEMA": {
        "description": "The custom destination.",
        "properties": {
            "data": {
                "description": "The definition of a custom destination.",
                "properties": {
                    "attributes": {
                        "description": "The attributes associated with the custom destination.",
                        "properties": {
                            "enabled": {
                                "default": True,
                                "description": "Whether "
                                "logs "
                                "matching "
                                "this "
                                "custom "
                                "destination "
                                "should "
                                "be "
                                "forwarded "
                                "or "
                                "not.",
                                "example": True,
                                "type": "boolean",
                            },
                            "forward_tags": {
                                "default": True,
                                "description": "Whether "
                                "tags "
                                "from "
                                "the "
                                "forwarded "
                                "logs "
                                "should "
                                "be "
                                "forwarded "
                                "or "
                                "not.",
                                "example": True,
                                "type": "boolean",
                            },
                            "forward_tags_restriction_list": {
                                "default": [],
                                "description": "List "
                                "of "
                                "[keys "
                                "of "
                                "tags](https://docs.datadoghq.com/getting_started/tagging/#define-tags) "
                                "to "
                                "be "
                                "filtered.\n"
                                "\n"
                                "An "
                                "empty "
                                "list "
                                "represents "
                                "no "
                                "restriction "
                                "is "
                                "in "
                                "place "
                                "and "
                                "either "
                                "all "
                                "or "
                                "no "
                                "tags "
                                "will "
                                "be\n"
                                "forwarded "
                                "depending "
                                "on "
                                "`forward_tags_restriction_list_type` "
                                "parameter.",
                                "example": ["datacenter", "host"],
                                "items": {
                                    "description": "The "
                                    "[key "
                                    "part "
                                    "of "
                                    "a "
                                    "tag](https://docs.datadoghq.com/getting_started/tagging/#define-tags).",
                                    "type": "string",
                                },
                                "maxItems": 10,
                                "minItems": 0,
                                "type": "array",
                            },
                            "forward_tags_restriction_list_type": {
                                "default": "ALLOW_LIST",
                                "description": "How "
                                "`forward_tags_restriction_list` "
                                "parameter "
                                "should "
                                "be "
                                "interpreted.\n"
                                "If "
                                "`ALLOW_LIST`, "
                                "then "
                                "only "
                                "tags "
                                "whose "
                                "keys "
                                "on "
                                "the "
                                "forwarded "
                                "logs "
                                "match "
                                "the "
                                "ones "
                                "on "
                                "the "
                                "restriction "
                                "list\n"
                                "are "
                                "forwarded.\n"
                                "\n"
                                "`BLOCK_LIST` "
                                "works "
                                "the "
                                "opposite "
                                "way. "
                                "It "
                                "does "
                                "not "
                                "forward "
                                "the "
                                "tags "
                                "matching "
                                "the "
                                "ones "
                                "on "
                                "the "
                                "list.",
                                "enum": ["ALLOW_LIST", "BLOCK_LIST"],
                                "example": "ALLOW_LIST",
                                "type": "string",
                                "x-enum-varnames": ["ALLOW_LIST", "BLOCK_LIST"],
                            },
                            "forwarder_destination": {
                                "description": "A custom destination's location to forward logs.",
                                "oneOf": [
                                    {
                                        "description": "The HTTP destination.",
                                        "properties": {
                                            "auth": {
                                                "description": "Authentication "
                                                "method "
                                                "of "
                                                "the "
                                                "HTTP "
                                                "requests.",
                                                "oneOf": [
                                                    {
                                                        "description": "Basic "
                                                        "access "
                                                        "authentication.",
                                                        "properties": {
                                                            "password": {
                                                                "description": "The "
                                                                "password "
                                                                "of "
                                                                "the "
                                                                "authentication. "
                                                                "This "
                                                                "field "
                                                                "is "
                                                                "not "
                                                                "returned "
                                                                "by "
                                                                "the "
                                                                "API.",
                                                                "example": "datadog-custom-destination-password",
                                                                "type": "string",
                                                                "writeOnly": True,
                                                            },
                                                            "type": {
                                                                "default": "basic",
                                                                "description": "Type "
                                                                "of "
                                                                "the "
                                                                "basic "
                                                                "access "
                                                                "authentication.",
                                                                "enum": ["basic"],
                                                                "example": "basic",
                                                                "type": "string",
                                                                "x-enum-varnames": ["BASIC"],
                                                            },
                                                            "username": {
                                                                "description": "The "
                                                                "username "
                                                                "of "
                                                                "the "
                                                                "authentication. "
                                                                "This "
                                                                "field "
                                                                "is "
                                                                "not "
                                                                "returned "
                                                                "by "
                                                                "the "
                                                                "API.",
                                                                "example": "datadog-custom-destination-username",
                                                                "type": "string",
                                                                "writeOnly": True,
                                                            },
                                                        },
                                                        "required": [
                                                            "type",
                                                            "username",
                                                            "password",
                                                        ],
                                                        "type": "object",
                                                    },
                                                    {
                                                        "description": "Custom "
                                                        "header "
                                                        "access "
                                                        "authentication.",
                                                        "properties": {
                                                            "header_name": {
                                                                "description": "The "
                                                                "header "
                                                                "name "
                                                                "of "
                                                                "the "
                                                                "authentication.",
                                                                "example": "CUSTOM-HEADER-NAME",
                                                                "type": "string",
                                                            },
                                                            "header_value": {
                                                                "description": "The "
                                                                "header "
                                                                "value "
                                                                "of "
                                                                "the "
                                                                "authentication. "
                                                                "This "
                                                                "field "
                                                                "is "
                                                                "not "
                                                                "returned "
                                                                "by "
                                                                "the "
                                                                "API.",
                                                                "example": "CUSTOM-HEADER-AUTHENTICATION-VALUE",
                                                                "type": "string",
                                                                "writeOnly": True,
                                                            },
                                                            "type": {
                                                                "default": "custom_header",
                                                                "description": "Type "
                                                                "of "
                                                                "the "
                                                                "custom "
                                                                "header "
                                                                "access "
                                                                "authentication.",
                                                                "enum": ["custom_header"],
                                                                "example": "custom_header",
                                                                "type": "string",
                                                                "x-enum-varnames": [
                                                                    "CUSTOM_HEADER"
                                                                ],
                                                            },
                                                        },
                                                        "required": [
                                                            "type",
                                                            "header_name",
                                                            "header_value",
                                                        ],
                                                        "type": "object",
                                                    },
                                                ],
                                            },
                                            "endpoint": {
                                                "description": "The "
                                                "destination "
                                                "for "
                                                "which "
                                                "logs "
                                                "will "
                                                "be "
                                                "forwarded "
                                                "to.\n"
                                                "Must "
                                                "have "
                                                "HTTPS "
                                                "scheme "
                                                "and "
                                                "forwarding "
                                                "back "
                                                "to "
                                                "Datadog "
                                                "is "
                                                "not "
                                                "allowed.",
                                                "example": "https://example.com",
                                                "type": "string",
                                            },
                                            "type": {
                                                "default": "http",
                                                "description": "Type of the HTTP destination.",
                                                "enum": ["http"],
                                                "example": "http",
                                                "type": "string",
                                                "x-enum-varnames": ["HTTP"],
                                            },
                                        },
                                        "required": ["type", "endpoint", "auth"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "The "
                                        "Splunk "
                                        "HTTP "
                                        "Event "
                                        "Collector "
                                        "(HEC) "
                                        "destination.",
                                        "properties": {
                                            "access_token": {
                                                "description": "Access "
                                                "token "
                                                "of "
                                                "the "
                                                "Splunk "
                                                "HTTP "
                                                "Event "
                                                "Collector. "
                                                "This "
                                                "field "
                                                "is "
                                                "not "
                                                "returned "
                                                "by "
                                                "the "
                                                "API.",
                                                "example": "splunk_access_token",
                                                "type": "string",
                                                "writeOnly": True,
                                            },
                                            "endpoint": {
                                                "description": "The "
                                                "destination "
                                                "for "
                                                "which "
                                                "logs "
                                                "will "
                                                "be "
                                                "forwarded "
                                                "to.\n"
                                                "Must "
                                                "have "
                                                "HTTPS "
                                                "scheme "
                                                "and "
                                                "forwarding "
                                                "back "
                                                "to "
                                                "Datadog "
                                                "is "
                                                "not "
                                                "allowed.",
                                                "example": "https://example.com",
                                                "type": "string",
                                            },
                                            "type": {
                                                "default": "splunk_hec",
                                                "description": "Type "
                                                "of "
                                                "the "
                                                "Splunk "
                                                "HTTP "
                                                "Event "
                                                "Collector "
                                                "(HEC) "
                                                "destination.",
                                                "enum": ["splunk_hec"],
                                                "example": "splunk_hec",
                                                "type": "string",
                                                "x-enum-varnames": ["SPLUNK_HEC"],
                                            },
                                        },
                                        "required": ["type", "endpoint", "access_token"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "The Elasticsearch destination.",
                                        "properties": {
                                            "auth": {
                                                "description": "Basic access authentication.",
                                                "properties": {
                                                    "password": {
                                                        "description": "The "
                                                        "password "
                                                        "of "
                                                        "the "
                                                        "authentication. "
                                                        "This "
                                                        "field "
                                                        "is "
                                                        "not "
                                                        "returned "
                                                        "by "
                                                        "the "
                                                        "API.",
                                                        "example": "datadog-custom-destination-password",
                                                        "type": "string",
                                                        "writeOnly": True,
                                                    },
                                                    "username": {
                                                        "description": "The "
                                                        "username "
                                                        "of "
                                                        "the "
                                                        "authentication. "
                                                        "This "
                                                        "field "
                                                        "is "
                                                        "not "
                                                        "returned "
                                                        "by "
                                                        "the "
                                                        "API.",
                                                        "example": "datadog-custom-destination-username",
                                                        "type": "string",
                                                        "writeOnly": True,
                                                    },
                                                },
                                                "required": ["username", "password"],
                                                "type": "object",
                                            },
                                            "endpoint": {
                                                "description": "The "
                                                "destination "
                                                "for "
                                                "which "
                                                "logs "
                                                "will "
                                                "be "
                                                "forwarded "
                                                "to.\n"
                                                "Must "
                                                "have "
                                                "HTTPS "
                                                "scheme "
                                                "and "
                                                "forwarding "
                                                "back "
                                                "to "
                                                "Datadog "
                                                "is "
                                                "not "
                                                "allowed.",
                                                "example": "https://example.com",
                                                "type": "string",
                                            },
                                            "index_name": {
                                                "description": "Name "
                                                "of "
                                                "the "
                                                "Elasticsearch "
                                                "index "
                                                "(must "
                                                "follow "
                                                "[Elasticsearch's "
                                                "criteria](https://www.elastic.co/guide/en/elasticsearch/reference/8.11/indices-create-index.html#indices-create-api-path-params)).",
                                                "example": "nginx-logs",
                                                "type": "string",
                                            },
                                            "index_rotation": {
                                                "description": "Date "
                                                "pattern "
                                                "with "
                                                "US "
                                                "locale "
                                                "and "
                                                "UTC "
                                                "timezone "
                                                "to "
                                                "be "
                                                "appended "
                                                "to "
                                                "the "
                                                "index "
                                                "name "
                                                "after "
                                                "adding "
                                                "`-`\n"
                                                "(that "
                                                "is, "
                                                "`${index_name}-${indexPattern}`).\n"
                                                "You "
                                                "can "
                                                "customize "
                                                "the "
                                                "index "
                                                "rotation "
                                                "naming "
                                                "pattern "
                                                "by "
                                                "choosing "
                                                "one "
                                                "of "
                                                "these "
                                                "options:\n"
                                                "- "
                                                "Hourly: "
                                                "`yyyy-MM-dd-HH` "
                                                "(as "
                                                "an "
                                                "example, "
                                                "it "
                                                "would "
                                                "render: "
                                                "`2022-10-19-09`)\n"
                                                "- "
                                                "Daily: "
                                                "`yyyy-MM-dd` "
                                                "(as "
                                                "an "
                                                "example, "
                                                "it "
                                                "would "
                                                "render: "
                                                "`2022-10-19`)\n"
                                                "- "
                                                "Weekly: "
                                                "`yyyy-'W'ww` "
                                                "(as "
                                                "an "
                                                "example, "
                                                "it "
                                                "would "
                                                "render: "
                                                "`2022-W42`)\n"
                                                "- "
                                                "Monthly: "
                                                "`yyyy-MM` "
                                                "(as "
                                                "an "
                                                "example, "
                                                "it "
                                                "would "
                                                "render: "
                                                "`2022-10`)\n"
                                                "\n"
                                                "If "
                                                "this "
                                                "field "
                                                "is "
                                                "missing "
                                                "or "
                                                "is "
                                                "blank, "
                                                "it "
                                                "means "
                                                "that "
                                                "the "
                                                "index "
                                                "name "
                                                "will "
                                                "always "
                                                "be "
                                                "the "
                                                "same\n"
                                                "(that "
                                                "is, "
                                                "no "
                                                "rotation).",
                                                "example": "yyyy-MM-dd",
                                                "type": "string",
                                            },
                                            "type": {
                                                "default": "elasticsearch",
                                                "description": "Type "
                                                "of "
                                                "the "
                                                "Elasticsearch "
                                                "destination.",
                                                "enum": ["elasticsearch"],
                                                "example": "elasticsearch",
                                                "type": "string",
                                                "x-enum-varnames": ["ELASTICSEARCH"],
                                            },
                                        },
                                        "required": ["type", "endpoint", "auth", "index_name"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "The Microsoft Sentinel destination.",
                                        "properties": {
                                            "client_id": {
                                                "description": "Client "
                                                "ID "
                                                "from "
                                                "the "
                                                "Datadog "
                                                "Azure "
                                                "integration.",
                                                "example": "9a2f4d83-2b5e-429e-a35a-2b3c4182db71",
                                                "type": "string",
                                            },
                                            "data_collection_endpoint": {
                                                "description": "Azure data collection endpoint.",
                                                "example": "https://my-dce-5kyl.eastus-1.ingest.monitor.azure.com",
                                                "type": "string",
                                            },
                                            "data_collection_rule_id": {
                                                "description": "Azure data collection rule ID.",
                                                "example": "dcr-000a00a000a00000a000000aa000a0aa",
                                                "type": "string",
                                            },
                                            "stream_name": {
                                                "description": "Azure stream name.",
                                                "example": "Custom-MyTable",
                                                "type": "string",
                                                "writeOnly": True,
                                            },
                                            "tenant_id": {
                                                "description": "Tenant "
                                                "ID "
                                                "from "
                                                "the "
                                                "Datadog "
                                                "Azure "
                                                "integration.",
                                                "example": "f3c9a8a1-4c2e-4d2e-b911-9f3c28c3c8b2",
                                                "type": "string",
                                            },
                                            "type": {
                                                "default": "microsoft_sentinel",
                                                "description": "Type "
                                                "of "
                                                "the "
                                                "Microsoft "
                                                "Sentinel "
                                                "destination.",
                                                "enum": ["microsoft_sentinel"],
                                                "example": "microsoft_sentinel",
                                                "type": "string",
                                                "x-enum-varnames": ["MICROSOFT_SENTINEL"],
                                            },
                                        },
                                        "required": [
                                            "type",
                                            "tenant_id",
                                            "client_id",
                                            "data_collection_endpoint",
                                            "data_collection_rule_id",
                                            "stream_name",
                                        ],
                                        "type": "object",
                                    },
                                ],
                            },
                            "name": {
                                "description": "The custom destination name.",
                                "example": "Nginx logs",
                                "type": "string",
                            },
                            "query": {
                                "default": "",
                                "description": "The "
                                "custom "
                                "destination "
                                "query "
                                "and "
                                "filter. "
                                "Logs "
                                "matching "
                                "this "
                                "query "
                                "are "
                                "forwarded "
                                "to "
                                "the "
                                "destination.",
                                "example": "source:nginx",
                                "type": "string",
                            },
                        },
                        "required": ["name", "forwarder_destination"],
                        "type": "object",
                    },
                    "type": {
                        "default": "custom_destination",
                        "description": "The type of the "
                        "resource. The value "
                        "should always be "
                        "`custom_destination`.",
                        "enum": ["custom_destination"],
                        "example": "custom_destination",
                        "type": "string",
                        "x-enum-varnames": ["CUSTOM_DESTINATION"],
                    },
                },
                "required": ["type", "attributes"],
                "type": "object",
            }
        },
        "type": "object",
    },
    "UPDATELOGSCUSTOMDESTINATION_REQUEST_BODY_SCHEMA": {
        "description": "The custom destination.",
        "properties": {
            "data": {
                "description": "The definition of a custom destination.",
                "properties": {
                    "attributes": {
                        "description": "The attributes associated with the custom destination.",
                        "properties": {
                            "enabled": {
                                "default": True,
                                "description": "Whether "
                                "logs "
                                "matching "
                                "this "
                                "custom "
                                "destination "
                                "should "
                                "be "
                                "forwarded "
                                "or "
                                "not.",
                                "example": True,
                                "type": "boolean",
                            },
                            "forward_tags": {
                                "default": True,
                                "description": "Whether "
                                "tags "
                                "from "
                                "the "
                                "forwarded "
                                "logs "
                                "should "
                                "be "
                                "forwarded "
                                "or "
                                "not.",
                                "example": True,
                                "type": "boolean",
                            },
                            "forward_tags_restriction_list": {
                                "default": [],
                                "description": "List "
                                "of "
                                "[keys "
                                "of "
                                "tags](https://docs.datadoghq.com/getting_started/tagging/#define-tags) "
                                "to "
                                "be "
                                "restricted "
                                "from "
                                "being "
                                "forwarded.\n"
                                "An "
                                "empty "
                                "list "
                                "represents "
                                "no "
                                "restriction "
                                "is "
                                "in "
                                "place "
                                "and "
                                "either "
                                "all "
                                "or "
                                "no "
                                "tags "
                                "will "
                                "be "
                                "forwarded "
                                "depending "
                                "on "
                                "`forward_tags_restriction_list_type` "
                                "parameter.",
                                "example": ["datacenter", "host"],
                                "items": {
                                    "description": "The "
                                    "[key "
                                    "part "
                                    "of "
                                    "a "
                                    "tag](https://docs.datadoghq.com/getting_started/tagging/#define-tags).",
                                    "type": "string",
                                },
                                "maxItems": 10,
                                "minItems": 0,
                                "type": "array",
                            },
                            "forward_tags_restriction_list_type": {
                                "default": "ALLOW_LIST",
                                "description": "How "
                                "`forward_tags_restriction_list` "
                                "parameter "
                                "should "
                                "be "
                                "interpreted.\n"
                                "If "
                                "`ALLOW_LIST`, "
                                "then "
                                "only "
                                "tags "
                                "whose "
                                "keys "
                                "on "
                                "the "
                                "forwarded "
                                "logs "
                                "match "
                                "the "
                                "ones "
                                "on "
                                "the "
                                "restriction "
                                "list\n"
                                "are "
                                "forwarded.\n"
                                "\n"
                                "`BLOCK_LIST` "
                                "works "
                                "the "
                                "opposite "
                                "way. "
                                "It "
                                "does "
                                "not "
                                "forward "
                                "the "
                                "tags "
                                "matching "
                                "the "
                                "ones "
                                "on "
                                "the "
                                "list.",
                                "enum": ["ALLOW_LIST", "BLOCK_LIST"],
                                "example": "ALLOW_LIST",
                                "type": "string",
                                "x-enum-varnames": ["ALLOW_LIST", "BLOCK_LIST"],
                            },
                            "forwarder_destination": {
                                "description": "A custom destination's location to forward logs.",
                                "oneOf": [
                                    {
                                        "description": "The HTTP destination.",
                                        "properties": {
                                            "auth": {
                                                "description": "Authentication "
                                                "method "
                                                "of "
                                                "the "
                                                "HTTP "
                                                "requests.",
                                                "oneOf": [
                                                    {
                                                        "description": "Basic "
                                                        "access "
                                                        "authentication.",
                                                        "properties": {
                                                            "password": {
                                                                "description": "The "
                                                                "password "
                                                                "of "
                                                                "the "
                                                                "authentication. "
                                                                "This "
                                                                "field "
                                                                "is "
                                                                "not "
                                                                "returned "
                                                                "by "
                                                                "the "
                                                                "API.",
                                                                "example": "datadog-custom-destination-password",
                                                                "type": "string",
                                                                "writeOnly": True,
                                                            },
                                                            "type": {
                                                                "default": "basic",
                                                                "description": "Type "
                                                                "of "
                                                                "the "
                                                                "basic "
                                                                "access "
                                                                "authentication.",
                                                                "enum": ["basic"],
                                                                "example": "basic",
                                                                "type": "string",
                                                                "x-enum-varnames": ["BASIC"],
                                                            },
                                                            "username": {
                                                                "description": "The "
                                                                "username "
                                                                "of "
                                                                "the "
                                                                "authentication. "
                                                                "This "
                                                                "field "
                                                                "is "
                                                                "not "
                                                                "returned "
                                                                "by "
                                                                "the "
                                                                "API.",
                                                                "example": "datadog-custom-destination-username",
                                                                "type": "string",
                                                                "writeOnly": True,
                                                            },
                                                        },
                                                        "required": [
                                                            "type",
                                                            "username",
                                                            "password",
                                                        ],
                                                        "type": "object",
                                                    },
                                                    {
                                                        "description": "Custom "
                                                        "header "
                                                        "access "
                                                        "authentication.",
                                                        "properties": {
                                                            "header_name": {
                                                                "description": "The "
                                                                "header "
                                                                "name "
                                                                "of "
                                                                "the "
                                                                "authentication.",
                                                                "example": "CUSTOM-HEADER-NAME",
                                                                "type": "string",
                                                            },
                                                            "header_value": {
                                                                "description": "The "
                                                                "header "
                                                                "value "
                                                                "of "
                                                                "the "
                                                                "authentication. "
                                                                "This "
                                                                "field "
                                                                "is "
                                                                "not "
                                                                "returned "
                                                                "by "
                                                                "the "
                                                                "API.",
                                                                "example": "CUSTOM-HEADER-AUTHENTICATION-VALUE",
                                                                "type": "string",
                                                                "writeOnly": True,
                                                            },
                                                            "type": {
                                                                "default": "custom_header",
                                                                "description": "Type "
                                                                "of "
                                                                "the "
                                                                "custom "
                                                                "header "
                                                                "access "
                                                                "authentication.",
                                                                "enum": ["custom_header"],
                                                                "example": "custom_header",
                                                                "type": "string",
                                                                "x-enum-varnames": [
                                                                    "CUSTOM_HEADER"
                                                                ],
                                                            },
                                                        },
                                                        "required": [
                                                            "type",
                                                            "header_name",
                                                            "header_value",
                                                        ],
                                                        "type": "object",
                                                    },
                                                ],
                                            },
                                            "endpoint": {
                                                "description": "The "
                                                "destination "
                                                "for "
                                                "which "
                                                "logs "
                                                "will "
                                                "be "
                                                "forwarded "
                                                "to.\n"
                                                "Must "
                                                "have "
                                                "HTTPS "
                                                "scheme "
                                                "and "
                                                "forwarding "
                                                "back "
                                                "to "
                                                "Datadog "
                                                "is "
                                                "not "
                                                "allowed.",
                                                "example": "https://example.com",
                                                "type": "string",
                                            },
                                            "type": {
                                                "default": "http",
                                                "description": "Type of the HTTP destination.",
                                                "enum": ["http"],
                                                "example": "http",
                                                "type": "string",
                                                "x-enum-varnames": ["HTTP"],
                                            },
                                        },
                                        "required": ["type", "endpoint", "auth"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "The "
                                        "Splunk "
                                        "HTTP "
                                        "Event "
                                        "Collector "
                                        "(HEC) "
                                        "destination.",
                                        "properties": {
                                            "access_token": {
                                                "description": "Access "
                                                "token "
                                                "of "
                                                "the "
                                                "Splunk "
                                                "HTTP "
                                                "Event "
                                                "Collector. "
                                                "This "
                                                "field "
                                                "is "
                                                "not "
                                                "returned "
                                                "by "
                                                "the "
                                                "API.",
                                                "example": "splunk_access_token",
                                                "type": "string",
                                                "writeOnly": True,
                                            },
                                            "endpoint": {
                                                "description": "The "
                                                "destination "
                                                "for "
                                                "which "
                                                "logs "
                                                "will "
                                                "be "
                                                "forwarded "
                                                "to.\n"
                                                "Must "
                                                "have "
                                                "HTTPS "
                                                "scheme "
                                                "and "
                                                "forwarding "
                                                "back "
                                                "to "
                                                "Datadog "
                                                "is "
                                                "not "
                                                "allowed.",
                                                "example": "https://example.com",
                                                "type": "string",
                                            },
                                            "type": {
                                                "default": "splunk_hec",
                                                "description": "Type "
                                                "of "
                                                "the "
                                                "Splunk "
                                                "HTTP "
                                                "Event "
                                                "Collector "
                                                "(HEC) "
                                                "destination.",
                                                "enum": ["splunk_hec"],
                                                "example": "splunk_hec",
                                                "type": "string",
                                                "x-enum-varnames": ["SPLUNK_HEC"],
                                            },
                                        },
                                        "required": ["type", "endpoint", "access_token"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "The Elasticsearch destination.",
                                        "properties": {
                                            "auth": {
                                                "description": "Basic access authentication.",
                                                "properties": {
                                                    "password": {
                                                        "description": "The "
                                                        "password "
                                                        "of "
                                                        "the "
                                                        "authentication. "
                                                        "This "
                                                        "field "
                                                        "is "
                                                        "not "
                                                        "returned "
                                                        "by "
                                                        "the "
                                                        "API.",
                                                        "example": "datadog-custom-destination-password",
                                                        "type": "string",
                                                        "writeOnly": True,
                                                    },
                                                    "username": {
                                                        "description": "The "
                                                        "username "
                                                        "of "
                                                        "the "
                                                        "authentication. "
                                                        "This "
                                                        "field "
                                                        "is "
                                                        "not "
                                                        "returned "
                                                        "by "
                                                        "the "
                                                        "API.",
                                                        "example": "datadog-custom-destination-username",
                                                        "type": "string",
                                                        "writeOnly": True,
                                                    },
                                                },
                                                "required": ["username", "password"],
                                                "type": "object",
                                            },
                                            "endpoint": {
                                                "description": "The "
                                                "destination "
                                                "for "
                                                "which "
                                                "logs "
                                                "will "
                                                "be "
                                                "forwarded "
                                                "to.\n"
                                                "Must "
                                                "have "
                                                "HTTPS "
                                                "scheme "
                                                "and "
                                                "forwarding "
                                                "back "
                                                "to "
                                                "Datadog "
                                                "is "
                                                "not "
                                                "allowed.",
                                                "example": "https://example.com",
                                                "type": "string",
                                            },
                                            "index_name": {
                                                "description": "Name "
                                                "of "
                                                "the "
                                                "Elasticsearch "
                                                "index "
                                                "(must "
                                                "follow "
                                                "[Elasticsearch's "
                                                "criteria](https://www.elastic.co/guide/en/elasticsearch/reference/8.11/indices-create-index.html#indices-create-api-path-params)).",
                                                "example": "nginx-logs",
                                                "type": "string",
                                            },
                                            "index_rotation": {
                                                "description": "Date "
                                                "pattern "
                                                "with "
                                                "US "
                                                "locale "
                                                "and "
                                                "UTC "
                                                "timezone "
                                                "to "
                                                "be "
                                                "appended "
                                                "to "
                                                "the "
                                                "index "
                                                "name "
                                                "after "
                                                "adding "
                                                "`-`\n"
                                                "(that "
                                                "is, "
                                                "`${index_name}-${indexPattern}`).\n"
                                                "You "
                                                "can "
                                                "customize "
                                                "the "
                                                "index "
                                                "rotation "
                                                "naming "
                                                "pattern "
                                                "by "
                                                "choosing "
                                                "one "
                                                "of "
                                                "these "
                                                "options:\n"
                                                "- "
                                                "Hourly: "
                                                "`yyyy-MM-dd-HH` "
                                                "(as "
                                                "an "
                                                "example, "
                                                "it "
                                                "would "
                                                "render: "
                                                "`2022-10-19-09`)\n"
                                                "- "
                                                "Daily: "
                                                "`yyyy-MM-dd` "
                                                "(as "
                                                "an "
                                                "example, "
                                                "it "
                                                "would "
                                                "render: "
                                                "`2022-10-19`)\n"
                                                "- "
                                                "Weekly: "
                                                "`yyyy-'W'ww` "
                                                "(as "
                                                "an "
                                                "example, "
                                                "it "
                                                "would "
                                                "render: "
                                                "`2022-W42`)\n"
                                                "- "
                                                "Monthly: "
                                                "`yyyy-MM` "
                                                "(as "
                                                "an "
                                                "example, "
                                                "it "
                                                "would "
                                                "render: "
                                                "`2022-10`)\n"
                                                "\n"
                                                "If "
                                                "this "
                                                "field "
                                                "is "
                                                "missing "
                                                "or "
                                                "is "
                                                "blank, "
                                                "it "
                                                "means "
                                                "that "
                                                "the "
                                                "index "
                                                "name "
                                                "will "
                                                "always "
                                                "be "
                                                "the "
                                                "same\n"
                                                "(that "
                                                "is, "
                                                "no "
                                                "rotation).",
                                                "example": "yyyy-MM-dd",
                                                "type": "string",
                                            },
                                            "type": {
                                                "default": "elasticsearch",
                                                "description": "Type "
                                                "of "
                                                "the "
                                                "Elasticsearch "
                                                "destination.",
                                                "enum": ["elasticsearch"],
                                                "example": "elasticsearch",
                                                "type": "string",
                                                "x-enum-varnames": ["ELASTICSEARCH"],
                                            },
                                        },
                                        "required": ["type", "endpoint", "auth", "index_name"],
                                        "type": "object",
                                    },
                                    {
                                        "description": "The Microsoft Sentinel destination.",
                                        "properties": {
                                            "client_id": {
                                                "description": "Client "
                                                "ID "
                                                "from "
                                                "the "
                                                "Datadog "
                                                "Azure "
                                                "integration.",
                                                "example": "9a2f4d83-2b5e-429e-a35a-2b3c4182db71",
                                                "type": "string",
                                            },
                                            "data_collection_endpoint": {
                                                "description": "Azure data collection endpoint.",
                                                "example": "https://my-dce-5kyl.eastus-1.ingest.monitor.azure.com",
                                                "type": "string",
                                            },
                                            "data_collection_rule_id": {
                                                "description": "Azure data collection rule ID.",
                                                "example": "dcr-000a00a000a00000a000000aa000a0aa",
                                                "type": "string",
                                            },
                                            "stream_name": {
                                                "description": "Azure stream name.",
                                                "example": "Custom-MyTable",
                                                "type": "string",
                                                "writeOnly": True,
                                            },
                                            "tenant_id": {
                                                "description": "Tenant "
                                                "ID "
                                                "from "
                                                "the "
                                                "Datadog "
                                                "Azure "
                                                "integration.",
                                                "example": "f3c9a8a1-4c2e-4d2e-b911-9f3c28c3c8b2",
                                                "type": "string",
                                            },
                                            "type": {
                                                "default": "microsoft_sentinel",
                                                "description": "Type "
                                                "of "
                                                "the "
                                                "Microsoft "
                                                "Sentinel "
                                                "destination.",
                                                "enum": ["microsoft_sentinel"],
                                                "example": "microsoft_sentinel",
                                                "type": "string",
                                                "x-enum-varnames": ["MICROSOFT_SENTINEL"],
                                            },
                                        },
                                        "required": [
                                            "type",
                                            "tenant_id",
                                            "client_id",
                                            "data_collection_endpoint",
                                            "data_collection_rule_id",
                                            "stream_name",
                                        ],
                                        "type": "object",
                                    },
                                ],
                            },
                            "name": {
                                "description": "The custom destination name.",
                                "example": "Nginx logs",
                                "type": "string",
                            },
                            "query": {
                                "default": "",
                                "description": "The "
                                "custom "
                                "destination "
                                "query "
                                "and "
                                "filter. "
                                "Logs "
                                "matching "
                                "this "
                                "query "
                                "are "
                                "forwarded "
                                "to "
                                "the "
                                "destination.",
                                "example": "source:nginx",
                                "type": "string",
                            },
                        },
                        "type": "object",
                    },
                    "id": {
                        "description": "The custom destination ID.",
                        "example": "be5d7a69-d0c8-4d4d-8ee8-bba292d98139",
                        "type": "string",
                    },
                    "type": {
                        "default": "custom_destination",
                        "description": "The type of the "
                        "resource. The value "
                        "should always be "
                        "`custom_destination`.",
                        "enum": ["custom_destination"],
                        "example": "custom_destination",
                        "type": "string",
                        "x-enum-varnames": ["CUSTOM_DESTINATION"],
                    },
                },
                "required": ["type", "id"],
                "type": "object",
            }
        },
        "type": "object",
    },
    "CREATELOGBASEDMETRIC_REQUEST_BODY_SCHEMA": {
        "description": "The new log-based metric body.",
        "properties": {
            "data": {
                "description": "The new log-based metric properties.",
                "properties": {
                    "attributes": {
                        "description": "The object "
                        "describing the "
                        "Datadog "
                        "log-based "
                        "metric to "
                        "create.",
                        "properties": {
                            "compute": {
                                "description": "The compute rule to compute the log-based metric.",
                                "properties": {
                                    "aggregation_type": {
                                        "description": "The type of aggregation to use.",
                                        "enum": ["count", "distribution"],
                                        "example": "distribution",
                                        "type": "string",
                                        "x-enum-varnames": ["COUNT", "DISTRIBUTION"],
                                    },
                                    "include_percentiles": {
                                        "description": "Toggle "
                                        "to "
                                        "include "
                                        "or "
                                        "exclude "
                                        "percentile "
                                        "aggregations "
                                        "for "
                                        "distribution "
                                        "metrics.\n"
                                        "Only "
                                        "present "
                                        "when "
                                        "the "
                                        "`aggregation_type` "
                                        "is "
                                        "`distribution`.",
                                        "example": True,
                                        "type": "boolean",
                                    },
                                    "path": {
                                        "description": "The "
                                        "path "
                                        "to "
                                        "the "
                                        "value "
                                        "the "
                                        "log-based "
                                        "metric "
                                        "will "
                                        "aggregate "
                                        "on "
                                        "(only "
                                        "used "
                                        "if "
                                        "the "
                                        "aggregation "
                                        "type "
                                        "is "
                                        "a "
                                        '"distribution").',
                                        "example": "@duration",
                                        "type": "string",
                                    },
                                },
                                "required": ["aggregation_type"],
                                "type": "object",
                            },
                            "filter": {
                                "description": "The "
                                "log-based "
                                "metric "
                                "filter. "
                                "Logs "
                                "matching "
                                "this "
                                "filter "
                                "will "
                                "be "
                                "aggregated "
                                "in "
                                "this "
                                "metric.",
                                "properties": {
                                    "query": {
                                        "default": "*",
                                        "description": "The "
                                        "search "
                                        "query "
                                        "- "
                                        "following "
                                        "the "
                                        "log "
                                        "search "
                                        "syntax.",
                                        "example": "service:web* "
                                        "AND "
                                        "@http.status_code:[200 "
                                        "TO "
                                        "299]",
                                        "type": "string",
                                    }
                                },
                                "type": "object",
                            },
                            "group_by": {
                                "description": "The rules for the group by.",
                                "items": {
                                    "description": "A group by rule.",
                                    "properties": {
                                        "path": {
                                            "description": "The "
                                            "path "
                                            "to "
                                            "the "
                                            "value "
                                            "the "
                                            "log-based "
                                            "metric "
                                            "will "
                                            "be "
                                            "aggregated "
                                            "over.",
                                            "example": "@http.status_code",
                                            "type": "string",
                                        },
                                        "tag_name": {
                                            "description": "Eventual "
                                            "name "
                                            "of "
                                            "the "
                                            "tag "
                                            "that "
                                            "gets "
                                            "created. "
                                            "By "
                                            "default, "
                                            "the "
                                            "path "
                                            "attribute "
                                            "is "
                                            "used "
                                            "as "
                                            "the "
                                            "tag "
                                            "name.",
                                            "example": "status_code",
                                            "type": "string",
                                        },
                                    },
                                    "required": ["path"],
                                    "type": "object",
                                },
                                "type": "array",
                            },
                        },
                        "required": ["compute"],
                        "type": "object",
                    },
                    "id": {
                        "description": "The name of the log-based metric.",
                        "example": "logs.page.load.count",
                        "type": "string",
                    },
                    "type": {
                        "default": "logs_metrics",
                        "description": "The type of the "
                        "resource. The value "
                        "should always be "
                        "logs_metrics.",
                        "enum": ["logs_metrics"],
                        "example": "logs_metrics",
                        "type": "string",
                        "x-enum-varnames": ["LOGS_METRICS"],
                    },
                },
                "required": ["id", "type", "attributes"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "UPDATELOGBASEDMETRIC_REQUEST_BODY_SCHEMA": {
        "description": "The new log-based metric body.",
        "properties": {
            "data": {
                "description": "The new log-based metric properties.",
                "properties": {
                    "attributes": {
                        "description": "The log-based metric properties that will be updated.",
                        "properties": {
                            "compute": {
                                "description": "The compute rule to compute the log-based metric.",
                                "properties": {
                                    "include_percentiles": {
                                        "description": "Toggle "
                                        "to "
                                        "include "
                                        "or "
                                        "exclude "
                                        "percentile "
                                        "aggregations "
                                        "for "
                                        "distribution "
                                        "metrics.\n"
                                        "Only "
                                        "present "
                                        "when "
                                        "the "
                                        "`aggregation_type` "
                                        "is "
                                        "`distribution`.",
                                        "example": True,
                                        "type": "boolean",
                                    }
                                },
                                "type": "object",
                            },
                            "filter": {
                                "description": "The "
                                "log-based "
                                "metric "
                                "filter. "
                                "Logs "
                                "matching "
                                "this "
                                "filter "
                                "will "
                                "be "
                                "aggregated "
                                "in "
                                "this "
                                "metric.",
                                "properties": {
                                    "query": {
                                        "default": "*",
                                        "description": "The "
                                        "search "
                                        "query "
                                        "- "
                                        "following "
                                        "the "
                                        "log "
                                        "search "
                                        "syntax.",
                                        "example": "service:web* "
                                        "AND "
                                        "@http.status_code:[200 "
                                        "TO "
                                        "299]",
                                        "type": "string",
                                    }
                                },
                                "type": "object",
                            },
                            "group_by": {
                                "description": "The rules for the group by.",
                                "items": {
                                    "description": "A group by rule.",
                                    "properties": {
                                        "path": {
                                            "description": "The "
                                            "path "
                                            "to "
                                            "the "
                                            "value "
                                            "the "
                                            "log-based "
                                            "metric "
                                            "will "
                                            "be "
                                            "aggregated "
                                            "over.",
                                            "example": "@http.status_code",
                                            "type": "string",
                                        },
                                        "tag_name": {
                                            "description": "Eventual "
                                            "name "
                                            "of "
                                            "the "
                                            "tag "
                                            "that "
                                            "gets "
                                            "created. "
                                            "By "
                                            "default, "
                                            "the "
                                            "path "
                                            "attribute "
                                            "is "
                                            "used "
                                            "as "
                                            "the "
                                            "tag "
                                            "name.",
                                            "example": "status_code",
                                            "type": "string",
                                        },
                                    },
                                    "required": ["path"],
                                    "type": "object",
                                },
                                "type": "array",
                            },
                        },
                        "type": "object",
                    },
                    "type": {
                        "default": "logs_metrics",
                        "description": "The type of the "
                        "resource. The value "
                        "should always be "
                        "logs_metrics.",
                        "enum": ["logs_metrics"],
                        "example": "logs_metrics",
                        "type": "string",
                        "x-enum-varnames": ["LOGS_METRICS"],
                    },
                },
                "required": ["type", "attributes"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "UPDATEMETRICTAGCONFIGURATION_REQUEST_BODY_SCHEMA": {
        "description": "Request object that includes the metric that you would like to edit "
        "the tag configuration on.",
        "properties": {
            "data": {
                "description": "Object for a single tag configuration to be edited.",
                "example": {
                    "attributes": {"group_by": ["app", "datacenter"], "include_percentiles": False},
                    "id": "http.endpoint.request",
                    "type": "manage_tags",
                },
                "properties": {
                    "attributes": {
                        "description": "Object "
                        "containing the "
                        "definition of a "
                        "metric tag "
                        "configuration "
                        "to be updated.",
                        "properties": {
                            "aggregations": {
                                "description": "Deprecated. "
                                "You "
                                "no "
                                "longer "
                                "need "
                                "to "
                                "configure "
                                "specific "
                                "time "
                                "and "
                                "space "
                                "aggregations "
                                "for "
                                "Metrics "
                                "Without "
                                "Limits.",
                                "example": [
                                    {"space": "sum", "time": "sum"},
                                    {"space": "sum", "time": "count"},
                                ],
                                "items": {
                                    "description": "A "
                                    "time "
                                    "and "
                                    "space "
                                    "aggregation "
                                    "combination "
                                    "for "
                                    "use "
                                    "in "
                                    "query.",
                                    "example": {"space": "sum", "time": "sum"},
                                    "properties": {
                                        "space": {
                                            "description": "A space aggregation for use in query.",
                                            "enum": ["avg", "max", "min", "sum"],
                                            "example": "sum",
                                            "type": "string",
                                            "x-enum-varnames": ["AVG", "MAX", "MIN", "SUM"],
                                        },
                                        "time": {
                                            "description": "A time aggregation for use in query.",
                                            "enum": ["avg", "count", "max", "min", "sum"],
                                            "example": "sum",
                                            "type": "string",
                                            "x-enum-varnames": [
                                                "AVG",
                                                "COUNT",
                                                "MAX",
                                                "MIN",
                                                "SUM",
                                            ],
                                        },
                                    },
                                    "required": ["time", "space"],
                                    "type": "object",
                                },
                                "type": "array",
                            },
                            "exclude_tags_mode": {
                                "description": "When "
                                "set "
                                "to "
                                "true, "
                                "the "
                                "configuration "
                                "will "
                                "exclude "
                                "the "
                                "configured "
                                "tags "
                                "and "
                                "include "
                                "any "
                                "other "
                                "submitted "
                                "tags.\n"
                                "When "
                                "set "
                                "to "
                                "false, "
                                "the "
                                "configuration "
                                "will "
                                "include "
                                "the "
                                "configured "
                                "tags "
                                "and "
                                "exclude "
                                "any "
                                "other "
                                "submitted "
                                "tags.\n"
                                "Defaults "
                                "to "
                                "false. "
                                "Requires "
                                "`tags` "
                                "property.",
                                "type": "boolean",
                            },
                            "include_percentiles": {
                                "description": "Toggle "
                                "to "
                                "include/exclude "
                                "percentiles "
                                "for "
                                "a "
                                "distribution "
                                "metric.\n"
                                "Defaults "
                                "to "
                                "false. "
                                "Can "
                                "only "
                                "be "
                                "applied "
                                "to "
                                "metrics "
                                "that "
                                "have "
                                "a "
                                "`metric_type` "
                                "of "
                                "`distribution`.",
                                "example": True,
                                "type": "boolean",
                            },
                            "tags": {
                                "default": [],
                                "description": "A "
                                "list "
                                "of "
                                "tag "
                                "keys "
                                "that "
                                "will "
                                "be "
                                "queryable "
                                "for "
                                "your "
                                "metric.",
                                "example": ["app", "datacenter"],
                                "items": {"description": "Tag keys to group by.", "type": "string"},
                                "type": "array",
                            },
                        },
                        "type": "object",
                    },
                    "id": {
                        "description": "The metric name for this resource.",
                        "example": "test.metric.latency",
                        "type": "string",
                    },
                    "type": {
                        "default": "manage_tags",
                        "description": "The metric tag configuration resource type.",
                        "enum": ["manage_tags"],
                        "example": "manage_tags",
                        "type": "string",
                        "x-enum-varnames": ["MANAGE_TAGS"],
                    },
                },
                "required": ["id", "type"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "CREATEMETRICTAGCONFIGURATION_REQUEST_BODY_SCHEMA": {
        "description": "Request object that includes the metric that you would like to "
        "configure tags for.",
        "properties": {
            "data": {
                "description": "Object for a single metric to be configure tags on.",
                "example": {
                    "attributes": {
                        "include_percentiles": False,
                        "metric_type": "distribution",
                        "tags": ["app", "datacenter"],
                    },
                    "id": "http.endpoint.request",
                    "type": "manage_tags",
                },
                "properties": {
                    "attributes": {
                        "description": "Object "
                        "containing the "
                        "definition of a "
                        "metric tag "
                        "configuration "
                        "to be created.",
                        "properties": {
                            "aggregations": {
                                "description": "Deprecated. "
                                "You "
                                "no "
                                "longer "
                                "need "
                                "to "
                                "configure "
                                "specific "
                                "time "
                                "and "
                                "space "
                                "aggregations "
                                "for "
                                "Metrics "
                                "Without "
                                "Limits.",
                                "example": [
                                    {"space": "sum", "time": "sum"},
                                    {"space": "sum", "time": "count"},
                                ],
                                "items": {
                                    "description": "A "
                                    "time "
                                    "and "
                                    "space "
                                    "aggregation "
                                    "combination "
                                    "for "
                                    "use "
                                    "in "
                                    "query.",
                                    "example": {"space": "sum", "time": "sum"},
                                    "properties": {
                                        "space": {
                                            "description": "A space aggregation for use in query.",
                                            "enum": ["avg", "max", "min", "sum"],
                                            "example": "sum",
                                            "type": "string",
                                            "x-enum-varnames": ["AVG", "MAX", "MIN", "SUM"],
                                        },
                                        "time": {
                                            "description": "A time aggregation for use in query.",
                                            "enum": ["avg", "count", "max", "min", "sum"],
                                            "example": "sum",
                                            "type": "string",
                                            "x-enum-varnames": [
                                                "AVG",
                                                "COUNT",
                                                "MAX",
                                                "MIN",
                                                "SUM",
                                            ],
                                        },
                                    },
                                    "required": ["time", "space"],
                                    "type": "object",
                                },
                                "type": "array",
                            },
                            "exclude_tags_mode": {
                                "description": "When "
                                "set "
                                "to "
                                "true, "
                                "the "
                                "configuration "
                                "will "
                                "exclude "
                                "the "
                                "configured "
                                "tags "
                                "and "
                                "include "
                                "any "
                                "other "
                                "submitted "
                                "tags.\n"
                                "When "
                                "set "
                                "to "
                                "false, "
                                "the "
                                "configuration "
                                "will "
                                "include "
                                "the "
                                "configured "
                                "tags "
                                "and "
                                "exclude "
                                "any "
                                "other "
                                "submitted "
                                "tags.\n"
                                "Defaults "
                                "to "
                                "false. "
                                "Requires "
                                "`tags` "
                                "property.",
                                "type": "boolean",
                            },
                            "include_percentiles": {
                                "description": "Toggle "
                                "to "
                                "include/exclude "
                                "percentiles "
                                "for "
                                "a "
                                "distribution "
                                "metric.\n"
                                "Defaults "
                                "to "
                                "false. "
                                "Can "
                                "only "
                                "be "
                                "applied "
                                "to "
                                "metrics "
                                "that "
                                "have "
                                "a "
                                "`metric_type` "
                                "of "
                                "`distribution`.",
                                "example": True,
                                "type": "boolean",
                            },
                            "metric_type": {
                                "default": "gauge",
                                "description": "The metric's type.",
                                "enum": ["gauge", "count", "rate", "distribution"],
                                "example": "count",
                                "type": "string",
                                "x-enum-varnames": ["GAUGE", "COUNT", "RATE", "DISTRIBUTION"],
                            },
                            "tags": {
                                "default": [],
                                "description": "A "
                                "list "
                                "of "
                                "tag "
                                "keys "
                                "that "
                                "will "
                                "be "
                                "queryable "
                                "for "
                                "your "
                                "metric.",
                                "example": ["app", "datacenter"],
                                "items": {"description": "Tag keys to group by.", "type": "string"},
                                "type": "array",
                            },
                        },
                        "required": ["tags", "metric_type"],
                        "type": "object",
                    },
                    "id": {
                        "description": "The metric name for this resource.",
                        "example": "test.metric.latency",
                        "type": "string",
                    },
                    "type": {
                        "default": "manage_tags",
                        "description": "The metric tag configuration resource type.",
                        "enum": ["manage_tags"],
                        "example": "manage_tags",
                        "type": "string",
                        "x-enum-varnames": ["MANAGE_TAGS"],
                    },
                },
                "required": ["id", "type"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "CREATEMONITORNOTIFICATIONRULE_REQUEST_BODY_SCHEMA": {
        "description": "Request for creating a monitor notification rule.",
        "properties": {
            "data": {
                "description": "Object to create a monitor notification rule.",
                "properties": {
                    "attributes": {
                        "additionalProperties": False,
                        "description": "Attributes of the monitor notification rule.",
                        "properties": {
                            "conditional_recipients": {
                                "description": "Use "
                                "conditional "
                                "recipients "
                                "to "
                                "define "
                                "different "
                                "recipients "
                                "for "
                                "different "
                                "situations.",
                                "properties": {
                                    "conditions": {
                                        "description": "Conditions of the notification rule.",
                                        "items": {
                                            "description": "Conditions "
                                            "for "
                                            "`conditional_recipients`.",
                                            "properties": {
                                                "recipients": {
                                                    "description": "A "
                                                    "list "
                                                    "of "
                                                    "recipients "
                                                    "to "
                                                    "notify. "
                                                    "Uses "
                                                    "the "
                                                    "same "
                                                    "format "
                                                    "as "
                                                    "the "
                                                    "monitor "
                                                    "`message` "
                                                    "field. "
                                                    "Must "
                                                    "not "
                                                    "start "
                                                    "with "
                                                    "an "
                                                    "'@'.",
                                                    "example": ["slack-test-channel", "jira-test"],
                                                    "items": {
                                                        "description": "individual recipient.",
                                                        "maxLength": 255,
                                                        "type": "string",
                                                    },
                                                    "maxItems": 20,
                                                    "minItems": 1,
                                                    "type": "array",
                                                    "uniqueItems": True,
                                                },
                                                "scope": {
                                                    "description": "The "
                                                    "scope "
                                                    "to "
                                                    "which "
                                                    "the "
                                                    "monitor "
                                                    "applied.",
                                                    "example": "transition_type:alert",
                                                    "maxLength": 3000,
                                                    "minLength": 1,
                                                    "type": "string",
                                                },
                                            },
                                            "required": ["scope", "recipients"],
                                            "type": "object",
                                        },
                                        "maxItems": 10,
                                        "minItems": 1,
                                        "type": "array",
                                    },
                                    "fallback_recipients": {
                                        "description": "A "
                                        "list "
                                        "of "
                                        "recipients "
                                        "to "
                                        "notify. "
                                        "Uses "
                                        "the "
                                        "same "
                                        "format "
                                        "as "
                                        "the "
                                        "monitor "
                                        "`message` "
                                        "field. "
                                        "Must "
                                        "not "
                                        "start "
                                        "with "
                                        "an "
                                        "'@'.",
                                        "example": ["slack-test-channel", "jira-test"],
                                        "items": {
                                            "description": "individual recipient.",
                                            "maxLength": 255,
                                            "type": "string",
                                        },
                                        "maxItems": 20,
                                        "minItems": 1,
                                        "type": "array",
                                        "uniqueItems": True,
                                    },
                                },
                                "required": ["conditions"],
                                "type": "object",
                            },
                            "filter": {
                                "description": "Filter "
                                "used "
                                "to "
                                "associate "
                                "the "
                                "notification "
                                "rule "
                                "with "
                                "monitors.",
                                "oneOf": [
                                    {
                                        "additionalProperties": False,
                                        "description": "Filter "
                                        "monitors "
                                        "by "
                                        "tags. "
                                        "Monitors "
                                        "must "
                                        "match "
                                        "all "
                                        "tags.",
                                        "properties": {
                                            "tags": {
                                                "description": "A list of monitor tags.",
                                                "example": ["team:product", "host:abc"],
                                                "items": {"maxLength": 255, "type": "string"},
                                                "maxItems": 20,
                                                "minItems": 1,
                                                "type": "array",
                                                "uniqueItems": True,
                                            }
                                        },
                                        "required": ["tags"],
                                        "type": "object",
                                    }
                                ],
                            },
                            "name": {
                                "description": "The name of the monitor notification rule.",
                                "example": "A notification rule name",
                                "maxLength": 1000,
                                "minLength": 1,
                                "type": "string",
                            },
                            "recipients": {
                                "description": "A "
                                "list "
                                "of "
                                "recipients "
                                "to "
                                "notify. "
                                "Uses "
                                "the "
                                "same "
                                "format "
                                "as "
                                "the "
                                "monitor "
                                "`message` "
                                "field. "
                                "Must "
                                "not "
                                "start "
                                "with "
                                "an "
                                "'@'.",
                                "example": ["slack-test-channel", "jira-test"],
                                "items": {
                                    "description": "individual recipient.",
                                    "maxLength": 255,
                                    "type": "string",
                                },
                                "maxItems": 20,
                                "minItems": 1,
                                "type": "array",
                                "uniqueItems": True,
                            },
                        },
                        "required": ["name"],
                        "type": "object",
                    },
                    "type": {
                        "default": "monitor-notification-rule",
                        "description": "Monitor notification rule resource type.",
                        "enum": ["monitor-notification-rule"],
                        "example": "monitor-notification-rule",
                        "type": "string",
                        "x-enum-varnames": ["MONITOR_NOTIFICATION_RULE"],
                    },
                },
                "required": ["attributes"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "UPDATEMONITORNOTIFICATIONRULE_REQUEST_BODY_SCHEMA": {
        "description": "Request for updating a monitor notification rule.",
        "properties": {
            "data": {
                "description": "Object to update a monitor notification rule.",
                "properties": {
                    "attributes": {
                        "additionalProperties": False,
                        "description": "Attributes of the monitor notification rule.",
                        "properties": {
                            "conditional_recipients": {
                                "description": "Use "
                                "conditional "
                                "recipients "
                                "to "
                                "define "
                                "different "
                                "recipients "
                                "for "
                                "different "
                                "situations.",
                                "properties": {
                                    "conditions": {
                                        "description": "Conditions of the notification rule.",
                                        "items": {
                                            "description": "Conditions "
                                            "for "
                                            "`conditional_recipients`.",
                                            "properties": {
                                                "recipients": {
                                                    "description": "A "
                                                    "list "
                                                    "of "
                                                    "recipients "
                                                    "to "
                                                    "notify. "
                                                    "Uses "
                                                    "the "
                                                    "same "
                                                    "format "
                                                    "as "
                                                    "the "
                                                    "monitor "
                                                    "`message` "
                                                    "field. "
                                                    "Must "
                                                    "not "
                                                    "start "
                                                    "with "
                                                    "an "
                                                    "'@'.",
                                                    "example": ["slack-test-channel", "jira-test"],
                                                    "items": {
                                                        "description": "individual recipient.",
                                                        "maxLength": 255,
                                                        "type": "string",
                                                    },
                                                    "maxItems": 20,
                                                    "minItems": 1,
                                                    "type": "array",
                                                    "uniqueItems": True,
                                                },
                                                "scope": {
                                                    "description": "The "
                                                    "scope "
                                                    "to "
                                                    "which "
                                                    "the "
                                                    "monitor "
                                                    "applied.",
                                                    "example": "transition_type:alert",
                                                    "maxLength": 3000,
                                                    "minLength": 1,
                                                    "type": "string",
                                                },
                                            },
                                            "required": ["scope", "recipients"],
                                            "type": "object",
                                        },
                                        "maxItems": 10,
                                        "minItems": 1,
                                        "type": "array",
                                    },
                                    "fallback_recipients": {
                                        "description": "A "
                                        "list "
                                        "of "
                                        "recipients "
                                        "to "
                                        "notify. "
                                        "Uses "
                                        "the "
                                        "same "
                                        "format "
                                        "as "
                                        "the "
                                        "monitor "
                                        "`message` "
                                        "field. "
                                        "Must "
                                        "not "
                                        "start "
                                        "with "
                                        "an "
                                        "'@'.",
                                        "example": ["slack-test-channel", "jira-test"],
                                        "items": {
                                            "description": "individual recipient.",
                                            "maxLength": 255,
                                            "type": "string",
                                        },
                                        "maxItems": 20,
                                        "minItems": 1,
                                        "type": "array",
                                        "uniqueItems": True,
                                    },
                                },
                                "required": ["conditions"],
                                "type": "object",
                            },
                            "filter": {
                                "description": "Filter "
                                "used "
                                "to "
                                "associate "
                                "the "
                                "notification "
                                "rule "
                                "with "
                                "monitors.",
                                "oneOf": [
                                    {
                                        "additionalProperties": False,
                                        "description": "Filter "
                                        "monitors "
                                        "by "
                                        "tags. "
                                        "Monitors "
                                        "must "
                                        "match "
                                        "all "
                                        "tags.",
                                        "properties": {
                                            "tags": {
                                                "description": "A list of monitor tags.",
                                                "example": ["team:product", "host:abc"],
                                                "items": {"maxLength": 255, "type": "string"},
                                                "maxItems": 20,
                                                "minItems": 1,
                                                "type": "array",
                                                "uniqueItems": True,
                                            }
                                        },
                                        "required": ["tags"],
                                        "type": "object",
                                    }
                                ],
                            },
                            "name": {
                                "description": "The name of the monitor notification rule.",
                                "example": "A notification rule name",
                                "maxLength": 1000,
                                "minLength": 1,
                                "type": "string",
                            },
                            "recipients": {
                                "description": "A "
                                "list "
                                "of "
                                "recipients "
                                "to "
                                "notify. "
                                "Uses "
                                "the "
                                "same "
                                "format "
                                "as "
                                "the "
                                "monitor "
                                "`message` "
                                "field. "
                                "Must "
                                "not "
                                "start "
                                "with "
                                "an "
                                "'@'.",
                                "example": ["slack-test-channel", "jira-test"],
                                "items": {
                                    "description": "individual recipient.",
                                    "maxLength": 255,
                                    "type": "string",
                                },
                                "maxItems": 20,
                                "minItems": 1,
                                "type": "array",
                                "uniqueItems": True,
                            },
                        },
                        "required": ["name"],
                        "type": "object",
                    },
                    "id": {
                        "description": "The ID of the monitor notification rule.",
                        "example": "00000000-0000-1234-0000-000000000000",
                        "type": "string",
                    },
                    "type": {
                        "default": "monitor-notification-rule",
                        "description": "Monitor notification rule resource type.",
                        "enum": ["monitor-notification-rule"],
                        "example": "monitor-notification-rule",
                        "type": "string",
                        "x-enum-varnames": ["MONITOR_NOTIFICATION_RULE"],
                    },
                },
                "required": ["id", "attributes"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "CREATEMONITORCONFIGPOLICY_REQUEST_BODY_SCHEMA": {
        "description": "Request for creating a monitor configuration policy.",
        "properties": {
            "data": {
                "description": "A monitor configuration policy data.",
                "properties": {
                    "attributes": {
                        "description": "Policy and policy type for a monitor configuration policy.",
                        "properties": {
                            "policy": {
                                "description": "Configuration for the policy.",
                                "oneOf": [
                                    {
                                        "description": "Tag "
                                        "attributes "
                                        "of "
                                        "a "
                                        "monitor "
                                        "configuration "
                                        "policy.",
                                        "properties": {
                                            "tag_key": {
                                                "description": "The key of the tag.",
                                                "example": "datacenter",
                                                "maxLength": 255,
                                                "type": "string",
                                            },
                                            "tag_key_required": {
                                                "description": "If "
                                                "a "
                                                "tag "
                                                "key "
                                                "is "
                                                "required "
                                                "for "
                                                "monitor "
                                                "creation.",
                                                "example": True,
                                                "type": "boolean",
                                            },
                                            "valid_tag_values": {
                                                "description": "Valid values for the tag.",
                                                "example": ["prod", "staging"],
                                                "items": {"maxLength": 255, "type": "string"},
                                                "type": "array",
                                            },
                                        },
                                        "required": [
                                            "tag_key",
                                            "tag_key_required",
                                            "valid_tag_values",
                                        ],
                                        "type": "object",
                                    }
                                ],
                            },
                            "policy_type": {
                                "default": "tag",
                                "description": "The monitor configuration policy type.",
                                "enum": ["tag"],
                                "example": "tag",
                                "type": "string",
                                "x-enum-varnames": ["TAG"],
                            },
                        },
                        "required": ["policy_type", "policy"],
                        "type": "object",
                    },
                    "type": {
                        "default": "monitor-config-policy",
                        "description": "Monitor configuration policy resource type.",
                        "enum": ["monitor-config-policy"],
                        "example": "monitor-config-policy",
                        "type": "string",
                        "x-enum-varnames": ["MONITOR_CONFIG_POLICY"],
                    },
                },
                "required": ["type", "attributes"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "EDITMONITORCONFIGPOLICY_REQUEST_BODY_SCHEMA": {
        "description": "Request for editing a monitor configuration policy.",
        "properties": {
            "data": {
                "description": "A monitor configuration policy data.",
                "properties": {
                    "attributes": {
                        "description": "Policy and policy type for a monitor configuration policy.",
                        "properties": {
                            "policy": {
                                "description": "Configuration for the policy.",
                                "oneOf": [
                                    {
                                        "description": "Tag "
                                        "attributes "
                                        "of "
                                        "a "
                                        "monitor "
                                        "configuration "
                                        "policy.",
                                        "properties": {
                                            "tag_key": {
                                                "description": "The key of the tag.",
                                                "example": "datacenter",
                                                "maxLength": 255,
                                                "type": "string",
                                            },
                                            "tag_key_required": {
                                                "description": "If "
                                                "a "
                                                "tag "
                                                "key "
                                                "is "
                                                "required "
                                                "for "
                                                "monitor "
                                                "creation.",
                                                "example": True,
                                                "type": "boolean",
                                            },
                                            "valid_tag_values": {
                                                "description": "Valid values for the tag.",
                                                "example": ["prod", "staging"],
                                                "items": {"maxLength": 255, "type": "string"},
                                                "type": "array",
                                            },
                                        },
                                        "type": "object",
                                    }
                                ],
                            },
                            "policy_type": {
                                "default": "tag",
                                "description": "The monitor configuration policy type.",
                                "enum": ["tag"],
                                "example": "tag",
                                "type": "string",
                                "x-enum-varnames": ["TAG"],
                            },
                        },
                        "required": ["policy_type", "policy"],
                        "type": "object",
                    },
                    "id": {
                        "description": "ID of this monitor configuration policy.",
                        "example": "00000000-0000-1234-0000-000000000000",
                        "type": "string",
                    },
                    "type": {
                        "default": "monitor-config-policy",
                        "description": "Monitor configuration policy resource type.",
                        "enum": ["monitor-config-policy"],
                        "example": "monitor-config-policy",
                        "type": "string",
                        "x-enum-varnames": ["MONITOR_CONFIG_POLICY"],
                    },
                },
                "required": ["id", "type", "attributes"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "CREATEMONITORUSERTEMPLATE_REQUEST_BODY_SCHEMA": {
        "description": "Request for creating a monitor user template.",
        "properties": {
            "data": {
                "description": "Monitor user template data.",
                "properties": {
                    "attributes": {
                        "additionalProperties": False,
                        "description": "Attributes for a monitor user template.",
                        "properties": {
                            "description": {
                                "description": "A brief description of the monitor user template.",
                                "example": "This is a template for monitoring user activity.",
                                "nullable": True,
                                "type": "string",
                            },
                            "monitor_definition": {
                                "additionalProperties": {},
                                "description": "A "
                                "valid "
                                "monitor "
                                "definition "
                                "in "
                                "the "
                                "same "
                                "format "
                                "as "
                                "the "
                                "[V1 "
                                "Monitor "
                                "API](https://docs.datadoghq.com/api/latest/monitors/#create-a-monitor).",
                                "example": {
                                    "message": "You "
                                    "may "
                                    "need "
                                    "to "
                                    "add "
                                    "web "
                                    "hosts "
                                    "if "
                                    "this "
                                    "is "
                                    "consistently "
                                    "high.",
                                    "name": "Bytes received on host0",
                                    "query": "avg(last_5m):sum:system.net.bytes_rcvd{host:host0} "
                                    "> "
                                    "100",
                                    "type": "query alert",
                                },
                                "type": "object",
                            },
                            "tags": {
                                "description": "The "
                                "definition "
                                "of "
                                "`MonitorUserTemplateTags` "
                                "object.",
                                "example": ["product:Our Custom App", "integration:Azure"],
                                "items": {
                                    "description": "Tags "
                                    "associated "
                                    "with "
                                    "the "
                                    "monitor "
                                    "user "
                                    "template. "
                                    "Must "
                                    "be "
                                    "key "
                                    "value. "
                                    "Only "
                                    "'product' "
                                    "and "
                                    "'integration' "
                                    "keys "
                                    "are\n"
                                    "allowed. "
                                    "The "
                                    "value "
                                    "is "
                                    "the "
                                    "name "
                                    "of "
                                    "the "
                                    "category "
                                    "to "
                                    "display "
                                    "the "
                                    "template "
                                    "under. "
                                    "Integrations "
                                    "can "
                                    "be "
                                    "filtered "
                                    "out "
                                    "in "
                                    "the "
                                    "UI.\n"
                                    "(Review "
                                    "note: "
                                    "This "
                                    "modeling "
                                    "of "
                                    "'categories' "
                                    "is "
                                    "subject "
                                    "to "
                                    "change.)",
                                    "example": "us-east1",
                                    "minLength": 1,
                                    "type": "string",
                                    "uniqueItems": True,
                                },
                                "type": "array",
                            },
                            "template_variables": {
                                "description": "The "
                                "definition "
                                "of "
                                "`MonitorUserTemplateTemplateVariables` "
                                "object.",
                                "items": {
                                    "additionalProperties": False,
                                    "description": "List "
                                    "of "
                                    "objects "
                                    "representing "
                                    "template "
                                    "variables "
                                    "on "
                                    "the "
                                    "monitor "
                                    "which "
                                    "can "
                                    "have "
                                    "selectable "
                                    "values.",
                                    "properties": {
                                        "available_values": {
                                            "description": "Available values for the variable.",
                                            "example": ["value1", "value2"],
                                            "items": {
                                                "minLength": 1,
                                                "type": "string",
                                                "uniqueItems": True,
                                            },
                                            "type": "array",
                                        },
                                        "defaults": {
                                            "description": "Default "
                                            "values "
                                            "of "
                                            "the "
                                            "template "
                                            "variable.",
                                            "example": ["defaultValue"],
                                            "items": {
                                                "minLength": 0,
                                                "type": "string",
                                                "uniqueItems": True,
                                            },
                                            "type": "array",
                                        },
                                        "name": {
                                            "description": "The name of the template variable.",
                                            "example": "regionName",
                                            "type": "string",
                                        },
                                        "tag_key": {
                                            "description": "The "
                                            "tag "
                                            "key "
                                            "associated "
                                            "with "
                                            "the "
                                            "variable. "
                                            "This "
                                            "works "
                                            "the "
                                            "same "
                                            "as "
                                            "dashboard "
                                            "template "
                                            "variables.",
                                            "example": "datacenter",
                                            "type": "string",
                                        },
                                    },
                                    "required": ["name"],
                                    "type": "object",
                                },
                                "type": "array",
                            },
                            "title": {
                                "description": "The title of the monitor user template.",
                                "example": "Postgres CPU Monitor",
                                "type": "string",
                            },
                        },
                        "required": ["title", "monitor_definition", "tags"],
                        "type": "object",
                    },
                    "type": {
                        "default": "monitor-user-template",
                        "description": "Monitor user template resource type.",
                        "enum": ["monitor-user-template"],
                        "example": "monitor-user-template",
                        "type": "string",
                        "x-enum-varnames": ["MONITOR_USER_TEMPLATE"],
                    },
                },
                "required": ["type", "attributes"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "VALIDATEMONITORUSERTEMPLATE_REQUEST_BODY_SCHEMA": {
        "description": "Request for creating a monitor user template.",
        "properties": {
            "data": {
                "description": "Monitor user template data.",
                "properties": {
                    "attributes": {
                        "additionalProperties": False,
                        "description": "Attributes for a monitor user template.",
                        "properties": {
                            "description": {
                                "description": "A brief description of the monitor user template.",
                                "example": "This is a template for monitoring user activity.",
                                "nullable": True,
                                "type": "string",
                            },
                            "monitor_definition": {
                                "additionalProperties": {},
                                "description": "A "
                                "valid "
                                "monitor "
                                "definition "
                                "in "
                                "the "
                                "same "
                                "format "
                                "as "
                                "the "
                                "[V1 "
                                "Monitor "
                                "API](https://docs.datadoghq.com/api/latest/monitors/#create-a-monitor).",
                                "example": {
                                    "message": "You "
                                    "may "
                                    "need "
                                    "to "
                                    "add "
                                    "web "
                                    "hosts "
                                    "if "
                                    "this "
                                    "is "
                                    "consistently "
                                    "high.",
                                    "name": "Bytes received on host0",
                                    "query": "avg(last_5m):sum:system.net.bytes_rcvd{host:host0} "
                                    "> "
                                    "100",
                                    "type": "query alert",
                                },
                                "type": "object",
                            },
                            "tags": {
                                "description": "The "
                                "definition "
                                "of "
                                "`MonitorUserTemplateTags` "
                                "object.",
                                "example": ["product:Our Custom App", "integration:Azure"],
                                "items": {
                                    "description": "Tags "
                                    "associated "
                                    "with "
                                    "the "
                                    "monitor "
                                    "user "
                                    "template. "
                                    "Must "
                                    "be "
                                    "key "
                                    "value. "
                                    "Only "
                                    "'product' "
                                    "and "
                                    "'integration' "
                                    "keys "
                                    "are\n"
                                    "allowed. "
                                    "The "
                                    "value "
                                    "is "
                                    "the "
                                    "name "
                                    "of "
                                    "the "
                                    "category "
                                    "to "
                                    "display "
                                    "the "
                                    "template "
                                    "under. "
                                    "Integrations "
                                    "can "
                                    "be "
                                    "filtered "
                                    "out "
                                    "in "
                                    "the "
                                    "UI.\n"
                                    "(Review "
                                    "note: "
                                    "This "
                                    "modeling "
                                    "of "
                                    "'categories' "
                                    "is "
                                    "subject "
                                    "to "
                                    "change.)",
                                    "example": "us-east1",
                                    "minLength": 1,
                                    "type": "string",
                                    "uniqueItems": True,
                                },
                                "type": "array",
                            },
                            "template_variables": {
                                "description": "The "
                                "definition "
                                "of "
                                "`MonitorUserTemplateTemplateVariables` "
                                "object.",
                                "items": {
                                    "additionalProperties": False,
                                    "description": "List "
                                    "of "
                                    "objects "
                                    "representing "
                                    "template "
                                    "variables "
                                    "on "
                                    "the "
                                    "monitor "
                                    "which "
                                    "can "
                                    "have "
                                    "selectable "
                                    "values.",
                                    "properties": {
                                        "available_values": {
                                            "description": "Available values for the variable.",
                                            "example": ["value1", "value2"],
                                            "items": {
                                                "minLength": 1,
                                                "type": "string",
                                                "uniqueItems": True,
                                            },
                                            "type": "array",
                                        },
                                        "defaults": {
                                            "description": "Default "
                                            "values "
                                            "of "
                                            "the "
                                            "template "
                                            "variable.",
                                            "example": ["defaultValue"],
                                            "items": {
                                                "minLength": 0,
                                                "type": "string",
                                                "uniqueItems": True,
                                            },
                                            "type": "array",
                                        },
                                        "name": {
                                            "description": "The name of the template variable.",
                                            "example": "regionName",
                                            "type": "string",
                                        },
                                        "tag_key": {
                                            "description": "The "
                                            "tag "
                                            "key "
                                            "associated "
                                            "with "
                                            "the "
                                            "variable. "
                                            "This "
                                            "works "
                                            "the "
                                            "same "
                                            "as "
                                            "dashboard "
                                            "template "
                                            "variables.",
                                            "example": "datacenter",
                                            "type": "string",
                                        },
                                    },
                                    "required": ["name"],
                                    "type": "object",
                                },
                                "type": "array",
                            },
                            "title": {
                                "description": "The title of the monitor user template.",
                                "example": "Postgres CPU Monitor",
                                "type": "string",
                            },
                        },
                        "required": ["title", "monitor_definition", "tags"],
                        "type": "object",
                    },
                    "type": {
                        "default": "monitor-user-template",
                        "description": "Monitor user template resource type.",
                        "enum": ["monitor-user-template"],
                        "example": "monitor-user-template",
                        "type": "string",
                        "x-enum-varnames": ["MONITOR_USER_TEMPLATE"],
                    },
                },
                "required": ["type", "attributes"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "UPDATEMONITORUSERTEMPLATE_REQUEST_BODY_SCHEMA": {
        "description": "Request for creating a new monitor user template version.",
        "properties": {
            "data": {
                "description": "Monitor user template data.",
                "properties": {
                    "attributes": {
                        "additionalProperties": False,
                        "description": "Attributes for a monitor user template.",
                        "properties": {
                            "description": {
                                "description": "A brief description of the monitor user template.",
                                "example": "This is a template for monitoring user activity.",
                                "nullable": True,
                                "type": "string",
                            },
                            "monitor_definition": {
                                "additionalProperties": {},
                                "description": "A "
                                "valid "
                                "monitor "
                                "definition "
                                "in "
                                "the "
                                "same "
                                "format "
                                "as "
                                "the "
                                "[V1 "
                                "Monitor "
                                "API](https://docs.datadoghq.com/api/latest/monitors/#create-a-monitor).",
                                "example": {
                                    "message": "You "
                                    "may "
                                    "need "
                                    "to "
                                    "add "
                                    "web "
                                    "hosts "
                                    "if "
                                    "this "
                                    "is "
                                    "consistently "
                                    "high.",
                                    "name": "Bytes received on host0",
                                    "query": "avg(last_5m):sum:system.net.bytes_rcvd{host:host0} "
                                    "> "
                                    "100",
                                    "type": "query alert",
                                },
                                "type": "object",
                            },
                            "tags": {
                                "description": "The "
                                "definition "
                                "of "
                                "`MonitorUserTemplateTags` "
                                "object.",
                                "example": ["product:Our Custom App", "integration:Azure"],
                                "items": {
                                    "description": "Tags "
                                    "associated "
                                    "with "
                                    "the "
                                    "monitor "
                                    "user "
                                    "template. "
                                    "Must "
                                    "be "
                                    "key "
                                    "value. "
                                    "Only "
                                    "'product' "
                                    "and "
                                    "'integration' "
                                    "keys "
                                    "are\n"
                                    "allowed. "
                                    "The "
                                    "value "
                                    "is "
                                    "the "
                                    "name "
                                    "of "
                                    "the "
                                    "category "
                                    "to "
                                    "display "
                                    "the "
                                    "template "
                                    "under. "
                                    "Integrations "
                                    "can "
                                    "be "
                                    "filtered "
                                    "out "
                                    "in "
                                    "the "
                                    "UI.\n"
                                    "(Review "
                                    "note: "
                                    "This "
                                    "modeling "
                                    "of "
                                    "'categories' "
                                    "is "
                                    "subject "
                                    "to "
                                    "change.)",
                                    "example": "us-east1",
                                    "minLength": 1,
                                    "type": "string",
                                    "uniqueItems": True,
                                },
                                "type": "array",
                            },
                            "template_variables": {
                                "description": "The "
                                "definition "
                                "of "
                                "`MonitorUserTemplateTemplateVariables` "
                                "object.",
                                "items": {
                                    "additionalProperties": False,
                                    "description": "List "
                                    "of "
                                    "objects "
                                    "representing "
                                    "template "
                                    "variables "
                                    "on "
                                    "the "
                                    "monitor "
                                    "which "
                                    "can "
                                    "have "
                                    "selectable "
                                    "values.",
                                    "properties": {
                                        "available_values": {
                                            "description": "Available values for the variable.",
                                            "example": ["value1", "value2"],
                                            "items": {
                                                "minLength": 1,
                                                "type": "string",
                                                "uniqueItems": True,
                                            },
                                            "type": "array",
                                        },
                                        "defaults": {
                                            "description": "Default "
                                            "values "
                                            "of "
                                            "the "
                                            "template "
                                            "variable.",
                                            "example": ["defaultValue"],
                                            "items": {
                                                "minLength": 0,
                                                "type": "string",
                                                "uniqueItems": True,
                                            },
                                            "type": "array",
                                        },
                                        "name": {
                                            "description": "The name of the template variable.",
                                            "example": "regionName",
                                            "type": "string",
                                        },
                                        "tag_key": {
                                            "description": "The "
                                            "tag "
                                            "key "
                                            "associated "
                                            "with "
                                            "the "
                                            "variable. "
                                            "This "
                                            "works "
                                            "the "
                                            "same "
                                            "as "
                                            "dashboard "
                                            "template "
                                            "variables.",
                                            "example": "datacenter",
                                            "type": "string",
                                        },
                                    },
                                    "required": ["name"],
                                    "type": "object",
                                },
                                "type": "array",
                            },
                            "title": {
                                "description": "The title of the monitor user template.",
                                "example": "Postgres CPU Monitor",
                                "type": "string",
                            },
                        },
                        "required": ["title", "monitor_definition", "tags"],
                        "type": "object",
                    },
                    "id": {
                        "description": "The unique identifier.",
                        "example": "00000000-0000-1234-0000-000000000000",
                        "type": "string",
                    },
                    "type": {
                        "default": "monitor-user-template",
                        "description": "Monitor user template resource type.",
                        "enum": ["monitor-user-template"],
                        "example": "monitor-user-template",
                        "type": "string",
                        "x-enum-varnames": ["MONITOR_USER_TEMPLATE"],
                    },
                },
                "required": ["id", "type", "attributes"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "VALIDATEMONITORTEMPLATE_REQUEST_BODY_SCHEMA": {
        "description": "Request for creating a new monitor user template version.",
        "properties": {
            "data": {
                "description": "Monitor user template data.",
                "properties": {
                    "attributes": {
                        "additionalProperties": False,
                        "description": "Attributes for a monitor user template.",
                        "properties": {
                            "description": {
                                "description": "A brief description of the monitor user template.",
                                "example": "This is a template for monitoring user activity.",
                                "nullable": True,
                                "type": "string",
                            },
                            "monitor_definition": {
                                "additionalProperties": {},
                                "description": "A "
                                "valid "
                                "monitor "
                                "definition "
                                "in "
                                "the "
                                "same "
                                "format "
                                "as "
                                "the "
                                "[V1 "
                                "Monitor "
                                "API](https://docs.datadoghq.com/api/latest/monitors/#create-a-monitor).",
                                "example": {
                                    "message": "You "
                                    "may "
                                    "need "
                                    "to "
                                    "add "
                                    "web "
                                    "hosts "
                                    "if "
                                    "this "
                                    "is "
                                    "consistently "
                                    "high.",
                                    "name": "Bytes received on host0",
                                    "query": "avg(last_5m):sum:system.net.bytes_rcvd{host:host0} "
                                    "> "
                                    "100",
                                    "type": "query alert",
                                },
                                "type": "object",
                            },
                            "tags": {
                                "description": "The "
                                "definition "
                                "of "
                                "`MonitorUserTemplateTags` "
                                "object.",
                                "example": ["product:Our Custom App", "integration:Azure"],
                                "items": {
                                    "description": "Tags "
                                    "associated "
                                    "with "
                                    "the "
                                    "monitor "
                                    "user "
                                    "template. "
                                    "Must "
                                    "be "
                                    "key "
                                    "value. "
                                    "Only "
                                    "'product' "
                                    "and "
                                    "'integration' "
                                    "keys "
                                    "are\n"
                                    "allowed. "
                                    "The "
                                    "value "
                                    "is "
                                    "the "
                                    "name "
                                    "of "
                                    "the "
                                    "category "
                                    "to "
                                    "display "
                                    "the "
                                    "template "
                                    "under. "
                                    "Integrations "
                                    "can "
                                    "be "
                                    "filtered "
                                    "out "
                                    "in "
                                    "the "
                                    "UI.\n"
                                    "(Review "
                                    "note: "
                                    "This "
                                    "modeling "
                                    "of "
                                    "'categories' "
                                    "is "
                                    "subject "
                                    "to "
                                    "change.)",
                                    "example": "us-east1",
                                    "minLength": 1,
                                    "type": "string",
                                    "uniqueItems": True,
                                },
                                "type": "array",
                            },
                            "template_variables": {
                                "description": "The "
                                "definition "
                                "of "
                                "`MonitorUserTemplateTemplateVariables` "
                                "object.",
                                "items": {
                                    "additionalProperties": False,
                                    "description": "List "
                                    "of "
                                    "objects "
                                    "representing "
                                    "template "
                                    "variables "
                                    "on "
                                    "the "
                                    "monitor "
                                    "which "
                                    "can "
                                    "have "
                                    "selectable "
                                    "values.",
                                    "properties": {
                                        "available_values": {
                                            "description": "Available values for the variable.",
                                            "example": ["value1", "value2"],
                                            "items": {
                                                "minLength": 1,
                                                "type": "string",
                                                "uniqueItems": True,
                                            },
                                            "type": "array",
                                        },
                                        "defaults": {
                                            "description": "Default "
                                            "values "
                                            "of "
                                            "the "
                                            "template "
                                            "variable.",
                                            "example": ["defaultValue"],
                                            "items": {
                                                "minLength": 0,
                                                "type": "string",
                                                "uniqueItems": True,
                                            },
                                            "type": "array",
                                        },
                                        "name": {
                                            "description": "The name of the template variable.",
                                            "example": "regionName",
                                            "type": "string",
                                        },
                                        "tag_key": {
                                            "description": "The "
                                            "tag "
                                            "key "
                                            "associated "
                                            "with "
                                            "the "
                                            "variable. "
                                            "This "
                                            "works "
                                            "the "
                                            "same "
                                            "as "
                                            "dashboard "
                                            "template "
                                            "variables.",
                                            "example": "datacenter",
                                            "type": "string",
                                        },
                                    },
                                    "required": ["name"],
                                    "type": "object",
                                },
                                "type": "array",
                            },
                            "title": {
                                "description": "The title of the monitor user template.",
                                "example": "Postgres CPU Monitor",
                                "type": "string",
                            },
                        },
                        "required": ["title", "monitor_definition", "tags"],
                        "type": "object",
                    },
                    "id": {
                        "description": "The unique identifier.",
                        "example": "00000000-0000-1234-0000-000000000000",
                        "type": "string",
                    },
                    "type": {
                        "default": "monitor-user-template",
                        "description": "Monitor user template resource type.",
                        "enum": ["monitor-user-template"],
                        "example": "monitor-user-template",
                        "type": "string",
                        "x-enum-varnames": ["MONITOR_USER_TEMPLATE"],
                    },
                },
                "required": ["id", "type", "attributes"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "CREATEONCALLESCALATIONPOLICY_REQUEST_BODY_SCHEMA": {
        "description": "Represents a request to create a new escalation policy, including the "
        "policy data.",
        "example": {
            "data": {
                "attributes": {
                    "name": "Escalation Policy 1",
                    "resolve_page_on_policy_end": True,
                    "retries": 2,
                    "steps": [
                        {
                            "assignment": "default",
                            "escalate_after_seconds": 3600,
                            "targets": [
                                {"id": "00000000-aba1-0000-0000-000000000000", "type": "users"},
                                {"id": "00000000-aba2-0000-0000-000000000000", "type": "schedules"},
                                {"id": "00000000-aba3-0000-0000-000000000000", "type": "teams"},
                            ],
                        },
                        {
                            "assignment": "round-robin",
                            "escalate_after_seconds": 3600,
                            "targets": [
                                {"id": "00000000-aba1-0000-0000-000000000000", "type": "users"},
                                {"id": "00000000-abb1-0000-0000-000000000000", "type": "users"},
                            ],
                        },
                    ],
                },
                "relationships": {
                    "teams": {
                        "data": [{"id": "00000000-da3a-0000-0000-000000000000", "type": "teams"}]
                    }
                },
                "type": "policies",
            }
        },
        "properties": {
            "data": {
                "description": "Represents the data for creating an "
                "escalation policy, including its attributes, "
                "relationships, and resource type.",
                "properties": {
                    "attributes": {
                        "description": "Defines the "
                        "attributes for "
                        "creating an "
                        "escalation "
                        "policy, "
                        "including its "
                        "description, "
                        "name, "
                        "resolution "
                        "behavior, "
                        "retries, and "
                        "steps.",
                        "properties": {
                            "name": {
                                "description": "Specifies the name for the new escalation policy.",
                                "example": "On-Call Escalation Policy",
                                "type": "string",
                            },
                            "resolve_page_on_policy_end": {
                                "description": "Indicates "
                                "whether "
                                "the "
                                "page "
                                "is "
                                "automatically "
                                "resolved "
                                "when "
                                "the "
                                "policy "
                                "ends.",
                                "type": "boolean",
                            },
                            "retries": {
                                "description": "Specifies "
                                "how "
                                "many "
                                "times "
                                "the "
                                "escalation "
                                "sequence "
                                "is "
                                "retried "
                                "if "
                                "there "
                                "is "
                                "no "
                                "response.",
                                "format": "int64",
                                "type": "integer",
                            },
                            "steps": {
                                "description": "A "
                                "list "
                                "of "
                                "escalation "
                                "steps, "
                                "each "
                                "defining "
                                "assignment, "
                                "escalation "
                                "timeout, "
                                "and "
                                "targets "
                                "for "
                                "the "
                                "new "
                                "policy.",
                                "items": {
                                    "description": "Defines "
                                    "a "
                                    "single "
                                    "escalation "
                                    "step "
                                    "within "
                                    "an "
                                    "escalation "
                                    "policy "
                                    "creation "
                                    "request. "
                                    "Contains "
                                    "assignment "
                                    "strategy, "
                                    "escalation "
                                    "timeout, "
                                    "and "
                                    "a "
                                    "list "
                                    "of "
                                    "targets.",
                                    "properties": {
                                        "assignment": {
                                            "description": "Specifies "
                                            "how "
                                            "this "
                                            "escalation "
                                            "step "
                                            "will "
                                            "assign "
                                            "targets "
                                            "(example "
                                            "`default` "
                                            "or "
                                            "`round-robin`).",
                                            "enum": ["default", "round-robin"],
                                            "type": "string",
                                            "x-enum-varnames": ["DEFAULT", "ROUND_ROBIN"],
                                        },
                                        "escalate_after_seconds": {
                                            "description": "Defines "
                                            "how "
                                            "many "
                                            "seconds "
                                            "to "
                                            "wait "
                                            "before "
                                            "escalating "
                                            "to "
                                            "the "
                                            "next "
                                            "step.",
                                            "example": 3600,
                                            "format": "int64",
                                            "type": "integer",
                                        },
                                        "targets": {
                                            "description": "Specifies "
                                            "the "
                                            "collection "
                                            "of "
                                            "escalation "
                                            "targets "
                                            "for "
                                            "this "
                                            "step.",
                                            "example": ["users"],
                                            "items": {
                                                "description": "Defines "
                                                "a "
                                                "single "
                                                "escalation "
                                                "target "
                                                "within "
                                                "a "
                                                "step "
                                                "for "
                                                "an "
                                                "escalation "
                                                "policy "
                                                "creation "
                                                "request. "
                                                "Contains "
                                                "`id` "
                                                "and "
                                                "`type`.",
                                                "properties": {
                                                    "id": {
                                                        "description": "Specifies "
                                                        "the "
                                                        "unique "
                                                        "identifier "
                                                        "for "
                                                        "this "
                                                        "target.",
                                                        "example": "00000000-aba1-0000-0000-000000000000",
                                                        "type": "string",
                                                    },
                                                    "type": {
                                                        "description": "Specifies "
                                                        "the "
                                                        "type "
                                                        "of "
                                                        "escalation "
                                                        "target "
                                                        "(example "
                                                        "`users`, "
                                                        "`schedules`, "
                                                        "or "
                                                        "`teams`).",
                                                        "enum": ["users", "schedules", "teams"],
                                                        "example": "users",
                                                        "type": "string",
                                                        "x-enum-varnames": [
                                                            "USERS",
                                                            "SCHEDULES",
                                                            "TEAMS",
                                                        ],
                                                    },
                                                },
                                                "type": "object",
                                            },
                                            "type": "array",
                                        },
                                    },
                                    "required": ["targets"],
                                    "type": "object",
                                },
                                "type": "array",
                            },
                        },
                        "required": ["name", "steps"],
                        "type": "object",
                    },
                    "relationships": {
                        "description": "Represents "
                        "relationships "
                        "in an "
                        "escalation "
                        "policy "
                        "creation "
                        "request, "
                        "including "
                        "references "
                        "to teams.",
                        "properties": {
                            "teams": {
                                "description": "Associates "
                                "teams "
                                "with "
                                "this "
                                "schedule "
                                "in "
                                "a "
                                "data "
                                "structure.",
                                "properties": {
                                    "data": {
                                        "description": "An "
                                        "array "
                                        "of "
                                        "team "
                                        "references "
                                        "for "
                                        "this "
                                        "schedule.",
                                        "items": {
                                            "description": "Relates "
                                            "a "
                                            "team "
                                            "to "
                                            "this "
                                            "schedule, "
                                            "identified "
                                            "by "
                                            "`id` "
                                            "and "
                                            "`type` "
                                            "(must "
                                            "be "
                                            "`teams`).",
                                            "properties": {
                                                "id": {
                                                    "description": "The "
                                                    "unique "
                                                    "identifier "
                                                    "of "
                                                    "the "
                                                    "team "
                                                    "in "
                                                    "this "
                                                    "relationship.",
                                                    "example": "00000000-da3a-0000-0000-000000000000",
                                                    "type": "string",
                                                },
                                                "type": {
                                                    "default": "teams",
                                                    "description": "Teams resource type.",
                                                    "enum": ["teams"],
                                                    "example": "teams",
                                                    "type": "string",
                                                    "x-enum-varnames": ["TEAMS"],
                                                },
                                            },
                                            "required": ["type", "id"],
                                            "type": "object",
                                        },
                                        "type": "array",
                                    }
                                },
                                "type": "object",
                            }
                        },
                        "type": "object",
                    },
                    "type": {
                        "default": "policies",
                        "description": "Indicates that the resource is of type `policies`.",
                        "enum": ["policies"],
                        "example": "policies",
                        "type": "string",
                        "x-enum-varnames": ["POLICIES"],
                    },
                },
                "required": ["type", "attributes"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "UPDATEONCALLESCALATIONPOLICY_REQUEST_BODY_SCHEMA": {
        "description": "Represents a request to update an existing escalation policy, "
        "including the updated policy data.",
        "example": {
            "data": {
                "attributes": {
                    "name": "Escalation Policy 1",
                    "resolve_page_on_policy_end": False,
                    "retries": 2,
                    "steps": [
                        {
                            "assignment": "default",
                            "escalate_after_seconds": 3600,
                            "id": "00000000-aba1-0000-0000-000000000000",
                            "targets": [
                                {"id": "00000000-aba1-0000-0000-000000000000", "type": "users"},
                                {"id": "00000000-aba2-0000-0000-000000000000", "type": "schedules"},
                            ],
                        }
                    ],
                },
                "id": "a3000000-0000-0000-0000-000000000000",
                "relationships": {
                    "teams": {
                        "data": [{"id": "00000000-da3a-0000-0000-000000000000", "type": "teams"}]
                    }
                },
                "type": "policies",
            }
        },
        "properties": {
            "data": {
                "description": "Represents the data for updating an existing "
                "escalation policy, including its ID, "
                "attributes, relationships, and resource type.",
                "properties": {
                    "attributes": {
                        "description": "Defines the "
                        "attributes that "
                        "can be updated "
                        "for an "
                        "escalation "
                        "policy, such as "
                        "description, "
                        "name, "
                        "resolution "
                        "behavior, "
                        "retries, and "
                        "steps.",
                        "properties": {
                            "name": {
                                "description": "Specifies the name of the escalation policy.",
                                "example": "On-Call Escalation Policy",
                                "type": "string",
                            },
                            "resolve_page_on_policy_end": {
                                "description": "Indicates "
                                "whether "
                                "the "
                                "page "
                                "is "
                                "automatically "
                                "resolved "
                                "when "
                                "the "
                                "policy "
                                "ends.",
                                "type": "boolean",
                            },
                            "retries": {
                                "description": "Specifies "
                                "how "
                                "many "
                                "times "
                                "the "
                                "escalation "
                                "sequence "
                                "is "
                                "retried "
                                "if "
                                "there "
                                "is "
                                "no "
                                "response.",
                                "format": "int64",
                                "type": "integer",
                            },
                            "steps": {
                                "description": "A "
                                "list "
                                "of "
                                "escalation "
                                "steps, "
                                "each "
                                "defining "
                                "assignment, "
                                "escalation "
                                "timeout, "
                                "and "
                                "targets.",
                                "items": {
                                    "description": "Defines "
                                    "a "
                                    "single "
                                    "escalation "
                                    "step "
                                    "within "
                                    "an "
                                    "escalation "
                                    "policy "
                                    "update "
                                    "request. "
                                    "Contains "
                                    "assignment "
                                    "strategy, "
                                    "escalation "
                                    "timeout, "
                                    "an "
                                    "optional "
                                    "step "
                                    "ID, "
                                    "and "
                                    "a "
                                    "list "
                                    "of "
                                    "targets.",
                                    "properties": {
                                        "assignment": {
                                            "description": "Specifies "
                                            "how "
                                            "this "
                                            "escalation "
                                            "step "
                                            "will "
                                            "assign "
                                            "targets "
                                            "(example "
                                            "`default` "
                                            "or "
                                            "`round-robin`).",
                                            "enum": ["default", "round-robin"],
                                            "type": "string",
                                            "x-enum-varnames": ["DEFAULT", "ROUND_ROBIN"],
                                        },
                                        "escalate_after_seconds": {
                                            "description": "Defines "
                                            "how "
                                            "many "
                                            "seconds "
                                            "to "
                                            "wait "
                                            "before "
                                            "escalating "
                                            "to "
                                            "the "
                                            "next "
                                            "step.",
                                            "example": 3600,
                                            "format": "int64",
                                            "type": "integer",
                                        },
                                        "id": {
                                            "description": "Specifies "
                                            "the "
                                            "unique "
                                            "identifier "
                                            "of "
                                            "this "
                                            "step.",
                                            "example": "00000000-aba1-0000-0000-000000000000",
                                            "type": "string",
                                        },
                                        "targets": {
                                            "description": "Specifies "
                                            "the "
                                            "collection "
                                            "of "
                                            "escalation "
                                            "targets "
                                            "for "
                                            "this "
                                            "step.",
                                            "items": {
                                                "description": "Defines "
                                                "a "
                                                "single "
                                                "escalation "
                                                "target "
                                                "within "
                                                "a "
                                                "step "
                                                "for "
                                                "an "
                                                "escalation "
                                                "policy "
                                                "creation "
                                                "request. "
                                                "Contains "
                                                "`id` "
                                                "and "
                                                "`type`.",
                                                "properties": {
                                                    "id": {
                                                        "description": "Specifies "
                                                        "the "
                                                        "unique "
                                                        "identifier "
                                                        "for "
                                                        "this "
                                                        "target.",
                                                        "example": "00000000-aba1-0000-0000-000000000000",
                                                        "type": "string",
                                                    },
                                                    "type": {
                                                        "description": "Specifies "
                                                        "the "
                                                        "type "
                                                        "of "
                                                        "escalation "
                                                        "target "
                                                        "(example "
                                                        "`users`, "
                                                        "`schedules`, "
                                                        "or "
                                                        "`teams`).",
                                                        "enum": ["users", "schedules", "teams"],
                                                        "example": "users",
                                                        "type": "string",
                                                        "x-enum-varnames": [
                                                            "USERS",
                                                            "SCHEDULES",
                                                            "TEAMS",
                                                        ],
                                                    },
                                                },
                                                "type": "object",
                                            },
                                            "type": "array",
                                        },
                                    },
                                    "required": ["targets"],
                                    "type": "object",
                                },
                                "type": "array",
                            },
                        },
                        "required": ["name", "steps"],
                        "type": "object",
                    },
                    "id": {
                        "description": "Specifies the unique "
                        "identifier of the "
                        "escalation policy being "
                        "updated.",
                        "example": "00000000-aba1-0000-0000-000000000000",
                        "type": "string",
                    },
                    "relationships": {
                        "description": "Represents "
                        "relationships "
                        "in an "
                        "escalation "
                        "policy "
                        "update "
                        "request, "
                        "including "
                        "references "
                        "to teams.",
                        "properties": {
                            "teams": {
                                "description": "Associates "
                                "teams "
                                "with "
                                "this "
                                "schedule "
                                "in "
                                "a "
                                "data "
                                "structure.",
                                "properties": {
                                    "data": {
                                        "description": "An "
                                        "array "
                                        "of "
                                        "team "
                                        "references "
                                        "for "
                                        "this "
                                        "schedule.",
                                        "items": {
                                            "description": "Relates "
                                            "a "
                                            "team "
                                            "to "
                                            "this "
                                            "schedule, "
                                            "identified "
                                            "by "
                                            "`id` "
                                            "and "
                                            "`type` "
                                            "(must "
                                            "be "
                                            "`teams`).",
                                            "properties": {
                                                "id": {
                                                    "description": "The "
                                                    "unique "
                                                    "identifier "
                                                    "of "
                                                    "the "
                                                    "team "
                                                    "in "
                                                    "this "
                                                    "relationship.",
                                                    "example": "00000000-da3a-0000-0000-000000000000",
                                                    "type": "string",
                                                },
                                                "type": {
                                                    "default": "teams",
                                                    "description": "Teams resource type.",
                                                    "enum": ["teams"],
                                                    "example": "teams",
                                                    "type": "string",
                                                    "x-enum-varnames": ["TEAMS"],
                                                },
                                            },
                                            "required": ["type", "id"],
                                            "type": "object",
                                        },
                                        "type": "array",
                                    }
                                },
                                "type": "object",
                            }
                        },
                        "type": "object",
                    },
                    "type": {
                        "default": "policies",
                        "description": "Indicates that the resource is of type `policies`.",
                        "enum": ["policies"],
                        "example": "policies",
                        "type": "string",
                        "x-enum-varnames": ["POLICIES"],
                    },
                },
                "required": ["type", "id", "attributes"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "CREATEONCALLSCHEDULE_REQUEST_BODY_SCHEMA": {
        "description": "The top-level request body for schedule creation, wrapping a `data` "
        "object.",
        "example": {
            "data": {
                "attributes": {
                    "layers": [
                        {
                            "effective_date": "2025-02-03T05:00:00Z",
                            "end_date": "2025-12-31T00:00:00Z",
                            "interval": {"days": 1},
                            "members": [{"user": {"id": "00000000-aba1-0000-0000-000000000000"}}],
                            "name": "Layer 1",
                            "restrictions": [
                                {
                                    "end_day": "friday",
                                    "end_time": "17:00:00",
                                    "start_day": "monday",
                                    "start_time": "09:00:00",
                                }
                            ],
                            "rotation_start": "2025-02-01T00:00:00Z",
                        }
                    ],
                    "name": "On-Call Schedule",
                    "time_zone": "America/New_York",
                },
                "relationships": {
                    "teams": {
                        "data": [{"id": "00000000-da3a-0000-0000-000000000000", "type": "teams"}]
                    }
                },
                "type": "schedules",
            }
        },
        "properties": {
            "data": {
                "description": "The core data wrapper for creating a "
                "schedule, encompassing attributes, "
                "relationships, and the resource type.",
                "properties": {
                    "attributes": {
                        "description": "Describes the "
                        "main attributes "
                        "for creating a "
                        "new schedule, "
                        "including name, "
                        "layers, and "
                        "time zone.",
                        "properties": {
                            "layers": {
                                "description": "The "
                                "layers "
                                "of "
                                "On-Call "
                                "coverage "
                                "that "
                                "define "
                                "rotation "
                                "intervals "
                                "and "
                                "restrictions.",
                                "items": {
                                    "description": "Describes "
                                    "a "
                                    "schedule "
                                    "layer, "
                                    "including "
                                    "rotation "
                                    "intervals, "
                                    "members, "
                                    "restrictions, "
                                    "and "
                                    "timeline "
                                    "settings.",
                                    "properties": {
                                        "effective_date": {
                                            "description": "The "
                                            "date/time "
                                            "when "
                                            "this "
                                            "layer "
                                            "becomes "
                                            "active "
                                            "(in "
                                            "ISO "
                                            "8601).",
                                            "example": "2025-01-01T00:00:00Z",
                                            "format": "date-time",
                                            "type": "string",
                                        },
                                        "end_date": {
                                            "description": "The "
                                            "date/time "
                                            "after "
                                            "which "
                                            "this "
                                            "layer "
                                            "no "
                                            "longer "
                                            "applies "
                                            "(in "
                                            "ISO "
                                            "8601).",
                                            "format": "date-time",
                                            "type": "string",
                                        },
                                        "interval": {
                                            "description": "Defines "
                                            "how "
                                            "often "
                                            "the "
                                            "rotation "
                                            "repeats, "
                                            "using "
                                            "a "
                                            "combination "
                                            "of "
                                            "days "
                                            "and "
                                            "optional "
                                            "seconds. "
                                            "Should "
                                            "be "
                                            "at "
                                            "least "
                                            "1 "
                                            "hour.",
                                            "properties": {
                                                "days": {
                                                    "description": "The "
                                                    "number "
                                                    "of "
                                                    "days "
                                                    "in "
                                                    "each "
                                                    "rotation "
                                                    "cycle.",
                                                    "example": 1,
                                                    "format": "int32",
                                                    "maximum": 400,
                                                    "type": "integer",
                                                },
                                                "seconds": {
                                                    "description": "Any "
                                                    "additional "
                                                    "seconds "
                                                    "for "
                                                    "the "
                                                    "rotation "
                                                    "cycle "
                                                    "(up "
                                                    "to "
                                                    "30 "
                                                    "days).",
                                                    "example": 300,
                                                    "format": "int64",
                                                    "maximum": 2592000,
                                                    "type": "integer",
                                                },
                                            },
                                            "type": "object",
                                        },
                                        "members": {
                                            "description": "A "
                                            "list "
                                            "of "
                                            "members "
                                            "who "
                                            "participate "
                                            "in "
                                            "this "
                                            "layer's "
                                            "rotation.",
                                            "items": {
                                                "description": "Defines "
                                                "a "
                                                "single "
                                                "member "
                                                "within "
                                                "a "
                                                "schedule "
                                                "layer, "
                                                "including "
                                                "the "
                                                "reference "
                                                "to "
                                                "the "
                                                "underlying "
                                                "user.",
                                                "properties": {
                                                    "user": {
                                                        "description": "Identifies "
                                                        "the "
                                                        "user "
                                                        "participating "
                                                        "in "
                                                        "this "
                                                        "layer "
                                                        "as "
                                                        "a "
                                                        "single "
                                                        "object "
                                                        "with "
                                                        "an "
                                                        "`id`.",
                                                        "properties": {
                                                            "id": {
                                                                "description": "The user's ID.",
                                                                "example": "00000000-aba1-0000-0000-000000000000",
                                                                "type": "string",
                                                            }
                                                        },
                                                        "type": "object",
                                                    }
                                                },
                                                "type": "object",
                                            },
                                            "type": "array",
                                        },
                                        "name": {
                                            "description": "The name of this layer.",
                                            "example": "Primary On-Call Layer",
                                            "type": "string",
                                        },
                                        "restrictions": {
                                            "description": "Zero "
                                            "or "
                                            "more "
                                            "time-based "
                                            "restrictions "
                                            "(for "
                                            "example, "
                                            "only "
                                            "weekdays, "
                                            "during "
                                            "business "
                                            "hours).",
                                            "items": {
                                                "description": "Defines "
                                                "a "
                                                "single "
                                                "time "
                                                "restriction "
                                                "rule "
                                                "with "
                                                "start "
                                                "and "
                                                "end "
                                                "times "
                                                "and "
                                                "the "
                                                "applicable "
                                                "weekdays.",
                                                "properties": {
                                                    "end_day": {
                                                        "description": "A day of the week.",
                                                        "enum": [
                                                            "monday",
                                                            "tuesday",
                                                            "wednesday",
                                                            "thursday",
                                                            "friday",
                                                            "saturday",
                                                            "sunday",
                                                        ],
                                                        "type": "string",
                                                        "x-enum-varnames": [
                                                            "MONDAY",
                                                            "TUESDAY",
                                                            "WEDNESDAY",
                                                            "THURSDAY",
                                                            "FRIDAY",
                                                            "SATURDAY",
                                                            "SUNDAY",
                                                        ],
                                                    },
                                                    "end_time": {
                                                        "description": "Specifies "
                                                        "the "
                                                        "ending "
                                                        "time "
                                                        "for "
                                                        "this "
                                                        "restriction.",
                                                        "type": "string",
                                                    },
                                                    "start_day": {
                                                        "description": "A day of the week.",
                                                        "enum": [
                                                            "monday",
                                                            "tuesday",
                                                            "wednesday",
                                                            "thursday",
                                                            "friday",
                                                            "saturday",
                                                            "sunday",
                                                        ],
                                                        "type": "string",
                                                        "x-enum-varnames": [
                                                            "MONDAY",
                                                            "TUESDAY",
                                                            "WEDNESDAY",
                                                            "THURSDAY",
                                                            "FRIDAY",
                                                            "SATURDAY",
                                                            "SUNDAY",
                                                        ],
                                                    },
                                                    "start_time": {
                                                        "description": "Specifies "
                                                        "the "
                                                        "starting "
                                                        "time "
                                                        "for "
                                                        "this "
                                                        "restriction.",
                                                        "type": "string",
                                                    },
                                                },
                                                "type": "object",
                                            },
                                            "type": "array",
                                        },
                                        "rotation_start": {
                                            "description": "The "
                                            "date/time "
                                            "when "
                                            "the "
                                            "rotation "
                                            "for "
                                            "this "
                                            "layer "
                                            "starts "
                                            "(in "
                                            "ISO "
                                            "8601).",
                                            "example": "2025-01-01T00:00:00Z",
                                            "format": "date-time",
                                            "type": "string",
                                        },
                                    },
                                    "required": [
                                        "name",
                                        "interval",
                                        "rotation_start",
                                        "effective_date",
                                        "members",
                                    ],
                                    "type": "object",
                                },
                                "type": "array",
                            },
                            "name": {
                                "description": "A human-readable name for the new schedule.",
                                "example": "Team A On-Call",
                                "type": "string",
                            },
                            "time_zone": {
                                "description": "The time zone in which the schedule is defined.",
                                "example": "America/New_York",
                                "type": "string",
                            },
                        },
                        "required": ["name", "time_zone", "layers"],
                        "type": "object",
                    },
                    "relationships": {
                        "description": "Gathers "
                        "relationship "
                        "objects for "
                        "the schedule "
                        "creation "
                        "request, "
                        "including "
                        "the teams to "
                        "associate.",
                        "properties": {
                            "teams": {
                                "description": "Associates "
                                "teams "
                                "with "
                                "this "
                                "schedule "
                                "in "
                                "a "
                                "data "
                                "structure.",
                                "properties": {
                                    "data": {
                                        "description": "An "
                                        "array "
                                        "of "
                                        "team "
                                        "references "
                                        "for "
                                        "this "
                                        "schedule.",
                                        "items": {
                                            "description": "Relates "
                                            "a "
                                            "team "
                                            "to "
                                            "this "
                                            "schedule, "
                                            "identified "
                                            "by "
                                            "`id` "
                                            "and "
                                            "`type` "
                                            "(must "
                                            "be "
                                            "`teams`).",
                                            "properties": {
                                                "id": {
                                                    "description": "The "
                                                    "unique "
                                                    "identifier "
                                                    "of "
                                                    "the "
                                                    "team "
                                                    "in "
                                                    "this "
                                                    "relationship.",
                                                    "example": "00000000-da3a-0000-0000-000000000000",
                                                    "type": "string",
                                                },
                                                "type": {
                                                    "default": "teams",
                                                    "description": "Teams resource type.",
                                                    "enum": ["teams"],
                                                    "example": "teams",
                                                    "type": "string",
                                                    "x-enum-varnames": ["TEAMS"],
                                                },
                                            },
                                            "required": ["type", "id"],
                                            "type": "object",
                                        },
                                        "type": "array",
                                    }
                                },
                                "type": "object",
                            }
                        },
                        "type": "object",
                    },
                    "type": {
                        "default": "schedules",
                        "description": "Schedules resource type.",
                        "enum": ["schedules"],
                        "example": "schedules",
                        "type": "string",
                        "x-enum-varnames": ["SCHEDULES"],
                    },
                },
                "required": ["type", "attributes"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "UPDATEONCALLSCHEDULE_REQUEST_BODY_SCHEMA": {
        "description": "A top-level wrapper for a schedule update request, referring to the "
        "`data` object with the new details.",
        "example": {
            "data": {
                "attributes": {
                    "layers": [
                        {
                            "effective_date": "2025-02-03T05:00:00Z",
                            "end_date": "2025-12-31T00:00:00Z",
                            "interval": {"seconds": 3600},
                            "members": [{"user": {"id": "00000000-aba1-0000-0000-000000000000"}}],
                            "name": "Layer 1",
                            "restrictions": [
                                {
                                    "end_day": "friday",
                                    "end_time": "17:00:00",
                                    "start_day": "monday",
                                    "start_time": "09:00:00",
                                }
                            ],
                            "rotation_start": "2025-02-01T00:00:00Z",
                        }
                    ],
                    "name": "On-Call Schedule Updated",
                    "time_zone": "America/New_York",
                },
                "id": "3653d3c6-0c75-11ea-ad28-fb5701eabc7d",
                "relationships": {
                    "teams": {
                        "data": [{"id": "00000000-da3a-0000-0000-000000000000", "type": "teams"}]
                    }
                },
                "type": "schedules",
            }
        },
        "properties": {
            "data": {
                "description": "Contains all data needed to update an "
                "existing schedule, including its attributes "
                "(such as name and time zone) and any "
                "relationships to teams.",
                "properties": {
                    "attributes": {
                        "description": "Defines the "
                        "updatable "
                        "attributes for "
                        "a schedule, "
                        "such as name, "
                        "time zone, and "
                        "layers.",
                        "properties": {
                            "layers": {
                                "description": "The "
                                "updated "
                                "list "
                                "of "
                                "layers "
                                "(rotations) "
                                "for "
                                "this "
                                "schedule.",
                                "items": {
                                    "description": "Represents "
                                    "a "
                                    "layer "
                                    "within "
                                    "a "
                                    "schedule "
                                    "update, "
                                    "including "
                                    "rotation "
                                    "details, "
                                    "members,\n"
                                    "and "
                                    "optional "
                                    "restrictions.",
                                    "properties": {
                                        "effective_date": {
                                            "description": "When "
                                            "this "
                                            "updated "
                                            "layer "
                                            "takes "
                                            "effect "
                                            "(ISO "
                                            "8601 "
                                            "format).",
                                            "example": "2025-02-03T05:00:00Z",
                                            "format": "date-time",
                                            "type": "string",
                                        },
                                        "end_date": {
                                            "description": "When "
                                            "this "
                                            "updated "
                                            "layer "
                                            "should "
                                            "stop "
                                            "being "
                                            "active "
                                            "(ISO "
                                            "8601 "
                                            "format).",
                                            "example": "2025-12-31T00:00:00Z",
                                            "format": "date-time",
                                            "type": "string",
                                        },
                                        "id": {
                                            "description": "A "
                                            "unique "
                                            "identifier "
                                            "for "
                                            "the "
                                            "layer "
                                            "being "
                                            "updated.",
                                            "example": "00000000-0000-0000-0000-000000000001",
                                            "type": "string",
                                        },
                                        "interval": {
                                            "description": "Defines "
                                            "how "
                                            "often "
                                            "the "
                                            "rotation "
                                            "repeats, "
                                            "using "
                                            "a "
                                            "combination "
                                            "of "
                                            "days "
                                            "and "
                                            "optional "
                                            "seconds. "
                                            "Should "
                                            "be "
                                            "at "
                                            "least "
                                            "1 "
                                            "hour.",
                                            "properties": {
                                                "days": {
                                                    "description": "The "
                                                    "number "
                                                    "of "
                                                    "days "
                                                    "in "
                                                    "each "
                                                    "rotation "
                                                    "cycle.",
                                                    "example": 1,
                                                    "format": "int32",
                                                    "maximum": 400,
                                                    "type": "integer",
                                                },
                                                "seconds": {
                                                    "description": "Any "
                                                    "additional "
                                                    "seconds "
                                                    "for "
                                                    "the "
                                                    "rotation "
                                                    "cycle "
                                                    "(up "
                                                    "to "
                                                    "30 "
                                                    "days).",
                                                    "example": 300,
                                                    "format": "int64",
                                                    "maximum": 2592000,
                                                    "type": "integer",
                                                },
                                            },
                                            "type": "object",
                                        },
                                        "members": {
                                            "description": "The members assigned to this layer.",
                                            "items": {
                                                "description": "Defines "
                                                "a "
                                                "single "
                                                "member "
                                                "within "
                                                "a "
                                                "schedule "
                                                "layer, "
                                                "including "
                                                "the "
                                                "reference "
                                                "to "
                                                "the "
                                                "underlying "
                                                "user.",
                                                "properties": {
                                                    "user": {
                                                        "description": "Identifies "
                                                        "the "
                                                        "user "
                                                        "participating "
                                                        "in "
                                                        "this "
                                                        "layer "
                                                        "as "
                                                        "a "
                                                        "single "
                                                        "object "
                                                        "with "
                                                        "an "
                                                        "`id`.",
                                                        "properties": {
                                                            "id": {
                                                                "description": "The user's ID.",
                                                                "example": "00000000-aba1-0000-0000-000000000000",
                                                                "type": "string",
                                                            }
                                                        },
                                                        "type": "object",
                                                    }
                                                },
                                                "type": "object",
                                            },
                                            "type": "array",
                                        },
                                        "name": {
                                            "description": "The "
                                            "name "
                                            "for "
                                            "this "
                                            "layer "
                                            "(for "
                                            "example, "
                                            '"Secondary '
                                            'Coverage").',
                                            "example": "Primary On-Call Layer",
                                            "type": "string",
                                        },
                                        "restrictions": {
                                            "description": "Any "
                                            "time "
                                            "restrictions "
                                            "that "
                                            "define "
                                            "when "
                                            "this "
                                            "layer "
                                            "is "
                                            "active.",
                                            "items": {
                                                "description": "Defines "
                                                "a "
                                                "single "
                                                "time "
                                                "restriction "
                                                "rule "
                                                "with "
                                                "start "
                                                "and "
                                                "end "
                                                "times "
                                                "and "
                                                "the "
                                                "applicable "
                                                "weekdays.",
                                                "properties": {
                                                    "end_day": {
                                                        "description": "A day of the week.",
                                                        "enum": [
                                                            "monday",
                                                            "tuesday",
                                                            "wednesday",
                                                            "thursday",
                                                            "friday",
                                                            "saturday",
                                                            "sunday",
                                                        ],
                                                        "type": "string",
                                                        "x-enum-varnames": [
                                                            "MONDAY",
                                                            "TUESDAY",
                                                            "WEDNESDAY",
                                                            "THURSDAY",
                                                            "FRIDAY",
                                                            "SATURDAY",
                                                            "SUNDAY",
                                                        ],
                                                    },
                                                    "end_time": {
                                                        "description": "Specifies "
                                                        "the "
                                                        "ending "
                                                        "time "
                                                        "for "
                                                        "this "
                                                        "restriction.",
                                                        "type": "string",
                                                    },
                                                    "start_day": {
                                                        "description": "A day of the week.",
                                                        "enum": [
                                                            "monday",
                                                            "tuesday",
                                                            "wednesday",
                                                            "thursday",
                                                            "friday",
                                                            "saturday",
                                                            "sunday",
                                                        ],
                                                        "type": "string",
                                                        "x-enum-varnames": [
                                                            "MONDAY",
                                                            "TUESDAY",
                                                            "WEDNESDAY",
                                                            "THURSDAY",
                                                            "FRIDAY",
                                                            "SATURDAY",
                                                            "SUNDAY",
                                                        ],
                                                    },
                                                    "start_time": {
                                                        "description": "Specifies "
                                                        "the "
                                                        "starting "
                                                        "time "
                                                        "for "
                                                        "this "
                                                        "restriction.",
                                                        "type": "string",
                                                    },
                                                },
                                                "type": "object",
                                            },
                                            "type": "array",
                                        },
                                        "rotation_start": {
                                            "description": "The "
                                            "date/time "
                                            "at "
                                            "which "
                                            "the "
                                            "rotation "
                                            "begins "
                                            "(ISO "
                                            "8601 "
                                            "format).",
                                            "example": "2025-02-01T00:00:00Z",
                                            "format": "date-time",
                                            "type": "string",
                                        },
                                    },
                                    "required": [
                                        "effective_date",
                                        "interval",
                                        "members",
                                        "name",
                                        "rotation_start",
                                    ],
                                    "type": "object",
                                },
                                "type": "array",
                            },
                            "name": {
                                "description": "A short name for the schedule.",
                                "example": "Primary On-Call",
                                "type": "string",
                            },
                            "time_zone": {
                                "description": "The "
                                "time "
                                "zone "
                                "used "
                                "when "
                                "interpreting "
                                "rotation "
                                "times.",
                                "example": "America/New_York",
                                "type": "string",
                            },
                        },
                        "required": ["name", "time_zone", "layers"],
                        "type": "object",
                    },
                    "id": {
                        "description": "The ID of the schedule to be updated.",
                        "example": "3653d3c6-0c75-11ea-ad28-fb5701eabc7d",
                        "type": "string",
                    },
                    "relationships": {
                        "description": "Houses "
                        "relationships "
                        "for the "
                        "schedule "
                        "update, "
                        "typically "
                        "referencing "
                        "teams.",
                        "properties": {
                            "teams": {
                                "description": "Associates "
                                "teams "
                                "with "
                                "this "
                                "schedule "
                                "in "
                                "a "
                                "data "
                                "structure.",
                                "properties": {
                                    "data": {
                                        "description": "An "
                                        "array "
                                        "of "
                                        "team "
                                        "references "
                                        "for "
                                        "this "
                                        "schedule.",
                                        "items": {
                                            "description": "Relates "
                                            "a "
                                            "team "
                                            "to "
                                            "this "
                                            "schedule, "
                                            "identified "
                                            "by "
                                            "`id` "
                                            "and "
                                            "`type` "
                                            "(must "
                                            "be "
                                            "`teams`).",
                                            "properties": {
                                                "id": {
                                                    "description": "The "
                                                    "unique "
                                                    "identifier "
                                                    "of "
                                                    "the "
                                                    "team "
                                                    "in "
                                                    "this "
                                                    "relationship.",
                                                    "example": "00000000-da3a-0000-0000-000000000000",
                                                    "type": "string",
                                                },
                                                "type": {
                                                    "default": "teams",
                                                    "description": "Teams resource type.",
                                                    "enum": ["teams"],
                                                    "example": "teams",
                                                    "type": "string",
                                                    "x-enum-varnames": ["TEAMS"],
                                                },
                                            },
                                            "required": ["type", "id"],
                                            "type": "object",
                                        },
                                        "type": "array",
                                    }
                                },
                                "type": "object",
                            }
                        },
                        "type": "object",
                    },
                    "type": {
                        "default": "schedules",
                        "description": "Schedules resource type.",
                        "enum": ["schedules"],
                        "example": "schedules",
                        "type": "string",
                        "x-enum-varnames": ["SCHEDULES"],
                    },
                },
                "required": ["type", "id", "attributes"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "SETONCALLTEAMROUTINGRULES_REQUEST_BODY_SCHEMA": {
        "description": "Represents a request to create or update team routing rules, "
        "including the data payload.",
        "example": {
            "data": {
                "attributes": {
                    "rules": [
                        {
                            "actions": None,
                            "policy_id": "",
                            "query": "tags.service:test",
                            "time_restriction": {
                                "restrictions": [
                                    {
                                        "end_day": "monday",
                                        "end_time": "17:00:00",
                                        "start_day": "monday",
                                        "start_time": "09:00:00",
                                    },
                                    {
                                        "end_day": "tuesday",
                                        "end_time": "17:00:00",
                                        "start_day": "tuesday",
                                        "start_time": "09:00:00",
                                    },
                                ],
                                "time_zone": "",
                            },
                            "urgency": "high",
                        },
                        {
                            "actions": [
                                {
                                    "channel": "channel",
                                    "type": "send_slack_message",
                                    "workspace": "workspace",
                                }
                            ],
                            "policy_id": "fad4eee1-13f5-40d8-886b-4e56d8d5d1c6",
                            "query": "",
                            "time_restriction": None,
                            "urgency": "low",
                        },
                    ]
                },
                "id": "27590dae-47be-4a7d-9abf-8f4e45124020",
                "type": "team_routing_rules",
            }
        },
        "properties": {
            "data": {
                "description": "Holds the data necessary to create or update "
                "team routing rules, including attributes, ID, "
                "and resource type.",
                "properties": {
                    "attributes": {
                        "description": "Represents the "
                        "attributes of a "
                        "request to "
                        "update or "
                        "create team "
                        "routing rules.",
                        "properties": {
                            "rules": {
                                "description": "A "
                                "list "
                                "of "
                                "routing "
                                "rule "
                                "items "
                                "that "
                                "define "
                                "how "
                                "incoming "
                                "pages "
                                "should "
                                "be "
                                "handled.",
                                "items": {
                                    "description": "Defines "
                                    "an "
                                    "individual "
                                    "routing "
                                    "rule "
                                    "item "
                                    "that "
                                    "contains "
                                    "the "
                                    "rule "
                                    "data "
                                    "for "
                                    "the "
                                    "request.",
                                    "properties": {
                                        "actions": {
                                            "description": "Specifies "
                                            "the "
                                            "list "
                                            "of "
                                            "actions "
                                            "to "
                                            "perform "
                                            "when "
                                            "the "
                                            "routing "
                                            "rule "
                                            "is "
                                            "matched.",
                                            "items": {
                                                "description": "Defines "
                                                "an "
                                                "action "
                                                "that "
                                                "is "
                                                "executed "
                                                "when "
                                                "a "
                                                "routing "
                                                "rule "
                                                "matches "
                                                "certain "
                                                "criteria.",
                                                "oneOf": [
                                                    {
                                                        "description": "Sends "
                                                        "a "
                                                        "message "
                                                        "to "
                                                        "a "
                                                        "Slack "
                                                        "channel.",
                                                        "properties": {
                                                            "channel": {
                                                                "description": "The channel ID.",
                                                                "example": "CHANNEL",
                                                                "type": "string",
                                                            },
                                                            "type": {
                                                                "default": "send_slack_message",
                                                                "description": "Indicates "
                                                                "that "
                                                                "the "
                                                                "action "
                                                                "is "
                                                                "a "
                                                                "send "
                                                                "Slack "
                                                                "message "
                                                                "action.",
                                                                "enum": ["send_slack_message"],
                                                                "example": "send_slack_message",
                                                                "type": "string",
                                                                "x-enum-varnames": [
                                                                    "SEND_SLACK_MESSAGE"
                                                                ],
                                                            },
                                                            "workspace": {
                                                                "description": "The workspace ID.",
                                                                "example": "WORKSPACE",
                                                                "type": "string",
                                                            },
                                                        },
                                                        "required": [
                                                            "type",
                                                            "channel",
                                                            "workspace",
                                                        ],
                                                        "type": "object",
                                                    },
                                                    {
                                                        "description": "Sends "
                                                        "a "
                                                        "message "
                                                        "to "
                                                        "a "
                                                        "Microsoft "
                                                        "Teams "
                                                        "channel.",
                                                        "properties": {
                                                            "channel": {
                                                                "description": "The channel ID.",
                                                                "example": "CHANNEL",
                                                                "type": "string",
                                                            },
                                                            "team": {
                                                                "description": "The team ID.",
                                                                "example": "TEAM",
                                                                "type": "string",
                                                            },
                                                            "tenant": {
                                                                "description": "The tenant ID.",
                                                                "example": "TENANT",
                                                                "type": "string",
                                                            },
                                                            "type": {
                                                                "default": "send_teams_message",
                                                                "description": "Indicates "
                                                                "that "
                                                                "the "
                                                                "action "
                                                                "is "
                                                                "a "
                                                                "send "
                                                                "Microsoft "
                                                                "Teams "
                                                                "message "
                                                                "action.",
                                                                "enum": ["send_teams_message"],
                                                                "example": "send_teams_message",
                                                                "type": "string",
                                                                "x-enum-varnames": [
                                                                    "SEND_TEAMS_MESSAGE"
                                                                ],
                                                            },
                                                        },
                                                        "required": [
                                                            "type",
                                                            "channel",
                                                            "tenant",
                                                            "team",
                                                        ],
                                                        "type": "object",
                                                    },
                                                ],
                                            },
                                            "type": "array",
                                        },
                                        "policy_id": {
                                            "description": "Identifies "
                                            "the "
                                            "policy "
                                            "to "
                                            "be "
                                            "applied "
                                            "when "
                                            "this "
                                            "routing "
                                            "rule "
                                            "matches.",
                                            "type": "string",
                                        },
                                        "query": {
                                            "description": "Defines "
                                            "the "
                                            "query "
                                            "or "
                                            "condition "
                                            "that "
                                            "triggers "
                                            "this "
                                            "routing "
                                            "rule.",
                                            "type": "string",
                                        },
                                        "time_restriction": {
                                            "description": "Holds "
                                            "time "
                                            "zone "
                                            "information "
                                            "and "
                                            "a "
                                            "list "
                                            "of "
                                            "time "
                                            "restrictions "
                                            "for "
                                            "a "
                                            "routing "
                                            "rule.",
                                            "properties": {
                                                "restrictions": {
                                                    "description": "Defines "
                                                    "the "
                                                    "list "
                                                    "of "
                                                    "time-based "
                                                    "restrictions.",
                                                    "items": {
                                                        "description": "Defines "
                                                        "a "
                                                        "single "
                                                        "time "
                                                        "restriction "
                                                        "rule "
                                                        "with "
                                                        "start "
                                                        "and "
                                                        "end "
                                                        "times "
                                                        "and "
                                                        "the "
                                                        "applicable "
                                                        "weekdays.",
                                                        "properties": {
                                                            "end_day": {
                                                                "description": "A day of the week.",
                                                                "enum": [
                                                                    "monday",
                                                                    "tuesday",
                                                                    "wednesday",
                                                                    "thursday",
                                                                    "friday",
                                                                    "saturday",
                                                                    "sunday",
                                                                ],
                                                                "type": "string",
                                                                "x-enum-varnames": [
                                                                    "MONDAY",
                                                                    "TUESDAY",
                                                                    "WEDNESDAY",
                                                                    "THURSDAY",
                                                                    "FRIDAY",
                                                                    "SATURDAY",
                                                                    "SUNDAY",
                                                                ],
                                                            },
                                                            "end_time": {
                                                                "description": "Specifies "
                                                                "the "
                                                                "ending "
                                                                "time "
                                                                "for "
                                                                "this "
                                                                "restriction.",
                                                                "type": "string",
                                                            },
                                                            "start_day": {
                                                                "description": "A day of the week.",
                                                                "enum": [
                                                                    "monday",
                                                                    "tuesday",
                                                                    "wednesday",
                                                                    "thursday",
                                                                    "friday",
                                                                    "saturday",
                                                                    "sunday",
                                                                ],
                                                                "type": "string",
                                                                "x-enum-varnames": [
                                                                    "MONDAY",
                                                                    "TUESDAY",
                                                                    "WEDNESDAY",
                                                                    "THURSDAY",
                                                                    "FRIDAY",
                                                                    "SATURDAY",
                                                                    "SUNDAY",
                                                                ],
                                                            },
                                                            "start_time": {
                                                                "description": "Specifies "
                                                                "the "
                                                                "starting "
                                                                "time "
                                                                "for "
                                                                "this "
                                                                "restriction.",
                                                                "type": "string",
                                                            },
                                                        },
                                                        "type": "object",
                                                    },
                                                    "type": "array",
                                                },
                                                "time_zone": {
                                                    "description": "Specifies "
                                                    "the "
                                                    "time "
                                                    "zone "
                                                    "applicable "
                                                    "to "
                                                    "the "
                                                    "restrictions.",
                                                    "example": "",
                                                    "type": "string",
                                                },
                                            },
                                            "required": ["time_zone", "restrictions"],
                                            "type": "object",
                                        },
                                        "urgency": {
                                            "description": "Specifies "
                                            "the "
                                            "level "
                                            "of "
                                            "urgency "
                                            "for "
                                            "a "
                                            "routing "
                                            "rule "
                                            "(low, "
                                            "high, "
                                            "or "
                                            "dynamic).",
                                            "enum": ["low", "high", "dynamic"],
                                            "example": "low",
                                            "type": "string",
                                            "x-enum-varnames": ["LOW", "HIGH", "DYNAMIC"],
                                        },
                                    },
                                    "type": "object",
                                },
                                "type": "array",
                            }
                        },
                        "type": "object",
                    },
                    "id": {
                        "description": "Specifies the unique "
                        "identifier for this set "
                        "of team routing rules.",
                        "type": "string",
                    },
                    "type": {
                        "default": "team_routing_rules",
                        "description": "Team routing rules resource type.",
                        "enum": ["team_routing_rules"],
                        "example": "team_routing_rules",
                        "type": "string",
                        "x-enum-varnames": ["TEAM_ROUTING_RULES"],
                    },
                },
                "required": ["type"],
                "type": "object",
            }
        },
        "type": "object",
    },
    "CREATEPOWERPACK_REQUEST_BODY_SCHEMA": {
        "description": "Powerpacks are templated groups of dashboard widgets you can save "
        "from an existing dashboard and turn into reusable packs in the widget "
        "tray.",
        "properties": {
            "data": {
                "description": "Powerpack data object.",
                "properties": {
                    "attributes": {
                        "description": "Powerpack attribute object.",
                        "properties": {
                            "description": {
                                "description": "Description of this powerpack.",
                                "example": "Powerpack for ABC",
                                "type": "string",
                            },
                            "group_widget": {
                                "description": "Powerpack group widget definition object.",
                                "properties": {
                                    "definition": {
                                        "description": "Powerpack group widget object.",
                                        "properties": {
                                            "layout_type": {
                                                "description": "Layout type of widgets.",
                                                "example": "ordered",
                                                "type": "string",
                                            },
                                            "show_title": {
                                                "description": "Boolean "
                                                "indicating "
                                                "whether "
                                                "powerpack "
                                                "group "
                                                "title "
                                                "should "
                                                "be "
                                                "visible "
                                                "or "
                                                "not.",
                                                "example": True,
                                                "type": "boolean",
                                            },
                                            "title": {
                                                "description": "Name for the group widget.",
                                                "example": "Sample Powerpack",
                                                "type": "string",
                                            },
                                            "type": {
                                                "description": "Type of widget, must be group.",
                                                "example": "group",
                                                "type": "string",
                                            },
                                            "widgets": {
                                                "description": "Widgets inside the powerpack.",
                                                "example": [
                                                    {
                                                        "definition": {
                                                            "content": "example",
                                                            "type": "note",
                                                        },
                                                        "layout": {
                                                            "height": 5,
                                                            "width": 10,
                                                            "x": 0,
                                                            "y": 0,
                                                        },
                                                    }
                                                ],
                                                "items": {
                                                    "description": "Powerpack "
                                                    "group "
                                                    "widget "
                                                    "definition "
                                                    "of "
                                                    "individual "
                                                    "widgets.",
                                                    "properties": {
                                                        "definition": {
                                                            "additionalProperties": {},
                                                            "description": "Information "
                                                            "about "
                                                            "widget.",
                                                            "example": {
                                                                "definition": {
                                                                    "content": "example",
                                                                    "type": "note",
                                                                }
                                                            },
                                                            "type": "object",
                                                        },
                                                        "layout": {
                                                            "description": "Powerpack "
                                                            "inner "
                                                            "widget "
                                                            "layout.",
                                                            "properties": {
                                                                "height": {
                                                                    "description": "The "
                                                                    "height "
                                                                    "of "
                                                                    "the "
                                                                    "widget. "
                                                                    "Should "
                                                                    "be "
                                                                    "a "
                                                                    "non-negative "
                                                                    "integer.",
                                                                    "example": 0,
                                                                    "format": "int64",
                                                                    "minimum": 0,
                                                                    "type": "integer",
                                                                },
                                                                "width": {
                                                                    "description": "The "
                                                                    "width "
                                                                    "of "
                                                                    "the "
                                                                    "widget. "
                                                                    "Should "
                                                                    "be "
                                                                    "a "
                                                                    "non-negative "
                                                                    "integer.",
                                                                    "example": 0,
                                                                    "format": "int64",
                                                                    "minimum": 0,
                                                                    "type": "integer",
                                                                },
                                                                "x": {
                                                                    "description": "The "
                                                                    "position "
                                                                    "of "
                                                                    "the "
                                                                    "widget "
                                                                    "on "
                                                                    "the "
                                                                    "x "
                                                                    "(horizontal) "
                                                                    "axis. "
                                                                    "Should "
                                                                    "be "
                                                                    "a "
                                                                    "non-negative "
                                                                    "integer.",
                                                                    "example": 0,
                                                                    "format": "int64",
                                                                    "minimum": 0,
                                                                    "type": "integer",
                                                                },
                                                                "y": {
                                                                    "description": "The "
                                                                    "position "
                                                                    "of "
                                                                    "the "
                                                                    "widget "
                                                                    "on "
                                                                    "the "
                                                                    "y "
                                                                    "(vertical) "
                                                                    "axis. "
                                                                    "Should "
                                                                    "be "
                                                                    "a "
                                                                    "non-negative "
                                                                    "integer.",
                                                                    "example": 0,
                                                                    "format": "int64",
                                                                    "minimum": 0,
                                                                    "type": "integer",
                                                                },
                                                            },
                                                            "required": [
                                                                "x",
                                                                "y",
                                                                "width",
                                                                "height",
                                                            ],
                                                            "type": "object",
                                                        },
                                                    },
                                                    "required": ["definition"],
                                                    "type": "object",
                                                },
                                                "type": "array",
                                            },
                                        },
                                        "required": ["widgets", "layout_type", "type"],
                                        "type": "object",
                                    },
                                    "layout": {
                                        "description": "Powerpack group widget layout.",
                                        "properties": {
                                            "height": {
                                                "description": "The "
                                                "height "
                                                "of "
                                                "the "
                                                "widget. "
                                                "Should "
                                                "be "
                                                "a "
                                                "non-negative "
                                                "integer.",
                                                "example": 0,
                                                "format": "int64",
                                                "minimum": 0,
                                                "type": "integer",
                                            },
                                            "width": {
                                                "description": "The "
                                                "width "
                                                "of "
                                                "the "
                                                "widget. "
                                                "Should "
                                                "be "
                                                "a "
                                                "non-negative "
                                                "integer.",
                                                "example": 0,
                                                "format": "int64",
                                                "minimum": 0,
                                                "type": "integer",
                                            },
                                            "x": {
                                                "description": "The "
                                                "position "
                                                "of "
                                                "the "
                                                "widget "
                                                "on "
                                                "the "
                                                "x "
                                                "(horizontal) "
                                                "axis. "
                                                "Should "
                                                "be "
                                                "a "
                                                "non-negative "
                                                "integer.",
                                                "example": 0,
                                                "format": "int64",
                                                "minimum": 0,
                                                "type": "integer",
                                            },
                                            "y": {
                                                "description": "The "
                                                "position "
                                                "of "
                                                "the "
                                                "widget "
                                                "on "
                                                "the "
                                                "y "
                                                "(vertical) "
                                                "axis. "
                                                "Should "
                                                "be "
                                                "a "
                                                "non-negative "
                                                "integer.",
                                                "example": 0,
                                                "format": "int64",
                                                "minimum": 0,
                                                "type": "integer",
                                            },
                                        },
                                        "required": ["x", "y", "width", "height"],
                                        "type": "object",
                                    },
                                    "live_span": {
                                        "description": "The "
                                        "available "
                                        "timeframes "
                                        "depend "
                                        "on "
                                        "the "
                                        "widget "
                                        "you "
                                        "are "
                                        "using.",
                                        "enum": [
                                            "1m",
                                            "5m",
                                            "10m",
                                            "15m",
                                            "30m",
                                            "1h",
                                            "4h",
                                            "1d",
                                            "2d",
                                            "1w",
                                            "1mo",
                                            "3mo",
                                            "6mo",
                                            "1y",
                                            "alert",
                                        ],
                                        "example": "5m",
                                        "type": "string",
                                        "x-enum-varnames": [
                                            "PAST_ONE_MINUTE",
                                            "PAST_FIVE_MINUTES",
                                            "PAST_TEN_MINUTES",
                                            "PAST_FIFTEEN_MINUTES",
                                            "PAST_THIRTY_MINUTES",
                                            "PAST_ONE_HOUR",
                                            "PAST_FOUR_HOURS",
                                            "PAST_ONE_DAY",
                                            "PAST_TWO_DAYS",
                                            "PAST_ONE_WEEK",
                                            "PAST_ONE_MONTH",
                                            "PAST_THREE_MONTHS",
                                            "PAST_SIX_MONTHS",
                                            "PAST_ONE_YEAR",
                                            "ALERT",
                                        ],
                                    },
                                },
                                "required": ["definition"],
                                "type": "object",
                            },
                            "name": {
                                "description": "Name of the powerpack.",
                                "example": "Sample Powerpack",
                                "type": "string",
                            },
                            "tags": {
                                "description": "List of tags to identify this powerpack.",
                                "example": ["tag:foo1"],
                                "items": {"maxLength": 80, "type": "string"},
                                "maxItems": 8,
                                "type": "array",
                            },
                            "template_variables": {
                                "description": "List of template variables for this powerpack.",
                                "example": [{"defaults": ["*"], "name": "test"}],
                                "items": {
                                    "description": "Powerpack template variables.",
                                    "properties": {
                                        "available_values": {
                                            "description": "The "
                                            "list "
                                            "of "
                                            "values "
                                            "that "
                                            "the "
                                            "template "
                                            "variable "
                                            "drop-down "
                                            "is "
                                            "limited "
                                            "to.",
                                            "example": ["my-host", "host1", "host2"],
                                            "items": {
                                                "description": "Template variable value.",
                                                "type": "string",
                                            },
                                            "nullable": True,
                                            "type": "array",
                                        },
                                        "defaults": {
                                            "description": "One "
                                            "or "
                                            "many "
                                            "template "
                                            "variable "
                                            "default "
                                            "values "
                                            "within "
                                            "the "
                                            "saved "
                                            "view, "
                                            "which "
                                            "are "
                                            "unioned "
                                            "together "
                                            "using "
                                            "`OR` "
                                            "if "
                                            "more "
                                            "than "
                                            "one "
                                            "is "
                                            "specified.",
                                            "items": {
                                                "description": "One "
                                                "or "
                                                "many "
                                                "default "
                                                "values "
                                                "of "
                                                "the "
                                                "template "
                                                "variable.",
                                                "minLength": 1,
                                                "type": "string",
                                            },
                                            "type": "array",
                                        },
                                        "name": {
                                            "description": "The name of the variable.",
                                            "example": "datacenter",
                                            "type": "string",
                                        },
                                        "prefix": {
                                            "description": "The "
                                            "tag "
                                            "prefix "
                                            "associated "
                                            "with "
                                            "the "
                                            "variable. "
                                            "Only "
                                            "tags "
                                            "with "
                                            "this "
                                            "prefix "
                                            "appear "
                                            "in "
                                            "the "
                                            "variable "
                                            "drop-down.",
                                            "example": "host",
                                            "nullable": True,
                                            "type": "string",
                                        },
                                    },
                                    "required": ["name"],
                                    "type": "object",
                                },
                                "type": "array",
                            },
                        },
                        "required": ["group_widget", "name"],
                        "type": "object",
                    },
                    "id": {"description": "ID of the powerpack.", "type": "string"},
                    "relationships": {
                        "description": "Powerpack relationship object.",
                        "properties": {
                            "author": {
                                "description": "Relationship to user.",
                                "properties": {
                                    "data": {
                                        "description": "Relationship to user object.",
                                        "properties": {
                                            "id": {
                                                "description": "A "
                                                "unique "
                                                "identifier "
                                                "that "
                                                "represents "
                                                "the "
                                                "user.",
                                                "example": "00000000-0000-0000-2345-000000000000",
                                                "type": "string",
                                            },
                                            "type": {
                                                "default": "users",
                                                "description": "Users resource type.",
                                                "enum": ["users"],
                                                "example": "users",
                                                "type": "string",
                                                "x-enum-varnames": ["USERS"],
                                            },
                                        },
                                        "required": ["id", "type"],
                                        "type": "object",
                                    }
                                },
                                "required": ["data"],
                                "type": "object",
                            }
                        },
                        "type": "object",
                    },
                    "type": {
                        "description": "Type of widget, must be powerpack.",
                        "example": "powerpack",
                        "type": "string",
                    },
                },
                "type": "object",
            }
        },
        "type": "object",
    },
    "UPDATEPOWERPACK_REQUEST_BODY_SCHEMA": {
        "description": "Powerpacks are templated groups of dashboard widgets you can save "
        "from an existing dashboard and turn into reusable packs in the widget "
        "tray.",
        "properties": {
            "data": {
                "description": "Powerpack data object.",
                "properties": {
                    "attributes": {
                        "description": "Powerpack attribute object.",
                        "properties": {
                            "description": {
                                "description": "Description of this powerpack.",
                                "example": "Powerpack for ABC",
                                "type": "string",
                            },
                            "group_widget": {
                                "description": "Powerpack group widget definition object.",
                                "properties": {
                                    "definition": {
                                        "description": "Powerpack group widget object.",
                                        "properties": {
                                            "layout_type": {
                                                "description": "Layout type of widgets.",
                                                "example": "ordered",
                                                "type": "string",
                                            },
                                            "show_title": {
                                                "description": "Boolean "
                                                "indicating "
                                                "whether "
                                                "powerpack "
                                                "group "
                                                "title "
                                                "should "
                                                "be "
                                                "visible "
                                                "or "
                                                "not.",
                                                "example": True,
                                                "type": "boolean",
                                            },
                                            "title": {
                                                "description": "Name for the group widget.",
                                                "example": "Sample Powerpack",
                                                "type": "string",
                                            },
                                            "type": {
                                                "description": "Type of widget, must be group.",
                                                "example": "group",
                                                "type": "string",
                                            },
                                            "widgets": {
                                                "description": "Widgets inside the powerpack.",
                                                "example": [
                                                    {
                                                        "definition": {
                                                            "content": "example",
                                                            "type": "note",
                                                        },
                                                        "layout": {
                                                            "height": 5,
                                                            "width": 10,
                                                            "x": 0,
                                                            "y": 0,
                                                        },
                                                    }
                                                ],
                                                "items": {
                                                    "description": "Powerpack "
                                                    "group "
                                                    "widget "
                                                    "definition "
                                                    "of "
                                                    "individual "
                                                    "widgets.",
                                                    "properties": {
                                                        "definition": {
                                                            "additionalProperties": {},
                                                            "description": "Information "
                                                            "about "
                                                            "widget.",
                                                            "example": {
                                                                "definition": {
                                                                    "content": "example",
                                                                    "type": "note",
                                                                }
                                                            },
                                                            "type": "object",
                                                        },
                                                        "layout": {
                                                            "description": "Powerpack "
                                                            "inner "
                                                            "widget "
                                                            "layout.",
                                                            "properties": {
                                                                "height": {
                                                                    "description": "The "
                                                                    "height "
                                                                    "of "
                                                                    "the "
                                                                    "widget. "
                                                                    "Should "
                                                                    "be "
                                                                    "a "
                                                                    "non-negative "
                                                                    "integer.",
                                                                    "example": 0,
                                                                    "format": "int64",
                                                                    "minimum": 0,
                                                                    "type": "integer",
                                                                },
                                                                "width": {
                                                                    "description": "The "
                                                                    "width "
                                                                    "of "
                                                                    "the "
                                                                    "widget. "
                                                                    "Should "
                                                                    "be "
                                                                    "a "
                                                                    "non-negative "
                                                                    "integer.",
                                                                    "example": 0,
                                                                    "format": "int64",
                                                                    "minimum": 0,
                                                                    "type": "integer",
                                                                },
                                                                "x": {
                                                                    "description": "The "
                                                                    "position "
                                                                    "of "
                                                                    "the "
                                                                    "widget "
                                                                    "on "
                                                                    "the "
                                                                    "x "
                                                                    "(horizontal) "
                                                                    "axis. "
                                                                    "Should "
                                                                    "be "
                                                                    "a "
                                                                    "non-negative "
                                                                    "integer.",
                                                                    "example": 0,
                                                                    "format": "int64",
                                                                    "minimum": 0,
                                                                    "type": "integer",
                                                                },
                                                                "y": {
                                                                    "description": "The "
                                                                    "position "
                                                                    "of "
                                                                    "the "
                                                                    "widget "
                                                                    "on "
                                                                    "the "
                                                                    "y "
                                                                    "(vertical) "
                                                                    "axis. "
                                                                    "Should "
                                                                    "be "
                                                                    "a "
                                                                    "non-negative "
                                                                    "integer.",
                                                                    "example": 0,
                                                                    "format": "int64",
                                                                    "minimum": 0,
                                                                    "type": "integer",
                                                                },
                                                            },
                                                            "required": [
                                                                "x",
                                                                "y",
                                                                "width",
                                                                "height",
                                                            ],
                                                            "type": "object",
                                                        },
                                                    },
                                                    "required": ["definition"],
                                                    "type": "object",
                                                },
                                                "type": "array",
                                            },
                                        },
                                        "required": ["widgets", "layout_type", "type"],
                                        "type": "object",
                                    },
                                    "layout": {
                                        "description": "Powerpack group widget layout.",
                                        "properties": {
                                            "height": {
                                                "description": "The "
                                                "height "
                                                "of "
                                                "the "
                                                "widget. "
                                                "Should "
                                                "be "
                                                "a "
                                                "non-negative "
                                                "integer.",
                                                "example": 0,
                                                "format": "int64",
                                                "minimum": 0,
                                                "type": "integer",
                                            },
                                            "width": {
                                                "description": "The "
                                                "width "
                                                "of "
                                                "the "
                                                "widget. "
                                                "Should "
                                                "be "
                                                "a "
                                                "non-negative "
                                                "integer.",
                                                "example": 0,
                                                "format": "int64",
                                                "minimum": 0,
                                                "type": "integer",
                                            },
                                            "x": {
                                                "description": "The "
                                                "position "
                                                "of "
                                                "the "
                                                "widget "
                                                "on "
                                                "the "
                                                "x "
                                                "(horizontal) "
                                                "axis. "
                                                "Should "
                                                "be "
                                                "a "
                                                "non-negative "
                                                "integer.",
                                                "example": 0,
                                                "format": "int64",
                                                "minimum": 0,
                                                "type": "integer",
                                            },
                                            "y": {
                                                "description": "The "
                                                "position "
                                                "of "
                                                "the "
                                                "widget "
                                                "on "
                                                "the "
                                                "y "
                                                "(vertical) "
                                                "axis. "
                                                "Should "
                                                "be "
                                                "a "
                                                "non-negative "
                                                "integer.",
                                                "example": 0,
                                                "format": "int64",
                                                "minimum": 0,
                                                "type": "integer",
                                            },
                                        },
                                        "required": ["x", "y", "width", "height"],
                                        "type": "object",
                                    },
                                    "live_span": {
                                        "description": "The "
                                        "available "
                                        "timeframes "
                                        "depend "
                                        "on "
                                        "the "
                                        "widget "
                                        "you "
                                        "are "
                                        "using.",
                                        "enum": [
                                            "1m",
                                            "5m",
                                            "10m",
                                            "15m",
                                            "30m",
                                            "1h",
                                            "4h",
                                            "1d",
                                            "2d",
                                            "1w",
                                            "1mo",
                                            "3mo",
                                            "6mo",
                                            "1y",
                                            "alert",
                                        ],
                                        "example": "5m",
                                        "type": "string",
                                        "x-enum-varnames": [
                                            "PAST_ONE_MINUTE",
                                            "PAST_FIVE_MINUTES",
                                            "PAST_TEN_MINUTES",
                                            "PAST_FIFTEEN_MINUTES",
                                            "PAST_THIRTY_MINUTES",
                                            "PAST_ONE_HOUR",
                                            "PAST_FOUR_HOURS",
                                            "PAST_ONE_DAY",
                                            "PAST_TWO_DAYS",
                                            "PAST_ONE_WEEK",
                                            "PAST_ONE_MONTH",
                                            "PAST_THREE_MONTHS",
                                            "PAST_SIX_MONTHS",
                                            "PAST_ONE_YEAR",
                                            "ALERT",
                                        ],
                                    },
                                },
                                "required": ["definition"],
                                "type": "object",
                            },
                            "name": {
                                "description": "Name of the powerpack.",
                                "example": "Sample Powerpack",
                                "type": "string",
                            },
                            "tags": {
                                "description": "List of tags to identify this powerpack.",
                                "example": ["tag:foo1"],
                                "items": {"maxLength": 80, "type": "string"},
                                "maxItems": 8,
                                "type": "array",
                            },
                            "template_variables": {
                                "description": "List of template variables for this powerpack.",
                                "example": [{"defaults": ["*"], "name": "test"}],
                                "items": {
                                    "description": "Powerpack template variables.",
                                    "properties": {
                                        "available_values": {
                                            "description": "The "
                                            "list "
                                            "of "
                                            "values "
                                            "that "
                                            "the "
                                            "template "
                                            "variable "
                                            "drop-down "
                                            "is "
                                            "limited "
                                            "to.",
                                            "example": ["my-host", "host1", "host2"],
                                            "items": {
                                                "description": "Template variable value.",
                                                "type": "string",
                                            },
                                            "nullable": True,
                                            "type": "array",
                                        },
                                        "defaults": {
                                            "description": "One "
                                            "or "
                                            "many "
                                            "template "
                                            "variable "
                                            "default "
                                            "values "
                                            "within "
                                            "the "
                                            "saved "
                                            "view, "
                                            "which "
                                            "are "
                                            "unioned "
                                            "together "
                                            "using "
                                            "`OR` "
                                            "if "
                                            "more "
                                            "than "
                                            "one "
                                            "is "
                                            "specified.",
                                            "items": {
                                                "description": "One "
                                                "or "
                                                "many "
                                                "default "
                                                "values "
                                                "of "
                                                "the "
                                                "template "
                                                "variable.",
                                                "minLength": 1,
                                                "type": "string",
                                            },
                                            "type": "array",
                                        },
                                        "name": {
                                            "description": "The name of the variable.",
                                            "example": "datacenter",
                                            "type": "string",
                                        },
                                        "prefix": {
                                            "description": "The "
                                            "tag "
                                            "prefix "
                                            "associated "
                                            "with "
                                            "the "
                                            "variable. "
                                            "Only "
                                            "tags "
                                            "with "
                                            "this "
                                            "prefix "
                                            "appear "
                                            "in "
                                            "the "
                                            "variable "
                                            "drop-down.",
                                            "example": "host",
                                            "nullable": True,
                                            "type": "string",
                                        },
                                    },
                                    "required": ["name"],
                                    "type": "object",
                                },
                                "type": "array",
                            },
                        },
                        "required": ["group_widget", "name"],
                        "type": "object",
                    },
                    "id": {"description": "ID of the powerpack.", "type": "string"},
                    "relationships": {
                        "description": "Powerpack relationship object.",
                        "properties": {
                            "author": {
                                "description": "Relationship to user.",
                                "properties": {
                                    "data": {
                                        "description": "Relationship to user object.",
                                        "properties": {
                                            "id": {
                                                "description": "A "
                                                "unique "
                                                "identifier "
                                                "that "
                                                "represents "
                                                "the "
                                                "user.",
                                                "example": "00000000-0000-0000-2345-000000000000",
                                                "type": "string",
                                            },
                                            "type": {
                                                "default": "users",
                                                "description": "Users resource type.",
                                                "enum": ["users"],
                                                "example": "users",
                                                "type": "string",
                                                "x-enum-varnames": ["USERS"],
                                            },
                                        },
                                        "required": ["id", "type"],
                                        "type": "object",
                                    }
                                },
                                "required": ["data"],
                                "type": "object",
                            }
                        },
                        "type": "object",
                    },
                    "type": {
                        "description": "Type of widget, must be powerpack.",
                        "example": "powerpack",
                        "type": "string",
                    },
                },
                "type": "object",
            }
        },
        "type": "object",
    },
    "QUERYSCALARDATA_REQUEST_BODY_SCHEMA": {
        "description": "A wrapper request around one scalar query to be executed.",
        "properties": {
            "data": {
                "description": "A single scalar query to be executed.",
                "properties": {
                    "attributes": {
                        "description": "The object describing a scalar formula request.",
                        "properties": {
                            "formulas": {
                                "description": "List "
                                "of "
                                "formulas "
                                "to "
                                "be "
                                "calculated "
                                "and "
                                "returned "
                                "as "
                                "responses.",
                                "items": {
                                    "description": "A "
                                    "formula "
                                    "for "
                                    "calculation "
                                    "based "
                                    "on "
                                    "one "
                                    "or "
                                    "more "
                                    "queries.",
                                    "properties": {
                                        "formula": {
                                            "description": "Formula "
                                            "string, "
                                            "referencing "
                                            "one "
                                            "or "
                                            "more "
                                            "queries "
                                            "with "
                                            "their "
                                            "name "
                                            "property.",
                                            "example": "a+b",
                                            "type": "string",
                                        },
                                        "limit": {
                                            "description": "Message "
                                            "for "
                                            "specifying "
                                            "limits "
                                            "to "
                                            "the "
                                            "number "
                                            "of "
                                            "values "
                                            "returned "
                                            "by "
                                            "a "
                                            "query.\n"
                                            "This "
                                            "limit "
                                            "is "
                                            "only "
                                            "for "
                                            "scalar "
                                            "queries "
                                            "and "
                                            "has "
                                            "no "
                                            "effect "
                                            "on "
                                            "timeseries "
                                            "queries.",
                                            "properties": {
                                                "count": {
                                                    "description": "The "
                                                    "number "
                                                    "of "
                                                    "results "
                                                    "to "
                                                    "which "
                                                    "to "
                                                    "limit.",
                                                    "example": 10,
                                                    "format": "int32",
                                                    "maximum": 2147483647,
                                                    "type": "integer",
                                                },
                                                "order": {
                                                    "default": "desc",
                                                    "description": "Direction of sort.",
                                                    "enum": ["asc", "desc"],
                                                    "type": "string",
                                                    "x-enum-varnames": ["ASC", "DESC"],
                                                },
                                            },
                                            "type": "object",
                                        },
                                    },
                                    "required": ["formula"],
                                    "type": "object",
                                },
                                "type": "array",
                            },
                            "from": {
                                "description": "Start "
                                "date "
                                "(inclusive) "
                                "of "
                                "the "
                                "query "
                                "in "
                                "milliseconds "
                                "since "
                                "the "
                                "Unix "
                                "epoch.",
                                "example": 1568899800000,
                                "format": "int64",
                                "type": "integer",
                            },
                            "queries": {
                                "description": "List "
                                "of "
                                "queries "
                                "to "
                                "be "
                                "run "
                                "and "
                                "used "
                                "as "
                                "inputs "
                                "to "
                                "the "
                                "formulas.",
                                "example": [
                                    {
                                        "aggregator": "avg",
                                        "data_source": "metrics",
                                        "query": "avg:system.cpu.user{*} by {env}",
                                    }
                                ],
                                "items": {
                                    "description": "An "
                                    "individual "
                                    "scalar "
                                    "query "
                                    "to "
                                    "one "
                                    "of "
                                    "the "
                                    "basic "
                                    "Datadog "
                                    "data "
                                    "sources.",
                                    "example": {
                                        "aggregator": "avg",
                                        "data_source": "metrics",
                                        "query": "avg:system.cpu.user{*} by {env}",
                                    },
                                    "oneOf": [
                                        {
                                            "description": "An individual scalar metrics query.",
                                            "properties": {
                                                "aggregator": {
                                                    "default": "avg",
                                                    "description": "The "
                                                    "type "
                                                    "of "
                                                    "aggregation "
                                                    "that "
                                                    "can "
                                                    "be "
                                                    "performed "
                                                    "on "
                                                    "metrics-based "
                                                    "queries.",
                                                    "enum": [
                                                        "avg",
                                                        "min",
                                                        "max",
                                                        "sum",
                                                        "last",
                                                        "percentile",
                                                        "mean",
                                                        "l2norm",
                                                        "area",
                                                    ],
                                                    "example": "avg",
                                                    "type": "string",
                                                    "x-enum-varnames": [
                                                        "AVG",
                                                        "MIN",
                                                        "MAX",
                                                        "SUM",
                                                        "LAST",
                                                        "PERCENTILE",
                                                        "MEAN",
                                                        "L2NORM",
                                                        "AREA",
                                                    ],
                                                },
                                                "data_source": {
                                                    "default": "metrics",
                                                    "description": "A "
                                                    "data "
                                                    "source "
                                                    "that "
                                                    "is "
                                                    "powered "
                                                    "by "
                                                    "the "
                                                    "Metrics "
                                                    "platform.",
                                                    "enum": ["metrics", "cloud_cost"],
                                                    "example": "metrics",
                                                    "type": "string",
                                                    "x-enum-varnames": ["METRICS", "CLOUD_COST"],
                                                },
                                                "name": {
                                                    "description": "The "
                                                    "variable "
                                                    "name "
                                                    "for "
                                                    "use "
                                                    "in "
                                                    "formulas.",
                                                    "type": "string",
                                                },
                                                "query": {
                                                    "description": "A "
                                                    "classic "
                                                    "metrics "
                                                    "query "
                                                    "string.",
                                                    "example": "avg:system.cpu.user{*} by {env}",
                                                    "type": "string",
                                                },
                                            },
                                            "required": ["data_source", "query", "aggregator"],
                                            "type": "object",
                                        },
                                        {
                                            "description": "An individual scalar events query.",
                                            "properties": {
                                                "compute": {
                                                    "description": "The "
                                                    "instructions "
                                                    "for "
                                                    "what "
                                                    "to "
                                                    "compute "
                                                    "for "
                                                    "this "
                                                    "query.",
                                                    "properties": {
                                                        "aggregation": {
                                                            "default": "count",
                                                            "description": "The "
                                                            "type "
                                                            "of "
                                                            "aggregation "
                                                            "that "
                                                            "can "
                                                            "be "
                                                            "performed "
                                                            "on "
                                                            "events-based "
                                                            "queries.",
                                                            "enum": [
                                                                "count",
                                                                "cardinality",
                                                                "pc75",
                                                                "pc90",
                                                                "pc95",
                                                                "pc98",
                                                                "pc99",
                                                                "sum",
                                                                "min",
                                                                "max",
                                                                "avg",
                                                            ],
                                                            "example": "count",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "COUNT",
                                                                "CARDINALITY",
                                                                "PC75",
                                                                "PC90",
                                                                "PC95",
                                                                "PC98",
                                                                "PC99",
                                                                "SUM",
                                                                "MIN",
                                                                "MAX",
                                                                "AVG",
                                                            ],
                                                        },
                                                        "interval": {
                                                            "description": "Interval "
                                                            "for "
                                                            "compute "
                                                            "in "
                                                            "milliseconds.",
                                                            "example": 60000,
                                                            "format": "int64",
                                                            "type": "integer",
                                                        },
                                                        "metric": {
                                                            "description": "The "
                                                            '"measure" '
                                                            "attribute "
                                                            "on "
                                                            "which "
                                                            "to "
                                                            "perform "
                                                            "the "
                                                            "computation.",
                                                            "type": "string",
                                                        },
                                                    },
                                                    "required": ["aggregation"],
                                                    "type": "object",
                                                },
                                                "data_source": {
                                                    "default": "logs",
                                                    "description": "A "
                                                    "data "
                                                    "source "
                                                    "that "
                                                    "is "
                                                    "powered "
                                                    "by "
                                                    "the "
                                                    "Events "
                                                    "Platform.",
                                                    "enum": ["logs", "rum", "dora"],
                                                    "example": "logs",
                                                    "type": "string",
                                                    "x-enum-varnames": ["LOGS", "RUM", "DORA"],
                                                },
                                                "group_by": {
                                                    "description": "The "
                                                    "list "
                                                    "of "
                                                    "facets "
                                                    "on "
                                                    "which "
                                                    "to "
                                                    "split "
                                                    "results.",
                                                    "items": {
                                                        "description": "A "
                                                        "dimension "
                                                        "on "
                                                        "which "
                                                        "to "
                                                        "split "
                                                        "a "
                                                        "query's "
                                                        "results.",
                                                        "properties": {
                                                            "facet": {
                                                                "description": "The "
                                                                "facet "
                                                                "by "
                                                                "which "
                                                                "to "
                                                                "split "
                                                                "groups.",
                                                                "example": "@error.type",
                                                                "type": "string",
                                                            },
                                                            "limit": {
                                                                "default": 10,
                                                                "description": "The "
                                                                "maximum "
                                                                "buckets "
                                                                "to "
                                                                "return "
                                                                "for "
                                                                "this "
                                                                "group "
                                                                "by. "
                                                                "Note: "
                                                                "at "
                                                                "most "
                                                                "10000 "
                                                                "buckets "
                                                                "are "
                                                                "allowed.\n"
                                                                "If "
                                                                "grouping "
                                                                "by "
                                                                "multiple "
                                                                "facets, "
                                                                "the "
                                                                "product "
                                                                "of "
                                                                "limits "
                                                                "must "
                                                                "not "
                                                                "exceed "
                                                                "10000.",
                                                                "example": 10,
                                                                "format": "int32",
                                                                "maximum": 10000,
                                                                "type": "integer",
                                                            },
                                                            "sort": {
                                                                "description": "The "
                                                                "dimension "
                                                                "by "
                                                                "which "
                                                                "to "
                                                                "sort "
                                                                "a "
                                                                "query's "
                                                                "results.",
                                                                "properties": {
                                                                    "aggregation": {
                                                                        "default": "count",
                                                                        "description": "The "
                                                                        "type "
                                                                        "of "
                                                                        "aggregation "
                                                                        "that "
                                                                        "can "
                                                                        "be "
                                                                        "performed "
                                                                        "on "
                                                                        "events-based "
                                                                        "queries.",
                                                                        "enum": [
                                                                            "count",
                                                                            "cardinality",
                                                                            "pc75",
                                                                            "pc90",
                                                                            "pc95",
                                                                            "pc98",
                                                                            "pc99",
                                                                            "sum",
                                                                            "min",
                                                                            "max",
                                                                            "avg",
                                                                        ],
                                                                        "example": "count",
                                                                        "type": "string",
                                                                        "x-enum-varnames": [
                                                                            "COUNT",
                                                                            "CARDINALITY",
                                                                            "PC75",
                                                                            "PC90",
                                                                            "PC95",
                                                                            "PC98",
                                                                            "PC99",
                                                                            "SUM",
                                                                            "MIN",
                                                                            "MAX",
                                                                            "AVG",
                                                                        ],
                                                                    },
                                                                    "metric": {
                                                                        "description": "The "
                                                                        "metric's "
                                                                        "calculated "
                                                                        "value "
                                                                        "which "
                                                                        "should "
                                                                        "be "
                                                                        "used "
                                                                        "to "
                                                                        "define "
                                                                        "the "
                                                                        "sort "
                                                                        "order "
                                                                        "of "
                                                                        "a "
                                                                        "query's "
                                                                        "results.",
                                                                        "example": "@duration",
                                                                        "type": "string",
                                                                    },
                                                                    "order": {
                                                                        "default": "desc",
                                                                        "description": "Direction "
                                                                        "of "
                                                                        "sort.",
                                                                        "enum": ["asc", "desc"],
                                                                        "type": "string",
                                                                        "x-enum-varnames": [
                                                                            "ASC",
                                                                            "DESC",
                                                                        ],
                                                                    },
                                                                    "type": {
                                                                        "description": "The "
                                                                        "type "
                                                                        "of "
                                                                        "sort "
                                                                        "to "
                                                                        "use "
                                                                        "on "
                                                                        "the "
                                                                        "calculated "
                                                                        "value.",
                                                                        "enum": [
                                                                            "alphabetical",
                                                                            "measure",
                                                                        ],
                                                                        "type": "string",
                                                                        "x-enum-varnames": [
                                                                            "ALPHABETICAL",
                                                                            "MEASURE",
                                                                        ],
                                                                    },
                                                                },
                                                                "required": ["aggregation"],
                                                                "type": "object",
                                                            },
                                                        },
                                                        "required": ["facet"],
                                                        "type": "object",
                                                    },
                                                    "type": "array",
                                                },
                                                "indexes": {
                                                    "description": "The "
                                                    "indexes "
                                                    "in "
                                                    "which "
                                                    "to "
                                                    "search.",
                                                    "example": ["main"],
                                                    "items": {
                                                        "description": "The unique index name.",
                                                        "example": "main",
                                                        "type": "string",
                                                    },
                                                    "type": "array",
                                                },
                                                "name": {
                                                    "description": "The "
                                                    "variable "
                                                    "name "
                                                    "for "
                                                    "use "
                                                    "in "
                                                    "formulas.",
                                                    "type": "string",
                                                },
                                                "search": {
                                                    "description": "Configuration "
                                                    "of "
                                                    "the "
                                                    "search/filter "
                                                    "for "
                                                    "an "
                                                    "events "
                                                    "query.",
                                                    "properties": {
                                                        "query": {
                                                            "description": "The "
                                                            "search/filter "
                                                            "string "
                                                            "for "
                                                            "an "
                                                            "events "
                                                            "query.",
                                                            "example": "status:warn service:foo",
                                                            "type": "string",
                                                        }
                                                    },
                                                    "type": "object",
                                                },
                                            },
                                            "required": ["data_source", "compute"],
                                            "type": "object",
                                        },
                                    ],
                                },
                                "type": "array",
                            },
                            "to": {
                                "description": "End "
                                "date "
                                "(exclusive) "
                                "of "
                                "the "
                                "query "
                                "in "
                                "milliseconds "
                                "since "
                                "the "
                                "Unix "
                                "epoch.",
                                "example": 1568923200000,
                                "format": "int64",
                                "type": "integer",
                            },
                        },
                        "required": ["to", "from", "queries"],
                        "type": "object",
                    },
                    "type": {
                        "default": "scalar_request",
                        "description": "The type of the "
                        "resource. The value "
                        "should always be "
                        "scalar_request.",
                        "enum": ["scalar_request"],
                        "example": "scalar_request",
                        "type": "string",
                        "x-enum-varnames": ["SCALAR_REQUEST"],
                    },
                },
                "required": ["type", "attributes"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "QUERYTIMESERIESDATA_REQUEST_BODY_SCHEMA": {
        "description": "A request wrapper around a single timeseries query to be executed.",
        "properties": {
            "data": {
                "description": "A single timeseries query to be executed.",
                "properties": {
                    "attributes": {
                        "description": "The object describing a timeseries formula request.",
                        "properties": {
                            "formulas": {
                                "description": "List "
                                "of "
                                "formulas "
                                "to "
                                "be "
                                "calculated "
                                "and "
                                "returned "
                                "as "
                                "responses.",
                                "items": {
                                    "description": "A "
                                    "formula "
                                    "for "
                                    "calculation "
                                    "based "
                                    "on "
                                    "one "
                                    "or "
                                    "more "
                                    "queries.",
                                    "properties": {
                                        "formula": {
                                            "description": "Formula "
                                            "string, "
                                            "referencing "
                                            "one "
                                            "or "
                                            "more "
                                            "queries "
                                            "with "
                                            "their "
                                            "name "
                                            "property.",
                                            "example": "a+b",
                                            "type": "string",
                                        },
                                        "limit": {
                                            "description": "Message "
                                            "for "
                                            "specifying "
                                            "limits "
                                            "to "
                                            "the "
                                            "number "
                                            "of "
                                            "values "
                                            "returned "
                                            "by "
                                            "a "
                                            "query.\n"
                                            "This "
                                            "limit "
                                            "is "
                                            "only "
                                            "for "
                                            "scalar "
                                            "queries "
                                            "and "
                                            "has "
                                            "no "
                                            "effect "
                                            "on "
                                            "timeseries "
                                            "queries.",
                                            "properties": {
                                                "count": {
                                                    "description": "The "
                                                    "number "
                                                    "of "
                                                    "results "
                                                    "to "
                                                    "which "
                                                    "to "
                                                    "limit.",
                                                    "example": 10,
                                                    "format": "int32",
                                                    "maximum": 2147483647,
                                                    "type": "integer",
                                                },
                                                "order": {
                                                    "default": "desc",
                                                    "description": "Direction of sort.",
                                                    "enum": ["asc", "desc"],
                                                    "type": "string",
                                                    "x-enum-varnames": ["ASC", "DESC"],
                                                },
                                            },
                                            "type": "object",
                                        },
                                    },
                                    "required": ["formula"],
                                    "type": "object",
                                },
                                "type": "array",
                            },
                            "from": {
                                "description": "Start "
                                "date "
                                "(inclusive) "
                                "of "
                                "the "
                                "query "
                                "in "
                                "milliseconds "
                                "since "
                                "the "
                                "Unix "
                                "epoch.",
                                "example": 1568899800000,
                                "format": "int64",
                                "type": "integer",
                            },
                            "interval": {
                                "description": "A "
                                "time "
                                "interval "
                                "in "
                                "milliseconds.\n"
                                "May "
                                "be "
                                "overridden "
                                "by "
                                "a "
                                "larger "
                                "interval "
                                "if "
                                "the "
                                "query "
                                "would "
                                "result "
                                "in\n"
                                "too "
                                "many "
                                "points "
                                "for "
                                "the "
                                "specified "
                                "timeframe.\n"
                                "Defaults "
                                "to "
                                "a "
                                "reasonable "
                                "interval "
                                "for "
                                "the "
                                "given "
                                "timeframe.",
                                "example": 5000,
                                "format": "int64",
                                "type": "integer",
                            },
                            "queries": {
                                "description": "List "
                                "of "
                                "queries "
                                "to "
                                "be "
                                "run "
                                "and "
                                "used "
                                "as "
                                "inputs "
                                "to "
                                "the "
                                "formulas.",
                                "example": [
                                    {
                                        "data_source": "metrics",
                                        "query": "avg:system.cpu.user{*} by {env}",
                                    }
                                ],
                                "items": {
                                    "description": "An "
                                    "individual "
                                    "timeseries "
                                    "query "
                                    "to "
                                    "one "
                                    "of "
                                    "the "
                                    "basic "
                                    "Datadog "
                                    "data "
                                    "sources.",
                                    "example": {
                                        "data_source": "metrics",
                                        "query": "avg:system.cpu.user{*} by {env}",
                                    },
                                    "oneOf": [
                                        {
                                            "description": "An "
                                            "individual "
                                            "timeseries "
                                            "metrics "
                                            "query.",
                                            "properties": {
                                                "data_source": {
                                                    "default": "metrics",
                                                    "description": "A "
                                                    "data "
                                                    "source "
                                                    "that "
                                                    "is "
                                                    "powered "
                                                    "by "
                                                    "the "
                                                    "Metrics "
                                                    "platform.",
                                                    "enum": ["metrics", "cloud_cost"],
                                                    "example": "metrics",
                                                    "type": "string",
                                                    "x-enum-varnames": ["METRICS", "CLOUD_COST"],
                                                },
                                                "name": {
                                                    "description": "The "
                                                    "variable "
                                                    "name "
                                                    "for "
                                                    "use "
                                                    "in "
                                                    "formulas.",
                                                    "type": "string",
                                                },
                                                "query": {
                                                    "description": "A "
                                                    "classic "
                                                    "metrics "
                                                    "query "
                                                    "string.",
                                                    "example": "avg:system.cpu.user{*} by {env}",
                                                    "type": "string",
                                                },
                                            },
                                            "required": ["data_source", "query"],
                                            "type": "object",
                                        },
                                        {
                                            "description": "An individual timeseries events query.",
                                            "properties": {
                                                "compute": {
                                                    "description": "The "
                                                    "instructions "
                                                    "for "
                                                    "what "
                                                    "to "
                                                    "compute "
                                                    "for "
                                                    "this "
                                                    "query.",
                                                    "properties": {
                                                        "aggregation": {
                                                            "default": "count",
                                                            "description": "The "
                                                            "type "
                                                            "of "
                                                            "aggregation "
                                                            "that "
                                                            "can "
                                                            "be "
                                                            "performed "
                                                            "on "
                                                            "events-based "
                                                            "queries.",
                                                            "enum": [
                                                                "count",
                                                                "cardinality",
                                                                "pc75",
                                                                "pc90",
                                                                "pc95",
                                                                "pc98",
                                                                "pc99",
                                                                "sum",
                                                                "min",
                                                                "max",
                                                                "avg",
                                                            ],
                                                            "example": "count",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "COUNT",
                                                                "CARDINALITY",
                                                                "PC75",
                                                                "PC90",
                                                                "PC95",
                                                                "PC98",
                                                                "PC99",
                                                                "SUM",
                                                                "MIN",
                                                                "MAX",
                                                                "AVG",
                                                            ],
                                                        },
                                                        "interval": {
                                                            "description": "Interval "
                                                            "for "
                                                            "compute "
                                                            "in "
                                                            "milliseconds.",
                                                            "example": 60000,
                                                            "format": "int64",
                                                            "type": "integer",
                                                        },
                                                        "metric": {
                                                            "description": "The "
                                                            '"measure" '
                                                            "attribute "
                                                            "on "
                                                            "which "
                                                            "to "
                                                            "perform "
                                                            "the "
                                                            "computation.",
                                                            "type": "string",
                                                        },
                                                    },
                                                    "required": ["aggregation"],
                                                    "type": "object",
                                                },
                                                "data_source": {
                                                    "default": "logs",
                                                    "description": "A "
                                                    "data "
                                                    "source "
                                                    "that "
                                                    "is "
                                                    "powered "
                                                    "by "
                                                    "the "
                                                    "Events "
                                                    "Platform.",
                                                    "enum": ["logs", "rum", "dora"],
                                                    "example": "logs",
                                                    "type": "string",
                                                    "x-enum-varnames": ["LOGS", "RUM", "DORA"],
                                                },
                                                "group_by": {
                                                    "description": "The "
                                                    "list "
                                                    "of "
                                                    "facets "
                                                    "on "
                                                    "which "
                                                    "to "
                                                    "split "
                                                    "results.",
                                                    "items": {
                                                        "description": "A "
                                                        "dimension "
                                                        "on "
                                                        "which "
                                                        "to "
                                                        "split "
                                                        "a "
                                                        "query's "
                                                        "results.",
                                                        "properties": {
                                                            "facet": {
                                                                "description": "The "
                                                                "facet "
                                                                "by "
                                                                "which "
                                                                "to "
                                                                "split "
                                                                "groups.",
                                                                "example": "@error.type",
                                                                "type": "string",
                                                            },
                                                            "limit": {
                                                                "default": 10,
                                                                "description": "The "
                                                                "maximum "
                                                                "buckets "
                                                                "to "
                                                                "return "
                                                                "for "
                                                                "this "
                                                                "group "
                                                                "by. "
                                                                "Note: "
                                                                "at "
                                                                "most "
                                                                "10000 "
                                                                "buckets "
                                                                "are "
                                                                "allowed.\n"
                                                                "If "
                                                                "grouping "
                                                                "by "
                                                                "multiple "
                                                                "facets, "
                                                                "the "
                                                                "product "
                                                                "of "
                                                                "limits "
                                                                "must "
                                                                "not "
                                                                "exceed "
                                                                "10000.",
                                                                "example": 10,
                                                                "format": "int32",
                                                                "maximum": 10000,
                                                                "type": "integer",
                                                            },
                                                            "sort": {
                                                                "description": "The "
                                                                "dimension "
                                                                "by "
                                                                "which "
                                                                "to "
                                                                "sort "
                                                                "a "
                                                                "query's "
                                                                "results.",
                                                                "properties": {
                                                                    "aggregation": {
                                                                        "default": "count",
                                                                        "description": "The "
                                                                        "type "
                                                                        "of "
                                                                        "aggregation "
                                                                        "that "
                                                                        "can "
                                                                        "be "
                                                                        "performed "
                                                                        "on "
                                                                        "events-based "
                                                                        "queries.",
                                                                        "enum": [
                                                                            "count",
                                                                            "cardinality",
                                                                            "pc75",
                                                                            "pc90",
                                                                            "pc95",
                                                                            "pc98",
                                                                            "pc99",
                                                                            "sum",
                                                                            "min",
                                                                            "max",
                                                                            "avg",
                                                                        ],
                                                                        "example": "count",
                                                                        "type": "string",
                                                                        "x-enum-varnames": [
                                                                            "COUNT",
                                                                            "CARDINALITY",
                                                                            "PC75",
                                                                            "PC90",
                                                                            "PC95",
                                                                            "PC98",
                                                                            "PC99",
                                                                            "SUM",
                                                                            "MIN",
                                                                            "MAX",
                                                                            "AVG",
                                                                        ],
                                                                    },
                                                                    "metric": {
                                                                        "description": "The "
                                                                        "metric's "
                                                                        "calculated "
                                                                        "value "
                                                                        "which "
                                                                        "should "
                                                                        "be "
                                                                        "used "
                                                                        "to "
                                                                        "define "
                                                                        "the "
                                                                        "sort "
                                                                        "order "
                                                                        "of "
                                                                        "a "
                                                                        "query's "
                                                                        "results.",
                                                                        "example": "@duration",
                                                                        "type": "string",
                                                                    },
                                                                    "order": {
                                                                        "default": "desc",
                                                                        "description": "Direction "
                                                                        "of "
                                                                        "sort.",
                                                                        "enum": ["asc", "desc"],
                                                                        "type": "string",
                                                                        "x-enum-varnames": [
                                                                            "ASC",
                                                                            "DESC",
                                                                        ],
                                                                    },
                                                                    "type": {
                                                                        "description": "The "
                                                                        "type "
                                                                        "of "
                                                                        "sort "
                                                                        "to "
                                                                        "use "
                                                                        "on "
                                                                        "the "
                                                                        "calculated "
                                                                        "value.",
                                                                        "enum": [
                                                                            "alphabetical",
                                                                            "measure",
                                                                        ],
                                                                        "type": "string",
                                                                        "x-enum-varnames": [
                                                                            "ALPHABETICAL",
                                                                            "MEASURE",
                                                                        ],
                                                                    },
                                                                },
                                                                "required": ["aggregation"],
                                                                "type": "object",
                                                            },
                                                        },
                                                        "required": ["facet"],
                                                        "type": "object",
                                                    },
                                                    "type": "array",
                                                },
                                                "indexes": {
                                                    "description": "The "
                                                    "indexes "
                                                    "in "
                                                    "which "
                                                    "to "
                                                    "search.",
                                                    "example": ["main"],
                                                    "items": {
                                                        "description": "The unique index name.",
                                                        "example": "main",
                                                        "type": "string",
                                                    },
                                                    "type": "array",
                                                },
                                                "name": {
                                                    "description": "The "
                                                    "variable "
                                                    "name "
                                                    "for "
                                                    "use "
                                                    "in "
                                                    "formulas.",
                                                    "type": "string",
                                                },
                                                "search": {
                                                    "description": "Configuration "
                                                    "of "
                                                    "the "
                                                    "search/filter "
                                                    "for "
                                                    "an "
                                                    "events "
                                                    "query.",
                                                    "properties": {
                                                        "query": {
                                                            "description": "The "
                                                            "search/filter "
                                                            "string "
                                                            "for "
                                                            "an "
                                                            "events "
                                                            "query.",
                                                            "example": "status:warn service:foo",
                                                            "type": "string",
                                                        }
                                                    },
                                                    "type": "object",
                                                },
                                            },
                                            "required": ["data_source", "compute"],
                                            "type": "object",
                                        },
                                    ],
                                },
                                "type": "array",
                            },
                            "to": {
                                "description": "End "
                                "date "
                                "(exclusive) "
                                "of "
                                "the "
                                "query "
                                "in "
                                "milliseconds "
                                "since "
                                "the "
                                "Unix "
                                "epoch.",
                                "example": 1568923200000,
                                "format": "int64",
                                "type": "integer",
                            },
                        },
                        "required": ["to", "from", "queries"],
                        "type": "object",
                    },
                    "type": {
                        "default": "timeseries_request",
                        "description": "The type of the "
                        "resource. The value "
                        "should always be "
                        "timeseries_request.",
                        "enum": ["timeseries_request"],
                        "example": "timeseries_request",
                        "type": "string",
                        "x-enum-varnames": ["TIMESERIES_REQUEST"],
                    },
                },
                "required": ["type", "attributes"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "CREATEREFERENCETABLE_REQUEST_BODY_SCHEMA": {
        "description": "The definition of `CreateTableRequest` object.",
        "example": {
            "data": {
                "attributes": {
                    "description": "this is a cloud table generated via a cloud bucket sync",
                    "file_metadata": {
                        "access_details": {
                            "aws_detail": {
                                "aws_account_id": "test-account-id",
                                "aws_bucket_name": "test-bucket",
                                "file_path": "test_rt.csv",
                            }
                        },
                        "sync_enabled": True,
                    },
                    "schema": {
                        "fields": [
                            {"name": "name", "type": "STRING"},
                            {"name": "account_id", "type": "STRING"},
                        ],
                        "primary_keys": ["account_id"],
                    },
                    "source": "S3",
                    "table_name": "test_reference_table",
                    "tags": ["test_tag"],
                },
                "type": "reference_table",
            }
        },
        "properties": {
            "data": {
                "description": "The definition of `CreateTableRequestData` object.",
                "properties": {
                    "attributes": {
                        "description": "The definition "
                        "of "
                        "`CreateTableRequestDataAttributes` "
                        "object.",
                        "properties": {
                            "description": {
                                "description": "The description of the reference table.",
                                "type": "string",
                            },
                            "file_metadata": {
                                "description": "The "
                                "definition "
                                "of "
                                "`CreateTableRequestDataAttributesFileMetadata` "
                                "object.",
                                "oneOf": [
                                    {
                                        "additionalProperties": False,
                                        "description": "Cloud "
                                        "storage "
                                        "file "
                                        "metadata "
                                        "for "
                                        "create "
                                        "requests. "
                                        "Both "
                                        "access_details "
                                        "and "
                                        "sync_enabled "
                                        "are "
                                        "required.",
                                        "properties": {
                                            "access_details": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "`CreateTableRequestDataAttributesFileMetadataOneOfAccessDetails` "
                                                "object.",
                                                "properties": {
                                                    "aws_detail": {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "`CreateTableRequestDataAttributesFileMetadataOneOfAccessDetailsAwsDetail` "
                                                        "object.",
                                                        "properties": {
                                                            "aws_account_id": {
                                                                "description": "The "
                                                                "ID "
                                                                "of "
                                                                "the "
                                                                "AWS "
                                                                "account.",
                                                                "example": "123456789000",
                                                                "type": "string",
                                                            },
                                                            "aws_bucket_name": {
                                                                "description": "The "
                                                                "name "
                                                                "of "
                                                                "the "
                                                                "Amazon "
                                                                "S3 "
                                                                "bucket.",
                                                                "example": "example-data-bucket",
                                                                "type": "string",
                                                            },
                                                            "file_path": {
                                                                "description": "The "
                                                                "relative "
                                                                "file "
                                                                "path "
                                                                "from "
                                                                "the "
                                                                "S3 "
                                                                "bucket "
                                                                "root "
                                                                "to "
                                                                "the "
                                                                "CSV "
                                                                "file.",
                                                                "example": "reference-tables/users.csv",
                                                                "type": "string",
                                                            },
                                                        },
                                                        "required": [
                                                            "aws_account_id",
                                                            "aws_bucket_name",
                                                            "file_path",
                                                        ],
                                                        "type": "object",
                                                        "x-oneOf-parent": ["AwsDetail"],
                                                    },
                                                    "azure_detail": {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "`CreateTableRequestDataAttributesFileMetadataOneOfAccessDetailsAzureDetail` "
                                                        "object.",
                                                        "properties": {
                                                            "azure_client_id": {
                                                                "description": "The "
                                                                "Azure "
                                                                "client "
                                                                "ID.",
                                                                "example": "aaaaaaaa-1111-2222-3333-bbbbbbbbbbbb",
                                                                "type": "string",
                                                            },
                                                            "azure_container_name": {
                                                                "description": "The "
                                                                "name "
                                                                "of "
                                                                "the "
                                                                "Azure "
                                                                "container.",
                                                                "example": "reference-data",
                                                                "type": "string",
                                                            },
                                                            "azure_storage_account_name": {
                                                                "description": "The "
                                                                "name "
                                                                "of "
                                                                "the "
                                                                "Azure "
                                                                "storage "
                                                                "account.",
                                                                "example": "examplestorageaccount",
                                                                "type": "string",
                                                            },
                                                            "azure_tenant_id": {
                                                                "description": "The "
                                                                "ID "
                                                                "of "
                                                                "the "
                                                                "Azure "
                                                                "tenant.",
                                                                "example": "cccccccc-4444-5555-6666-dddddddddddd",
                                                                "type": "string",
                                                            },
                                                            "file_path": {
                                                                "description": "The "
                                                                "relative "
                                                                "file "
                                                                "path "
                                                                "from "
                                                                "the "
                                                                "Azure "
                                                                "container "
                                                                "root "
                                                                "to "
                                                                "the "
                                                                "CSV "
                                                                "file.",
                                                                "example": "tables/users.csv",
                                                                "type": "string",
                                                            },
                                                        },
                                                        "required": [
                                                            "azure_client_id",
                                                            "azure_container_name",
                                                            "azure_storage_account_name",
                                                            "azure_tenant_id",
                                                            "file_path",
                                                        ],
                                                        "type": "object",
                                                        "x-oneOf-parent": ["AzureDetail"],
                                                    },
                                                    "gcp_detail": {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "`CreateTableRequestDataAttributesFileMetadataOneOfAccessDetailsGcpDetail` "
                                                        "object.",
                                                        "properties": {
                                                            "file_path": {
                                                                "description": "The "
                                                                "relative "
                                                                "file "
                                                                "path "
                                                                "from "
                                                                "the "
                                                                "GCS "
                                                                "bucket "
                                                                "root "
                                                                "to "
                                                                "the "
                                                                "CSV "
                                                                "file.",
                                                                "example": "data/reference_tables/users.csv",
                                                                "type": "string",
                                                            },
                                                            "gcp_bucket_name": {
                                                                "description": "The "
                                                                "name "
                                                                "of "
                                                                "the "
                                                                "GCP "
                                                                "bucket.",
                                                                "example": "example-data-bucket",
                                                                "type": "string",
                                                            },
                                                            "gcp_project_id": {
                                                                "description": "The "
                                                                "ID "
                                                                "of "
                                                                "the "
                                                                "GCP "
                                                                "project.",
                                                                "example": "example-gcp-project-12345",
                                                                "type": "string",
                                                            },
                                                            "gcp_service_account_email": {
                                                                "description": "The "
                                                                "email "
                                                                "of "
                                                                "the "
                                                                "GCP "
                                                                "service "
                                                                "account.",
                                                                "example": "example-service@example-gcp-project-12345.iam.gserviceaccount.com",
                                                                "type": "string",
                                                            },
                                                        },
                                                        "required": [
                                                            "file_path",
                                                            "gcp_bucket_name",
                                                            "gcp_project_id",
                                                            "gcp_service_account_email",
                                                        ],
                                                        "type": "object",
                                                        "x-oneOf-parent": ["GcpDetail"],
                                                    },
                                                },
                                                "type": "object",
                                            },
                                            "sync_enabled": {
                                                "description": "Whether "
                                                "this "
                                                "table "
                                                "is "
                                                "synced "
                                                "automatically.",
                                                "example": False,
                                                "type": "boolean",
                                            },
                                        },
                                        "required": ["access_details", "sync_enabled"],
                                        "title": "CloudFileMetadataV2",
                                        "type": "object",
                                    },
                                    {
                                        "additionalProperties": False,
                                        "description": "Local "
                                        "file "
                                        "metadata "
                                        "for "
                                        "create "
                                        "requests "
                                        "using "
                                        "the "
                                        "upload "
                                        "ID.",
                                        "properties": {
                                            "upload_id": {
                                                "description": "The upload ID.",
                                                "example": "",
                                                "type": "string",
                                            }
                                        },
                                        "required": ["upload_id"],
                                        "title": "LocalFileMetadataV2",
                                        "type": "object",
                                    },
                                ],
                            },
                            "schema": {
                                "description": "The "
                                "definition "
                                "of "
                                "`CreateTableRequestDataAttributesSchema` "
                                "object.",
                                "properties": {
                                    "fields": {
                                        "description": "The `schema` `fields`.",
                                        "items": {
                                            "description": "The "
                                            "definition "
                                            "of "
                                            "`CreateTableRequestDataAttributesSchemaFieldsItems` "
                                            "object.",
                                            "properties": {
                                                "name": {
                                                    "description": "The field name.",
                                                    "example": "",
                                                    "type": "string",
                                                },
                                                "type": {
                                                    "description": "The "
                                                    "field "
                                                    "type "
                                                    "for "
                                                    "reference "
                                                    "table "
                                                    "schema "
                                                    "fields.",
                                                    "enum": ["STRING", "INT32"],
                                                    "example": "STRING",
                                                    "type": "string",
                                                    "x-enum-varnames": ["STRING", "INT32"],
                                                },
                                            },
                                            "required": ["name", "type"],
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "primary_keys": {
                                        "description": "List "
                                        "of "
                                        "field "
                                        "names "
                                        "that "
                                        "serve "
                                        "as "
                                        "primary "
                                        "keys "
                                        "for "
                                        "the "
                                        "table. "
                                        "Only "
                                        "one "
                                        "primary "
                                        "key "
                                        "is "
                                        "supported, "
                                        "and "
                                        "it "
                                        "is "
                                        "used "
                                        "as "
                                        "an "
                                        "ID "
                                        "to "
                                        "retrieve "
                                        "rows.",
                                        "example": [""],
                                        "items": {"type": "string"},
                                        "type": "array",
                                    },
                                },
                                "required": ["fields", "primary_keys"],
                                "type": "object",
                            },
                            "source": {
                                "description": "The "
                                "source "
                                "type "
                                "for "
                                "creating "
                                "reference "
                                "table "
                                "data. "
                                "Only "
                                "these "
                                "source "
                                "types "
                                "can "
                                "be "
                                "created "
                                "through "
                                "this "
                                "API.",
                                "enum": ["LOCAL_FILE", "S3", "GCS", "AZURE"],
                                "example": "LOCAL_FILE",
                                "type": "string",
                                "x-enum-varnames": ["LOCAL_FILE", "S3", "GCS", "AZURE"],
                            },
                            "table_name": {
                                "description": "The name of the reference table.",
                                "example": "",
                                "type": "string",
                            },
                            "tags": {
                                "description": "The tags of the reference table.",
                                "items": {"type": "string"},
                                "type": "array",
                            },
                        },
                        "required": ["table_name", "schema", "source"],
                        "type": "object",
                    },
                    "id": {"description": "The ID of the reference table.", "type": "string"},
                    "type": {
                        "default": "reference_table",
                        "description": "Reference table resource type.",
                        "enum": ["reference_table"],
                        "example": "reference_table",
                        "type": "string",
                        "x-enum-varnames": ["REFERENCE_TABLE"],
                    },
                },
                "required": ["type"],
                "type": "object",
            }
        },
        "type": "object",
    },
    "UPDATEREFERENCETABLE_REQUEST_BODY_SCHEMA": {
        "description": "The definition of `PatchTableRequest` object.",
        "example": {
            "data": {
                "attributes": {
                    "description": "this is a cloud table generated via a cloud bucket sync",
                    "file_metadata": {
                        "access_details": {
                            "aws_detail": {
                                "aws_account_id": "test-account-id",
                                "aws_bucket_name": "test-bucket",
                                "file_path": "test_rt.csv",
                            }
                        },
                        "sync_enabled": True,
                    },
                    "schema": {
                        "fields": [
                            {"name": "id", "type": "INT32"},
                            {"name": "name", "type": "STRING"},
                        ],
                        "primary_keys": ["id"],
                    },
                    "sync_enabled": False,
                    "tags": ["test_tag"],
                },
                "id": "00000000-0000-0000-0000-000000000000",
                "type": "reference_table",
            }
        },
        "properties": {
            "data": {
                "description": "The definition of `PatchTableRequestData` object.",
                "properties": {
                    "attributes": {
                        "description": "The definition "
                        "of "
                        "`PatchTableRequestDataAttributes` "
                        "object.",
                        "properties": {
                            "description": {
                                "description": "The description of the reference table.",
                                "type": "string",
                            },
                            "file_metadata": {
                                "description": "The "
                                "definition "
                                "of "
                                "`PatchTableRequestDataAttributesFileMetadata` "
                                "object.",
                                "oneOf": [
                                    {
                                        "additionalProperties": False,
                                        "description": "Cloud "
                                        "storage "
                                        "file "
                                        "metadata "
                                        "for "
                                        "patch "
                                        "requests. "
                                        "Allows "
                                        "partial "
                                        "updates "
                                        "of "
                                        "access_details "
                                        "and "
                                        "sync_enabled.",
                                        "properties": {
                                            "access_details": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "`PatchTableRequestDataAttributesFileMetadataOneOfAccessDetails` "
                                                "object.",
                                                "properties": {
                                                    "aws_detail": {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "`PatchTableRequestDataAttributesFileMetadataOneOfAccessDetailsAwsDetail` "
                                                        "object.",
                                                        "properties": {
                                                            "aws_account_id": {
                                                                "description": "The "
                                                                "ID "
                                                                "of "
                                                                "the "
                                                                "AWS "
                                                                "account.",
                                                                "example": "123456789000",
                                                                "type": "string",
                                                            },
                                                            "aws_bucket_name": {
                                                                "description": "The "
                                                                "name "
                                                                "of "
                                                                "the "
                                                                "AWS "
                                                                "bucket.",
                                                                "example": "example-data-bucket",
                                                                "type": "string",
                                                            },
                                                            "file_path": {
                                                                "description": "The "
                                                                "relative "
                                                                "file "
                                                                "path "
                                                                "from "
                                                                "the "
                                                                "S3 "
                                                                "bucket "
                                                                "root "
                                                                "to "
                                                                "the "
                                                                "CSV "
                                                                "file.",
                                                                "example": "reference-tables/users.csv",
                                                                "type": "string",
                                                            },
                                                        },
                                                        "type": "object",
                                                        "x-oneOf-parent": ["AwsDetail"],
                                                    },
                                                    "azure_detail": {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "`PatchTableRequestDataAttributesFileMetadataOneOfAccessDetailsAzureDetail` "
                                                        "object.",
                                                        "properties": {
                                                            "azure_client_id": {
                                                                "description": "The "
                                                                "Azure "
                                                                "client "
                                                                "ID.",
                                                                "example": "aaaaaaaa-1111-2222-3333-bbbbbbbbbbbb",
                                                                "type": "string",
                                                            },
                                                            "azure_container_name": {
                                                                "description": "The "
                                                                "name "
                                                                "of "
                                                                "the "
                                                                "Azure "
                                                                "container.",
                                                                "example": "reference-data",
                                                                "type": "string",
                                                            },
                                                            "azure_storage_account_name": {
                                                                "description": "The "
                                                                "name "
                                                                "of "
                                                                "the "
                                                                "Azure "
                                                                "storage "
                                                                "account.",
                                                                "example": "examplestorageaccount",
                                                                "type": "string",
                                                            },
                                                            "azure_tenant_id": {
                                                                "description": "The "
                                                                "ID "
                                                                "of "
                                                                "the "
                                                                "Azure "
                                                                "tenant.",
                                                                "example": "cccccccc-4444-5555-6666-dddddddddddd",
                                                                "type": "string",
                                                            },
                                                            "file_path": {
                                                                "description": "The "
                                                                "relative "
                                                                "file "
                                                                "path "
                                                                "from "
                                                                "the "
                                                                "Azure "
                                                                "container "
                                                                "root "
                                                                "to "
                                                                "the "
                                                                "CSV "
                                                                "file.",
                                                                "example": "tables/users.csv",
                                                                "type": "string",
                                                            },
                                                        },
                                                        "type": "object",
                                                        "x-oneOf-parent": ["AzureDetail"],
                                                    },
                                                    "gcp_detail": {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "`PatchTableRequestDataAttributesFileMetadataOneOfAccessDetailsGcpDetail` "
                                                        "object.",
                                                        "properties": {
                                                            "file_path": {
                                                                "description": "The "
                                                                "relative "
                                                                "file "
                                                                "path "
                                                                "from "
                                                                "the "
                                                                "GCS "
                                                                "bucket "
                                                                "root "
                                                                "to "
                                                                "the "
                                                                "CSV "
                                                                "file.",
                                                                "example": "data/reference_tables/users.csv",
                                                                "type": "string",
                                                            },
                                                            "gcp_bucket_name": {
                                                                "description": "The "
                                                                "name "
                                                                "of "
                                                                "the "
                                                                "GCP "
                                                                "bucket.",
                                                                "example": "example-data-bucket",
                                                                "type": "string",
                                                            },
                                                            "gcp_project_id": {
                                                                "description": "The "
                                                                "ID "
                                                                "of "
                                                                "the "
                                                                "GCP "
                                                                "project.",
                                                                "example": "example-gcp-project-12345",
                                                                "type": "string",
                                                            },
                                                            "gcp_service_account_email": {
                                                                "description": "The "
                                                                "email "
                                                                "of "
                                                                "the "
                                                                "GCP "
                                                                "service "
                                                                "account.",
                                                                "example": "example-service@example-gcp-project-12345.iam.gserviceaccount.com",
                                                                "type": "string",
                                                            },
                                                        },
                                                        "type": "object",
                                                        "x-oneOf-parent": ["GcpDetail"],
                                                    },
                                                },
                                                "type": "object",
                                            },
                                            "sync_enabled": {
                                                "description": "Whether "
                                                "this "
                                                "table "
                                                "is "
                                                "synced "
                                                "automatically.",
                                                "example": False,
                                                "type": "boolean",
                                            },
                                        },
                                        "title": "CloudFileMetadataV2",
                                        "type": "object",
                                    },
                                    {
                                        "additionalProperties": False,
                                        "description": "Local "
                                        "file "
                                        "metadata "
                                        "for "
                                        "patch "
                                        "requests "
                                        "using "
                                        "upload "
                                        "ID.",
                                        "properties": {
                                            "upload_id": {
                                                "description": "The upload ID.",
                                                "example": "",
                                                "type": "string",
                                            }
                                        },
                                        "required": ["upload_id"],
                                        "title": "LocalFileMetadataV2",
                                        "type": "object",
                                    },
                                ],
                            },
                            "schema": {
                                "description": "The "
                                "definition "
                                "of "
                                "`PatchTableRequestDataAttributesSchema` "
                                "object.",
                                "properties": {
                                    "fields": {
                                        "description": "The `schema` `fields`.",
                                        "items": {
                                            "description": "The "
                                            "definition "
                                            "of "
                                            "`PatchTableRequestDataAttributesSchemaFieldsItems` "
                                            "object.",
                                            "properties": {
                                                "name": {
                                                    "description": "The field name.",
                                                    "example": "",
                                                    "type": "string",
                                                },
                                                "type": {
                                                    "description": "The "
                                                    "field "
                                                    "type "
                                                    "for "
                                                    "reference "
                                                    "table "
                                                    "schema "
                                                    "fields.",
                                                    "enum": ["STRING", "INT32"],
                                                    "example": "STRING",
                                                    "type": "string",
                                                    "x-enum-varnames": ["STRING", "INT32"],
                                                },
                                            },
                                            "required": ["name", "type"],
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "primary_keys": {
                                        "description": "List "
                                        "of "
                                        "field "
                                        "names "
                                        "that "
                                        "serve "
                                        "as "
                                        "primary "
                                        "keys "
                                        "for "
                                        "the "
                                        "table. "
                                        "Only "
                                        "one "
                                        "primary "
                                        "key "
                                        "is "
                                        "supported, "
                                        "and "
                                        "it "
                                        "is "
                                        "used "
                                        "as "
                                        "an "
                                        "ID "
                                        "to "
                                        "retrieve "
                                        "rows.",
                                        "example": [""],
                                        "items": {"type": "string"},
                                        "type": "array",
                                    },
                                },
                                "required": ["fields", "primary_keys"],
                                "type": "object",
                            },
                            "sync_enabled": {
                                "description": "Whether this table is synced automatically.",
                                "type": "boolean",
                            },
                            "tags": {
                                "description": "The tags of the reference table.",
                                "items": {"type": "string"},
                                "type": "array",
                            },
                        },
                        "type": "object",
                    },
                    "id": {"description": "The ID of the reference table.", "type": "string"},
                    "type": {
                        "default": "reference_table",
                        "description": "Reference table resource type.",
                        "enum": ["reference_table"],
                        "example": "reference_table",
                        "type": "string",
                        "x-enum-varnames": ["REFERENCE_TABLE"],
                    },
                },
                "required": ["type"],
                "type": "object",
            }
        },
        "type": "object",
    },
    "CREATEWAFCUSTOMRULE_REQUEST_BODY_SCHEMA": {
        "description": "Request object that includes the custom rule to create.",
        "properties": {
            "data": {
                "description": "Object for a single WAF custom rule.",
                "properties": {
                    "attributes": {
                        "description": "Create a new WAF custom rule.",
                        "properties": {
                            "action": {
                                "description": "The "
                                "definition "
                                "of "
                                "`ApplicationSecurityWafCustomRuleAction` "
                                "object.",
                                "properties": {
                                    "action": {
                                        "default": "block_request",
                                        "description": "Override "
                                        "the "
                                        "default "
                                        "action "
                                        "to "
                                        "take "
                                        "when "
                                        "the "
                                        "WAF "
                                        "custom "
                                        "rule "
                                        "would "
                                        "block.",
                                        "enum": ["redirect_request", "block_request"],
                                        "example": "block_request",
                                        "type": "string",
                                        "x-enum-varnames": ["REDIRECT_REQUEST", "BLOCK_REQUEST"],
                                    },
                                    "parameters": {
                                        "description": "The "
                                        "definition "
                                        "of "
                                        "`ApplicationSecurityWafCustomRuleActionParameters` "
                                        "object.",
                                        "properties": {
                                            "location": {
                                                "description": "The "
                                                "location "
                                                "to "
                                                "redirect "
                                                "to "
                                                "when "
                                                "the "
                                                "WAF "
                                                "custom "
                                                "rule "
                                                "triggers.",
                                                "example": "/blocking",
                                                "type": "string",
                                            },
                                            "status_code": {
                                                "default": 403,
                                                "description": "The "
                                                "status "
                                                "code "
                                                "to "
                                                "return "
                                                "when "
                                                "the "
                                                "WAF "
                                                "custom "
                                                "rule "
                                                "triggers.",
                                                "example": 403,
                                                "format": "int64",
                                                "type": "integer",
                                            },
                                        },
                                        "type": "object",
                                    },
                                },
                                "type": "object",
                            },
                            "blocking": {
                                "description": "Indicates "
                                "whether "
                                "the "
                                "WAF "
                                "custom "
                                "rule "
                                "will "
                                "block "
                                "the "
                                "request.",
                                "example": False,
                                "type": "boolean",
                            },
                            "conditions": {
                                "description": "Conditions "
                                "for "
                                "which "
                                "the "
                                "WAF "
                                "Custom "
                                "Rule "
                                "will "
                                "triggers, "
                                "all "
                                "conditions "
                                "needs "
                                "to "
                                "match "
                                "in "
                                "order "
                                "for "
                                "the "
                                "WAF\n"
                                "rule "
                                "to "
                                "trigger",
                                "items": {
                                    "description": "One condition of the WAF Custom Rule.",
                                    "properties": {
                                        "operator": {
                                            "description": "Operator to use for the WAF Condition.",
                                            "enum": [
                                                "match_regex",
                                                "!match_regex",
                                                "phrase_match",
                                                "!phrase_match",
                                                "is_xss",
                                                "is_sqli",
                                                "exact_match",
                                                "!exact_match",
                                                "ip_match",
                                                "!ip_match",
                                                "capture_data",
                                            ],
                                            "example": "match_regex",
                                            "type": "string",
                                            "x-enum-varnames": [
                                                "MATCH_REGEX",
                                                "NOT_MATCH_REGEX",
                                                "PHRASE_MATCH",
                                                "NOT_PHRASE_MATCH",
                                                "IS_XSS",
                                                "IS_SQLI",
                                                "EXACT_MATCH",
                                                "NOT_EXACT_MATCH",
                                                "IP_MATCH",
                                                "NOT_IP_MATCH",
                                                "CAPTURE_DATA",
                                            ],
                                        },
                                        "parameters": {
                                            "description": "The scope of the WAF custom rule.",
                                            "properties": {
                                                "data": {
                                                    "description": "Identifier "
                                                    "of "
                                                    "a "
                                                    "list "
                                                    "of "
                                                    "data "
                                                    "from "
                                                    "the "
                                                    "denylist. "
                                                    "Can "
                                                    "only "
                                                    "be "
                                                    "used "
                                                    "as "
                                                    "substitution "
                                                    "from "
                                                    "the "
                                                    "list "
                                                    "parameter.",
                                                    "example": "blocked_users",
                                                    "type": "string",
                                                },
                                                "inputs": {
                                                    "description": "List "
                                                    "of "
                                                    "inputs "
                                                    "on "
                                                    "which "
                                                    "at "
                                                    "least "
                                                    "one "
                                                    "should "
                                                    "match "
                                                    "with "
                                                    "the "
                                                    "given "
                                                    "operator.",
                                                    "items": {
                                                        "description": "Input "
                                                        "from "
                                                        "the "
                                                        "request "
                                                        "on "
                                                        "which "
                                                        "the "
                                                        "condition "
                                                        "should "
                                                        "apply.",
                                                        "properties": {
                                                            "address": {
                                                                "description": "Input "
                                                                "from "
                                                                "the "
                                                                "request "
                                                                "on "
                                                                "which "
                                                                "the "
                                                                "condition "
                                                                "should "
                                                                "apply.",
                                                                "enum": [
                                                                    "server.db.statement",
                                                                    "server.io.fs.file",
                                                                    "server.io.net.url",
                                                                    "server.sys.shell.cmd",
                                                                    "server.request.method",
                                                                    "server.request.uri.raw",
                                                                    "server.request.path_params",
                                                                    "server.request.query",
                                                                    "server.request.headers.no_cookies",
                                                                    "server.request.cookies",
                                                                    "server.request.trailers",
                                                                    "server.request.body",
                                                                    "server.response.status",
                                                                    "server.response.headers.no_cookies",
                                                                    "server.response.trailers",
                                                                    "grpc.server.request.metadata",
                                                                    "grpc.server.request.message",
                                                                    "grpc.server.method",
                                                                    "graphql.server.all_resolvers",
                                                                    "usr.id",
                                                                    "http.client_ip",
                                                                ],
                                                                "example": "server.db.statement",
                                                                "type": "string",
                                                                "x-enum-varnames": [
                                                                    "SERVER_DB_STATEMENT",
                                                                    "SERVER_IO_FS_FILE",
                                                                    "SERVER_IO_NET_URL",
                                                                    "SERVER_SYS_SHELL_CMD",
                                                                    "SERVER_REQUEST_METHOD",
                                                                    "SERVER_REQUEST_URI_RAW",
                                                                    "SERVER_REQUEST_PATH_PARAMS",
                                                                    "SERVER_REQUEST_QUERY",
                                                                    "SERVER_REQUEST_HEADERS_NO_COOKIES",
                                                                    "SERVER_REQUEST_COOKIES",
                                                                    "SERVER_REQUEST_TRAILERS",
                                                                    "SERVER_REQUEST_BODY",
                                                                    "SERVER_RESPONSE_STATUS",
                                                                    "SERVER_RESPONSE_HEADERS_NO_COOKIES",
                                                                    "SERVER_RESPONSE_TRAILERS",
                                                                    "GRPC_SERVER_REQUEST_METADATA",
                                                                    "GRPC_SERVER_REQUEST_MESSAGE",
                                                                    "GRPC_SERVER_METHOD",
                                                                    "GRAPHQL_SERVER_ALL_RESOLVERS",
                                                                    "USR_ID",
                                                                    "HTTP_CLIENT_IP",
                                                                ],
                                                            },
                                                            "key_path": {
                                                                "description": "Specific "
                                                                "path "
                                                                "for "
                                                                "the "
                                                                "input.",
                                                                "items": {"type": "string"},
                                                                "type": "array",
                                                            },
                                                        },
                                                        "required": ["address"],
                                                        "type": "object",
                                                    },
                                                    "type": "array",
                                                },
                                                "list": {
                                                    "description": "List "
                                                    "of "
                                                    "value "
                                                    "to "
                                                    "use "
                                                    "with "
                                                    "the "
                                                    "condition. "
                                                    "Only "
                                                    "used "
                                                    "with "
                                                    "the "
                                                    "phrase_match, "
                                                    "!phrase_match, "
                                                    "exact_match "
                                                    "and\n"
                                                    "!exact_match "
                                                    "operator.",
                                                    "items": {"type": "string"},
                                                    "type": "array",
                                                },
                                                "options": {
                                                    "description": "Options "
                                                    "for "
                                                    "the "
                                                    "operator "
                                                    "of "
                                                    "this "
                                                    "condition.",
                                                    "properties": {
                                                        "case_sensitive": {
                                                            "default": False,
                                                            "description": "Evaluate "
                                                            "the "
                                                            "value "
                                                            "as "
                                                            "case "
                                                            "sensitive.",
                                                            "type": "boolean",
                                                        },
                                                        "min_length": {
                                                            "default": 0,
                                                            "description": "Only "
                                                            "evaluate "
                                                            "this "
                                                            "condition "
                                                            "if "
                                                            "the "
                                                            "value "
                                                            "has "
                                                            "a "
                                                            "minimum "
                                                            "amount "
                                                            "of "
                                                            "characters.",
                                                            "format": "int64",
                                                            "type": "integer",
                                                        },
                                                    },
                                                    "type": "object",
                                                },
                                                "regex": {
                                                    "description": "Regex "
                                                    "to "
                                                    "use "
                                                    "with "
                                                    "the "
                                                    "condition. "
                                                    "Only "
                                                    "used "
                                                    "with "
                                                    "match_regex "
                                                    "and "
                                                    "!match_regex "
                                                    "operator.",
                                                    "example": "path.*",
                                                    "type": "string",
                                                },
                                                "value": {
                                                    "description": "Store "
                                                    "the "
                                                    "captured "
                                                    "value "
                                                    "in "
                                                    "the "
                                                    "specified "
                                                    "tag "
                                                    "name. "
                                                    "Only "
                                                    "used "
                                                    "with "
                                                    "the "
                                                    "capture_data "
                                                    "operator.",
                                                    "example": "custom_tag",
                                                    "type": "string",
                                                },
                                            },
                                            "required": ["inputs"],
                                            "type": "object",
                                        },
                                    },
                                    "required": ["operator", "parameters"],
                                    "type": "object",
                                },
                                "type": "array",
                            },
                            "enabled": {
                                "description": "Indicates whether the WAF custom rule is enabled.",
                                "example": False,
                                "type": "boolean",
                            },
                            "name": {
                                "description": "The Name of the WAF custom rule.",
                                "example": "Block request from a bad useragent",
                                "type": "string",
                            },
                            "path_glob": {
                                "description": "The path glob for the WAF custom rule.",
                                "example": "/api/search/*",
                                "type": "string",
                            },
                            "scope": {
                                "description": "The scope of the WAF custom rule.",
                                "items": {
                                    "description": "The scope of the WAF custom rule.",
                                    "properties": {
                                        "env": {
                                            "description": "The "
                                            "environment "
                                            "scope "
                                            "for "
                                            "the "
                                            "WAF "
                                            "custom "
                                            "rule.",
                                            "example": "prod",
                                            "type": "string",
                                        },
                                        "service": {
                                            "description": "The "
                                            "service "
                                            "scope "
                                            "for "
                                            "the "
                                            "WAF "
                                            "custom "
                                            "rule.",
                                            "example": "billing-service",
                                            "type": "string",
                                        },
                                    },
                                    "required": ["service", "env"],
                                    "type": "object",
                                },
                                "type": "array",
                            },
                            "tags": {
                                "additionalProperties": {"type": "string"},
                                "description": "Tags "
                                "associated "
                                "with "
                                "the "
                                "WAF "
                                "Custom "
                                "Rule. "
                                "The "
                                "concatenation "
                                "of "
                                "category "
                                "and "
                                "type "
                                "will "
                                "form "
                                "the "
                                "security\n"
                                "activity "
                                "field "
                                "associated "
                                "with "
                                "the "
                                "traces.",
                                "maxProperties": 32,
                                "properties": {
                                    "category": {
                                        "description": "The "
                                        "category "
                                        "of "
                                        "the "
                                        "WAF "
                                        "Rule, "
                                        "can "
                                        "be "
                                        "either "
                                        "`business_logic`, "
                                        "`attack_attempt` "
                                        "or "
                                        "`security_response`.",
                                        "enum": [
                                            "attack_attempt",
                                            "business_logic",
                                            "security_response",
                                        ],
                                        "example": "business_logic",
                                        "type": "string",
                                        "x-enum-varnames": [
                                            "ATTACK_ATTEMPT",
                                            "BUSINESS_LOGIC",
                                            "SECURITY_RESPONSE",
                                        ],
                                    },
                                    "type": {
                                        "description": "The "
                                        "type "
                                        "of "
                                        "the "
                                        "WAF "
                                        "rule, "
                                        "associated "
                                        "with "
                                        "the "
                                        "category "
                                        "will "
                                        "form "
                                        "the "
                                        "security "
                                        "activity.",
                                        "example": "users.login.success",
                                        "type": "string",
                                    },
                                },
                                "required": ["category", "type"],
                                "type": "object",
                            },
                        },
                        "required": ["enabled", "blocking", "name", "tags", "conditions"],
                        "type": "object",
                    },
                    "type": {
                        "default": "custom_rule",
                        "description": "The type of the "
                        "resource. The value "
                        "should always be "
                        "`custom_rule`.",
                        "enum": ["custom_rule"],
                        "example": "custom_rule",
                        "type": "string",
                        "x-enum-varnames": ["CUSTOM_RULE"],
                    },
                },
                "required": ["attributes", "type"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "UPDATEWAFCUSTOMRULE_REQUEST_BODY_SCHEMA": {
        "description": "Request object that includes the Custom Rule to update.",
        "properties": {
            "data": {
                "description": "Object for a single WAF Custom Rule.",
                "properties": {
                    "attributes": {
                        "description": "Update a WAF custom rule.",
                        "properties": {
                            "action": {
                                "description": "The "
                                "definition "
                                "of "
                                "`ApplicationSecurityWafCustomRuleAction` "
                                "object.",
                                "properties": {
                                    "action": {
                                        "default": "block_request",
                                        "description": "Override "
                                        "the "
                                        "default "
                                        "action "
                                        "to "
                                        "take "
                                        "when "
                                        "the "
                                        "WAF "
                                        "custom "
                                        "rule "
                                        "would "
                                        "block.",
                                        "enum": ["redirect_request", "block_request"],
                                        "example": "block_request",
                                        "type": "string",
                                        "x-enum-varnames": ["REDIRECT_REQUEST", "BLOCK_REQUEST"],
                                    },
                                    "parameters": {
                                        "description": "The "
                                        "definition "
                                        "of "
                                        "`ApplicationSecurityWafCustomRuleActionParameters` "
                                        "object.",
                                        "properties": {
                                            "location": {
                                                "description": "The "
                                                "location "
                                                "to "
                                                "redirect "
                                                "to "
                                                "when "
                                                "the "
                                                "WAF "
                                                "custom "
                                                "rule "
                                                "triggers.",
                                                "example": "/blocking",
                                                "type": "string",
                                            },
                                            "status_code": {
                                                "default": 403,
                                                "description": "The "
                                                "status "
                                                "code "
                                                "to "
                                                "return "
                                                "when "
                                                "the "
                                                "WAF "
                                                "custom "
                                                "rule "
                                                "triggers.",
                                                "example": 403,
                                                "format": "int64",
                                                "type": "integer",
                                            },
                                        },
                                        "type": "object",
                                    },
                                },
                                "type": "object",
                            },
                            "blocking": {
                                "description": "Indicates "
                                "whether "
                                "the "
                                "WAF "
                                "custom "
                                "rule "
                                "will "
                                "block "
                                "the "
                                "request.",
                                "example": False,
                                "type": "boolean",
                            },
                            "conditions": {
                                "description": "Conditions "
                                "for "
                                "which "
                                "the "
                                "WAF "
                                "Custom "
                                "Rule "
                                "will "
                                "triggers, "
                                "all "
                                "conditions "
                                "needs "
                                "to "
                                "match "
                                "in "
                                "order "
                                "for "
                                "the "
                                "WAF\n"
                                "rule "
                                "to "
                                "trigger.",
                                "items": {
                                    "description": "One condition of the WAF Custom Rule.",
                                    "properties": {
                                        "operator": {
                                            "description": "Operator to use for the WAF Condition.",
                                            "enum": [
                                                "match_regex",
                                                "!match_regex",
                                                "phrase_match",
                                                "!phrase_match",
                                                "is_xss",
                                                "is_sqli",
                                                "exact_match",
                                                "!exact_match",
                                                "ip_match",
                                                "!ip_match",
                                                "capture_data",
                                            ],
                                            "example": "match_regex",
                                            "type": "string",
                                            "x-enum-varnames": [
                                                "MATCH_REGEX",
                                                "NOT_MATCH_REGEX",
                                                "PHRASE_MATCH",
                                                "NOT_PHRASE_MATCH",
                                                "IS_XSS",
                                                "IS_SQLI",
                                                "EXACT_MATCH",
                                                "NOT_EXACT_MATCH",
                                                "IP_MATCH",
                                                "NOT_IP_MATCH",
                                                "CAPTURE_DATA",
                                            ],
                                        },
                                        "parameters": {
                                            "description": "The scope of the WAF custom rule.",
                                            "properties": {
                                                "data": {
                                                    "description": "Identifier "
                                                    "of "
                                                    "a "
                                                    "list "
                                                    "of "
                                                    "data "
                                                    "from "
                                                    "the "
                                                    "denylist. "
                                                    "Can "
                                                    "only "
                                                    "be "
                                                    "used "
                                                    "as "
                                                    "substitution "
                                                    "from "
                                                    "the "
                                                    "list "
                                                    "parameter.",
                                                    "example": "blocked_users",
                                                    "type": "string",
                                                },
                                                "inputs": {
                                                    "description": "List "
                                                    "of "
                                                    "inputs "
                                                    "on "
                                                    "which "
                                                    "at "
                                                    "least "
                                                    "one "
                                                    "should "
                                                    "match "
                                                    "with "
                                                    "the "
                                                    "given "
                                                    "operator.",
                                                    "items": {
                                                        "description": "Input "
                                                        "from "
                                                        "the "
                                                        "request "
                                                        "on "
                                                        "which "
                                                        "the "
                                                        "condition "
                                                        "should "
                                                        "apply.",
                                                        "properties": {
                                                            "address": {
                                                                "description": "Input "
                                                                "from "
                                                                "the "
                                                                "request "
                                                                "on "
                                                                "which "
                                                                "the "
                                                                "condition "
                                                                "should "
                                                                "apply.",
                                                                "enum": [
                                                                    "server.db.statement",
                                                                    "server.io.fs.file",
                                                                    "server.io.net.url",
                                                                    "server.sys.shell.cmd",
                                                                    "server.request.method",
                                                                    "server.request.uri.raw",
                                                                    "server.request.path_params",
                                                                    "server.request.query",
                                                                    "server.request.headers.no_cookies",
                                                                    "server.request.cookies",
                                                                    "server.request.trailers",
                                                                    "server.request.body",
                                                                    "server.response.status",
                                                                    "server.response.headers.no_cookies",
                                                                    "server.response.trailers",
                                                                    "grpc.server.request.metadata",
                                                                    "grpc.server.request.message",
                                                                    "grpc.server.method",
                                                                    "graphql.server.all_resolvers",
                                                                    "usr.id",
                                                                    "http.client_ip",
                                                                ],
                                                                "example": "server.db.statement",
                                                                "type": "string",
                                                                "x-enum-varnames": [
                                                                    "SERVER_DB_STATEMENT",
                                                                    "SERVER_IO_FS_FILE",
                                                                    "SERVER_IO_NET_URL",
                                                                    "SERVER_SYS_SHELL_CMD",
                                                                    "SERVER_REQUEST_METHOD",
                                                                    "SERVER_REQUEST_URI_RAW",
                                                                    "SERVER_REQUEST_PATH_PARAMS",
                                                                    "SERVER_REQUEST_QUERY",
                                                                    "SERVER_REQUEST_HEADERS_NO_COOKIES",
                                                                    "SERVER_REQUEST_COOKIES",
                                                                    "SERVER_REQUEST_TRAILERS",
                                                                    "SERVER_REQUEST_BODY",
                                                                    "SERVER_RESPONSE_STATUS",
                                                                    "SERVER_RESPONSE_HEADERS_NO_COOKIES",
                                                                    "SERVER_RESPONSE_TRAILERS",
                                                                    "GRPC_SERVER_REQUEST_METADATA",
                                                                    "GRPC_SERVER_REQUEST_MESSAGE",
                                                                    "GRPC_SERVER_METHOD",
                                                                    "GRAPHQL_SERVER_ALL_RESOLVERS",
                                                                    "USR_ID",
                                                                    "HTTP_CLIENT_IP",
                                                                ],
                                                            },
                                                            "key_path": {
                                                                "description": "Specific "
                                                                "path "
                                                                "for "
                                                                "the "
                                                                "input.",
                                                                "items": {"type": "string"},
                                                                "type": "array",
                                                            },
                                                        },
                                                        "required": ["address"],
                                                        "type": "object",
                                                    },
                                                    "type": "array",
                                                },
                                                "list": {
                                                    "description": "List "
                                                    "of "
                                                    "value "
                                                    "to "
                                                    "use "
                                                    "with "
                                                    "the "
                                                    "condition. "
                                                    "Only "
                                                    "used "
                                                    "with "
                                                    "the "
                                                    "phrase_match, "
                                                    "!phrase_match, "
                                                    "exact_match "
                                                    "and\n"
                                                    "!exact_match "
                                                    "operator.",
                                                    "items": {"type": "string"},
                                                    "type": "array",
                                                },
                                                "options": {
                                                    "description": "Options "
                                                    "for "
                                                    "the "
                                                    "operator "
                                                    "of "
                                                    "this "
                                                    "condition.",
                                                    "properties": {
                                                        "case_sensitive": {
                                                            "default": False,
                                                            "description": "Evaluate "
                                                            "the "
                                                            "value "
                                                            "as "
                                                            "case "
                                                            "sensitive.",
                                                            "type": "boolean",
                                                        },
                                                        "min_length": {
                                                            "default": 0,
                                                            "description": "Only "
                                                            "evaluate "
                                                            "this "
                                                            "condition "
                                                            "if "
                                                            "the "
                                                            "value "
                                                            "has "
                                                            "a "
                                                            "minimum "
                                                            "amount "
                                                            "of "
                                                            "characters.",
                                                            "format": "int64",
                                                            "type": "integer",
                                                        },
                                                    },
                                                    "type": "object",
                                                },
                                                "regex": {
                                                    "description": "Regex "
                                                    "to "
                                                    "use "
                                                    "with "
                                                    "the "
                                                    "condition. "
                                                    "Only "
                                                    "used "
                                                    "with "
                                                    "match_regex "
                                                    "and "
                                                    "!match_regex "
                                                    "operator.",
                                                    "example": "path.*",
                                                    "type": "string",
                                                },
                                                "value": {
                                                    "description": "Store "
                                                    "the "
                                                    "captured "
                                                    "value "
                                                    "in "
                                                    "the "
                                                    "specified "
                                                    "tag "
                                                    "name. "
                                                    "Only "
                                                    "used "
                                                    "with "
                                                    "the "
                                                    "capture_data "
                                                    "operator.",
                                                    "example": "custom_tag",
                                                    "type": "string",
                                                },
                                            },
                                            "required": ["inputs"],
                                            "type": "object",
                                        },
                                    },
                                    "required": ["operator", "parameters"],
                                    "type": "object",
                                },
                                "type": "array",
                            },
                            "enabled": {
                                "description": "Indicates whether the WAF custom rule is enabled.",
                                "example": False,
                                "type": "boolean",
                            },
                            "name": {
                                "description": "The Name of the WAF custom rule.",
                                "example": "Block request from bad useragent",
                                "type": "string",
                            },
                            "path_glob": {
                                "description": "The path glob for the WAF custom rule.",
                                "example": "/api/search/*",
                                "type": "string",
                            },
                            "scope": {
                                "description": "The scope of the WAF custom rule.",
                                "items": {
                                    "description": "The scope of the WAF custom rule.",
                                    "properties": {
                                        "env": {
                                            "description": "The "
                                            "environment "
                                            "scope "
                                            "for "
                                            "the "
                                            "WAF "
                                            "custom "
                                            "rule.",
                                            "example": "prod",
                                            "type": "string",
                                        },
                                        "service": {
                                            "description": "The "
                                            "service "
                                            "scope "
                                            "for "
                                            "the "
                                            "WAF "
                                            "custom "
                                            "rule.",
                                            "example": "billing-service",
                                            "type": "string",
                                        },
                                    },
                                    "required": ["service", "env"],
                                    "type": "object",
                                },
                                "type": "array",
                            },
                            "tags": {
                                "additionalProperties": {"type": "string"},
                                "description": "Tags "
                                "associated "
                                "with "
                                "the "
                                "WAF "
                                "Custom "
                                "Rule. "
                                "The "
                                "concatenation "
                                "of "
                                "category "
                                "and "
                                "type "
                                "will "
                                "form "
                                "the "
                                "security\n"
                                "activity "
                                "field "
                                "associated "
                                "with "
                                "the "
                                "traces.",
                                "maxProperties": 32,
                                "properties": {
                                    "category": {
                                        "description": "The "
                                        "category "
                                        "of "
                                        "the "
                                        "WAF "
                                        "Rule, "
                                        "can "
                                        "be "
                                        "either "
                                        "`business_logic`, "
                                        "`attack_attempt` "
                                        "or "
                                        "`security_response`.",
                                        "enum": [
                                            "attack_attempt",
                                            "business_logic",
                                            "security_response",
                                        ],
                                        "example": "business_logic",
                                        "type": "string",
                                        "x-enum-varnames": [
                                            "ATTACK_ATTEMPT",
                                            "BUSINESS_LOGIC",
                                            "SECURITY_RESPONSE",
                                        ],
                                    },
                                    "type": {
                                        "description": "The "
                                        "type "
                                        "of "
                                        "the "
                                        "WAF "
                                        "rule, "
                                        "associated "
                                        "with "
                                        "the "
                                        "category "
                                        "will "
                                        "form "
                                        "the "
                                        "security "
                                        "activity.",
                                        "example": "users.login.success",
                                        "type": "string",
                                    },
                                },
                                "required": ["category", "type"],
                                "type": "object",
                            },
                        },
                        "required": ["enabled", "blocking", "name", "tags", "conditions"],
                        "type": "object",
                    },
                    "type": {
                        "default": "custom_rule",
                        "description": "The type of the "
                        "resource. The value "
                        "should always be "
                        "`custom_rule`.",
                        "enum": ["custom_rule"],
                        "example": "custom_rule",
                        "type": "string",
                        "x-enum-varnames": ["CUSTOM_RULE"],
                    },
                },
                "required": ["attributes", "type"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "CREATEWAFEXCLUSIONFILTER_REQUEST_BODY_SCHEMA": {
        "description": "Request object for creating a single WAF exclusion filter.",
        "properties": {
            "data": {
                "description": "Object for creating a single WAF exclusion filter.",
                "properties": {
                    "attributes": {
                        "description": "Attributes for creating a WAF exclusion filter.",
                        "properties": {
                            "description": {
                                "description": "A description for the exclusion filter.",
                                "example": "Exclude false positives on a path",
                                "type": "string",
                            },
                            "enabled": {
                                "description": "Indicates whether the exclusion filter is enabled.",
                                "example": True,
                                "type": "boolean",
                            },
                            "ip_list": {
                                "description": "The "
                                "client "
                                "IP "
                                "addresses "
                                "matched "
                                "by "
                                "the "
                                "exclusion "
                                "filter "
                                "(CIDR "
                                "notation "
                                "is "
                                "supported).",
                                "items": {"example": "198.51.100.72", "type": "string"},
                                "type": "array",
                            },
                            "on_match": {
                                "description": "The "
                                "action "
                                "taken "
                                "when "
                                "the "
                                "exclusion "
                                "filter "
                                "matches. "
                                "When "
                                "set "
                                "to "
                                "`monitor`, "
                                "security "
                                "traces "
                                "are "
                                "emitted "
                                "but "
                                "the "
                                "requests "
                                "are "
                                "not "
                                "blocked. "
                                "By "
                                "default, "
                                "security "
                                "traces "
                                "are "
                                "not "
                                "emitted "
                                "and "
                                "the "
                                "requests "
                                "are "
                                "not "
                                "blocked.",
                                "enum": ["monitor"],
                                "type": "string",
                                "x-enum-varnames": ["MONITOR"],
                            },
                            "parameters": {
                                "description": "A "
                                "list "
                                "of "
                                "parameters "
                                "matched "
                                "by "
                                "the "
                                "exclusion "
                                "filter "
                                "in "
                                "the "
                                "HTTP "
                                "query "
                                "string "
                                "and "
                                "HTTP "
                                "request "
                                "body. "
                                "Nested "
                                "parameters "
                                "can "
                                "be "
                                "matched "
                                "by "
                                "joining "
                                "fields "
                                "with "
                                "a "
                                "dot "
                                "character.",
                                "items": {"example": "list.search.query", "type": "string"},
                                "type": "array",
                            },
                            "path_glob": {
                                "description": "The "
                                "HTTP "
                                "path "
                                "glob "
                                "expression "
                                "matched "
                                "by "
                                "the "
                                "exclusion "
                                "filter.",
                                "example": "/accounts/*",
                                "type": "string",
                            },
                            "rules_target": {
                                "description": "The WAF rules targeted by the exclusion filter.",
                                "items": {
                                    "description": "Target "
                                    "WAF "
                                    "rules "
                                    "based "
                                    "either "
                                    "on "
                                    "an "
                                    "identifier "
                                    "or "
                                    "tags.",
                                    "properties": {
                                        "rule_id": {
                                            "description": "Target "
                                            "a "
                                            "single "
                                            "WAF "
                                            "rule "
                                            "based "
                                            "on "
                                            "its "
                                            "identifier.",
                                            "example": "dog-913-009",
                                            "type": "string",
                                        },
                                        "tags": {
                                            "additionalProperties": {"type": "string"},
                                            "description": "Target "
                                            "multiple "
                                            "WAF "
                                            "rules "
                                            "based "
                                            "on "
                                            "their "
                                            "tags.",
                                            "properties": {
                                                "category": {
                                                    "description": "The "
                                                    "category "
                                                    "of "
                                                    "the "
                                                    "targeted "
                                                    "WAF "
                                                    "rules.",
                                                    "example": "attack_attempt",
                                                    "type": "string",
                                                },
                                                "type": {
                                                    "description": "The "
                                                    "type "
                                                    "of "
                                                    "the "
                                                    "targeted "
                                                    "WAF "
                                                    "rules.",
                                                    "example": "lfi",
                                                    "type": "string",
                                                },
                                            },
                                            "type": "object",
                                        },
                                    },
                                    "type": "object",
                                },
                                "type": "array",
                            },
                            "scope": {
                                "description": "The "
                                "services "
                                "where "
                                "the "
                                "exclusion "
                                "filter "
                                "is "
                                "deployed.",
                                "items": {
                                    "description": "Deploy "
                                    "on "
                                    "services "
                                    "based "
                                    "on "
                                    "their "
                                    "environment "
                                    "and/or "
                                    "service "
                                    "name.",
                                    "properties": {
                                        "env": {
                                            "description": "Deploy on this environment.",
                                            "example": "www",
                                            "type": "string",
                                        },
                                        "service": {
                                            "description": "Deploy on this service.",
                                            "example": "prod",
                                            "type": "string",
                                        },
                                    },
                                    "type": "object",
                                },
                                "type": "array",
                            },
                        },
                        "required": ["description", "enabled"],
                        "type": "object",
                    },
                    "type": {
                        "default": "exclusion_filter",
                        "description": "Type of the resource. "
                        "The value should "
                        "always be "
                        "`exclusion_filter`.",
                        "enum": ["exclusion_filter"],
                        "example": "exclusion_filter",
                        "type": "string",
                        "x-enum-varnames": ["EXCLUSION_FILTER"],
                    },
                },
                "required": ["attributes", "type"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "UPDATEWAFEXCLUSIONFILTER_REQUEST_BODY_SCHEMA": {
        "description": "Request object for updating a single WAF exclusion filter.",
        "properties": {
            "data": {
                "description": "Object for updating a single WAF exclusion filter.",
                "properties": {
                    "attributes": {
                        "description": "Attributes for updating a WAF exclusion filter.",
                        "properties": {
                            "description": {
                                "description": "A description for the exclusion filter.",
                                "example": "Exclude false positives on a path",
                                "type": "string",
                            },
                            "enabled": {
                                "description": "Indicates whether the exclusion filter is enabled.",
                                "example": True,
                                "type": "boolean",
                            },
                            "ip_list": {
                                "description": "The "
                                "client "
                                "IP "
                                "addresses "
                                "matched "
                                "by "
                                "the "
                                "exclusion "
                                "filter "
                                "(CIDR "
                                "notation "
                                "is "
                                "supported).",
                                "items": {"example": "198.51.100.72", "type": "string"},
                                "type": "array",
                            },
                            "on_match": {
                                "description": "The "
                                "action "
                                "taken "
                                "when "
                                "the "
                                "exclusion "
                                "filter "
                                "matches. "
                                "When "
                                "set "
                                "to "
                                "`monitor`, "
                                "security "
                                "traces "
                                "are "
                                "emitted "
                                "but "
                                "the "
                                "requests "
                                "are "
                                "not "
                                "blocked. "
                                "By "
                                "default, "
                                "security "
                                "traces "
                                "are "
                                "not "
                                "emitted "
                                "and "
                                "the "
                                "requests "
                                "are "
                                "not "
                                "blocked.",
                                "enum": ["monitor"],
                                "type": "string",
                                "x-enum-varnames": ["MONITOR"],
                            },
                            "parameters": {
                                "description": "A "
                                "list "
                                "of "
                                "parameters "
                                "matched "
                                "by "
                                "the "
                                "exclusion "
                                "filter "
                                "in "
                                "the "
                                "HTTP "
                                "query "
                                "string "
                                "and "
                                "HTTP "
                                "request "
                                "body. "
                                "Nested "
                                "parameters "
                                "can "
                                "be "
                                "matched "
                                "by "
                                "joining "
                                "fields "
                                "with "
                                "a "
                                "dot "
                                "character.",
                                "items": {"example": "list.search.query", "type": "string"},
                                "type": "array",
                            },
                            "path_glob": {
                                "description": "The "
                                "HTTP "
                                "path "
                                "glob "
                                "expression "
                                "matched "
                                "by "
                                "the "
                                "exclusion "
                                "filter.",
                                "example": "/accounts/*",
                                "type": "string",
                            },
                            "rules_target": {
                                "description": "The WAF rules targeted by the exclusion filter.",
                                "items": {
                                    "description": "Target "
                                    "WAF "
                                    "rules "
                                    "based "
                                    "either "
                                    "on "
                                    "an "
                                    "identifier "
                                    "or "
                                    "tags.",
                                    "properties": {
                                        "rule_id": {
                                            "description": "Target "
                                            "a "
                                            "single "
                                            "WAF "
                                            "rule "
                                            "based "
                                            "on "
                                            "its "
                                            "identifier.",
                                            "example": "dog-913-009",
                                            "type": "string",
                                        },
                                        "tags": {
                                            "additionalProperties": {"type": "string"},
                                            "description": "Target "
                                            "multiple "
                                            "WAF "
                                            "rules "
                                            "based "
                                            "on "
                                            "their "
                                            "tags.",
                                            "properties": {
                                                "category": {
                                                    "description": "The "
                                                    "category "
                                                    "of "
                                                    "the "
                                                    "targeted "
                                                    "WAF "
                                                    "rules.",
                                                    "example": "attack_attempt",
                                                    "type": "string",
                                                },
                                                "type": {
                                                    "description": "The "
                                                    "type "
                                                    "of "
                                                    "the "
                                                    "targeted "
                                                    "WAF "
                                                    "rules.",
                                                    "example": "lfi",
                                                    "type": "string",
                                                },
                                            },
                                            "type": "object",
                                        },
                                    },
                                    "type": "object",
                                },
                                "type": "array",
                            },
                            "scope": {
                                "description": "The "
                                "services "
                                "where "
                                "the "
                                "exclusion "
                                "filter "
                                "is "
                                "deployed.",
                                "items": {
                                    "description": "Deploy "
                                    "on "
                                    "services "
                                    "based "
                                    "on "
                                    "their "
                                    "environment "
                                    "and/or "
                                    "service "
                                    "name.",
                                    "properties": {
                                        "env": {
                                            "description": "Deploy on this environment.",
                                            "example": "www",
                                            "type": "string",
                                        },
                                        "service": {
                                            "description": "Deploy on this service.",
                                            "example": "prod",
                                            "type": "string",
                                        },
                                    },
                                    "type": "object",
                                },
                                "type": "array",
                            },
                        },
                        "required": ["description", "enabled"],
                        "type": "object",
                    },
                    "type": {
                        "default": "exclusion_filter",
                        "description": "Type of the resource. "
                        "The value should "
                        "always be "
                        "`exclusion_filter`.",
                        "enum": ["exclusion_filter"],
                        "example": "exclusion_filter",
                        "type": "string",
                        "x-enum-varnames": ["EXCLUSION_FILTER"],
                    },
                },
                "required": ["attributes", "type"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "CREATEWORKLOADPROTECTIONRULE_REQUEST_BODY_SCHEMA": {
        "description": "Request object that includes the Agent rule to create",
        "properties": {
            "data": {
                "description": "Object for a single Agent rule",
                "properties": {
                    "attributes": {
                        "description": "Create a new Cloud Workload Security Agent rule.",
                        "properties": {
                            "actions": {
                                "description": "The "
                                "array "
                                "of "
                                "actions "
                                "the "
                                "rule "
                                "can "
                                "perform "
                                "if "
                                "triggered",
                                "items": {
                                    "description": "The action the rule can perform if triggered",
                                    "properties": {
                                        "filter": {
                                            "description": "SECL "
                                            "expression "
                                            "used "
                                            "to "
                                            "target "
                                            "the "
                                            "container "
                                            "to "
                                            "apply "
                                            "the "
                                            "action "
                                            "on",
                                            "type": "string",
                                        },
                                        "hash": {
                                            "additionalProperties": {},
                                            "description": "An "
                                            "empty "
                                            "object "
                                            "indicating "
                                            "the "
                                            "hash "
                                            "action",
                                            "type": "object",
                                        },
                                        "kill": {
                                            "description": "Kill "
                                            "system "
                                            "call "
                                            "applied "
                                            "on "
                                            "the "
                                            "container "
                                            "matching "
                                            "the "
                                            "rule",
                                            "properties": {
                                                "signal": {
                                                    "description": "Supported "
                                                    "signals "
                                                    "for "
                                                    "the "
                                                    "kill "
                                                    "system "
                                                    "call",
                                                    "type": "string",
                                                }
                                            },
                                            "type": "object",
                                        },
                                        "metadata": {
                                            "description": "The "
                                            "metadata "
                                            "action "
                                            "applied "
                                            "on "
                                            "the "
                                            "scope "
                                            "matching "
                                            "the "
                                            "rule",
                                            "properties": {
                                                "image_tag": {
                                                    "description": "The "
                                                    "image "
                                                    "tag "
                                                    "of "
                                                    "the "
                                                    "metadata "
                                                    "action",
                                                    "type": "string",
                                                },
                                                "service": {
                                                    "description": "The "
                                                    "service "
                                                    "of "
                                                    "the "
                                                    "metadata "
                                                    "action",
                                                    "type": "string",
                                                },
                                                "short_image": {
                                                    "description": "The "
                                                    "short "
                                                    "image "
                                                    "of "
                                                    "the "
                                                    "metadata "
                                                    "action",
                                                    "type": "string",
                                                },
                                            },
                                            "type": "object",
                                        },
                                        "set": {
                                            "description": "The "
                                            "set "
                                            "action "
                                            "applied "
                                            "on "
                                            "the "
                                            "scope "
                                            "matching "
                                            "the "
                                            "rule",
                                            "properties": {
                                                "append": {
                                                    "description": "Whether "
                                                    "the "
                                                    "value "
                                                    "should "
                                                    "be "
                                                    "appended "
                                                    "to "
                                                    "the "
                                                    "field.",
                                                    "type": "boolean",
                                                },
                                                "default_value": {
                                                    "description": "The "
                                                    "default "
                                                    "value "
                                                    "of "
                                                    "the "
                                                    "set "
                                                    "action",
                                                    "type": "string",
                                                },
                                                "expression": {
                                                    "description": "The "
                                                    "expression "
                                                    "of "
                                                    "the "
                                                    "set "
                                                    "action.",
                                                    "type": "string",
                                                },
                                                "field": {
                                                    "description": "The field of the set action",
                                                    "type": "string",
                                                },
                                                "inherited": {
                                                    "description": "Whether "
                                                    "the "
                                                    "value "
                                                    "should "
                                                    "be "
                                                    "inherited.",
                                                    "type": "boolean",
                                                },
                                                "name": {
                                                    "description": "The name of the set action",
                                                    "type": "string",
                                                },
                                                "scope": {
                                                    "description": "The scope of the set action.",
                                                    "type": "string",
                                                },
                                                "size": {
                                                    "description": "The size of the set action.",
                                                    "format": "int64",
                                                    "type": "integer",
                                                },
                                                "ttl": {
                                                    "description": "The "
                                                    "time "
                                                    "to "
                                                    "live "
                                                    "of "
                                                    "the "
                                                    "set "
                                                    "action.",
                                                    "format": "int64",
                                                    "type": "integer",
                                                },
                                                "value": {
                                                    "description": "The value of the set action",
                                                    "type": "string",
                                                },
                                            },
                                            "type": "object",
                                        },
                                    },
                                    "type": "object",
                                },
                                "nullable": True,
                                "type": "array",
                            },
                            "agent_version": {
                                "description": "Constrain "
                                "the "
                                "rule "
                                "to "
                                "specific "
                                "versions "
                                "of "
                                "the "
                                "Datadog "
                                "Agent.",
                                "type": "string",
                            },
                            "blocking": {
                                "description": "The blocking policies that the rule belongs to.",
                                "items": {"type": "string"},
                                "type": "array",
                            },
                            "description": {
                                "description": "The description of the Agent rule.",
                                "example": "My Agent rule",
                                "type": "string",
                            },
                            "disabled": {
                                "description": "The disabled policies that the rule belongs to.",
                                "items": {"type": "string"},
                                "type": "array",
                            },
                            "enabled": {
                                "description": "Whether the Agent rule is enabled.",
                                "example": True,
                                "type": "boolean",
                            },
                            "expression": {
                                "description": "The SECL expression of the Agent rule.",
                                "example": 'exec.file.name == "sh"',
                                "type": "string",
                            },
                            "filters": {
                                "description": "The platforms the Agent rule is supported on.",
                                "items": {"type": "string"},
                                "type": "array",
                            },
                            "monitoring": {
                                "description": "The monitoring policies that the rule belongs to.",
                                "items": {"type": "string"},
                                "type": "array",
                            },
                            "name": {
                                "description": "The name of the Agent rule.",
                                "example": "my_agent_rule",
                                "type": "string",
                            },
                            "policy_id": {
                                "description": "The "
                                "ID "
                                "of "
                                "the "
                                "policy "
                                "where "
                                "the "
                                "Agent "
                                "rule "
                                "is "
                                "saved.",
                                "example": "a8c8e364-6556-434d-b798-a4c23de29c0b",
                                "type": "string",
                            },
                            "product_tags": {
                                "description": "The list of product tags associated with the rule.",
                                "items": {"type": "string"},
                                "type": "array",
                            },
                            "silent": {
                                "description": "Whether the rule is silent.",
                                "example": False,
                                "type": "boolean",
                            },
                        },
                        "required": ["name", "expression"],
                        "type": "object",
                    },
                    "type": {
                        "default": "agent_rule",
                        "description": "The type of the resource, must always be `agent_rule`",
                        "enum": ["agent_rule"],
                        "example": "agent_rule",
                        "type": "string",
                        "x-enum-varnames": ["AGENT_RULE"],
                    },
                },
                "required": ["attributes", "type"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "UPDATEWORKLOADPROTECTIONAGENTRULE_REQUEST_BODY_SCHEMA": {
        "description": "Request object that includes the Agent rule with the attributes to update",
        "properties": {
            "data": {
                "description": "Object for a single Agent rule",
                "properties": {
                    "attributes": {
                        "description": "Update an existing Cloud Workload Security Agent rule",
                        "properties": {
                            "actions": {
                                "description": "The "
                                "array "
                                "of "
                                "actions "
                                "the "
                                "rule "
                                "can "
                                "perform "
                                "if "
                                "triggered",
                                "items": {
                                    "description": "The action the rule can perform if triggered",
                                    "properties": {
                                        "filter": {
                                            "description": "SECL "
                                            "expression "
                                            "used "
                                            "to "
                                            "target "
                                            "the "
                                            "container "
                                            "to "
                                            "apply "
                                            "the "
                                            "action "
                                            "on",
                                            "type": "string",
                                        },
                                        "hash": {
                                            "additionalProperties": {},
                                            "description": "An "
                                            "empty "
                                            "object "
                                            "indicating "
                                            "the "
                                            "hash "
                                            "action",
                                            "type": "object",
                                        },
                                        "kill": {
                                            "description": "Kill "
                                            "system "
                                            "call "
                                            "applied "
                                            "on "
                                            "the "
                                            "container "
                                            "matching "
                                            "the "
                                            "rule",
                                            "properties": {
                                                "signal": {
                                                    "description": "Supported "
                                                    "signals "
                                                    "for "
                                                    "the "
                                                    "kill "
                                                    "system "
                                                    "call",
                                                    "type": "string",
                                                }
                                            },
                                            "type": "object",
                                        },
                                        "metadata": {
                                            "description": "The "
                                            "metadata "
                                            "action "
                                            "applied "
                                            "on "
                                            "the "
                                            "scope "
                                            "matching "
                                            "the "
                                            "rule",
                                            "properties": {
                                                "image_tag": {
                                                    "description": "The "
                                                    "image "
                                                    "tag "
                                                    "of "
                                                    "the "
                                                    "metadata "
                                                    "action",
                                                    "type": "string",
                                                },
                                                "service": {
                                                    "description": "The "
                                                    "service "
                                                    "of "
                                                    "the "
                                                    "metadata "
                                                    "action",
                                                    "type": "string",
                                                },
                                                "short_image": {
                                                    "description": "The "
                                                    "short "
                                                    "image "
                                                    "of "
                                                    "the "
                                                    "metadata "
                                                    "action",
                                                    "type": "string",
                                                },
                                            },
                                            "type": "object",
                                        },
                                        "set": {
                                            "description": "The "
                                            "set "
                                            "action "
                                            "applied "
                                            "on "
                                            "the "
                                            "scope "
                                            "matching "
                                            "the "
                                            "rule",
                                            "properties": {
                                                "append": {
                                                    "description": "Whether "
                                                    "the "
                                                    "value "
                                                    "should "
                                                    "be "
                                                    "appended "
                                                    "to "
                                                    "the "
                                                    "field.",
                                                    "type": "boolean",
                                                },
                                                "default_value": {
                                                    "description": "The "
                                                    "default "
                                                    "value "
                                                    "of "
                                                    "the "
                                                    "set "
                                                    "action",
                                                    "type": "string",
                                                },
                                                "expression": {
                                                    "description": "The "
                                                    "expression "
                                                    "of "
                                                    "the "
                                                    "set "
                                                    "action.",
                                                    "type": "string",
                                                },
                                                "field": {
                                                    "description": "The field of the set action",
                                                    "type": "string",
                                                },
                                                "inherited": {
                                                    "description": "Whether "
                                                    "the "
                                                    "value "
                                                    "should "
                                                    "be "
                                                    "inherited.",
                                                    "type": "boolean",
                                                },
                                                "name": {
                                                    "description": "The name of the set action",
                                                    "type": "string",
                                                },
                                                "scope": {
                                                    "description": "The scope of the set action.",
                                                    "type": "string",
                                                },
                                                "size": {
                                                    "description": "The size of the set action.",
                                                    "format": "int64",
                                                    "type": "integer",
                                                },
                                                "ttl": {
                                                    "description": "The "
                                                    "time "
                                                    "to "
                                                    "live "
                                                    "of "
                                                    "the "
                                                    "set "
                                                    "action.",
                                                    "format": "int64",
                                                    "type": "integer",
                                                },
                                                "value": {
                                                    "description": "The value of the set action",
                                                    "type": "string",
                                                },
                                            },
                                            "type": "object",
                                        },
                                    },
                                    "type": "object",
                                },
                                "nullable": True,
                                "type": "array",
                            },
                            "agent_version": {
                                "description": "Constrain "
                                "the "
                                "rule "
                                "to "
                                "specific "
                                "versions "
                                "of "
                                "the "
                                "Datadog "
                                "Agent",
                                "type": "string",
                            },
                            "blocking": {
                                "description": "The blocking policies that the rule belongs to",
                                "items": {"type": "string"},
                                "type": "array",
                            },
                            "description": {
                                "description": "The description of the Agent rule",
                                "example": "My Agent rule",
                                "type": "string",
                            },
                            "disabled": {
                                "description": "The disabled policies that the rule belongs to",
                                "items": {"type": "string"},
                                "type": "array",
                            },
                            "enabled": {
                                "description": "Whether the Agent rule is enabled",
                                "example": True,
                                "type": "boolean",
                            },
                            "expression": {
                                "description": "The SECL expression of the Agent rule",
                                "example": 'exec.file.name == "sh"',
                                "type": "string",
                            },
                            "monitoring": {
                                "description": "The monitoring policies that the rule belongs to",
                                "items": {"type": "string"},
                                "type": "array",
                            },
                            "policy_id": {
                                "description": "The ID of the policy where the Agent rule is saved",
                                "example": "a8c8e364-6556-434d-b798-a4c23de29c0b",
                                "type": "string",
                            },
                            "product_tags": {
                                "description": "The list of product tags associated with the rule",
                                "items": {"type": "string"},
                                "type": "array",
                            },
                            "silent": {
                                "description": "Whether the rule is silent.",
                                "example": False,
                                "type": "boolean",
                            },
                        },
                        "type": "object",
                    },
                    "id": {
                        "description": "The ID of the Agent rule",
                        "example": "3dd-0uc-h1s",
                        "type": "string",
                    },
                    "type": {
                        "default": "agent_rule",
                        "description": "The type of the resource, must always be `agent_rule`",
                        "enum": ["agent_rule"],
                        "example": "agent_rule",
                        "type": "string",
                        "x-enum-varnames": ["AGENT_RULE"],
                    },
                },
                "required": ["attributes", "type"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "CREATEPIPELINE_REQUEST_BODY_SCHEMA": {
        "description": "Input schema representing an observability pipeline configuration. "
        "Used in create and validate requests.",
        "properties": {
            "data": {
                "description": "Contains the the pipeline configuration.",
                "properties": {
                    "attributes": {
                        "description": "Defines the "
                        "pipeline’s name "
                        "and its "
                        "components "
                        "(sources, "
                        "processors, and "
                        "destinations).",
                        "properties": {
                            "config": {
                                "description": "Specifies "
                                "the "
                                "pipeline's "
                                "configuration, "
                                "including "
                                "its "
                                "sources, "
                                "processors, "
                                "and "
                                "destinations.",
                                "properties": {
                                    "destinations": {
                                        "description": "A "
                                        "list "
                                        "of "
                                        "destination "
                                        "components "
                                        "where "
                                        "processed "
                                        "logs "
                                        "are "
                                        "sent.",
                                        "example": [
                                            {
                                                "id": "datadog-logs-destination",
                                                "inputs": ["filter-processor"],
                                                "type": "datadog_logs",
                                            }
                                        ],
                                        "items": {
                                            "description": "A destination for the pipeline.",
                                            "oneOf": [
                                                {
                                                    "description": "The "
                                                    "`datadog_logs` "
                                                    "destination "
                                                    "forwards "
                                                    "logs "
                                                    "to "
                                                    "Datadog "
                                                    "Log "
                                                    "Management.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": "datadog-logs-destination",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["filter-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "datadog_logs",
                                                            "description": "The "
                                                            "destination "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`datadog_logs`.",
                                                            "enum": ["datadog_logs"],
                                                            "example": "datadog_logs",
                                                            "type": "string",
                                                            "x-enum-varnames": ["DATADOG_LOGS"],
                                                        },
                                                    },
                                                    "required": ["id", "type", "inputs"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`amazon_s3` "
                                                    "destination "
                                                    "sends "
                                                    "your "
                                                    "logs "
                                                    "in "
                                                    "Datadog-rehydratable "
                                                    "format "
                                                    "to "
                                                    "an "
                                                    "Amazon "
                                                    "S3 "
                                                    "bucket "
                                                    "for "
                                                    "archiving.",
                                                    "properties": {
                                                        "auth": {
                                                            "description": "AWS "
                                                            "authentication "
                                                            "credentials "
                                                            "used "
                                                            "for "
                                                            "accessing "
                                                            "AWS "
                                                            "services "
                                                            "such "
                                                            "as "
                                                            "S3.\n"
                                                            "If "
                                                            "omitted, "
                                                            "the "
                                                            "system’s "
                                                            "default "
                                                            "credentials "
                                                            "are "
                                                            "used "
                                                            "(for "
                                                            "example, "
                                                            "the "
                                                            "IAM "
                                                            "role "
                                                            "and "
                                                            "environment "
                                                            "variables).",
                                                            "properties": {
                                                                "assume_role": {
                                                                    "description": "The "
                                                                    "Amazon "
                                                                    "Resource "
                                                                    "Name "
                                                                    "(ARN) "
                                                                    "of "
                                                                    "the "
                                                                    "role "
                                                                    "to "
                                                                    "assume.",
                                                                    "type": "string",
                                                                },
                                                                "external_id": {
                                                                    "description": "A "
                                                                    "unique "
                                                                    "identifier "
                                                                    "for "
                                                                    "cross-account "
                                                                    "role "
                                                                    "assumption.",
                                                                    "type": "string",
                                                                },
                                                                "session_name": {
                                                                    "description": "A "
                                                                    "session "
                                                                    "identifier "
                                                                    "used "
                                                                    "for "
                                                                    "logging "
                                                                    "and "
                                                                    "tracing "
                                                                    "the "
                                                                    "assumed "
                                                                    "role "
                                                                    "session.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "type": "object",
                                                        },
                                                        "bucket": {
                                                            "description": "S3 bucket name.",
                                                            "example": "error-logs",
                                                            "type": "string",
                                                        },
                                                        "id": {
                                                            "description": "Unique "
                                                            "identifier "
                                                            "for "
                                                            "the "
                                                            "destination "
                                                            "component.",
                                                            "example": "amazon-s3-destination",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["datadog-agent-source"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "key_prefix": {
                                                            "description": "Optional "
                                                            "prefix "
                                                            "for "
                                                            "object "
                                                            "keys.",
                                                            "type": "string",
                                                        },
                                                        "region": {
                                                            "description": "AWS "
                                                            "region "
                                                            "of "
                                                            "the "
                                                            "S3 "
                                                            "bucket.",
                                                            "example": "us-east-1",
                                                            "type": "string",
                                                        },
                                                        "storage_class": {
                                                            "description": "S3 storage class.",
                                                            "enum": [
                                                                "STANDARD",
                                                                "REDUCED_REDUNDANCY",
                                                                "INTELLIGENT_TIERING",
                                                                "STANDARD_IA",
                                                                "EXPRESS_ONEZONE",
                                                                "ONEZONE_IA",
                                                                "GLACIER",
                                                                "GLACIER_IR",
                                                                "DEEP_ARCHIVE",
                                                            ],
                                                            "example": "STANDARD",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "STANDARD",
                                                                "REDUCED_REDUNDANCY",
                                                                "INTELLIGENT_TIERING",
                                                                "STANDARD_IA",
                                                                "EXPRESS_ONEZONE",
                                                                "ONEZONE_IA",
                                                                "GLACIER",
                                                                "GLACIER_IR",
                                                                "DEEP_ARCHIVE",
                                                            ],
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "amazon_s3",
                                                            "description": "The "
                                                            "destination "
                                                            "type. "
                                                            "Always "
                                                            "`amazon_s3`.",
                                                            "enum": ["amazon_s3"],
                                                            "example": "amazon_s3",
                                                            "type": "string",
                                                            "x-enum-varnames": ["AMAZON_S3"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "inputs",
                                                        "bucket",
                                                        "region",
                                                        "storage_class",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`google_cloud_storage` "
                                                    "destination "
                                                    "stores "
                                                    "logs "
                                                    "in "
                                                    "a "
                                                    "Google "
                                                    "Cloud "
                                                    "Storage "
                                                    "(GCS) "
                                                    "bucket.\n"
                                                    "It "
                                                    "requires "
                                                    "a "
                                                    "bucket "
                                                    "name, "
                                                    "GCP "
                                                    "authentication, "
                                                    "and "
                                                    "metadata "
                                                    "fields.",
                                                    "properties": {
                                                        "acl": {
                                                            "description": "Access "
                                                            "control "
                                                            "list "
                                                            "setting "
                                                            "for "
                                                            "objects "
                                                            "written "
                                                            "to "
                                                            "the "
                                                            "bucket.",
                                                            "enum": [
                                                                "private",
                                                                "project-private",
                                                                "public-read",
                                                                "authenticated-read",
                                                                "bucket-owner-read",
                                                                "bucket-owner-full-control",
                                                            ],
                                                            "example": "private",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "PRIVATE",
                                                                "PROJECTNOT_PRIVATE",
                                                                "PUBLICNOT_READ",
                                                                "AUTHENTICATEDNOT_READ",
                                                                "BUCKETNOT_OWNERNOT_READ",
                                                                "BUCKETNOT_OWNERNOT_FULLNOT_CONTROL",
                                                            ],
                                                        },
                                                        "auth": {
                                                            "description": "GCP "
                                                            "credentials "
                                                            "used "
                                                            "to "
                                                            "authenticate "
                                                            "with "
                                                            "Google "
                                                            "Cloud "
                                                            "Storage.",
                                                            "properties": {
                                                                "credentials_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "GCP "
                                                                    "service "
                                                                    "account "
                                                                    "key "
                                                                    "file.",
                                                                    "example": "/var/secrets/gcp-credentials.json",
                                                                    "type": "string",
                                                                }
                                                            },
                                                            "required": ["credentials_file"],
                                                            "type": "object",
                                                        },
                                                        "bucket": {
                                                            "description": "Name "
                                                            "of "
                                                            "the "
                                                            "GCS "
                                                            "bucket.",
                                                            "example": "error-logs",
                                                            "type": "string",
                                                        },
                                                        "id": {
                                                            "description": "Unique "
                                                            "identifier "
                                                            "for "
                                                            "the "
                                                            "destination "
                                                            "component.",
                                                            "example": "gcs-destination",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["datadog-agent-source"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "key_prefix": {
                                                            "description": "Optional "
                                                            "prefix "
                                                            "for "
                                                            "object "
                                                            "keys "
                                                            "within "
                                                            "the "
                                                            "GCS "
                                                            "bucket.",
                                                            "type": "string",
                                                        },
                                                        "metadata": {
                                                            "description": "Custom "
                                                            "metadata "
                                                            "to "
                                                            "attach "
                                                            "to "
                                                            "each "
                                                            "object "
                                                            "uploaded "
                                                            "to "
                                                            "the "
                                                            "GCS "
                                                            "bucket.",
                                                            "items": {
                                                                "description": "A "
                                                                "custom "
                                                                "metadata "
                                                                "entry.",
                                                                "properties": {
                                                                    "name": {
                                                                        "description": "The "
                                                                        "metadata "
                                                                        "key.",
                                                                        "example": "environment",
                                                                        "type": "string",
                                                                    },
                                                                    "value": {
                                                                        "description": "The "
                                                                        "metadata "
                                                                        "value.",
                                                                        "example": "production",
                                                                        "type": "string",
                                                                    },
                                                                },
                                                                "required": ["name", "value"],
                                                                "type": "object",
                                                            },
                                                            "type": "array",
                                                        },
                                                        "storage_class": {
                                                            "description": "Storage "
                                                            "class "
                                                            "used "
                                                            "for "
                                                            "objects "
                                                            "stored "
                                                            "in "
                                                            "GCS.",
                                                            "enum": [
                                                                "STANDARD",
                                                                "NEARLINE",
                                                                "COLDLINE",
                                                                "ARCHIVE",
                                                            ],
                                                            "example": "STANDARD",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "STANDARD",
                                                                "NEARLINE",
                                                                "COLDLINE",
                                                                "ARCHIVE",
                                                            ],
                                                        },
                                                        "type": {
                                                            "default": "google_cloud_storage",
                                                            "description": "The "
                                                            "destination "
                                                            "type. "
                                                            "Always "
                                                            "`google_cloud_storage`.",
                                                            "enum": ["google_cloud_storage"],
                                                            "example": "google_cloud_storage",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "GOOGLE_CLOUD_STORAGE"
                                                            ],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "inputs",
                                                        "bucket",
                                                        "auth",
                                                        "storage_class",
                                                        "acl",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`splunk_hec` "
                                                    "destination "
                                                    "forwards "
                                                    "logs "
                                                    "to "
                                                    "Splunk "
                                                    "using "
                                                    "the "
                                                    "HTTP "
                                                    "Event "
                                                    "Collector "
                                                    "(HEC).",
                                                    "properties": {
                                                        "auto_extract_timestamp": {
                                                            "description": "If "
                                                            "`true`, "
                                                            "Splunk "
                                                            "tries "
                                                            "to "
                                                            "extract "
                                                            "timestamps "
                                                            "from "
                                                            "incoming "
                                                            "log "
                                                            "events.\n"
                                                            "If "
                                                            "`false`, "
                                                            "Splunk "
                                                            "assigns "
                                                            "the "
                                                            "time "
                                                            "the "
                                                            "event "
                                                            "was "
                                                            "received.",
                                                            "example": True,
                                                            "type": "boolean",
                                                        },
                                                        "encoding": {
                                                            "description": "Encoding "
                                                            "format "
                                                            "for "
                                                            "log "
                                                            "events.",
                                                            "enum": ["json", "raw_message"],
                                                            "example": "json",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "JSON",
                                                                "RAW_MESSAGE",
                                                            ],
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(e.g., "
                                                            "as "
                                                            "input "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "splunk-hec-destination",
                                                            "type": "string",
                                                        },
                                                        "index": {
                                                            "description": "Optional "
                                                            "name "
                                                            "of "
                                                            "the "
                                                            "Splunk "
                                                            "index "
                                                            "where "
                                                            "logs "
                                                            "are "
                                                            "written.",
                                                            "example": "main",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["filter-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "sourcetype": {
                                                            "description": "The "
                                                            "Splunk "
                                                            "sourcetype "
                                                            "to "
                                                            "assign "
                                                            "to "
                                                            "log "
                                                            "events.",
                                                            "example": "custom_sourcetype",
                                                            "type": "string",
                                                        },
                                                        "type": {
                                                            "default": "splunk_hec",
                                                            "description": "The "
                                                            "destination "
                                                            "type. "
                                                            "Always "
                                                            "`splunk_hec`.",
                                                            "enum": ["splunk_hec"],
                                                            "example": "splunk_hec",
                                                            "type": "string",
                                                            "x-enum-varnames": ["SPLUNK_HEC"],
                                                        },
                                                    },
                                                    "required": ["id", "type", "inputs"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`sumo_logic` "
                                                    "destination "
                                                    "forwards "
                                                    "logs "
                                                    "to "
                                                    "Sumo "
                                                    "Logic.",
                                                    "properties": {
                                                        "encoding": {
                                                            "description": "The "
                                                            "output "
                                                            "encoding "
                                                            "format.",
                                                            "enum": [
                                                                "json",
                                                                "raw_message",
                                                                "logfmt",
                                                            ],
                                                            "example": "json",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "JSON",
                                                                "RAW_MESSAGE",
                                                                "LOGFMT",
                                                            ],
                                                        },
                                                        "header_custom_fields": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "custom "
                                                            "headers "
                                                            "to "
                                                            "include "
                                                            "in "
                                                            "the "
                                                            "request "
                                                            "to "
                                                            "Sumo "
                                                            "Logic.",
                                                            "items": {
                                                                "description": "Single "
                                                                "key-value "
                                                                "pair "
                                                                "used "
                                                                "as "
                                                                "a "
                                                                "custom "
                                                                "log "
                                                                "header "
                                                                "for "
                                                                "Sumo "
                                                                "Logic.",
                                                                "properties": {
                                                                    "name": {
                                                                        "description": "The "
                                                                        "header "
                                                                        "field "
                                                                        "name.",
                                                                        "example": "X-Sumo-Category",
                                                                        "type": "string",
                                                                    },
                                                                    "value": {
                                                                        "description": "The "
                                                                        "header "
                                                                        "field "
                                                                        "value.",
                                                                        "example": "my-app-logs",
                                                                        "type": "string",
                                                                    },
                                                                },
                                                                "required": ["name", "value"],
                                                                "type": "object",
                                                            },
                                                            "type": "array",
                                                        },
                                                        "header_host_name": {
                                                            "description": "Optional "
                                                            "override "
                                                            "for "
                                                            "the "
                                                            "host "
                                                            "name "
                                                            "header.",
                                                            "example": "host-123",
                                                            "type": "string",
                                                        },
                                                        "header_source_category": {
                                                            "description": "Optional "
                                                            "override "
                                                            "for "
                                                            "the "
                                                            "source "
                                                            "category "
                                                            "header.",
                                                            "example": "source-category",
                                                            "type": "string",
                                                        },
                                                        "header_source_name": {
                                                            "description": "Optional "
                                                            "override "
                                                            "for "
                                                            "the "
                                                            "source "
                                                            "name "
                                                            "header.",
                                                            "example": "source-name",
                                                            "type": "string",
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": "sumo-logic-destination",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["filter-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "sumo_logic",
                                                            "description": "The "
                                                            "destination "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`sumo_logic`.",
                                                            "enum": ["sumo_logic"],
                                                            "example": "sumo_logic",
                                                            "type": "string",
                                                            "x-enum-varnames": ["SUMO_LOGIC"],
                                                        },
                                                    },
                                                    "required": ["id", "type", "inputs"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`elasticsearch` "
                                                    "destination "
                                                    "writes "
                                                    "logs "
                                                    "to "
                                                    "an "
                                                    "Elasticsearch "
                                                    "cluster.",
                                                    "properties": {
                                                        "api_version": {
                                                            "description": "The "
                                                            "Elasticsearch "
                                                            "API "
                                                            "version "
                                                            "to "
                                                            "use. "
                                                            "Set "
                                                            "to "
                                                            "`auto` "
                                                            "to "
                                                            "auto-detect.",
                                                            "enum": ["auto", "v6", "v7", "v8"],
                                                            "example": "auto",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "AUTO",
                                                                "V6",
                                                                "V7",
                                                                "V8",
                                                            ],
                                                        },
                                                        "bulk_index": {
                                                            "description": "The "
                                                            "index "
                                                            "to "
                                                            "write "
                                                            "logs "
                                                            "to "
                                                            "in "
                                                            "Elasticsearch.",
                                                            "example": "logs-index",
                                                            "type": "string",
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": "elasticsearch-destination",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["filter-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "elasticsearch",
                                                            "description": "The "
                                                            "destination "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`elasticsearch`.",
                                                            "enum": ["elasticsearch"],
                                                            "example": "elasticsearch",
                                                            "type": "string",
                                                            "x-enum-varnames": ["ELASTICSEARCH"],
                                                        },
                                                    },
                                                    "required": ["id", "type", "inputs"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`rsyslog` "
                                                    "destination "
                                                    "forwards "
                                                    "logs "
                                                    "to "
                                                    "an "
                                                    "external "
                                                    "`rsyslog` "
                                                    "server "
                                                    "over "
                                                    "TCP "
                                                    "or "
                                                    "UDP "
                                                    "using "
                                                    "the "
                                                    "syslog "
                                                    "protocol.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": "rsyslog-destination",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["filter-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "keepalive": {
                                                            "description": "Optional "
                                                            "socket "
                                                            "keepalive "
                                                            "duration "
                                                            "in "
                                                            "milliseconds.",
                                                            "example": 60000,
                                                            "format": "int64",
                                                            "minimum": 0,
                                                            "type": "integer",
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "rsyslog",
                                                            "description": "The "
                                                            "destination "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`rsyslog`.",
                                                            "enum": ["rsyslog"],
                                                            "example": "rsyslog",
                                                            "type": "string",
                                                            "x-enum-varnames": ["RSYSLOG"],
                                                        },
                                                    },
                                                    "required": ["id", "type", "inputs"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`syslog_ng` "
                                                    "destination "
                                                    "forwards "
                                                    "logs "
                                                    "to "
                                                    "an "
                                                    "external "
                                                    "`syslog-ng` "
                                                    "server "
                                                    "over "
                                                    "TCP "
                                                    "or "
                                                    "UDP "
                                                    "using "
                                                    "the "
                                                    "syslog "
                                                    "protocol.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": "syslog-ng-destination",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["filter-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "keepalive": {
                                                            "description": "Optional "
                                                            "socket "
                                                            "keepalive "
                                                            "duration "
                                                            "in "
                                                            "milliseconds.",
                                                            "example": 60000,
                                                            "format": "int64",
                                                            "minimum": 0,
                                                            "type": "integer",
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "syslog_ng",
                                                            "description": "The "
                                                            "destination "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`syslog_ng`.",
                                                            "enum": ["syslog_ng"],
                                                            "example": "syslog_ng",
                                                            "type": "string",
                                                            "x-enum-varnames": ["SYSLOG_NG"],
                                                        },
                                                    },
                                                    "required": ["id", "type", "inputs"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`azure_storage` "
                                                    "destination "
                                                    "forwards "
                                                    "logs "
                                                    "to "
                                                    "an "
                                                    "Azure "
                                                    "Blob "
                                                    "Storage "
                                                    "container.",
                                                    "properties": {
                                                        "blob_prefix": {
                                                            "description": "Optional "
                                                            "prefix "
                                                            "for "
                                                            "blobs "
                                                            "written "
                                                            "to "
                                                            "the "
                                                            "container.",
                                                            "example": "logs/",
                                                            "type": "string",
                                                        },
                                                        "container_name": {
                                                            "description": "The "
                                                            "name "
                                                            "of "
                                                            "the "
                                                            "Azure "
                                                            "Blob "
                                                            "Storage "
                                                            "container "
                                                            "to "
                                                            "store "
                                                            "logs "
                                                            "in.",
                                                            "example": "my-log-container",
                                                            "type": "string",
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": "azure-storage-destination",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["processor-id"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "azure_storage",
                                                            "description": "The "
                                                            "destination "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`azure_storage`.",
                                                            "enum": ["azure_storage"],
                                                            "example": "azure_storage",
                                                            "type": "string",
                                                            "x-enum-varnames": ["AZURE_STORAGE"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "inputs",
                                                        "container_name",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`microsoft_sentinel` "
                                                    "destination "
                                                    "forwards "
                                                    "logs "
                                                    "to "
                                                    "Microsoft "
                                                    "Sentinel.",
                                                    "properties": {
                                                        "client_id": {
                                                            "description": "Azure "
                                                            "AD "
                                                            "client "
                                                            "ID "
                                                            "used "
                                                            "for "
                                                            "authentication.",
                                                            "example": "a1b2c3d4-5678-90ab-cdef-1234567890ab",
                                                            "type": "string",
                                                        },
                                                        "dcr_immutable_id": {
                                                            "description": "The "
                                                            "immutable "
                                                            "ID "
                                                            "of "
                                                            "the "
                                                            "Data "
                                                            "Collection "
                                                            "Rule "
                                                            "(DCR).",
                                                            "example": "dcr-uuid-1234",
                                                            "type": "string",
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": "sentinel-destination",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["filter-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "table": {
                                                            "description": "The "
                                                            "name "
                                                            "of "
                                                            "the "
                                                            "Log "
                                                            "Analytics "
                                                            "table "
                                                            "where "
                                                            "logs "
                                                            "are "
                                                            "sent.",
                                                            "example": "CustomLogsTable",
                                                            "type": "string",
                                                        },
                                                        "tenant_id": {
                                                            "description": "Azure AD tenant ID.",
                                                            "example": "abcdef12-3456-7890-abcd-ef1234567890",
                                                            "type": "string",
                                                        },
                                                        "type": {
                                                            "default": "microsoft_sentinel",
                                                            "description": "The "
                                                            "destination "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`microsoft_sentinel`.",
                                                            "enum": ["microsoft_sentinel"],
                                                            "example": "microsoft_sentinel",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "MICROSOFT_SENTINEL"
                                                            ],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "inputs",
                                                        "client_id",
                                                        "tenant_id",
                                                        "dcr_immutable_id",
                                                        "table",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`google_chronicle` "
                                                    "destination "
                                                    "sends "
                                                    "logs "
                                                    "to "
                                                    "Google "
                                                    "Chronicle.",
                                                    "properties": {
                                                        "auth": {
                                                            "description": "GCP "
                                                            "credentials "
                                                            "used "
                                                            "to "
                                                            "authenticate "
                                                            "with "
                                                            "Google "
                                                            "Cloud "
                                                            "Storage.",
                                                            "properties": {
                                                                "credentials_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "GCP "
                                                                    "service "
                                                                    "account "
                                                                    "key "
                                                                    "file.",
                                                                    "example": "/var/secrets/gcp-credentials.json",
                                                                    "type": "string",
                                                                }
                                                            },
                                                            "required": ["credentials_file"],
                                                            "type": "object",
                                                        },
                                                        "customer_id": {
                                                            "description": "The "
                                                            "Google "
                                                            "Chronicle "
                                                            "customer "
                                                            "ID.",
                                                            "example": "abcdefg123456789",
                                                            "type": "string",
                                                        },
                                                        "encoding": {
                                                            "description": "The "
                                                            "encoding "
                                                            "format "
                                                            "for "
                                                            "the "
                                                            "logs "
                                                            "sent "
                                                            "to "
                                                            "Chronicle.",
                                                            "enum": ["json", "raw_message"],
                                                            "example": "json",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "JSON",
                                                                "RAW_MESSAGE",
                                                            ],
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": "google-chronicle-destination",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["parse-json-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "log_type": {
                                                            "description": "The "
                                                            "log "
                                                            "type "
                                                            "metadata "
                                                            "associated "
                                                            "with "
                                                            "the "
                                                            "Chronicle "
                                                            "destination.",
                                                            "example": "nginx_logs",
                                                            "type": "string",
                                                        },
                                                        "type": {
                                                            "default": "google_chronicle",
                                                            "description": "The "
                                                            "destination "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`google_chronicle`.",
                                                            "enum": ["google_chronicle"],
                                                            "example": "google_chronicle",
                                                            "type": "string",
                                                            "x-enum-varnames": ["GOOGLE_CHRONICLE"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "inputs",
                                                        "auth",
                                                        "customer_id",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`new_relic` "
                                                    "destination "
                                                    "sends "
                                                    "logs "
                                                    "to "
                                                    "the "
                                                    "New "
                                                    "Relic "
                                                    "platform.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": "new-relic-destination",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["parse-json-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "region": {
                                                            "description": "The New Relic region.",
                                                            "enum": ["us", "eu"],
                                                            "example": "us",
                                                            "type": "string",
                                                            "x-enum-varnames": ["US", "EU"],
                                                        },
                                                        "type": {
                                                            "default": "new_relic",
                                                            "description": "The "
                                                            "destination "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`new_relic`.",
                                                            "enum": ["new_relic"],
                                                            "example": "new_relic",
                                                            "type": "string",
                                                            "x-enum-varnames": ["NEW_RELIC"],
                                                        },
                                                    },
                                                    "required": ["id", "type", "inputs", "region"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`sentinel_one` "
                                                    "destination "
                                                    "sends "
                                                    "logs "
                                                    "to "
                                                    "SentinelOne.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": "sentinelone-destination",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["filter-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "region": {
                                                            "description": "The "
                                                            "SentinelOne "
                                                            "region "
                                                            "to "
                                                            "send "
                                                            "logs "
                                                            "to.",
                                                            "enum": [
                                                                "us",
                                                                "eu",
                                                                "ca",
                                                                "data_set_us",
                                                            ],
                                                            "example": "us",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "US",
                                                                "EU",
                                                                "CA",
                                                                "DATA_SET_US",
                                                            ],
                                                        },
                                                        "type": {
                                                            "default": "sentinel_one",
                                                            "description": "The "
                                                            "destination "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`sentinel_one`.",
                                                            "enum": ["sentinel_one"],
                                                            "example": "sentinel_one",
                                                            "type": "string",
                                                            "x-enum-varnames": ["SENTINEL_ONE"],
                                                        },
                                                    },
                                                    "required": ["id", "type", "inputs", "region"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`opensearch` "
                                                    "destination "
                                                    "writes "
                                                    "logs "
                                                    "to "
                                                    "an "
                                                    "OpenSearch "
                                                    "cluster.",
                                                    "properties": {
                                                        "bulk_index": {
                                                            "description": "The "
                                                            "index "
                                                            "to "
                                                            "write "
                                                            "logs "
                                                            "to.",
                                                            "example": "logs-index",
                                                            "type": "string",
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": "opensearch-destination",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["filter-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "opensearch",
                                                            "description": "The "
                                                            "destination "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`opensearch`.",
                                                            "enum": ["opensearch"],
                                                            "example": "opensearch",
                                                            "type": "string",
                                                            "x-enum-varnames": ["OPENSEARCH"],
                                                        },
                                                    },
                                                    "required": ["id", "type", "inputs"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`amazon_opensearch` "
                                                    "destination "
                                                    "writes "
                                                    "logs "
                                                    "to "
                                                    "Amazon "
                                                    "OpenSearch.",
                                                    "properties": {
                                                        "auth": {
                                                            "description": "Authentication "
                                                            "settings "
                                                            "for "
                                                            "the "
                                                            "Amazon "
                                                            "OpenSearch "
                                                            "destination.\n"
                                                            "The "
                                                            "`strategy` "
                                                            "field "
                                                            "determines "
                                                            "whether "
                                                            "basic "
                                                            "or "
                                                            "AWS-based "
                                                            "authentication "
                                                            "is "
                                                            "used.",
                                                            "properties": {
                                                                "assume_role": {
                                                                    "description": "The "
                                                                    "ARN "
                                                                    "of "
                                                                    "the "
                                                                    "role "
                                                                    "to "
                                                                    "assume "
                                                                    "(used "
                                                                    "with "
                                                                    "`aws` "
                                                                    "strategy).",
                                                                    "type": "string",
                                                                },
                                                                "aws_region": {
                                                                    "description": "AWS region",
                                                                    "type": "string",
                                                                },
                                                                "external_id": {
                                                                    "description": "External "
                                                                    "ID "
                                                                    "for "
                                                                    "the "
                                                                    "assumed "
                                                                    "role "
                                                                    "(used "
                                                                    "with "
                                                                    "`aws` "
                                                                    "strategy).",
                                                                    "type": "string",
                                                                },
                                                                "session_name": {
                                                                    "description": "Session "
                                                                    "name "
                                                                    "for "
                                                                    "the "
                                                                    "assumed "
                                                                    "role "
                                                                    "(used "
                                                                    "with "
                                                                    "`aws` "
                                                                    "strategy).",
                                                                    "type": "string",
                                                                },
                                                                "strategy": {
                                                                    "description": "The "
                                                                    "authentication "
                                                                    "strategy "
                                                                    "to "
                                                                    "use.",
                                                                    "enum": ["basic", "aws"],
                                                                    "example": "aws",
                                                                    "type": "string",
                                                                    "x-enum-varnames": [
                                                                        "BASIC",
                                                                        "AWS",
                                                                    ],
                                                                },
                                                            },
                                                            "required": ["strategy"],
                                                            "type": "object",
                                                        },
                                                        "bulk_index": {
                                                            "description": "The "
                                                            "index "
                                                            "to "
                                                            "write "
                                                            "logs "
                                                            "to.",
                                                            "example": "logs-index",
                                                            "type": "string",
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": "elasticsearch-destination",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["filter-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "amazon_opensearch",
                                                            "description": "The "
                                                            "destination "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`amazon_opensearch`.",
                                                            "enum": ["amazon_opensearch"],
                                                            "example": "amazon_opensearch",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "AMAZON_OPENSEARCH"
                                                            ],
                                                        },
                                                    },
                                                    "required": ["id", "type", "inputs", "auth"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`socket` "
                                                    "destination "
                                                    "sends "
                                                    "logs "
                                                    "over "
                                                    "TCP "
                                                    "or "
                                                    "UDP "
                                                    "to "
                                                    "a "
                                                    "remote "
                                                    "server.",
                                                    "properties": {
                                                        "encoding": {
                                                            "description": "Encoding "
                                                            "format "
                                                            "for "
                                                            "log "
                                                            "events.",
                                                            "enum": ["json", "raw_message"],
                                                            "example": "json",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "JSON",
                                                                "RAW_MESSAGE",
                                                            ],
                                                        },
                                                        "framing": {
                                                            "description": "Framing "
                                                            "method "
                                                            "configuration.",
                                                            "oneOf": [
                                                                {
                                                                    "description": "Each "
                                                                    "log "
                                                                    "event "
                                                                    "is "
                                                                    "delimited "
                                                                    "by "
                                                                    "a "
                                                                    "newline "
                                                                    "character.",
                                                                    "properties": {
                                                                        "method": {
                                                                            "description": "The "
                                                                            "definition "
                                                                            "of "
                                                                            "`ObservabilityPipelineSocketDestinationFramingNewlineDelimitedMethod` "
                                                                            "object.",
                                                                            "enum": [
                                                                                "newline_delimited"
                                                                            ],
                                                                            "example": "newline_delimited",
                                                                            "type": "string",
                                                                            "x-enum-varnames": [
                                                                                "NEWLINE_DELIMITED"
                                                                            ],
                                                                        }
                                                                    },
                                                                    "required": ["method"],
                                                                    "type": "object",
                                                                },
                                                                {
                                                                    "description": "Event "
                                                                    "data "
                                                                    "is "
                                                                    "not "
                                                                    "delimited "
                                                                    "at "
                                                                    "all.",
                                                                    "properties": {
                                                                        "method": {
                                                                            "description": "The "
                                                                            "definition "
                                                                            "of "
                                                                            "`ObservabilityPipelineSocketDestinationFramingBytesMethod` "
                                                                            "object.",
                                                                            "enum": ["bytes"],
                                                                            "example": "bytes",
                                                                            "type": "string",
                                                                            "x-enum-varnames": [
                                                                                "BYTES"
                                                                            ],
                                                                        }
                                                                    },
                                                                    "required": ["method"],
                                                                    "type": "object",
                                                                },
                                                                {
                                                                    "description": "Each "
                                                                    "log "
                                                                    "event "
                                                                    "is "
                                                                    "separated "
                                                                    "using "
                                                                    "the "
                                                                    "specified "
                                                                    "delimiter "
                                                                    "character.",
                                                                    "properties": {
                                                                        "delimiter": {
                                                                            "description": "A "
                                                                            "single "
                                                                            "ASCII "
                                                                            "character "
                                                                            "used "
                                                                            "as "
                                                                            "a "
                                                                            "delimiter.",
                                                                            "example": "|",
                                                                            "maxLength": 1,
                                                                            "minLength": 1,
                                                                            "type": "string",
                                                                        },
                                                                        "method": {
                                                                            "description": "The "
                                                                            "definition "
                                                                            "of "
                                                                            "`ObservabilityPipelineSocketDestinationFramingCharacterDelimitedMethod` "
                                                                            "object.",
                                                                            "enum": [
                                                                                "character_delimited"
                                                                            ],
                                                                            "example": "character_delimited",
                                                                            "type": "string",
                                                                            "x-enum-varnames": [
                                                                                "CHARACTER_DELIMITED"
                                                                            ],
                                                                        },
                                                                    },
                                                                    "required": [
                                                                        "method",
                                                                        "delimiter",
                                                                    ],
                                                                    "type": "object",
                                                                },
                                                            ],
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": "socket-destination",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["filter-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "mode": {
                                                            "description": "Protocol "
                                                            "used "
                                                            "to "
                                                            "send "
                                                            "logs.",
                                                            "enum": ["tcp", "udp"],
                                                            "example": "tcp",
                                                            "type": "string",
                                                            "x-enum-varnames": ["TCP", "UDP"],
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "socket",
                                                            "description": "The "
                                                            "destination "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`socket`.",
                                                            "enum": ["socket"],
                                                            "example": "socket",
                                                            "type": "string",
                                                            "x-enum-varnames": ["SOCKET"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "inputs",
                                                        "encoding",
                                                        "framing",
                                                        "mode",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`amazon_security_lake` "
                                                    "destination "
                                                    "sends "
                                                    "your "
                                                    "logs "
                                                    "to "
                                                    "Amazon "
                                                    "Security "
                                                    "Lake.",
                                                    "properties": {
                                                        "auth": {
                                                            "description": "AWS "
                                                            "authentication "
                                                            "credentials "
                                                            "used "
                                                            "for "
                                                            "accessing "
                                                            "AWS "
                                                            "services "
                                                            "such "
                                                            "as "
                                                            "S3.\n"
                                                            "If "
                                                            "omitted, "
                                                            "the "
                                                            "system’s "
                                                            "default "
                                                            "credentials "
                                                            "are "
                                                            "used "
                                                            "(for "
                                                            "example, "
                                                            "the "
                                                            "IAM "
                                                            "role "
                                                            "and "
                                                            "environment "
                                                            "variables).",
                                                            "properties": {
                                                                "assume_role": {
                                                                    "description": "The "
                                                                    "Amazon "
                                                                    "Resource "
                                                                    "Name "
                                                                    "(ARN) "
                                                                    "of "
                                                                    "the "
                                                                    "role "
                                                                    "to "
                                                                    "assume.",
                                                                    "type": "string",
                                                                },
                                                                "external_id": {
                                                                    "description": "A "
                                                                    "unique "
                                                                    "identifier "
                                                                    "for "
                                                                    "cross-account "
                                                                    "role "
                                                                    "assumption.",
                                                                    "type": "string",
                                                                },
                                                                "session_name": {
                                                                    "description": "A "
                                                                    "session "
                                                                    "identifier "
                                                                    "used "
                                                                    "for "
                                                                    "logging "
                                                                    "and "
                                                                    "tracing "
                                                                    "the "
                                                                    "assumed "
                                                                    "role "
                                                                    "session.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "type": "object",
                                                        },
                                                        "bucket": {
                                                            "description": "Name "
                                                            "of "
                                                            "the "
                                                            "Amazon "
                                                            "S3 "
                                                            "bucket "
                                                            "in "
                                                            "Security "
                                                            "Lake "
                                                            "(3-63 "
                                                            "characters).",
                                                            "example": "security-lake-bucket",
                                                            "type": "string",
                                                        },
                                                        "custom_source_name": {
                                                            "description": "Custom "
                                                            "source "
                                                            "name "
                                                            "for "
                                                            "the "
                                                            "logs "
                                                            "in "
                                                            "Security "
                                                            "Lake.",
                                                            "example": "my-custom-source",
                                                            "type": "string",
                                                        },
                                                        "id": {
                                                            "description": "Unique "
                                                            "identifier "
                                                            "for "
                                                            "the "
                                                            "destination "
                                                            "component.",
                                                            "example": "amazon-security-lake-destination",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["filter-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "region": {
                                                            "description": "AWS "
                                                            "region "
                                                            "of "
                                                            "the "
                                                            "S3 "
                                                            "bucket.",
                                                            "example": "us-east-1",
                                                            "type": "string",
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "amazon_security_lake",
                                                            "description": "The "
                                                            "destination "
                                                            "type. "
                                                            "Always "
                                                            "`amazon_security_lake`.",
                                                            "enum": ["amazon_security_lake"],
                                                            "example": "amazon_security_lake",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "AMAZON_SECURITY_LAKE"
                                                            ],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "inputs",
                                                        "bucket",
                                                        "region",
                                                        "custom_source_name",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`crowdstrike_next_gen_siem` "
                                                    "destination "
                                                    "forwards "
                                                    "logs "
                                                    "to "
                                                    "CrowdStrike "
                                                    "Next "
                                                    "Gen "
                                                    "SIEM.",
                                                    "properties": {
                                                        "compression": {
                                                            "description": "Compression "
                                                            "configuration "
                                                            "for "
                                                            "log "
                                                            "events.",
                                                            "properties": {
                                                                "algorithm": {
                                                                    "description": "Compression "
                                                                    "algorithm "
                                                                    "for "
                                                                    "log "
                                                                    "events.",
                                                                    "enum": ["gzip", "zlib"],
                                                                    "example": "gzip",
                                                                    "type": "string",
                                                                    "x-enum-varnames": [
                                                                        "GZIP",
                                                                        "ZLIB",
                                                                    ],
                                                                },
                                                                "level": {
                                                                    "description": "Compression "
                                                                    "level.",
                                                                    "example": 6,
                                                                    "format": "int64",
                                                                    "type": "integer",
                                                                },
                                                            },
                                                            "required": ["algorithm"],
                                                            "type": "object",
                                                        },
                                                        "encoding": {
                                                            "description": "Encoding "
                                                            "format "
                                                            "for "
                                                            "log "
                                                            "events.",
                                                            "enum": ["json", "raw_message"],
                                                            "example": "json",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "JSON",
                                                                "RAW_MESSAGE",
                                                            ],
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": "crowdstrike-ngsiem-destination",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["filter-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "crowdstrike_next_gen_siem",
                                                            "description": "The "
                                                            "destination "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`crowdstrike_next_gen_siem`.",
                                                            "enum": ["crowdstrike_next_gen_siem"],
                                                            "example": "crowdstrike_next_gen_siem",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "CROWDSTRIKE_NEXT_GEN_SIEM"
                                                            ],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "inputs",
                                                        "encoding",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`google_pubsub` "
                                                    "destination "
                                                    "publishes "
                                                    "logs "
                                                    "to "
                                                    "a "
                                                    "Google "
                                                    "Cloud "
                                                    "Pub/Sub "
                                                    "topic.",
                                                    "properties": {
                                                        "auth": {
                                                            "description": "GCP "
                                                            "credentials "
                                                            "used "
                                                            "to "
                                                            "authenticate "
                                                            "with "
                                                            "Google "
                                                            "Cloud "
                                                            "Storage.",
                                                            "properties": {
                                                                "credentials_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "GCP "
                                                                    "service "
                                                                    "account "
                                                                    "key "
                                                                    "file.",
                                                                    "example": "/var/secrets/gcp-credentials.json",
                                                                    "type": "string",
                                                                }
                                                            },
                                                            "required": ["credentials_file"],
                                                            "type": "object",
                                                        },
                                                        "encoding": {
                                                            "description": "Encoding "
                                                            "format "
                                                            "for "
                                                            "log "
                                                            "events.",
                                                            "enum": ["json", "raw_message"],
                                                            "example": "json",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "JSON",
                                                                "RAW_MESSAGE",
                                                            ],
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": "google-pubsub-destination",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["filter-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "project": {
                                                            "description": "The "
                                                            "GCP "
                                                            "project "
                                                            "ID "
                                                            "that "
                                                            "owns "
                                                            "the "
                                                            "Pub/Sub "
                                                            "topic.",
                                                            "example": "my-gcp-project",
                                                            "type": "string",
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "topic": {
                                                            "description": "The "
                                                            "Pub/Sub "
                                                            "topic "
                                                            "name "
                                                            "to "
                                                            "publish "
                                                            "logs "
                                                            "to.",
                                                            "example": "logs-subscription",
                                                            "type": "string",
                                                        },
                                                        "type": {
                                                            "default": "google_pubsub",
                                                            "description": "The "
                                                            "destination "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`google_pubsub`.",
                                                            "enum": ["google_pubsub"],
                                                            "example": "google_pubsub",
                                                            "type": "string",
                                                            "x-enum-varnames": ["GOOGLE_PUBSUB"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "inputs",
                                                        "encoding",
                                                        "project",
                                                        "topic",
                                                    ],
                                                    "type": "object",
                                                },
                                            ],
                                        },
                                        "type": "array",
                                    },
                                    "processors": {
                                        "description": "A "
                                        "list "
                                        "of "
                                        "processors "
                                        "that "
                                        "transform "
                                        "or "
                                        "enrich "
                                        "log "
                                        "data.",
                                        "example": [
                                            {
                                                "id": "filter-processor",
                                                "include": "service:my-service",
                                                "inputs": ["datadog-agent-source"],
                                                "type": "filter",
                                            }
                                        ],
                                        "items": {
                                            "description": "A processor for the pipeline.",
                                            "oneOf": [
                                                {
                                                    "description": "The "
                                                    "`filter` "
                                                    "processor "
                                                    "allows "
                                                    "conditional "
                                                    "processing "
                                                    "of "
                                                    "logs "
                                                    "based "
                                                    "on "
                                                    "a "
                                                    "Datadog "
                                                    "search "
                                                    "query. "
                                                    "Logs "
                                                    "that "
                                                    "match "
                                                    "the "
                                                    "`include` "
                                                    "query "
                                                    "are "
                                                    "passed "
                                                    "through; "
                                                    "others "
                                                    "are "
                                                    "discarded.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(for "
                                                            "example, "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "filter-processor",
                                                            "type": "string",
                                                        },
                                                        "include": {
                                                            "description": "A "
                                                            "Datadog "
                                                            "search "
                                                            "query "
                                                            "used "
                                                            "to "
                                                            "determine "
                                                            "which "
                                                            "logs "
                                                            "should "
                                                            "pass "
                                                            "through "
                                                            "the "
                                                            "filter. "
                                                            "Logs "
                                                            "that "
                                                            "match "
                                                            "this "
                                                            "query "
                                                            "continue "
                                                            "to "
                                                            "downstream "
                                                            "components; "
                                                            "others "
                                                            "are "
                                                            "dropped.",
                                                            "example": "service:my-service",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["datadog-agent-source"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "filter",
                                                            "description": "The "
                                                            "processor "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`filter`.",
                                                            "enum": ["filter"],
                                                            "example": "filter",
                                                            "type": "string",
                                                            "x-enum-varnames": ["FILTER"],
                                                        },
                                                    },
                                                    "required": ["id", "type", "include", "inputs"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`parse_json` "
                                                    "processor "
                                                    "extracts "
                                                    "JSON "
                                                    "from "
                                                    "a "
                                                    "specified "
                                                    "field "
                                                    "and "
                                                    "flattens "
                                                    "it "
                                                    "into "
                                                    "the "
                                                    "event. "
                                                    "This "
                                                    "is "
                                                    "useful "
                                                    "when "
                                                    "logs "
                                                    "contain "
                                                    "embedded "
                                                    "JSON "
                                                    "as "
                                                    "a "
                                                    "string.",
                                                    "properties": {
                                                        "field": {
                                                            "description": "The "
                                                            "name "
                                                            "of "
                                                            "the "
                                                            "log "
                                                            "field "
                                                            "that "
                                                            "contains "
                                                            "a "
                                                            "JSON "
                                                            "string.",
                                                            "example": "message",
                                                            "type": "string",
                                                        },
                                                        "id": {
                                                            "description": "A "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(e.g., "
                                                            "as "
                                                            "input "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "parse-json-processor",
                                                            "type": "string",
                                                        },
                                                        "include": {
                                                            "description": "A "
                                                            "Datadog "
                                                            "search "
                                                            "query "
                                                            "used "
                                                            "to "
                                                            "determine "
                                                            "which "
                                                            "logs "
                                                            "this "
                                                            "processor "
                                                            "targets.",
                                                            "example": "service:my-service",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["datadog-agent-source"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "parse_json",
                                                            "description": "The "
                                                            "processor "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`parse_json`.",
                                                            "enum": ["parse_json"],
                                                            "example": "parse_json",
                                                            "type": "string",
                                                            "x-enum-varnames": ["PARSE_JSON"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "include",
                                                        "field",
                                                        "inputs",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "Quota "
                                                    "Processor "
                                                    "measures "
                                                    "logging "
                                                    "traffic "
                                                    "for "
                                                    "logs "
                                                    "that "
                                                    "match "
                                                    "a "
                                                    "specified "
                                                    "filter. "
                                                    "When "
                                                    "the "
                                                    "configured "
                                                    "daily "
                                                    "quota "
                                                    "is "
                                                    "met, "
                                                    "the "
                                                    "processor "
                                                    "can "
                                                    "drop "
                                                    "or "
                                                    "alert.",
                                                    "properties": {
                                                        "drop_events": {
                                                            "description": "If "
                                                            "set "
                                                            "to "
                                                            "`true`, "
                                                            "logs "
                                                            "that "
                                                            "matched "
                                                            "the "
                                                            "quota "
                                                            "filter "
                                                            "and "
                                                            "sent "
                                                            "after "
                                                            "the "
                                                            "quota "
                                                            "has "
                                                            "been "
                                                            "met "
                                                            "are "
                                                            "dropped; "
                                                            "only "
                                                            "logs "
                                                            "that "
                                                            "did "
                                                            "not "
                                                            "match "
                                                            "the "
                                                            "filter "
                                                            "query "
                                                            "continue "
                                                            "through "
                                                            "the "
                                                            "pipeline.",
                                                            "example": False,
                                                            "type": "boolean",
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(for "
                                                            "example, "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "quota-processor",
                                                            "type": "string",
                                                        },
                                                        "ignore_when_missing_partitions": {
                                                            "description": "If "
                                                            "`true`, "
                                                            "the "
                                                            "processor "
                                                            "skips "
                                                            "quota "
                                                            "checks "
                                                            "when "
                                                            "partition "
                                                            "fields "
                                                            "are "
                                                            "missing "
                                                            "from "
                                                            "the "
                                                            "logs.",
                                                            "type": "boolean",
                                                        },
                                                        "include": {
                                                            "description": "A "
                                                            "Datadog "
                                                            "search "
                                                            "query "
                                                            "used "
                                                            "to "
                                                            "determine "
                                                            "which "
                                                            "logs "
                                                            "this "
                                                            "processor "
                                                            "targets.",
                                                            "example": "service:my-service",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["datadog-agent-source"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "limit": {
                                                            "description": "The "
                                                            "maximum "
                                                            "amount "
                                                            "of "
                                                            "data "
                                                            "or "
                                                            "number "
                                                            "of "
                                                            "events "
                                                            "allowed "
                                                            "before "
                                                            "the "
                                                            "quota "
                                                            "is "
                                                            "enforced. "
                                                            "Can "
                                                            "be "
                                                            "specified "
                                                            "in "
                                                            "bytes "
                                                            "or "
                                                            "events.",
                                                            "properties": {
                                                                "enforce": {
                                                                    "description": "Unit "
                                                                    "for "
                                                                    "quota "
                                                                    "enforcement "
                                                                    "in "
                                                                    "bytes "
                                                                    "for "
                                                                    "data "
                                                                    "size "
                                                                    "or "
                                                                    "events "
                                                                    "for "
                                                                    "count.",
                                                                    "enum": ["bytes", "events"],
                                                                    "example": "bytes",
                                                                    "type": "string",
                                                                    "x-enum-varnames": [
                                                                        "BYTES",
                                                                        "EVENTS",
                                                                    ],
                                                                },
                                                                "limit": {
                                                                    "description": "The "
                                                                    "limit "
                                                                    "for "
                                                                    "quota "
                                                                    "enforcement.",
                                                                    "example": 1000,
                                                                    "format": "int64",
                                                                    "type": "integer",
                                                                },
                                                            },
                                                            "required": ["enforce", "limit"],
                                                            "type": "object",
                                                        },
                                                        "name": {
                                                            "description": "Name of the quota.",
                                                            "example": "MyQuota",
                                                            "type": "string",
                                                        },
                                                        "overflow_action": {
                                                            "description": "The "
                                                            "action "
                                                            "to "
                                                            "take "
                                                            "when "
                                                            "the "
                                                            "quota "
                                                            "is "
                                                            "exceeded. "
                                                            "Options:\n"
                                                            "- "
                                                            "`drop`: "
                                                            "Drop "
                                                            "the "
                                                            "event.\n"
                                                            "- "
                                                            "`no_action`: "
                                                            "Let "
                                                            "the "
                                                            "event "
                                                            "pass "
                                                            "through.\n"
                                                            "- "
                                                            "`overflow_routing`: "
                                                            "Route "
                                                            "to "
                                                            "an "
                                                            "overflow "
                                                            "destination.",
                                                            "enum": [
                                                                "drop",
                                                                "no_action",
                                                                "overflow_routing",
                                                            ],
                                                            "example": "drop",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "DROP",
                                                                "NO_ACTION",
                                                                "OVERFLOW_ROUTING",
                                                            ],
                                                        },
                                                        "overrides": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "alternate "
                                                            "quota "
                                                            "rules "
                                                            "that "
                                                            "apply "
                                                            "to "
                                                            "specific "
                                                            "sets "
                                                            "of "
                                                            "events, "
                                                            "identified "
                                                            "by "
                                                            "matching "
                                                            "field "
                                                            "values. "
                                                            "Each "
                                                            "override "
                                                            "can "
                                                            "define "
                                                            "a "
                                                            "custom "
                                                            "limit.",
                                                            "items": {
                                                                "description": "Defines "
                                                                "a "
                                                                "custom "
                                                                "quota "
                                                                "limit "
                                                                "that "
                                                                "applies "
                                                                "to "
                                                                "specific "
                                                                "log "
                                                                "events "
                                                                "based "
                                                                "on "
                                                                "matching "
                                                                "field "
                                                                "values.",
                                                                "properties": {
                                                                    "fields": {
                                                                        "description": "A "
                                                                        "list "
                                                                        "of "
                                                                        "field "
                                                                        "matchers "
                                                                        "used "
                                                                        "to "
                                                                        "apply "
                                                                        "a "
                                                                        "specific "
                                                                        "override. "
                                                                        "If "
                                                                        "an "
                                                                        "event "
                                                                        "matches "
                                                                        "all "
                                                                        "listed "
                                                                        "key-value "
                                                                        "pairs, "
                                                                        "the "
                                                                        "corresponding "
                                                                        "override "
                                                                        "limit "
                                                                        "is "
                                                                        "enforced.",
                                                                        "items": {
                                                                            "description": "Represents "
                                                                            "a "
                                                                            "static "
                                                                            "key-value "
                                                                            "pair "
                                                                            "used "
                                                                            "in "
                                                                            "various "
                                                                            "processors.",
                                                                            "properties": {
                                                                                "name": {
                                                                                    "description": "The "
                                                                                    "field "
                                                                                    "name.",
                                                                                    "example": "field_name",
                                                                                    "type": "string",
                                                                                },
                                                                                "value": {
                                                                                    "description": "The "
                                                                                    "field "
                                                                                    "value.",
                                                                                    "example": "field_value",
                                                                                    "type": "string",
                                                                                },
                                                                            },
                                                                            "required": [
                                                                                "name",
                                                                                "value",
                                                                            ],
                                                                            "type": "object",
                                                                        },
                                                                        "type": "array",
                                                                    },
                                                                    "limit": {
                                                                        "description": "The "
                                                                        "maximum "
                                                                        "amount "
                                                                        "of "
                                                                        "data "
                                                                        "or "
                                                                        "number "
                                                                        "of "
                                                                        "events "
                                                                        "allowed "
                                                                        "before "
                                                                        "the "
                                                                        "quota "
                                                                        "is "
                                                                        "enforced. "
                                                                        "Can "
                                                                        "be "
                                                                        "specified "
                                                                        "in "
                                                                        "bytes "
                                                                        "or "
                                                                        "events.",
                                                                        "properties": {
                                                                            "enforce": {
                                                                                "description": "Unit "
                                                                                "for "
                                                                                "quota "
                                                                                "enforcement "
                                                                                "in "
                                                                                "bytes "
                                                                                "for "
                                                                                "data "
                                                                                "size "
                                                                                "or "
                                                                                "events "
                                                                                "for "
                                                                                "count.",
                                                                                "enum": [
                                                                                    "bytes",
                                                                                    "events",
                                                                                ],
                                                                                "example": "bytes",
                                                                                "type": "string",
                                                                                "x-enum-varnames": [
                                                                                    "BYTES",
                                                                                    "EVENTS",
                                                                                ],
                                                                            },
                                                                            "limit": {
                                                                                "description": "The "
                                                                                "limit "
                                                                                "for "
                                                                                "quota "
                                                                                "enforcement.",
                                                                                "example": 1000,
                                                                                "format": "int64",
                                                                                "type": "integer",
                                                                            },
                                                                        },
                                                                        "required": [
                                                                            "enforce",
                                                                            "limit",
                                                                        ],
                                                                        "type": "object",
                                                                    },
                                                                },
                                                                "required": ["fields", "limit"],
                                                                "type": "object",
                                                            },
                                                            "type": "array",
                                                        },
                                                        "partition_fields": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "fields "
                                                            "used "
                                                            "to "
                                                            "segment "
                                                            "log "
                                                            "traffic "
                                                            "for "
                                                            "quota "
                                                            "enforcement. "
                                                            "Quotas "
                                                            "are "
                                                            "tracked "
                                                            "independently "
                                                            "by "
                                                            "unique "
                                                            "combinations "
                                                            "of "
                                                            "these "
                                                            "field "
                                                            "values.",
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "quota",
                                                            "description": "The "
                                                            "processor "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`quota`.",
                                                            "enum": ["quota"],
                                                            "example": "quota",
                                                            "type": "string",
                                                            "x-enum-varnames": ["QUOTA"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "include",
                                                        "name",
                                                        "drop_events",
                                                        "limit",
                                                        "inputs",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`add_fields` "
                                                    "processor "
                                                    "adds "
                                                    "static "
                                                    "key-value "
                                                    "fields "
                                                    "to "
                                                    "logs.",
                                                    "properties": {
                                                        "fields": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "static "
                                                            "fields "
                                                            "(key-value "
                                                            "pairs) "
                                                            "that "
                                                            "is "
                                                            "added "
                                                            "to "
                                                            "each "
                                                            "log "
                                                            "event "
                                                            "processed "
                                                            "by "
                                                            "this "
                                                            "component.",
                                                            "items": {
                                                                "description": "Represents "
                                                                "a "
                                                                "static "
                                                                "key-value "
                                                                "pair "
                                                                "used "
                                                                "in "
                                                                "various "
                                                                "processors.",
                                                                "properties": {
                                                                    "name": {
                                                                        "description": "The "
                                                                        "field "
                                                                        "name.",
                                                                        "example": "field_name",
                                                                        "type": "string",
                                                                    },
                                                                    "value": {
                                                                        "description": "The "
                                                                        "field "
                                                                        "value.",
                                                                        "example": "field_value",
                                                                        "type": "string",
                                                                    },
                                                                },
                                                                "required": ["name", "value"],
                                                                "type": "object",
                                                            },
                                                            "type": "array",
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(for "
                                                            "example, "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "add-fields-processor",
                                                            "type": "string",
                                                        },
                                                        "include": {
                                                            "description": "A "
                                                            "Datadog "
                                                            "search "
                                                            "query "
                                                            "used "
                                                            "to "
                                                            "determine "
                                                            "which "
                                                            "logs "
                                                            "this "
                                                            "processor "
                                                            "targets.",
                                                            "example": "service:my-service",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["datadog-agent-source"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "add_fields",
                                                            "description": "The "
                                                            "processor "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`add_fields`.",
                                                            "enum": ["add_fields"],
                                                            "example": "add_fields",
                                                            "type": "string",
                                                            "x-enum-varnames": ["ADD_FIELDS"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "include",
                                                        "fields",
                                                        "inputs",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`remove_fields` "
                                                    "processor "
                                                    "deletes "
                                                    "specified "
                                                    "fields "
                                                    "from "
                                                    "logs.",
                                                    "properties": {
                                                        "fields": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "field "
                                                            "names "
                                                            "to "
                                                            "be "
                                                            "removed "
                                                            "from "
                                                            "each "
                                                            "log "
                                                            "event.",
                                                            "example": ["field1", "field2"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(e.g., "
                                                            "as "
                                                            "input "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "remove-fields-processor",
                                                            "type": "string",
                                                        },
                                                        "include": {
                                                            "description": "A "
                                                            "Datadog "
                                                            "search "
                                                            "query "
                                                            "used "
                                                            "to "
                                                            "determine "
                                                            "which "
                                                            "logs "
                                                            "this "
                                                            "processor "
                                                            "targets.",
                                                            "example": "service:my-service",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "The "
                                                            "`PipelineRemoveFieldsProcessor` "
                                                            "`inputs`.",
                                                            "example": ["datadog-agent-source"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "remove_fields",
                                                            "description": "The "
                                                            "processor "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`remove_fields`.",
                                                            "enum": ["remove_fields"],
                                                            "example": "remove_fields",
                                                            "type": "string",
                                                            "x-enum-varnames": ["REMOVE_FIELDS"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "include",
                                                        "fields",
                                                        "inputs",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`rename_fields` "
                                                    "processor "
                                                    "changes "
                                                    "field "
                                                    "names.",
                                                    "properties": {
                                                        "fields": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "rename "
                                                            "rules "
                                                            "specifying "
                                                            "which "
                                                            "fields "
                                                            "to "
                                                            "rename "
                                                            "in "
                                                            "the "
                                                            "event, "
                                                            "what "
                                                            "to "
                                                            "rename "
                                                            "them "
                                                            "to, "
                                                            "and "
                                                            "whether "
                                                            "to "
                                                            "preserve "
                                                            "the "
                                                            "original "
                                                            "fields.",
                                                            "items": {
                                                                "description": "Defines "
                                                                "how "
                                                                "to "
                                                                "rename "
                                                                "a "
                                                                "field "
                                                                "in "
                                                                "log "
                                                                "events.",
                                                                "properties": {
                                                                    "destination": {
                                                                        "description": "The "
                                                                        "field "
                                                                        "name "
                                                                        "to "
                                                                        "assign "
                                                                        "the "
                                                                        "renamed "
                                                                        "value "
                                                                        "to.",
                                                                        "example": "destination_field",
                                                                        "type": "string",
                                                                    },
                                                                    "preserve_source": {
                                                                        "description": "Indicates "
                                                                        "whether "
                                                                        "the "
                                                                        "original "
                                                                        "field, "
                                                                        "that "
                                                                        "is "
                                                                        "received "
                                                                        "from "
                                                                        "the "
                                                                        "source, "
                                                                        "should "
                                                                        "be "
                                                                        "kept "
                                                                        "(`true`) "
                                                                        "or "
                                                                        "removed "
                                                                        "(`false`) "
                                                                        "after "
                                                                        "renaming.",
                                                                        "example": False,
                                                                        "type": "boolean",
                                                                    },
                                                                    "source": {
                                                                        "description": "The "
                                                                        "original "
                                                                        "field "
                                                                        "name "
                                                                        "in "
                                                                        "the "
                                                                        "log "
                                                                        "event "
                                                                        "that "
                                                                        "should "
                                                                        "be "
                                                                        "renamed.",
                                                                        "example": "source_field",
                                                                        "type": "string",
                                                                    },
                                                                },
                                                                "required": [
                                                                    "source",
                                                                    "destination",
                                                                    "preserve_source",
                                                                ],
                                                                "type": "object",
                                                            },
                                                            "type": "array",
                                                        },
                                                        "id": {
                                                            "description": "A "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(e.g., "
                                                            "as "
                                                            "input "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "rename-fields-processor",
                                                            "type": "string",
                                                        },
                                                        "include": {
                                                            "description": "A "
                                                            "Datadog "
                                                            "search "
                                                            "query "
                                                            "used "
                                                            "to "
                                                            "determine "
                                                            "which "
                                                            "logs "
                                                            "this "
                                                            "processor "
                                                            "targets.",
                                                            "example": "service:my-service",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["datadog-agent-source"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "rename_fields",
                                                            "description": "The "
                                                            "processor "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`rename_fields`.",
                                                            "enum": ["rename_fields"],
                                                            "example": "rename_fields",
                                                            "type": "string",
                                                            "x-enum-varnames": ["RENAME_FIELDS"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "include",
                                                        "fields",
                                                        "inputs",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`generate_datadog_metrics` "
                                                    "processor "
                                                    "creates "
                                                    "custom "
                                                    "metrics "
                                                    "from "
                                                    "logs "
                                                    "and "
                                                    "sends "
                                                    "them "
                                                    "to "
                                                    "Datadog.\n"
                                                    "Metrics "
                                                    "can "
                                                    "be "
                                                    "counters, "
                                                    "gauges, "
                                                    "or "
                                                    "distributions "
                                                    "and "
                                                    "optionally "
                                                    "grouped "
                                                    "by "
                                                    "log "
                                                    "fields.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline.",
                                                            "example": "generate-metrics-processor",
                                                            "type": "string",
                                                        },
                                                        "include": {
                                                            "description": "A "
                                                            "Datadog "
                                                            "search "
                                                            "query "
                                                            "used "
                                                            "to "
                                                            "determine "
                                                            "which "
                                                            "logs "
                                                            "this "
                                                            "processor "
                                                            "targets.",
                                                            "example": "service:my-service",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "processor.",
                                                            "example": ["source-id"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "metrics": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "generating "
                                                            "individual "
                                                            "metrics.",
                                                            "items": {
                                                                "description": "Defines "
                                                                "a "
                                                                "log-based "
                                                                "custom "
                                                                "metric, "
                                                                "including "
                                                                "its "
                                                                "name, "
                                                                "type, "
                                                                "filter, "
                                                                "value "
                                                                "computation "
                                                                "strategy,\n"
                                                                "and "
                                                                "optional "
                                                                "grouping "
                                                                "fields.",
                                                                "properties": {
                                                                    "group_by": {
                                                                        "description": "Optional "
                                                                        "fields "
                                                                        "used "
                                                                        "to "
                                                                        "group "
                                                                        "the "
                                                                        "metric "
                                                                        "series.",
                                                                        "example": [
                                                                            "service",
                                                                            "env",
                                                                        ],
                                                                        "items": {"type": "string"},
                                                                        "type": "array",
                                                                    },
                                                                    "include": {
                                                                        "description": "Datadog "
                                                                        "filter "
                                                                        "query "
                                                                        "to "
                                                                        "match "
                                                                        "logs "
                                                                        "for "
                                                                        "metric "
                                                                        "generation.",
                                                                        "example": "service:billing",
                                                                        "type": "string",
                                                                    },
                                                                    "metric_type": {
                                                                        "description": "Type "
                                                                        "of "
                                                                        "metric "
                                                                        "to "
                                                                        "create.",
                                                                        "enum": [
                                                                            "count",
                                                                            "gauge",
                                                                            "distribution",
                                                                        ],
                                                                        "example": "count",
                                                                        "type": "string",
                                                                        "x-enum-varnames": [
                                                                            "COUNT",
                                                                            "GAUGE",
                                                                            "DISTRIBUTION",
                                                                        ],
                                                                    },
                                                                    "name": {
                                                                        "description": "Name "
                                                                        "of "
                                                                        "the "
                                                                        "custom "
                                                                        "metric "
                                                                        "to "
                                                                        "be "
                                                                        "created.",
                                                                        "example": "logs.processed",
                                                                        "type": "string",
                                                                    },
                                                                    "value": {
                                                                        "description": "Specifies "
                                                                        "how "
                                                                        "the "
                                                                        "value "
                                                                        "of "
                                                                        "the "
                                                                        "generated "
                                                                        "metric "
                                                                        "is "
                                                                        "computed.",
                                                                        "oneOf": [
                                                                            {
                                                                                "description": "Strategy "
                                                                                "that "
                                                                                "increments "
                                                                                "a "
                                                                                "generated "
                                                                                "metric "
                                                                                "by "
                                                                                "one "
                                                                                "for "
                                                                                "each "
                                                                                "matching "
                                                                                "event.",
                                                                                "properties": {
                                                                                    "strategy": {
                                                                                        "description": "Increments "
                                                                                        "the "
                                                                                        "metric "
                                                                                        "by "
                                                                                        "1 "
                                                                                        "for "
                                                                                        "each "
                                                                                        "matching "
                                                                                        "event.",
                                                                                        "enum": [
                                                                                            "increment_by_one"
                                                                                        ],
                                                                                        "example": "increment_by_one",
                                                                                        "type": "string",
                                                                                        "x-enum-varnames": [
                                                                                            "INCREMENT_BY_ONE"
                                                                                        ],
                                                                                    }
                                                                                },
                                                                                "required": [
                                                                                    "strategy"
                                                                                ],
                                                                                "type": "object",
                                                                            },
                                                                            {
                                                                                "description": "Strategy "
                                                                                "that "
                                                                                "increments "
                                                                                "a "
                                                                                "generated "
                                                                                "metric "
                                                                                "based "
                                                                                "on "
                                                                                "the "
                                                                                "value "
                                                                                "of "
                                                                                "a "
                                                                                "log "
                                                                                "field.",
                                                                                "properties": {
                                                                                    "field": {
                                                                                        "description": "Name "
                                                                                        "of "
                                                                                        "the "
                                                                                        "log "
                                                                                        "field "
                                                                                        "containing "
                                                                                        "the "
                                                                                        "numeric "
                                                                                        "value "
                                                                                        "to "
                                                                                        "increment "
                                                                                        "the "
                                                                                        "metric "
                                                                                        "by.",
                                                                                        "example": "errors",
                                                                                        "type": "string",
                                                                                    },
                                                                                    "strategy": {
                                                                                        "description": "Uses "
                                                                                        "a "
                                                                                        "numeric "
                                                                                        "field "
                                                                                        "in "
                                                                                        "the "
                                                                                        "log "
                                                                                        "event "
                                                                                        "as "
                                                                                        "the "
                                                                                        "metric "
                                                                                        "increment.",
                                                                                        "enum": [
                                                                                            "increment_by_field"
                                                                                        ],
                                                                                        "example": "increment_by_field",
                                                                                        "type": "string",
                                                                                        "x-enum-varnames": [
                                                                                            "INCREMENT_BY_FIELD"
                                                                                        ],
                                                                                    },
                                                                                },
                                                                                "required": [
                                                                                    "strategy",
                                                                                    "field",
                                                                                ],
                                                                                "type": "object",
                                                                            },
                                                                        ],
                                                                    },
                                                                },
                                                                "required": [
                                                                    "name",
                                                                    "include",
                                                                    "metric_type",
                                                                    "value",
                                                                ],
                                                                "type": "object",
                                                            },
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "generate_datadog_metrics",
                                                            "description": "The "
                                                            "processor "
                                                            "type. "
                                                            "Always "
                                                            "`generate_datadog_metrics`.",
                                                            "enum": ["generate_datadog_metrics"],
                                                            "example": "generate_datadog_metrics",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "GENERATE_DATADOG_METRICS"
                                                            ],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "inputs",
                                                        "include",
                                                        "metrics",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`sample` "
                                                    "processor "
                                                    "allows "
                                                    "probabilistic "
                                                    "sampling "
                                                    "of "
                                                    "logs "
                                                    "at "
                                                    "a "
                                                    "fixed "
                                                    "rate.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(for "
                                                            "example, "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "sample-processor",
                                                            "type": "string",
                                                        },
                                                        "include": {
                                                            "description": "A "
                                                            "Datadog "
                                                            "search "
                                                            "query "
                                                            "used "
                                                            "to "
                                                            "determine "
                                                            "which "
                                                            "logs "
                                                            "this "
                                                            "processor "
                                                            "targets.",
                                                            "example": "service:my-service",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["datadog-agent-source"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "percentage": {
                                                            "description": "The "
                                                            "percentage "
                                                            "of "
                                                            "logs "
                                                            "to "
                                                            "sample.",
                                                            "example": 10.0,
                                                            "format": "double",
                                                            "type": "number",
                                                        },
                                                        "rate": {
                                                            "description": "Number "
                                                            "of "
                                                            "events "
                                                            "to "
                                                            "sample "
                                                            "(1 "
                                                            "in "
                                                            "N).",
                                                            "example": 10,
                                                            "format": "int64",
                                                            "minimum": 1,
                                                            "type": "integer",
                                                        },
                                                        "type": {
                                                            "default": "sample",
                                                            "description": "The "
                                                            "processor "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`sample`.",
                                                            "enum": ["sample"],
                                                            "example": "sample",
                                                            "type": "string",
                                                            "x-enum-varnames": ["SAMPLE"],
                                                        },
                                                    },
                                                    "required": ["id", "type", "include", "inputs"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`parse_grok` "
                                                    "processor "
                                                    "extracts "
                                                    "structured "
                                                    "fields "
                                                    "from "
                                                    "unstructured "
                                                    "log "
                                                    "messages "
                                                    "using "
                                                    "Grok "
                                                    "patterns.",
                                                    "properties": {
                                                        "disable_library_rules": {
                                                            "default": False,
                                                            "description": "If "
                                                            "set "
                                                            "to "
                                                            "`true`, "
                                                            "disables "
                                                            "the "
                                                            "default "
                                                            "Grok "
                                                            "rules "
                                                            "provided "
                                                            "by "
                                                            "Datadog.",
                                                            "example": True,
                                                            "type": "boolean",
                                                        },
                                                        "id": {
                                                            "description": "A "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "processor.",
                                                            "example": "parse-grok-processor",
                                                            "type": "string",
                                                        },
                                                        "include": {
                                                            "description": "A "
                                                            "Datadog "
                                                            "search "
                                                            "query "
                                                            "used "
                                                            "to "
                                                            "determine "
                                                            "which "
                                                            "logs "
                                                            "this "
                                                            "processor "
                                                            "targets.",
                                                            "example": "service:my-service",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["datadog-agent-source"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "rules": {
                                                            "description": "The "
                                                            "list "
                                                            "of "
                                                            "Grok "
                                                            "parsing "
                                                            "rules. "
                                                            "If "
                                                            "multiple "
                                                            "matching "
                                                            "rules "
                                                            "are "
                                                            "provided, "
                                                            "they "
                                                            "are "
                                                            "evaluated "
                                                            "in "
                                                            "order. "
                                                            "The "
                                                            "first "
                                                            "successful "
                                                            "match "
                                                            "is "
                                                            "applied.",
                                                            "items": {
                                                                "description": "A "
                                                                "Grok "
                                                                "parsing "
                                                                "rule "
                                                                "used "
                                                                "in "
                                                                "the "
                                                                "`parse_grok` "
                                                                "processor. "
                                                                "Each "
                                                                "rule "
                                                                "defines "
                                                                "how "
                                                                "to "
                                                                "extract "
                                                                "structured "
                                                                "fields\n"
                                                                "from "
                                                                "a "
                                                                "specific "
                                                                "log "
                                                                "field "
                                                                "using "
                                                                "Grok "
                                                                "patterns.",
                                                                "properties": {
                                                                    "match_rules": {
                                                                        "description": "A "
                                                                        "list "
                                                                        "of "
                                                                        "Grok "
                                                                        "parsing "
                                                                        "rules "
                                                                        "that "
                                                                        "define "
                                                                        "how "
                                                                        "to "
                                                                        "extract "
                                                                        "fields "
                                                                        "from "
                                                                        "the "
                                                                        "source "
                                                                        "field.\n"
                                                                        "Each "
                                                                        "rule "
                                                                        "must "
                                                                        "contain "
                                                                        "a "
                                                                        "name "
                                                                        "and "
                                                                        "a "
                                                                        "valid "
                                                                        "Grok "
                                                                        "pattern.",
                                                                        "example": [
                                                                            {
                                                                                "name": "MyParsingRule",
                                                                                "rule": "%{word:user} "
                                                                                "connected "
                                                                                "on "
                                                                                '%{date("MM/dd/yyyy"):date}',
                                                                            }
                                                                        ],
                                                                        "items": {
                                                                            "description": "Defines "
                                                                            "a "
                                                                            "Grok "
                                                                            "parsing "
                                                                            "rule, "
                                                                            "which "
                                                                            "extracts "
                                                                            "structured "
                                                                            "fields "
                                                                            "from "
                                                                            "log "
                                                                            "content "
                                                                            "using "
                                                                            "named "
                                                                            "Grok "
                                                                            "patterns.\n"
                                                                            "Each "
                                                                            "rule "
                                                                            "must "
                                                                            "have "
                                                                            "a "
                                                                            "unique "
                                                                            "name "
                                                                            "and "
                                                                            "a "
                                                                            "valid "
                                                                            "Datadog "
                                                                            "Grok "
                                                                            "pattern "
                                                                            "that "
                                                                            "will "
                                                                            "be "
                                                                            "applied "
                                                                            "to "
                                                                            "the "
                                                                            "source "
                                                                            "field.",
                                                                            "properties": {
                                                                                "name": {
                                                                                    "description": "The "
                                                                                    "name "
                                                                                    "of "
                                                                                    "the "
                                                                                    "rule.",
                                                                                    "example": "MyParsingRule",
                                                                                    "type": "string",
                                                                                },
                                                                                "rule": {
                                                                                    "description": "The "
                                                                                    "definition "
                                                                                    "of "
                                                                                    "the "
                                                                                    "Grok "
                                                                                    "rule.",
                                                                                    "example": "%{word:user} "
                                                                                    "connected "
                                                                                    "on "
                                                                                    '%{date("MM/dd/yyyy"):date}',
                                                                                    "type": "string",
                                                                                },
                                                                            },
                                                                            "required": [
                                                                                "name",
                                                                                "rule",
                                                                            ],
                                                                            "type": "object",
                                                                        },
                                                                        "type": "array",
                                                                    },
                                                                    "source": {
                                                                        "description": "The "
                                                                        "name "
                                                                        "of "
                                                                        "the "
                                                                        "field "
                                                                        "in "
                                                                        "the "
                                                                        "log "
                                                                        "event "
                                                                        "to "
                                                                        "apply "
                                                                        "the "
                                                                        "Grok "
                                                                        "rules "
                                                                        "to.",
                                                                        "example": "message",
                                                                        "type": "string",
                                                                    },
                                                                    "support_rules": {
                                                                        "description": "A "
                                                                        "list "
                                                                        "of "
                                                                        "Grok "
                                                                        "helper "
                                                                        "rules "
                                                                        "that "
                                                                        "can "
                                                                        "be "
                                                                        "referenced "
                                                                        "by "
                                                                        "the "
                                                                        "parsing "
                                                                        "rules.",
                                                                        "example": [
                                                                            {
                                                                                "name": "user",
                                                                                "rule": "%{word:user.name}",
                                                                            }
                                                                        ],
                                                                        "items": {
                                                                            "description": "The "
                                                                            "Grok "
                                                                            "helper "
                                                                            "rule "
                                                                            "referenced "
                                                                            "in "
                                                                            "the "
                                                                            "parsing "
                                                                            "rules.",
                                                                            "properties": {
                                                                                "name": {
                                                                                    "description": "The "
                                                                                    "name "
                                                                                    "of "
                                                                                    "the "
                                                                                    "Grok "
                                                                                    "helper "
                                                                                    "rule.",
                                                                                    "example": "user",
                                                                                    "type": "string",
                                                                                },
                                                                                "rule": {
                                                                                    "description": "The "
                                                                                    "definition "
                                                                                    "of "
                                                                                    "the "
                                                                                    "Grok "
                                                                                    "helper "
                                                                                    "rule.",
                                                                                    "example": " "
                                                                                    "%{word:user.name}",
                                                                                    "type": "string",
                                                                                },
                                                                            },
                                                                            "required": [
                                                                                "name",
                                                                                "rule",
                                                                            ],
                                                                            "type": "object",
                                                                        },
                                                                        "type": "array",
                                                                    },
                                                                },
                                                                "required": [
                                                                    "source",
                                                                    "match_rules",
                                                                ],
                                                                "type": "object",
                                                            },
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "parse_grok",
                                                            "description": "The "
                                                            "processor "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`parse_grok`.",
                                                            "enum": ["parse_grok"],
                                                            "example": "parse_grok",
                                                            "type": "string",
                                                            "x-enum-varnames": ["PARSE_GROK"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "include",
                                                        "inputs",
                                                        "rules",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`sensitive_data_scanner` "
                                                    "processor "
                                                    "detects "
                                                    "and "
                                                    "optionally "
                                                    "redacts "
                                                    "sensitive "
                                                    "data "
                                                    "in "
                                                    "log "
                                                    "events.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(e.g., "
                                                            "as "
                                                            "input "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "sensitive-scanner",
                                                            "type": "string",
                                                        },
                                                        "include": {
                                                            "description": "A "
                                                            "Datadog "
                                                            "search "
                                                            "query "
                                                            "used "
                                                            "to "
                                                            "determine "
                                                            "which "
                                                            "logs "
                                                            "this "
                                                            "processor "
                                                            "targets.",
                                                            "example": "source:prod",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["parse-json-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "rules": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "rules "
                                                            "for "
                                                            "identifying "
                                                            "and "
                                                            "acting "
                                                            "on "
                                                            "sensitive "
                                                            "data "
                                                            "patterns.",
                                                            "items": {
                                                                "description": "Defines "
                                                                "a "
                                                                "rule "
                                                                "for "
                                                                "detecting "
                                                                "sensitive "
                                                                "data, "
                                                                "including "
                                                                "matching "
                                                                "pattern, "
                                                                "scope, "
                                                                "and "
                                                                "the "
                                                                "action "
                                                                "to "
                                                                "take.",
                                                                "properties": {
                                                                    "keyword_options": {
                                                                        "description": "Configuration "
                                                                        "for "
                                                                        "keywords "
                                                                        "used "
                                                                        "to "
                                                                        "reinforce "
                                                                        "sensitive "
                                                                        "data "
                                                                        "pattern "
                                                                        "detection.",
                                                                        "properties": {
                                                                            "keywords": {
                                                                                "description": "A "
                                                                                "list "
                                                                                "of "
                                                                                "keywords "
                                                                                "to "
                                                                                "match "
                                                                                "near "
                                                                                "the "
                                                                                "sensitive "
                                                                                "pattern.",
                                                                                "example": [
                                                                                    "ssn",
                                                                                    "card",
                                                                                    "account",
                                                                                ],
                                                                                "items": {
                                                                                    "type": "string"
                                                                                },
                                                                                "type": "array",
                                                                            },
                                                                            "proximity": {
                                                                                "description": "Maximum "
                                                                                "number "
                                                                                "of "
                                                                                "tokens "
                                                                                "between "
                                                                                "a "
                                                                                "keyword "
                                                                                "and "
                                                                                "a "
                                                                                "sensitive "
                                                                                "value "
                                                                                "match.",
                                                                                "example": 5,
                                                                                "format": "int64",
                                                                                "type": "integer",
                                                                            },
                                                                        },
                                                                        "required": [
                                                                            "keywords",
                                                                            "proximity",
                                                                        ],
                                                                        "type": "object",
                                                                    },
                                                                    "name": {
                                                                        "description": "A "
                                                                        "name "
                                                                        "identifying "
                                                                        "the "
                                                                        "rule.",
                                                                        "example": "Redact "
                                                                        "Credit "
                                                                        "Card "
                                                                        "Numbers",
                                                                        "type": "string",
                                                                    },
                                                                    "on_match": {
                                                                        "description": "Defines "
                                                                        "what "
                                                                        "action "
                                                                        "to "
                                                                        "take "
                                                                        "when "
                                                                        "sensitive "
                                                                        "data "
                                                                        "is "
                                                                        "matched.",
                                                                        "oneOf": [
                                                                            {
                                                                                "description": "Configuration "
                                                                                "for "
                                                                                "completely "
                                                                                "redacting "
                                                                                "matched "
                                                                                "sensitive "
                                                                                "data.",
                                                                                "properties": {
                                                                                    "action": {
                                                                                        "description": "Action "
                                                                                        "type "
                                                                                        "that "
                                                                                        "completely "
                                                                                        "replaces "
                                                                                        "the "
                                                                                        "matched "
                                                                                        "sensitive "
                                                                                        "data "
                                                                                        "with "
                                                                                        "a "
                                                                                        "fixed "
                                                                                        "replacement "
                                                                                        "string "
                                                                                        "to "
                                                                                        "remove "
                                                                                        "all "
                                                                                        "visibility.",
                                                                                        "enum": [
                                                                                            "redact"
                                                                                        ],
                                                                                        "example": "redact",
                                                                                        "type": "string",
                                                                                        "x-enum-varnames": [
                                                                                            "REDACT"
                                                                                        ],
                                                                                    },
                                                                                    "options": {
                                                                                        "description": "Configuration "
                                                                                        "for "
                                                                                        "fully "
                                                                                        "redacting "
                                                                                        "sensitive "
                                                                                        "data.",
                                                                                        "properties": {
                                                                                            "replace": {
                                                                                                "description": "The "
                                                                                                "`ObservabilityPipelineSensitiveDataScannerProcessorActionRedactOptions` "
                                                                                                "`replace`.",
                                                                                                "example": "***",
                                                                                                "type": "string",
                                                                                            }
                                                                                        },
                                                                                        "required": [
                                                                                            "replace"
                                                                                        ],
                                                                                        "type": "object",
                                                                                    },
                                                                                },
                                                                                "required": [
                                                                                    "action",
                                                                                    "options",
                                                                                ],
                                                                                "type": "object",
                                                                            },
                                                                            {
                                                                                "description": "Configuration "
                                                                                "for "
                                                                                "hashing "
                                                                                "matched "
                                                                                "sensitive "
                                                                                "values.",
                                                                                "properties": {
                                                                                    "action": {
                                                                                        "description": "Action "
                                                                                        "type "
                                                                                        "that "
                                                                                        "replaces "
                                                                                        "the "
                                                                                        "matched "
                                                                                        "sensitive "
                                                                                        "data "
                                                                                        "with "
                                                                                        "a "
                                                                                        "hashed "
                                                                                        "representation, "
                                                                                        "preserving "
                                                                                        "structure "
                                                                                        "while "
                                                                                        "securing "
                                                                                        "content.",
                                                                                        "enum": [
                                                                                            "hash"
                                                                                        ],
                                                                                        "example": "hash",
                                                                                        "type": "string",
                                                                                        "x-enum-varnames": [
                                                                                            "HASH"
                                                                                        ],
                                                                                    },
                                                                                    "options": {
                                                                                        "description": "The "
                                                                                        "`ObservabilityPipelineSensitiveDataScannerProcessorActionHash` "
                                                                                        "`options`.",
                                                                                        "type": "object",
                                                                                    },
                                                                                },
                                                                                "required": [
                                                                                    "action"
                                                                                ],
                                                                                "type": "object",
                                                                            },
                                                                            {
                                                                                "description": "Configuration "
                                                                                "for "
                                                                                "partially "
                                                                                "redacting "
                                                                                "matched "
                                                                                "sensitive "
                                                                                "data.",
                                                                                "properties": {
                                                                                    "action": {
                                                                                        "description": "Action "
                                                                                        "type "
                                                                                        "that "
                                                                                        "redacts "
                                                                                        "part "
                                                                                        "of "
                                                                                        "the "
                                                                                        "sensitive "
                                                                                        "data "
                                                                                        "while "
                                                                                        "preserving "
                                                                                        "a "
                                                                                        "configurable "
                                                                                        "number "
                                                                                        "of "
                                                                                        "characters, "
                                                                                        "typically "
                                                                                        "used "
                                                                                        "for "
                                                                                        "masking "
                                                                                        "purposes "
                                                                                        "(e.g., "
                                                                                        "show "
                                                                                        "last "
                                                                                        "4 "
                                                                                        "digits "
                                                                                        "of "
                                                                                        "a "
                                                                                        "credit "
                                                                                        "card).",
                                                                                        "enum": [
                                                                                            "partial_redact"
                                                                                        ],
                                                                                        "example": "partial_redact",
                                                                                        "type": "string",
                                                                                        "x-enum-varnames": [
                                                                                            "PARTIAL_REDACT"
                                                                                        ],
                                                                                    },
                                                                                    "options": {
                                                                                        "description": "Controls "
                                                                                        "how "
                                                                                        "partial "
                                                                                        "redaction "
                                                                                        "is "
                                                                                        "applied, "
                                                                                        "including "
                                                                                        "character "
                                                                                        "count "
                                                                                        "and "
                                                                                        "direction.",
                                                                                        "properties": {
                                                                                            "characters": {
                                                                                                "description": "The "
                                                                                                "`ObservabilityPipelineSensitiveDataScannerProcessorActionPartialRedactOptions` "
                                                                                                "`characters`.",
                                                                                                "example": 4,
                                                                                                "format": "int64",
                                                                                                "type": "integer",
                                                                                            },
                                                                                            "direction": {
                                                                                                "description": "Indicates "
                                                                                                "whether "
                                                                                                "to "
                                                                                                "redact "
                                                                                                "characters "
                                                                                                "from "
                                                                                                "the "
                                                                                                "first "
                                                                                                "or "
                                                                                                "last "
                                                                                                "part "
                                                                                                "of "
                                                                                                "the "
                                                                                                "matched "
                                                                                                "value.",
                                                                                                "enum": [
                                                                                                    "first",
                                                                                                    "last",
                                                                                                ],
                                                                                                "example": "last",
                                                                                                "type": "string",
                                                                                                "x-enum-varnames": [
                                                                                                    "FIRST",
                                                                                                    "LAST",
                                                                                                ],
                                                                                            },
                                                                                        },
                                                                                        "required": [
                                                                                            "characters",
                                                                                            "direction",
                                                                                        ],
                                                                                        "type": "object",
                                                                                    },
                                                                                },
                                                                                "required": [
                                                                                    "action",
                                                                                    "options",
                                                                                ],
                                                                                "type": "object",
                                                                            },
                                                                        ],
                                                                    },
                                                                    "pattern": {
                                                                        "description": "Pattern "
                                                                        "detection "
                                                                        "configuration "
                                                                        "for "
                                                                        "identifying "
                                                                        "sensitive "
                                                                        "data "
                                                                        "using "
                                                                        "either "
                                                                        "a "
                                                                        "custom "
                                                                        "regex "
                                                                        "or "
                                                                        "a "
                                                                        "library "
                                                                        "reference.",
                                                                        "oneOf": [
                                                                            {
                                                                                "description": "Defines "
                                                                                "a "
                                                                                "custom "
                                                                                "regex-based "
                                                                                "pattern "
                                                                                "for "
                                                                                "identifying "
                                                                                "sensitive "
                                                                                "data "
                                                                                "in "
                                                                                "logs.",
                                                                                "properties": {
                                                                                    "options": {
                                                                                        "description": "Options "
                                                                                        "for "
                                                                                        "defining "
                                                                                        "a "
                                                                                        "custom "
                                                                                        "regex "
                                                                                        "pattern.",
                                                                                        "properties": {
                                                                                            "rule": {
                                                                                                "description": "A "
                                                                                                "regular "
                                                                                                "expression "
                                                                                                "used "
                                                                                                "to "
                                                                                                "detect "
                                                                                                "sensitive "
                                                                                                "values. "
                                                                                                "Must "
                                                                                                "be "
                                                                                                "a "
                                                                                                "valid "
                                                                                                "regex.",
                                                                                                "example": "\\b\\d{16}\\b",
                                                                                                "type": "string",
                                                                                            }
                                                                                        },
                                                                                        "required": [
                                                                                            "rule"
                                                                                        ],
                                                                                        "type": "object",
                                                                                    },
                                                                                    "type": {
                                                                                        "description": "Indicates "
                                                                                        "a "
                                                                                        "custom "
                                                                                        "regular "
                                                                                        "expression "
                                                                                        "is "
                                                                                        "used "
                                                                                        "for "
                                                                                        "matching.",
                                                                                        "enum": [
                                                                                            "custom"
                                                                                        ],
                                                                                        "example": "custom",
                                                                                        "type": "string",
                                                                                        "x-enum-varnames": [
                                                                                            "CUSTOM"
                                                                                        ],
                                                                                    },
                                                                                },
                                                                                "required": [
                                                                                    "type",
                                                                                    "options",
                                                                                ],
                                                                                "type": "object",
                                                                            },
                                                                            {
                                                                                "description": "Specifies "
                                                                                "a "
                                                                                "pattern "
                                                                                "from "
                                                                                "Datadog’s "
                                                                                "sensitive "
                                                                                "data "
                                                                                "detection "
                                                                                "library "
                                                                                "to "
                                                                                "match "
                                                                                "known "
                                                                                "sensitive "
                                                                                "data "
                                                                                "types.",
                                                                                "properties": {
                                                                                    "options": {
                                                                                        "description": "Options "
                                                                                        "for "
                                                                                        "selecting "
                                                                                        "a "
                                                                                        "predefined "
                                                                                        "library "
                                                                                        "pattern "
                                                                                        "and "
                                                                                        "enabling "
                                                                                        "keyword "
                                                                                        "support.",
                                                                                        "properties": {
                                                                                            "id": {
                                                                                                "description": "Identifier "
                                                                                                "for "
                                                                                                "a "
                                                                                                "predefined "
                                                                                                "pattern "
                                                                                                "from "
                                                                                                "the "
                                                                                                "sensitive "
                                                                                                "data "
                                                                                                "scanner "
                                                                                                "pattern "
                                                                                                "library.",
                                                                                                "example": "credit_card",
                                                                                                "type": "string",
                                                                                            },
                                                                                            "use_recommended_keywords": {
                                                                                                "description": "Whether "
                                                                                                "to "
                                                                                                "augment "
                                                                                                "the "
                                                                                                "pattern "
                                                                                                "with "
                                                                                                "recommended "
                                                                                                "keywords "
                                                                                                "(optional).",
                                                                                                "type": "boolean",
                                                                                            },
                                                                                        },
                                                                                        "required": [
                                                                                            "id"
                                                                                        ],
                                                                                        "type": "object",
                                                                                    },
                                                                                    "type": {
                                                                                        "description": "Indicates "
                                                                                        "that "
                                                                                        "a "
                                                                                        "predefined "
                                                                                        "library "
                                                                                        "pattern "
                                                                                        "is "
                                                                                        "used.",
                                                                                        "enum": [
                                                                                            "library"
                                                                                        ],
                                                                                        "example": "library",
                                                                                        "type": "string",
                                                                                        "x-enum-varnames": [
                                                                                            "LIBRARY"
                                                                                        ],
                                                                                    },
                                                                                },
                                                                                "required": [
                                                                                    "type",
                                                                                    "options",
                                                                                ],
                                                                                "type": "object",
                                                                            },
                                                                        ],
                                                                    },
                                                                    "scope": {
                                                                        "description": "Determines "
                                                                        "which "
                                                                        "parts "
                                                                        "of "
                                                                        "the "
                                                                        "log "
                                                                        "the "
                                                                        "pattern-matching "
                                                                        "rule "
                                                                        "should "
                                                                        "be "
                                                                        "applied "
                                                                        "to.",
                                                                        "oneOf": [
                                                                            {
                                                                                "description": "Includes "
                                                                                "only "
                                                                                "specific "
                                                                                "fields "
                                                                                "for "
                                                                                "sensitive "
                                                                                "data "
                                                                                "scanning.",
                                                                                "properties": {
                                                                                    "options": {
                                                                                        "description": "Fields "
                                                                                        "to "
                                                                                        "which "
                                                                                        "the "
                                                                                        "scope "
                                                                                        "rule "
                                                                                        "applies.",
                                                                                        "properties": {
                                                                                            "fields": {
                                                                                                "description": "The "
                                                                                                "`ObservabilityPipelineSensitiveDataScannerProcessorScopeOptions` "
                                                                                                "`fields`.",
                                                                                                "example": [
                                                                                                    ""
                                                                                                ],
                                                                                                "items": {
                                                                                                    "type": "string"
                                                                                                },
                                                                                                "type": "array",
                                                                                            }
                                                                                        },
                                                                                        "required": [
                                                                                            "fields"
                                                                                        ],
                                                                                        "type": "object",
                                                                                    },
                                                                                    "target": {
                                                                                        "description": "Applies "
                                                                                        "the "
                                                                                        "rule "
                                                                                        "only "
                                                                                        "to "
                                                                                        "included "
                                                                                        "fields.",
                                                                                        "enum": [
                                                                                            "include"
                                                                                        ],
                                                                                        "example": "include",
                                                                                        "type": "string",
                                                                                        "x-enum-varnames": [
                                                                                            "INCLUDE"
                                                                                        ],
                                                                                    },
                                                                                },
                                                                                "required": [
                                                                                    "target",
                                                                                    "options",
                                                                                ],
                                                                                "type": "object",
                                                                            },
                                                                            {
                                                                                "description": "Excludes "
                                                                                "specific "
                                                                                "fields "
                                                                                "from "
                                                                                "sensitive "
                                                                                "data "
                                                                                "scanning.",
                                                                                "properties": {
                                                                                    "options": {
                                                                                        "description": "Fields "
                                                                                        "to "
                                                                                        "which "
                                                                                        "the "
                                                                                        "scope "
                                                                                        "rule "
                                                                                        "applies.",
                                                                                        "properties": {
                                                                                            "fields": {
                                                                                                "description": "The "
                                                                                                "`ObservabilityPipelineSensitiveDataScannerProcessorScopeOptions` "
                                                                                                "`fields`.",
                                                                                                "example": [
                                                                                                    ""
                                                                                                ],
                                                                                                "items": {
                                                                                                    "type": "string"
                                                                                                },
                                                                                                "type": "array",
                                                                                            }
                                                                                        },
                                                                                        "required": [
                                                                                            "fields"
                                                                                        ],
                                                                                        "type": "object",
                                                                                    },
                                                                                    "target": {
                                                                                        "description": "Excludes "
                                                                                        "specific "
                                                                                        "fields "
                                                                                        "from "
                                                                                        "processing.",
                                                                                        "enum": [
                                                                                            "exclude"
                                                                                        ],
                                                                                        "example": "exclude",
                                                                                        "type": "string",
                                                                                        "x-enum-varnames": [
                                                                                            "EXCLUDE"
                                                                                        ],
                                                                                    },
                                                                                },
                                                                                "required": [
                                                                                    "target",
                                                                                    "options",
                                                                                ],
                                                                                "type": "object",
                                                                            },
                                                                            {
                                                                                "description": "Applies "
                                                                                "scanning "
                                                                                "across "
                                                                                "all "
                                                                                "available "
                                                                                "fields.",
                                                                                "properties": {
                                                                                    "target": {
                                                                                        "description": "Applies "
                                                                                        "the "
                                                                                        "rule "
                                                                                        "to "
                                                                                        "all "
                                                                                        "fields.",
                                                                                        "enum": [
                                                                                            "all"
                                                                                        ],
                                                                                        "example": "all",
                                                                                        "type": "string",
                                                                                        "x-enum-varnames": [
                                                                                            "ALL"
                                                                                        ],
                                                                                    }
                                                                                },
                                                                                "required": [
                                                                                    "target"
                                                                                ],
                                                                                "type": "object",
                                                                            },
                                                                        ],
                                                                    },
                                                                    "tags": {
                                                                        "description": "Tags "
                                                                        "assigned "
                                                                        "to "
                                                                        "this "
                                                                        "rule "
                                                                        "for "
                                                                        "filtering "
                                                                        "and "
                                                                        "classification.",
                                                                        "example": ["pii", "ccn"],
                                                                        "items": {"type": "string"},
                                                                        "type": "array",
                                                                    },
                                                                },
                                                                "required": [
                                                                    "name",
                                                                    "tags",
                                                                    "pattern",
                                                                    "scope",
                                                                    "on_match",
                                                                ],
                                                                "type": "object",
                                                            },
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "sensitive_data_scanner",
                                                            "description": "The "
                                                            "processor "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`sensitive_data_scanner`.",
                                                            "enum": ["sensitive_data_scanner"],
                                                            "example": "sensitive_data_scanner",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "SENSITIVE_DATA_SCANNER"
                                                            ],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "include",
                                                        "inputs",
                                                        "rules",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`ocsf_mapper` "
                                                    "processor "
                                                    "transforms "
                                                    "logs "
                                                    "into "
                                                    "the "
                                                    "OCSF "
                                                    "schema "
                                                    "using "
                                                    "a "
                                                    "predefined "
                                                    "mapping "
                                                    "configuration.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline.",
                                                            "example": "ocsf-mapper-processor",
                                                            "type": "string",
                                                        },
                                                        "include": {
                                                            "description": "A "
                                                            "Datadog "
                                                            "search "
                                                            "query "
                                                            "used "
                                                            "to "
                                                            "determine "
                                                            "which "
                                                            "logs "
                                                            "this "
                                                            "processor "
                                                            "targets.",
                                                            "example": "service:my-service",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "processor.",
                                                            "example": ["filter-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "mappings": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "mapping "
                                                            "rules "
                                                            "to "
                                                            "convert "
                                                            "events "
                                                            "to "
                                                            "the "
                                                            "OCSF "
                                                            "format.",
                                                            "items": {
                                                                "description": "Defines "
                                                                "how "
                                                                "specific "
                                                                "events "
                                                                "are "
                                                                "transformed "
                                                                "to "
                                                                "OCSF "
                                                                "using "
                                                                "a "
                                                                "mapping "
                                                                "configuration.",
                                                                "properties": {
                                                                    "include": {
                                                                        "description": "A "
                                                                        "Datadog "
                                                                        "search "
                                                                        "query "
                                                                        "used "
                                                                        "to "
                                                                        "select "
                                                                        "the "
                                                                        "logs "
                                                                        "that "
                                                                        "this "
                                                                        "mapping "
                                                                        "should "
                                                                        "apply "
                                                                        "to.",
                                                                        "example": "service:my-service",
                                                                        "type": "string",
                                                                    },
                                                                    "mapping": {
                                                                        "description": "Defines "
                                                                        "a "
                                                                        "single "
                                                                        "mapping "
                                                                        "rule "
                                                                        "for "
                                                                        "transforming "
                                                                        "logs "
                                                                        "into "
                                                                        "the "
                                                                        "OCSF "
                                                                        "schema.",
                                                                        "oneOf": [
                                                                            {
                                                                                "description": "Predefined "
                                                                                "library "
                                                                                "mappings "
                                                                                "for "
                                                                                "common "
                                                                                "log "
                                                                                "formats.",
                                                                                "enum": [
                                                                                    "CloudTrail "
                                                                                    "Account "
                                                                                    "Change",
                                                                                    "GCP "
                                                                                    "Cloud "
                                                                                    "Audit "
                                                                                    "CreateBucket",
                                                                                    "GCP "
                                                                                    "Cloud "
                                                                                    "Audit "
                                                                                    "CreateSink",
                                                                                    "GCP "
                                                                                    "Cloud "
                                                                                    "Audit "
                                                                                    "SetIamPolicy",
                                                                                    "GCP "
                                                                                    "Cloud "
                                                                                    "Audit "
                                                                                    "UpdateSink",
                                                                                    "Github "
                                                                                    "Audit "
                                                                                    "Log "
                                                                                    "API "
                                                                                    "Activity",
                                                                                    "Google "
                                                                                    "Workspace "
                                                                                    "Admin "
                                                                                    "Audit "
                                                                                    "addPrivilege",
                                                                                    "Microsoft "
                                                                                    "365 "
                                                                                    "Defender "
                                                                                    "Incident",
                                                                                    "Microsoft "
                                                                                    "365 "
                                                                                    "Defender "
                                                                                    "UserLoggedIn",
                                                                                    "Okta "
                                                                                    "System "
                                                                                    "Log "
                                                                                    "Authentication",
                                                                                    "Palo "
                                                                                    "Alto "
                                                                                    "Networks "
                                                                                    "Firewall "
                                                                                    "Traffic",
                                                                                ],
                                                                                "example": "CloudTrail "
                                                                                "Account "
                                                                                "Change",
                                                                                "type": "string",
                                                                                "x-enum-varnames": [
                                                                                    "CLOUDTRAIL_ACCOUNT_CHANGE",
                                                                                    "GCP_CLOUD_AUDIT_CREATEBUCKET",
                                                                                    "GCP_CLOUD_AUDIT_CREATESINK",
                                                                                    "GCP_CLOUD_AUDIT_SETIAMPOLICY",
                                                                                    "GCP_CLOUD_AUDIT_UPDATESINK",
                                                                                    "GITHUB_AUDIT_LOG_API_ACTIVITY",
                                                                                    "GOOGLE_WORKSPACE_ADMIN_AUDIT_ADDPRIVILEGE",
                                                                                    "MICROSOFT_365_DEFENDER_INCIDENT",
                                                                                    "MICROSOFT_365_DEFENDER_USERLOGGEDIN",
                                                                                    "OKTA_SYSTEM_LOG_AUTHENTICATION",
                                                                                    "PALO_ALTO_NETWORKS_FIREWALL_TRAFFIC",
                                                                                ],
                                                                            }
                                                                        ],
                                                                    },
                                                                },
                                                                "required": ["include", "mapping"],
                                                                "type": "object",
                                                            },
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "ocsf_mapper",
                                                            "description": "The "
                                                            "processor "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`ocsf_mapper`.",
                                                            "enum": ["ocsf_mapper"],
                                                            "example": "ocsf_mapper",
                                                            "type": "string",
                                                            "x-enum-varnames": ["OCSF_MAPPER"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "include",
                                                        "inputs",
                                                        "mappings",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`add_env_vars` "
                                                    "processor "
                                                    "adds "
                                                    "environment "
                                                    "variable "
                                                    "values "
                                                    "to "
                                                    "log "
                                                    "events.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "processor "
                                                            "in "
                                                            "the "
                                                            "pipeline.",
                                                            "example": "add-env-vars-processor",
                                                            "type": "string",
                                                        },
                                                        "include": {
                                                            "description": "A "
                                                            "Datadog "
                                                            "search "
                                                            "query "
                                                            "used "
                                                            "to "
                                                            "determine "
                                                            "which "
                                                            "logs "
                                                            "this "
                                                            "processor "
                                                            "targets.",
                                                            "example": "service:my-service",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "input "
                                                            "for "
                                                            "this "
                                                            "processor.",
                                                            "example": ["datadog-agent-source"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "add_env_vars",
                                                            "description": "The "
                                                            "processor "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`add_env_vars`.",
                                                            "enum": ["add_env_vars"],
                                                            "example": "add_env_vars",
                                                            "type": "string",
                                                            "x-enum-varnames": ["ADD_ENV_VARS"],
                                                        },
                                                        "variables": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "environment "
                                                            "variable "
                                                            "mappings "
                                                            "to "
                                                            "apply "
                                                            "to "
                                                            "log "
                                                            "fields.",
                                                            "items": {
                                                                "description": "Defines "
                                                                "a "
                                                                "mapping "
                                                                "between "
                                                                "an "
                                                                "environment "
                                                                "variable "
                                                                "and "
                                                                "a "
                                                                "log "
                                                                "field.",
                                                                "properties": {
                                                                    "field": {
                                                                        "description": "The "
                                                                        "target "
                                                                        "field "
                                                                        "in "
                                                                        "the "
                                                                        "log "
                                                                        "event.",
                                                                        "example": "log.environment.region",
                                                                        "type": "string",
                                                                    },
                                                                    "name": {
                                                                        "description": "The "
                                                                        "name "
                                                                        "of "
                                                                        "the "
                                                                        "environment "
                                                                        "variable "
                                                                        "to "
                                                                        "read.",
                                                                        "example": "AWS_REGION",
                                                                        "type": "string",
                                                                    },
                                                                },
                                                                "required": ["field", "name"],
                                                                "type": "object",
                                                            },
                                                            "type": "array",
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "include",
                                                        "inputs",
                                                        "variables",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`dedupe` "
                                                    "processor "
                                                    "removes "
                                                    "duplicate "
                                                    "fields "
                                                    "in "
                                                    "log "
                                                    "events.",
                                                    "properties": {
                                                        "fields": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "log "
                                                            "field "
                                                            "paths "
                                                            "to "
                                                            "check "
                                                            "for "
                                                            "duplicates.",
                                                            "example": ["log.message", "log.error"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "processor.",
                                                            "example": "dedupe-processor",
                                                            "type": "string",
                                                        },
                                                        "include": {
                                                            "description": "A "
                                                            "Datadog "
                                                            "search "
                                                            "query "
                                                            "used "
                                                            "to "
                                                            "determine "
                                                            "which "
                                                            "logs "
                                                            "this "
                                                            "processor "
                                                            "targets.",
                                                            "example": "service:my-service",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "input "
                                                            "for "
                                                            "this "
                                                            "processor.",
                                                            "example": ["parse-json-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "mode": {
                                                            "description": "The "
                                                            "deduplication "
                                                            "mode "
                                                            "to "
                                                            "apply "
                                                            "to "
                                                            "the "
                                                            "fields.",
                                                            "enum": ["match", "ignore"],
                                                            "example": "match",
                                                            "type": "string",
                                                            "x-enum-varnames": ["MATCH", "IGNORE"],
                                                        },
                                                        "type": {
                                                            "default": "dedupe",
                                                            "description": "The "
                                                            "processor "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`dedupe`.",
                                                            "enum": ["dedupe"],
                                                            "example": "dedupe",
                                                            "type": "string",
                                                            "x-enum-varnames": ["DEDUPE"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "include",
                                                        "inputs",
                                                        "fields",
                                                        "mode",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`enrichment_table` "
                                                    "processor "
                                                    "enriches "
                                                    "logs "
                                                    "using "
                                                    "a "
                                                    "static "
                                                    "CSV "
                                                    "file "
                                                    "or "
                                                    "GeoIP "
                                                    "database.",
                                                    "properties": {
                                                        "file": {
                                                            "description": "Defines "
                                                            "a "
                                                            "static "
                                                            "enrichment "
                                                            "table "
                                                            "loaded "
                                                            "from "
                                                            "a "
                                                            "CSV "
                                                            "file.",
                                                            "properties": {
                                                                "encoding": {
                                                                    "description": "File "
                                                                    "encoding "
                                                                    "format.",
                                                                    "properties": {
                                                                        "delimiter": {
                                                                            "description": "The "
                                                                            "`encoding` "
                                                                            "`delimiter`.",
                                                                            "example": ",",
                                                                            "type": "string",
                                                                        },
                                                                        "includes_headers": {
                                                                            "description": "The "
                                                                            "`encoding` "
                                                                            "`includes_headers`.",
                                                                            "example": True,
                                                                            "type": "boolean",
                                                                        },
                                                                        "type": {
                                                                            "description": "Specifies "
                                                                            "the "
                                                                            "encoding "
                                                                            "format "
                                                                            "(e.g., "
                                                                            "CSV) "
                                                                            "used "
                                                                            "for "
                                                                            "enrichment "
                                                                            "tables.",
                                                                            "enum": ["csv"],
                                                                            "example": "csv",
                                                                            "type": "string",
                                                                            "x-enum-varnames": [
                                                                                "CSV"
                                                                            ],
                                                                        },
                                                                    },
                                                                    "required": [
                                                                        "type",
                                                                        "delimiter",
                                                                        "includes_headers",
                                                                    ],
                                                                    "type": "object",
                                                                },
                                                                "key": {
                                                                    "description": "Key "
                                                                    "fields "
                                                                    "used "
                                                                    "to "
                                                                    "look "
                                                                    "up "
                                                                    "enrichment "
                                                                    "values.",
                                                                    "items": {
                                                                        "description": "Defines "
                                                                        "how "
                                                                        "to "
                                                                        "map "
                                                                        "log "
                                                                        "fields "
                                                                        "to "
                                                                        "enrichment "
                                                                        "table "
                                                                        "columns "
                                                                        "during "
                                                                        "lookups.",
                                                                        "properties": {
                                                                            "column": {
                                                                                "description": "The "
                                                                                "`items` "
                                                                                "`column`.",
                                                                                "example": "user_id",
                                                                                "type": "string",
                                                                            },
                                                                            "comparison": {
                                                                                "description": "Defines "
                                                                                "how "
                                                                                "to "
                                                                                "compare "
                                                                                "key "
                                                                                "fields "
                                                                                "for "
                                                                                "enrichment "
                                                                                "table "
                                                                                "lookups.",
                                                                                "enum": ["equals"],
                                                                                "example": "equals",
                                                                                "type": "string",
                                                                                "x-enum-varnames": [
                                                                                    "EQUALS"
                                                                                ],
                                                                            },
                                                                            "field": {
                                                                                "description": "The "
                                                                                "`items` "
                                                                                "`field`.",
                                                                                "example": "log.user.id",
                                                                                "type": "string",
                                                                            },
                                                                        },
                                                                        "required": [
                                                                            "column",
                                                                            "comparison",
                                                                            "field",
                                                                        ],
                                                                        "type": "object",
                                                                    },
                                                                    "type": "array",
                                                                },
                                                                "path": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "CSV "
                                                                    "file.",
                                                                    "example": "/etc/enrichment/lookup.csv",
                                                                    "type": "string",
                                                                },
                                                                "schema": {
                                                                    "description": "Schema "
                                                                    "defining "
                                                                    "column "
                                                                    "names "
                                                                    "and "
                                                                    "their "
                                                                    "types.",
                                                                    "items": {
                                                                        "description": "Describes "
                                                                        "a "
                                                                        "single "
                                                                        "column "
                                                                        "and "
                                                                        "its "
                                                                        "type "
                                                                        "in "
                                                                        "an "
                                                                        "enrichment "
                                                                        "table "
                                                                        "schema.",
                                                                        "properties": {
                                                                            "column": {
                                                                                "description": "The "
                                                                                "`items` "
                                                                                "`column`.",
                                                                                "example": "region",
                                                                                "type": "string",
                                                                            },
                                                                            "type": {
                                                                                "description": "Declares "
                                                                                "allowed "
                                                                                "data "
                                                                                "types "
                                                                                "for "
                                                                                "enrichment "
                                                                                "table "
                                                                                "columns.",
                                                                                "enum": [
                                                                                    "string",
                                                                                    "boolean",
                                                                                    "integer",
                                                                                    "float",
                                                                                    "date",
                                                                                    "timestamp",
                                                                                ],
                                                                                "example": "string",
                                                                                "type": "string",
                                                                                "x-enum-varnames": [
                                                                                    "STRING",
                                                                                    "BOOLEAN",
                                                                                    "INTEGER",
                                                                                    "FLOAT",
                                                                                    "DATE",
                                                                                    "TIMESTAMP",
                                                                                ],
                                                                            },
                                                                        },
                                                                        "required": [
                                                                            "column",
                                                                            "type",
                                                                        ],
                                                                        "type": "object",
                                                                    },
                                                                    "type": "array",
                                                                },
                                                            },
                                                            "required": [
                                                                "encoding",
                                                                "key",
                                                                "path",
                                                                "schema",
                                                            ],
                                                            "type": "object",
                                                        },
                                                        "geoip": {
                                                            "description": "Uses "
                                                            "a "
                                                            "GeoIP "
                                                            "database "
                                                            "to "
                                                            "enrich "
                                                            "logs "
                                                            "based "
                                                            "on "
                                                            "an "
                                                            "IP "
                                                            "field.",
                                                            "properties": {
                                                                "key_field": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "IP "
                                                                    "field "
                                                                    "in "
                                                                    "the "
                                                                    "log.",
                                                                    "example": "log.source.ip",
                                                                    "type": "string",
                                                                },
                                                                "locale": {
                                                                    "description": "Locale "
                                                                    "used "
                                                                    "to "
                                                                    "resolve "
                                                                    "geographical "
                                                                    "names.",
                                                                    "example": "en",
                                                                    "type": "string",
                                                                },
                                                                "path": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "GeoIP "
                                                                    "database "
                                                                    "file.",
                                                                    "example": "/etc/geoip/GeoLite2-City.mmdb",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": [
                                                                "key_field",
                                                                "locale",
                                                                "path",
                                                            ],
                                                            "type": "object",
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "processor.",
                                                            "example": "enrichment-table-processor",
                                                            "type": "string",
                                                        },
                                                        "include": {
                                                            "description": "A "
                                                            "Datadog "
                                                            "search "
                                                            "query "
                                                            "used "
                                                            "to "
                                                            "determine "
                                                            "which "
                                                            "logs "
                                                            "this "
                                                            "processor "
                                                            "targets.",
                                                            "example": "source:my-source",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "input "
                                                            "for "
                                                            "this "
                                                            "processor.",
                                                            "example": ["add-fields-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "target": {
                                                            "description": "Path "
                                                            "where "
                                                            "enrichment "
                                                            "results "
                                                            "should "
                                                            "be "
                                                            "stored "
                                                            "in "
                                                            "the "
                                                            "log.",
                                                            "example": "enriched.geoip",
                                                            "type": "string",
                                                        },
                                                        "type": {
                                                            "default": "enrichment_table",
                                                            "description": "The "
                                                            "processor "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`enrichment_table`.",
                                                            "enum": ["enrichment_table"],
                                                            "example": "enrichment_table",
                                                            "type": "string",
                                                            "x-enum-varnames": ["ENRICHMENT_TABLE"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "include",
                                                        "inputs",
                                                        "target",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`reduce` "
                                                    "processor "
                                                    "aggregates "
                                                    "and "
                                                    "merges "
                                                    "logs "
                                                    "based "
                                                    "on "
                                                    "matching "
                                                    "keys "
                                                    "and "
                                                    "merge "
                                                    "strategies.",
                                                    "properties": {
                                                        "group_by": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "fields "
                                                            "used "
                                                            "to "
                                                            "group "
                                                            "log "
                                                            "events "
                                                            "for "
                                                            "merging.",
                                                            "example": [
                                                                "log.user.id",
                                                                "log.device.id",
                                                            ],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "processor.",
                                                            "example": "reduce-processor",
                                                            "type": "string",
                                                        },
                                                        "include": {
                                                            "description": "A "
                                                            "Datadog "
                                                            "search "
                                                            "query "
                                                            "used "
                                                            "to "
                                                            "determine "
                                                            "which "
                                                            "logs "
                                                            "this "
                                                            "processor "
                                                            "targets.",
                                                            "example": "env:prod",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "input "
                                                            "for "
                                                            "this "
                                                            "processor.",
                                                            "example": ["parse-json-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "merge_strategies": {
                                                            "description": "List "
                                                            "of "
                                                            "merge "
                                                            "strategies "
                                                            "defining "
                                                            "how "
                                                            "values "
                                                            "from "
                                                            "grouped "
                                                            "events "
                                                            "should "
                                                            "be "
                                                            "combined.",
                                                            "items": {
                                                                "description": "Defines "
                                                                "how "
                                                                "a "
                                                                "specific "
                                                                "field "
                                                                "should "
                                                                "be "
                                                                "merged "
                                                                "across "
                                                                "grouped "
                                                                "events.",
                                                                "properties": {
                                                                    "path": {
                                                                        "description": "The "
                                                                        "field "
                                                                        "path "
                                                                        "in "
                                                                        "the "
                                                                        "log "
                                                                        "event.",
                                                                        "example": "log.user.roles",
                                                                        "type": "string",
                                                                    },
                                                                    "strategy": {
                                                                        "description": "The "
                                                                        "merge "
                                                                        "strategy "
                                                                        "to "
                                                                        "apply.",
                                                                        "enum": [
                                                                            "discard",
                                                                            "retain",
                                                                            "sum",
                                                                            "max",
                                                                            "min",
                                                                            "array",
                                                                            "concat",
                                                                            "concat_newline",
                                                                            "concat_raw",
                                                                            "shortest_array",
                                                                            "longest_array",
                                                                            "flat_unique",
                                                                        ],
                                                                        "example": "flat_unique",
                                                                        "type": "string",
                                                                        "x-enum-varnames": [
                                                                            "DISCARD",
                                                                            "RETAIN",
                                                                            "SUM",
                                                                            "MAX",
                                                                            "MIN",
                                                                            "ARRAY",
                                                                            "CONCAT",
                                                                            "CONCAT_NEWLINE",
                                                                            "CONCAT_RAW",
                                                                            "SHORTEST_ARRAY",
                                                                            "LONGEST_ARRAY",
                                                                            "FLAT_UNIQUE",
                                                                        ],
                                                                    },
                                                                },
                                                                "required": ["path", "strategy"],
                                                                "type": "object",
                                                            },
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "reduce",
                                                            "description": "The "
                                                            "processor "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`reduce`.",
                                                            "enum": ["reduce"],
                                                            "example": "reduce",
                                                            "type": "string",
                                                            "x-enum-varnames": ["REDUCE"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "include",
                                                        "inputs",
                                                        "group_by",
                                                        "merge_strategies",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`throttle` "
                                                    "processor "
                                                    "limits "
                                                    "the "
                                                    "number "
                                                    "of "
                                                    "events "
                                                    "that "
                                                    "pass "
                                                    "through "
                                                    "over "
                                                    "a "
                                                    "given "
                                                    "time "
                                                    "window.",
                                                    "properties": {
                                                        "group_by": {
                                                            "description": "Optional "
                                                            "list "
                                                            "of "
                                                            "fields "
                                                            "used "
                                                            "to "
                                                            "group "
                                                            "events "
                                                            "before "
                                                            "the "
                                                            "threshold "
                                                            "has "
                                                            "been "
                                                            "reached.",
                                                            "example": ["log.user.id"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "processor.",
                                                            "example": "throttle-processor",
                                                            "type": "string",
                                                        },
                                                        "include": {
                                                            "description": "A "
                                                            "Datadog "
                                                            "search "
                                                            "query "
                                                            "used "
                                                            "to "
                                                            "determine "
                                                            "which "
                                                            "logs "
                                                            "this "
                                                            "processor "
                                                            "targets.",
                                                            "example": "env:prod",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "input "
                                                            "for "
                                                            "this "
                                                            "processor.",
                                                            "example": ["datadog-agent-source"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "threshold": {
                                                            "description": "the "
                                                            "number "
                                                            "of "
                                                            "events "
                                                            "allowed "
                                                            "in "
                                                            "a "
                                                            "given "
                                                            "time "
                                                            "window. "
                                                            "Events "
                                                            "sent "
                                                            "after "
                                                            "the "
                                                            "threshold "
                                                            "has "
                                                            "been "
                                                            "reached, "
                                                            "are "
                                                            "dropped.",
                                                            "example": 1000,
                                                            "format": "int64",
                                                            "type": "integer",
                                                        },
                                                        "type": {
                                                            "default": "throttle",
                                                            "description": "The "
                                                            "processor "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`throttle`.",
                                                            "enum": ["throttle"],
                                                            "example": "throttle",
                                                            "type": "string",
                                                            "x-enum-varnames": ["THROTTLE"],
                                                        },
                                                        "window": {
                                                            "description": "The "
                                                            "time "
                                                            "window "
                                                            "in "
                                                            "seconds "
                                                            "over "
                                                            "which "
                                                            "the "
                                                            "threshold "
                                                            "applies.",
                                                            "example": 60.0,
                                                            "format": "double",
                                                            "type": "number",
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "include",
                                                        "inputs",
                                                        "threshold",
                                                        "window",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`custom_processor` "
                                                    "processor "
                                                    "transforms "
                                                    "events "
                                                    "using "
                                                    "[Vector "
                                                    "Remap "
                                                    "Language "
                                                    "(VRL)](https://vector.dev/docs/reference/vrl/) "
                                                    "scripts "
                                                    "with "
                                                    "advanced "
                                                    "filtering "
                                                    "capabilities.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "processor.",
                                                            "example": "remap-vrl-processor",
                                                            "type": "string",
                                                        },
                                                        "include": {
                                                            "default": "*",
                                                            "description": "A "
                                                            "Datadog "
                                                            "search "
                                                            "query "
                                                            "used "
                                                            "to "
                                                            "determine "
                                                            "which "
                                                            "logs "
                                                            "this "
                                                            "processor "
                                                            "targets. "
                                                            "This "
                                                            "field "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "set "
                                                            "to "
                                                            "`*` "
                                                            "for "
                                                            "the "
                                                            "custom_processor "
                                                            "processor.",
                                                            "example": "*",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "input "
                                                            "for "
                                                            "this "
                                                            "processor.",
                                                            "example": ["datadog-agent-source"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "remaps": {
                                                            "description": "Array "
                                                            "of "
                                                            "VRL "
                                                            "remap "
                                                            "rules.",
                                                            "items": {
                                                                "description": "Defines "
                                                                "a "
                                                                "single "
                                                                "VRL "
                                                                "remap "
                                                                "rule "
                                                                "with "
                                                                "its "
                                                                "own "
                                                                "filtering "
                                                                "and "
                                                                "transformation "
                                                                "logic.",
                                                                "properties": {
                                                                    "drop_on_error": {
                                                                        "description": "Whether "
                                                                        "to "
                                                                        "drop "
                                                                        "events "
                                                                        "that "
                                                                        "caused "
                                                                        "errors "
                                                                        "during "
                                                                        "processing.",
                                                                        "example": False,
                                                                        "type": "boolean",
                                                                    },
                                                                    "enabled": {
                                                                        "description": "Whether "
                                                                        "this "
                                                                        "remap "
                                                                        "rule "
                                                                        "is "
                                                                        "enabled.",
                                                                        "example": True,
                                                                        "type": "boolean",
                                                                    },
                                                                    "include": {
                                                                        "description": "A "
                                                                        "Datadog "
                                                                        "search "
                                                                        "query "
                                                                        "used "
                                                                        "to "
                                                                        "filter "
                                                                        "events "
                                                                        "for "
                                                                        "this "
                                                                        "specific "
                                                                        "remap "
                                                                        "rule.",
                                                                        "example": "service:web",
                                                                        "type": "string",
                                                                    },
                                                                    "name": {
                                                                        "description": "A "
                                                                        "descriptive "
                                                                        "name "
                                                                        "for "
                                                                        "this "
                                                                        "remap "
                                                                        "rule.",
                                                                        "example": "Parse "
                                                                        "JSON "
                                                                        "from "
                                                                        "message "
                                                                        "field",
                                                                        "type": "string",
                                                                    },
                                                                    "source": {
                                                                        "description": "The "
                                                                        "VRL "
                                                                        "script "
                                                                        "source "
                                                                        "code "
                                                                        "that "
                                                                        "defines "
                                                                        "the "
                                                                        "processing "
                                                                        "logic.",
                                                                        "example": ". "
                                                                        "= "
                                                                        "parse_json!(.message)",
                                                                        "type": "string",
                                                                    },
                                                                },
                                                                "required": [
                                                                    "include",
                                                                    "name",
                                                                    "source",
                                                                    "enabled",
                                                                    "drop_on_error",
                                                                ],
                                                                "type": "object",
                                                            },
                                                            "minItems": 1,
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "custom_processor",
                                                            "description": "The "
                                                            "processor "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`custom_processor`.",
                                                            "enum": ["custom_processor"],
                                                            "example": "custom_processor",
                                                            "type": "string",
                                                            "x-enum-varnames": ["CUSTOM_PROCESSOR"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "include",
                                                        "remaps",
                                                        "inputs",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`datadog_tags` "
                                                    "processor "
                                                    "includes "
                                                    "or "
                                                    "excludes "
                                                    "specific "
                                                    "Datadog "
                                                    "tags "
                                                    "in "
                                                    "your "
                                                    "logs.",
                                                    "properties": {
                                                        "action": {
                                                            "description": "The "
                                                            "action "
                                                            "to "
                                                            "take "
                                                            "on "
                                                            "tags "
                                                            "with "
                                                            "matching "
                                                            "keys.",
                                                            "enum": ["include", "exclude"],
                                                            "example": "include",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "INCLUDE",
                                                                "EXCLUDE",
                                                            ],
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(for "
                                                            "example, "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "datadog-tags-processor",
                                                            "type": "string",
                                                        },
                                                        "include": {
                                                            "description": "A "
                                                            "Datadog "
                                                            "search "
                                                            "query "
                                                            "used "
                                                            "to "
                                                            "determine "
                                                            "which "
                                                            "logs "
                                                            "this "
                                                            "processor "
                                                            "targets.",
                                                            "example": "service:my-service",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["datadog-agent-source"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "keys": {
                                                            "description": "A list of tag keys.",
                                                            "example": [
                                                                "env",
                                                                "service",
                                                                "version",
                                                            ],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "mode": {
                                                            "description": "The processing mode.",
                                                            "enum": ["filter"],
                                                            "example": "filter",
                                                            "type": "string",
                                                            "x-enum-varnames": ["FILTER"],
                                                        },
                                                        "type": {
                                                            "default": "datadog_tags",
                                                            "description": "The "
                                                            "processor "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`datadog_tags`.",
                                                            "enum": ["datadog_tags"],
                                                            "example": "datadog_tags",
                                                            "type": "string",
                                                            "x-enum-varnames": ["DATADOG_TAGS"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "include",
                                                        "mode",
                                                        "action",
                                                        "keys",
                                                        "inputs",
                                                    ],
                                                    "type": "object",
                                                },
                                            ],
                                        },
                                        "type": "array",
                                    },
                                    "sources": {
                                        "description": "A "
                                        "list "
                                        "of "
                                        "configured "
                                        "data "
                                        "sources "
                                        "for "
                                        "the "
                                        "pipeline.",
                                        "example": [
                                            {"id": "datadog-agent-source", "type": "datadog_agent"}
                                        ],
                                        "items": {
                                            "description": "A data source for the pipeline.",
                                            "oneOf": [
                                                {
                                                    "description": "The "
                                                    "`kafka` "
                                                    "source "
                                                    "ingests "
                                                    "data "
                                                    "from "
                                                    "Apache "
                                                    "Kafka "
                                                    "topics.",
                                                    "properties": {
                                                        "group_id": {
                                                            "description": "Consumer "
                                                            "group "
                                                            "ID "
                                                            "used "
                                                            "by "
                                                            "the "
                                                            "Kafka "
                                                            "client.",
                                                            "example": "consumer-group-0",
                                                            "type": "string",
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(e.g., "
                                                            "as "
                                                            "input "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "kafka-source",
                                                            "type": "string",
                                                        },
                                                        "librdkafka_options": {
                                                            "description": "Optional "
                                                            "list "
                                                            "of "
                                                            "advanced "
                                                            "Kafka "
                                                            "client "
                                                            "configuration "
                                                            "options, "
                                                            "defined "
                                                            "as "
                                                            "key-value "
                                                            "pairs.",
                                                            "items": {
                                                                "description": "Represents "
                                                                "a "
                                                                "key-value "
                                                                "pair "
                                                                "used "
                                                                "to "
                                                                "configure "
                                                                "low-level "
                                                                "`librdkafka` "
                                                                "client "
                                                                "options "
                                                                "for "
                                                                "Kafka "
                                                                "sources, "
                                                                "such "
                                                                "as "
                                                                "timeouts, "
                                                                "buffer "
                                                                "sizes, "
                                                                "and "
                                                                "security "
                                                                "settings.",
                                                                "properties": {
                                                                    "name": {
                                                                        "description": "The "
                                                                        "name "
                                                                        "of "
                                                                        "the "
                                                                        "`librdkafka` "
                                                                        "configuration "
                                                                        "option "
                                                                        "to "
                                                                        "set.",
                                                                        "example": "fetch.message.max.bytes",
                                                                        "type": "string",
                                                                    },
                                                                    "value": {
                                                                        "description": "The "
                                                                        "value "
                                                                        "assigned "
                                                                        "to "
                                                                        "the "
                                                                        "specified "
                                                                        "`librdkafka` "
                                                                        "configuration "
                                                                        "option.",
                                                                        "example": "1048576",
                                                                        "type": "string",
                                                                    },
                                                                },
                                                                "required": ["name", "value"],
                                                                "type": "object",
                                                            },
                                                            "type": "array",
                                                        },
                                                        "sasl": {
                                                            "description": "Specifies "
                                                            "the "
                                                            "SASL "
                                                            "mechanism "
                                                            "for "
                                                            "authenticating "
                                                            "with "
                                                            "a "
                                                            "Kafka "
                                                            "cluster.",
                                                            "properties": {
                                                                "mechanism": {
                                                                    "description": "SASL "
                                                                    "mechanism "
                                                                    "used "
                                                                    "for "
                                                                    "Kafka "
                                                                    "authentication.",
                                                                    "enum": [
                                                                        "PLAIN",
                                                                        "SCRAM-SHA-256",
                                                                        "SCRAM-SHA-512",
                                                                    ],
                                                                    "type": "string",
                                                                    "x-enum-varnames": [
                                                                        "PLAIN",
                                                                        "SCRAMNOT_SHANOT_256",
                                                                        "SCRAMNOT_SHANOT_512",
                                                                    ],
                                                                }
                                                            },
                                                            "type": "object",
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "topics": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "Kafka "
                                                            "topic "
                                                            "names "
                                                            "to "
                                                            "subscribe "
                                                            "to. "
                                                            "The "
                                                            "source "
                                                            "ingests "
                                                            "messages "
                                                            "from "
                                                            "each "
                                                            "topic "
                                                            "specified.",
                                                            "example": ["topic1", "topic2"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "kafka",
                                                            "description": "The "
                                                            "source "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`kafka`.",
                                                            "enum": ["kafka"],
                                                            "example": "kafka",
                                                            "type": "string",
                                                            "x-enum-varnames": ["KAFKA"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "group_id",
                                                        "topics",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`datadog_agent` "
                                                    "source "
                                                    "collects "
                                                    "logs "
                                                    "from "
                                                    "the "
                                                    "Datadog "
                                                    "Agent.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(e.g., "
                                                            "as "
                                                            "input "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "datadog-agent-source",
                                                            "type": "string",
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "datadog_agent",
                                                            "description": "The "
                                                            "source "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`datadog_agent`.",
                                                            "enum": ["datadog_agent"],
                                                            "example": "datadog_agent",
                                                            "type": "string",
                                                            "x-enum-varnames": ["DATADOG_AGENT"],
                                                        },
                                                    },
                                                    "required": ["id", "type"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`splunk_tcp` "
                                                    "source "
                                                    "receives "
                                                    "logs "
                                                    "from "
                                                    "a "
                                                    "Splunk "
                                                    "Universal "
                                                    "Forwarder "
                                                    "over "
                                                    "TCP.\n"
                                                    "TLS "
                                                    "is "
                                                    "supported "
                                                    "for "
                                                    "secure "
                                                    "transmission.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(e.g., "
                                                            "as "
                                                            "input "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "splunk-tcp-source",
                                                            "type": "string",
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "splunk_tcp",
                                                            "description": "The "
                                                            "source "
                                                            "type. "
                                                            "Always "
                                                            "`splunk_tcp`.",
                                                            "enum": ["splunk_tcp"],
                                                            "example": "splunk_tcp",
                                                            "type": "string",
                                                            "x-enum-varnames": ["SPLUNK_TCP"],
                                                        },
                                                    },
                                                    "required": ["id", "type"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`splunk_hec` "
                                                    "source "
                                                    "implements "
                                                    "the "
                                                    "Splunk "
                                                    "HTTP "
                                                    "Event "
                                                    "Collector "
                                                    "(HEC) "
                                                    "API.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(e.g., "
                                                            "as "
                                                            "input "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "splunk-hec-source",
                                                            "type": "string",
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "splunk_hec",
                                                            "description": "The "
                                                            "source "
                                                            "type. "
                                                            "Always "
                                                            "`splunk_hec`.",
                                                            "enum": ["splunk_hec"],
                                                            "example": "splunk_hec",
                                                            "type": "string",
                                                            "x-enum-varnames": ["SPLUNK_HEC"],
                                                        },
                                                    },
                                                    "required": ["id", "type"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`amazon_s3` "
                                                    "source "
                                                    "ingests "
                                                    "logs "
                                                    "from "
                                                    "an "
                                                    "Amazon "
                                                    "S3 "
                                                    "bucket.\n"
                                                    "It "
                                                    "supports "
                                                    "AWS "
                                                    "authentication "
                                                    "and "
                                                    "TLS "
                                                    "encryption.",
                                                    "properties": {
                                                        "auth": {
                                                            "description": "AWS "
                                                            "authentication "
                                                            "credentials "
                                                            "used "
                                                            "for "
                                                            "accessing "
                                                            "AWS "
                                                            "services "
                                                            "such "
                                                            "as "
                                                            "S3.\n"
                                                            "If "
                                                            "omitted, "
                                                            "the "
                                                            "system’s "
                                                            "default "
                                                            "credentials "
                                                            "are "
                                                            "used "
                                                            "(for "
                                                            "example, "
                                                            "the "
                                                            "IAM "
                                                            "role "
                                                            "and "
                                                            "environment "
                                                            "variables).",
                                                            "properties": {
                                                                "assume_role": {
                                                                    "description": "The "
                                                                    "Amazon "
                                                                    "Resource "
                                                                    "Name "
                                                                    "(ARN) "
                                                                    "of "
                                                                    "the "
                                                                    "role "
                                                                    "to "
                                                                    "assume.",
                                                                    "type": "string",
                                                                },
                                                                "external_id": {
                                                                    "description": "A "
                                                                    "unique "
                                                                    "identifier "
                                                                    "for "
                                                                    "cross-account "
                                                                    "role "
                                                                    "assumption.",
                                                                    "type": "string",
                                                                },
                                                                "session_name": {
                                                                    "description": "A "
                                                                    "session "
                                                                    "identifier "
                                                                    "used "
                                                                    "for "
                                                                    "logging "
                                                                    "and "
                                                                    "tracing "
                                                                    "the "
                                                                    "assumed "
                                                                    "role "
                                                                    "session.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "type": "object",
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(e.g., "
                                                            "as "
                                                            "input "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "aws-s3-source",
                                                            "type": "string",
                                                        },
                                                        "region": {
                                                            "description": "AWS "
                                                            "region "
                                                            "where "
                                                            "the "
                                                            "S3 "
                                                            "bucket "
                                                            "resides.",
                                                            "example": "us-east-1",
                                                            "type": "string",
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "amazon_s3",
                                                            "description": "The "
                                                            "source "
                                                            "type. "
                                                            "Always "
                                                            "`amazon_s3`.",
                                                            "enum": ["amazon_s3"],
                                                            "example": "amazon_s3",
                                                            "type": "string",
                                                            "x-enum-varnames": ["AMAZON_S3"],
                                                        },
                                                    },
                                                    "required": ["id", "type", "region"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`fluentd` "
                                                    "source "
                                                    "ingests "
                                                    "logs "
                                                    "from "
                                                    "a "
                                                    "Fluentd-compatible "
                                                    "service.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(for "
                                                            "example, "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "fluent-source",
                                                            "type": "string",
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "fluentd",
                                                            "description": "The "
                                                            "source "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`fluentd.",
                                                            "enum": ["fluentd"],
                                                            "example": "fluentd",
                                                            "type": "string",
                                                            "x-enum-varnames": ["FLUENTD"],
                                                        },
                                                    },
                                                    "required": ["id", "type"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`fluent_bit` "
                                                    "source "
                                                    "ingests "
                                                    "logs "
                                                    "from "
                                                    "Fluent "
                                                    "Bit.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(for "
                                                            "example, "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "fluent-source",
                                                            "type": "string",
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "fluent_bit",
                                                            "description": "The "
                                                            "source "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`fluent_bit`.",
                                                            "enum": ["fluent_bit"],
                                                            "example": "fluent_bit",
                                                            "type": "string",
                                                            "x-enum-varnames": ["FLUENT_BIT"],
                                                        },
                                                    },
                                                    "required": ["id", "type"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`http_server` "
                                                    "source "
                                                    "collects "
                                                    "logs "
                                                    "over "
                                                    "HTTP "
                                                    "POST "
                                                    "from "
                                                    "external "
                                                    "services.",
                                                    "properties": {
                                                        "auth_strategy": {
                                                            "description": "HTTP "
                                                            "authentication "
                                                            "method.",
                                                            "enum": ["none", "plain"],
                                                            "example": "plain",
                                                            "type": "string",
                                                            "x-enum-varnames": ["NONE", "PLAIN"],
                                                        },
                                                        "decoding": {
                                                            "description": "The "
                                                            "decoding "
                                                            "format "
                                                            "used "
                                                            "to "
                                                            "interpret "
                                                            "incoming "
                                                            "logs.",
                                                            "enum": [
                                                                "bytes",
                                                                "gelf",
                                                                "json",
                                                                "syslog",
                                                            ],
                                                            "example": "json",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "DECODE_BYTES",
                                                                "DECODE_GELF",
                                                                "DECODE_JSON",
                                                                "DECODE_SYSLOG",
                                                            ],
                                                        },
                                                        "id": {
                                                            "description": "Unique "
                                                            "ID "
                                                            "for "
                                                            "the "
                                                            "HTTP "
                                                            "server "
                                                            "source.",
                                                            "example": "http-server-source",
                                                            "type": "string",
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "http_server",
                                                            "description": "The "
                                                            "source "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`http_server`.",
                                                            "enum": ["http_server"],
                                                            "example": "http_server",
                                                            "type": "string",
                                                            "x-enum-varnames": ["HTTP_SERVER"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "auth_strategy",
                                                        "decoding",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`sumo_logic` "
                                                    "source "
                                                    "receives "
                                                    "logs "
                                                    "from "
                                                    "Sumo "
                                                    "Logic "
                                                    "collectors.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(e.g., "
                                                            "as "
                                                            "input "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "sumo-logic-source",
                                                            "type": "string",
                                                        },
                                                        "type": {
                                                            "default": "sumo_logic",
                                                            "description": "The "
                                                            "source "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`sumo_logic`.",
                                                            "enum": ["sumo_logic"],
                                                            "example": "sumo_logic",
                                                            "type": "string",
                                                            "x-enum-varnames": ["SUMO_LOGIC"],
                                                        },
                                                    },
                                                    "required": ["id", "type"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`rsyslog` "
                                                    "source "
                                                    "listens "
                                                    "for "
                                                    "logs "
                                                    "over "
                                                    "TCP "
                                                    "or "
                                                    "UDP "
                                                    "from "
                                                    "an "
                                                    "`rsyslog` "
                                                    "server "
                                                    "using "
                                                    "the "
                                                    "syslog "
                                                    "protocol.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(e.g., "
                                                            "as "
                                                            "input "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "rsyslog-source",
                                                            "type": "string",
                                                        },
                                                        "mode": {
                                                            "description": "Protocol "
                                                            "used "
                                                            "by "
                                                            "the "
                                                            "syslog "
                                                            "source "
                                                            "to "
                                                            "receive "
                                                            "messages.",
                                                            "enum": ["tcp", "udp"],
                                                            "example": "tcp",
                                                            "type": "string",
                                                            "x-enum-varnames": ["TCP", "UDP"],
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "rsyslog",
                                                            "description": "The "
                                                            "source "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`rsyslog`.",
                                                            "enum": ["rsyslog"],
                                                            "example": "rsyslog",
                                                            "type": "string",
                                                            "x-enum-varnames": ["RSYSLOG"],
                                                        },
                                                    },
                                                    "required": ["id", "type", "mode"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`syslog_ng` "
                                                    "source "
                                                    "listens "
                                                    "for "
                                                    "logs "
                                                    "over "
                                                    "TCP "
                                                    "or "
                                                    "UDP "
                                                    "from "
                                                    "a "
                                                    "`syslog-ng` "
                                                    "server "
                                                    "using "
                                                    "the "
                                                    "syslog "
                                                    "protocol.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(e.g., "
                                                            "as "
                                                            "input "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "syslog-ng-source",
                                                            "type": "string",
                                                        },
                                                        "mode": {
                                                            "description": "Protocol "
                                                            "used "
                                                            "by "
                                                            "the "
                                                            "syslog "
                                                            "source "
                                                            "to "
                                                            "receive "
                                                            "messages.",
                                                            "enum": ["tcp", "udp"],
                                                            "example": "tcp",
                                                            "type": "string",
                                                            "x-enum-varnames": ["TCP", "UDP"],
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "syslog_ng",
                                                            "description": "The "
                                                            "source "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`syslog_ng`.",
                                                            "enum": ["syslog_ng"],
                                                            "example": "syslog_ng",
                                                            "type": "string",
                                                            "x-enum-varnames": ["SYSLOG_NG"],
                                                        },
                                                    },
                                                    "required": ["id", "type", "mode"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`amazon_data_firehose` "
                                                    "source "
                                                    "ingests "
                                                    "logs "
                                                    "from "
                                                    "AWS "
                                                    "Data "
                                                    "Firehose.",
                                                    "properties": {
                                                        "auth": {
                                                            "description": "AWS "
                                                            "authentication "
                                                            "credentials "
                                                            "used "
                                                            "for "
                                                            "accessing "
                                                            "AWS "
                                                            "services "
                                                            "such "
                                                            "as "
                                                            "S3.\n"
                                                            "If "
                                                            "omitted, "
                                                            "the "
                                                            "system’s "
                                                            "default "
                                                            "credentials "
                                                            "are "
                                                            "used "
                                                            "(for "
                                                            "example, "
                                                            "the "
                                                            "IAM "
                                                            "role "
                                                            "and "
                                                            "environment "
                                                            "variables).",
                                                            "properties": {
                                                                "assume_role": {
                                                                    "description": "The "
                                                                    "Amazon "
                                                                    "Resource "
                                                                    "Name "
                                                                    "(ARN) "
                                                                    "of "
                                                                    "the "
                                                                    "role "
                                                                    "to "
                                                                    "assume.",
                                                                    "type": "string",
                                                                },
                                                                "external_id": {
                                                                    "description": "A "
                                                                    "unique "
                                                                    "identifier "
                                                                    "for "
                                                                    "cross-account "
                                                                    "role "
                                                                    "assumption.",
                                                                    "type": "string",
                                                                },
                                                                "session_name": {
                                                                    "description": "A "
                                                                    "session "
                                                                    "identifier "
                                                                    "used "
                                                                    "for "
                                                                    "logging "
                                                                    "and "
                                                                    "tracing "
                                                                    "the "
                                                                    "assumed "
                                                                    "role "
                                                                    "session.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "type": "object",
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(e.g., "
                                                            "as "
                                                            "input "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "amazon-firehose-source",
                                                            "type": "string",
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "amazon_data_firehose",
                                                            "description": "The "
                                                            "source "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`amazon_data_firehose`.",
                                                            "enum": ["amazon_data_firehose"],
                                                            "example": "amazon_data_firehose",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "AMAZON_DATA_FIREHOSE"
                                                            ],
                                                        },
                                                    },
                                                    "required": ["id", "type"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`google_pubsub` "
                                                    "source "
                                                    "ingests "
                                                    "logs "
                                                    "from "
                                                    "a "
                                                    "Google "
                                                    "Cloud "
                                                    "Pub/Sub "
                                                    "subscription.",
                                                    "properties": {
                                                        "auth": {
                                                            "description": "GCP "
                                                            "credentials "
                                                            "used "
                                                            "to "
                                                            "authenticate "
                                                            "with "
                                                            "Google "
                                                            "Cloud "
                                                            "Storage.",
                                                            "properties": {
                                                                "credentials_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "GCP "
                                                                    "service "
                                                                    "account "
                                                                    "key "
                                                                    "file.",
                                                                    "example": "/var/secrets/gcp-credentials.json",
                                                                    "type": "string",
                                                                }
                                                            },
                                                            "required": ["credentials_file"],
                                                            "type": "object",
                                                        },
                                                        "decoding": {
                                                            "description": "The "
                                                            "decoding "
                                                            "format "
                                                            "used "
                                                            "to "
                                                            "interpret "
                                                            "incoming "
                                                            "logs.",
                                                            "enum": [
                                                                "bytes",
                                                                "gelf",
                                                                "json",
                                                                "syslog",
                                                            ],
                                                            "example": "json",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "DECODE_BYTES",
                                                                "DECODE_GELF",
                                                                "DECODE_JSON",
                                                                "DECODE_SYSLOG",
                                                            ],
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(e.g., "
                                                            "as "
                                                            "input "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "google-pubsub-source",
                                                            "type": "string",
                                                        },
                                                        "project": {
                                                            "description": "The "
                                                            "GCP "
                                                            "project "
                                                            "ID "
                                                            "that "
                                                            "owns "
                                                            "the "
                                                            "Pub/Sub "
                                                            "subscription.",
                                                            "example": "my-gcp-project",
                                                            "type": "string",
                                                        },
                                                        "subscription": {
                                                            "description": "The "
                                                            "Pub/Sub "
                                                            "subscription "
                                                            "name "
                                                            "from "
                                                            "which "
                                                            "messages "
                                                            "are "
                                                            "consumed.",
                                                            "example": "logs-subscription",
                                                            "type": "string",
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "google_pubsub",
                                                            "description": "The "
                                                            "source "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`google_pubsub`.",
                                                            "enum": ["google_pubsub"],
                                                            "example": "google_pubsub",
                                                            "type": "string",
                                                            "x-enum-varnames": ["GOOGLE_PUBSUB"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "auth",
                                                        "decoding",
                                                        "project",
                                                        "subscription",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`http_client` "
                                                    "source "
                                                    "scrapes "
                                                    "logs "
                                                    "from "
                                                    "HTTP "
                                                    "endpoints "
                                                    "at "
                                                    "regular "
                                                    "intervals.",
                                                    "properties": {
                                                        "auth_strategy": {
                                                            "description": "Optional "
                                                            "authentication "
                                                            "strategy "
                                                            "for "
                                                            "HTTP "
                                                            "requests.",
                                                            "enum": ["basic", "bearer"],
                                                            "example": "basic",
                                                            "type": "string",
                                                            "x-enum-varnames": ["BASIC", "BEARER"],
                                                        },
                                                        "decoding": {
                                                            "description": "The "
                                                            "decoding "
                                                            "format "
                                                            "used "
                                                            "to "
                                                            "interpret "
                                                            "incoming "
                                                            "logs.",
                                                            "enum": [
                                                                "bytes",
                                                                "gelf",
                                                                "json",
                                                                "syslog",
                                                            ],
                                                            "example": "json",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "DECODE_BYTES",
                                                                "DECODE_GELF",
                                                                "DECODE_JSON",
                                                                "DECODE_SYSLOG",
                                                            ],
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(e.g., "
                                                            "as "
                                                            "input "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "http-client-source",
                                                            "type": "string",
                                                        },
                                                        "scrape_interval_secs": {
                                                            "description": "The "
                                                            "interval "
                                                            "(in "
                                                            "seconds) "
                                                            "between "
                                                            "HTTP "
                                                            "scrape "
                                                            "requests.",
                                                            "example": 60,
                                                            "format": "int64",
                                                            "type": "integer",
                                                        },
                                                        "scrape_timeout_secs": {
                                                            "description": "The "
                                                            "timeout "
                                                            "(in "
                                                            "seconds) "
                                                            "for "
                                                            "each "
                                                            "scrape "
                                                            "request.",
                                                            "example": 10,
                                                            "format": "int64",
                                                            "type": "integer",
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "http_client",
                                                            "description": "The "
                                                            "source "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`http_client`.",
                                                            "enum": ["http_client"],
                                                            "example": "http_client",
                                                            "type": "string",
                                                            "x-enum-varnames": ["HTTP_CLIENT"],
                                                        },
                                                    },
                                                    "required": ["id", "type", "decoding"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`logstash` "
                                                    "source "
                                                    "ingests "
                                                    "logs "
                                                    "from "
                                                    "a "
                                                    "Logstash "
                                                    "forwarder.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(e.g., "
                                                            "as "
                                                            "input "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "logstash-source",
                                                            "type": "string",
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "logstash",
                                                            "description": "The "
                                                            "source "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`logstash`.",
                                                            "enum": ["logstash"],
                                                            "example": "logstash",
                                                            "type": "string",
                                                            "x-enum-varnames": ["LOGSTASH"],
                                                        },
                                                    },
                                                    "required": ["id", "type"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`socket` "
                                                    "source "
                                                    "ingests "
                                                    "logs "
                                                    "over "
                                                    "TCP "
                                                    "or "
                                                    "UDP.",
                                                    "properties": {
                                                        "framing": {
                                                            "description": "Framing "
                                                            "method "
                                                            "configuration "
                                                            "for "
                                                            "the "
                                                            "socket "
                                                            "source.",
                                                            "oneOf": [
                                                                {
                                                                    "description": "Byte "
                                                                    "frames "
                                                                    "which "
                                                                    "are "
                                                                    "delimited "
                                                                    "by "
                                                                    "a "
                                                                    "newline "
                                                                    "character.",
                                                                    "properties": {
                                                                        "method": {
                                                                            "description": "Byte "
                                                                            "frames "
                                                                            "which "
                                                                            "are "
                                                                            "delimited "
                                                                            "by "
                                                                            "a "
                                                                            "newline "
                                                                            "character.",
                                                                            "enum": [
                                                                                "newline_delimited"
                                                                            ],
                                                                            "example": "newline_delimited",
                                                                            "type": "string",
                                                                            "x-enum-varnames": [
                                                                                "NEWLINE_DELIMITED"
                                                                            ],
                                                                        }
                                                                    },
                                                                    "required": ["method"],
                                                                    "type": "object",
                                                                },
                                                                {
                                                                    "description": "Byte "
                                                                    "frames "
                                                                    "are "
                                                                    "passed "
                                                                    "through "
                                                                    "as-is "
                                                                    "according "
                                                                    "to "
                                                                    "the "
                                                                    "underlying "
                                                                    "I/O "
                                                                    "boundaries "
                                                                    "(for "
                                                                    "example, "
                                                                    "split "
                                                                    "between "
                                                                    "messages "
                                                                    "or "
                                                                    "stream "
                                                                    "segments).",
                                                                    "properties": {
                                                                        "method": {
                                                                            "description": "Byte "
                                                                            "frames "
                                                                            "are "
                                                                            "passed "
                                                                            "through "
                                                                            "as-is "
                                                                            "according "
                                                                            "to "
                                                                            "the "
                                                                            "underlying "
                                                                            "I/O "
                                                                            "boundaries "
                                                                            "(for "
                                                                            "example, "
                                                                            "split "
                                                                            "between "
                                                                            "messages "
                                                                            "or "
                                                                            "stream "
                                                                            "segments).",
                                                                            "enum": ["bytes"],
                                                                            "example": "bytes",
                                                                            "type": "string",
                                                                            "x-enum-varnames": [
                                                                                "BYTES"
                                                                            ],
                                                                        }
                                                                    },
                                                                    "required": ["method"],
                                                                    "type": "object",
                                                                },
                                                                {
                                                                    "description": "Byte "
                                                                    "frames "
                                                                    "which "
                                                                    "are "
                                                                    "delimited "
                                                                    "by "
                                                                    "a "
                                                                    "chosen "
                                                                    "character.",
                                                                    "properties": {
                                                                        "delimiter": {
                                                                            "description": "A "
                                                                            "single "
                                                                            "ASCII "
                                                                            "character "
                                                                            "used "
                                                                            "to "
                                                                            "delimit "
                                                                            "events.",
                                                                            "example": "|",
                                                                            "maxLength": 1,
                                                                            "minLength": 1,
                                                                            "type": "string",
                                                                        },
                                                                        "method": {
                                                                            "description": "Byte "
                                                                            "frames "
                                                                            "which "
                                                                            "are "
                                                                            "delimited "
                                                                            "by "
                                                                            "a "
                                                                            "chosen "
                                                                            "character.",
                                                                            "enum": [
                                                                                "character_delimited"
                                                                            ],
                                                                            "example": "character_delimited",
                                                                            "type": "string",
                                                                            "x-enum-varnames": [
                                                                                "CHARACTER_DELIMITED"
                                                                            ],
                                                                        },
                                                                    },
                                                                    "required": [
                                                                        "method",
                                                                        "delimiter",
                                                                    ],
                                                                    "type": "object",
                                                                },
                                                                {
                                                                    "description": "Byte "
                                                                    "frames "
                                                                    "according "
                                                                    "to "
                                                                    "the "
                                                                    "octet "
                                                                    "counting "
                                                                    "format "
                                                                    "as "
                                                                    "per "
                                                                    "RFC6587.",
                                                                    "properties": {
                                                                        "method": {
                                                                            "description": "Byte "
                                                                            "frames "
                                                                            "according "
                                                                            "to "
                                                                            "the "
                                                                            "octet "
                                                                            "counting "
                                                                            "format "
                                                                            "as "
                                                                            "per "
                                                                            "RFC6587.",
                                                                            "enum": [
                                                                                "octet_counting"
                                                                            ],
                                                                            "example": "octet_counting",
                                                                            "type": "string",
                                                                            "x-enum-varnames": [
                                                                                "OCTET_COUNTING"
                                                                            ],
                                                                        }
                                                                    },
                                                                    "required": ["method"],
                                                                    "type": "object",
                                                                },
                                                                {
                                                                    "description": "Byte "
                                                                    "frames "
                                                                    "which "
                                                                    "are "
                                                                    "chunked "
                                                                    "GELF "
                                                                    "messages.",
                                                                    "properties": {
                                                                        "method": {
                                                                            "description": "Byte "
                                                                            "frames "
                                                                            "which "
                                                                            "are "
                                                                            "chunked "
                                                                            "GELF "
                                                                            "messages.",
                                                                            "enum": [
                                                                                "chunked_gelf"
                                                                            ],
                                                                            "example": "chunked_gelf",
                                                                            "type": "string",
                                                                            "x-enum-varnames": [
                                                                                "CHUNKED_GELF"
                                                                            ],
                                                                        }
                                                                    },
                                                                    "required": ["method"],
                                                                    "type": "object",
                                                                },
                                                            ],
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(e.g., "
                                                            "as "
                                                            "input "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "socket-source",
                                                            "type": "string",
                                                        },
                                                        "mode": {
                                                            "description": "Protocol "
                                                            "used "
                                                            "to "
                                                            "receive "
                                                            "logs.",
                                                            "enum": ["tcp", "udp"],
                                                            "example": "tcp",
                                                            "type": "string",
                                                            "x-enum-varnames": ["TCP", "UDP"],
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "socket",
                                                            "description": "The "
                                                            "source "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`socket`.",
                                                            "enum": ["socket"],
                                                            "example": "socket",
                                                            "type": "string",
                                                            "x-enum-varnames": ["SOCKET"],
                                                        },
                                                    },
                                                    "required": ["id", "type", "mode", "framing"],
                                                    "type": "object",
                                                },
                                            ],
                                        },
                                        "type": "array",
                                    },
                                },
                                "required": ["sources", "destinations"],
                                "type": "object",
                            },
                            "name": {
                                "description": "Name of the pipeline.",
                                "example": "Main Observability Pipeline",
                                "type": "string",
                            },
                        },
                        "required": ["name", "config"],
                        "type": "object",
                    },
                    "type": {
                        "default": "pipelines",
                        "description": "The resource type "
                        "identifier. For "
                        "pipeline resources, "
                        "this should always be "
                        "set to `pipelines`.",
                        "example": "pipelines",
                        "type": "string",
                    },
                },
                "required": ["type", "attributes"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "VALIDATEPIPELINECONFIG_REQUEST_BODY_SCHEMA": {
        "description": "Input schema representing an observability pipeline configuration. "
        "Used in create and validate requests.",
        "properties": {
            "data": {
                "description": "Contains the the pipeline configuration.",
                "properties": {
                    "attributes": {
                        "description": "Defines the "
                        "pipeline’s name "
                        "and its "
                        "components "
                        "(sources, "
                        "processors, and "
                        "destinations).",
                        "properties": {
                            "config": {
                                "description": "Specifies "
                                "the "
                                "pipeline's "
                                "configuration, "
                                "including "
                                "its "
                                "sources, "
                                "processors, "
                                "and "
                                "destinations.",
                                "properties": {
                                    "destinations": {
                                        "description": "A "
                                        "list "
                                        "of "
                                        "destination "
                                        "components "
                                        "where "
                                        "processed "
                                        "logs "
                                        "are "
                                        "sent.",
                                        "example": [
                                            {
                                                "id": "datadog-logs-destination",
                                                "inputs": ["filter-processor"],
                                                "type": "datadog_logs",
                                            }
                                        ],
                                        "items": {
                                            "description": "A destination for the pipeline.",
                                            "oneOf": [
                                                {
                                                    "description": "The "
                                                    "`datadog_logs` "
                                                    "destination "
                                                    "forwards "
                                                    "logs "
                                                    "to "
                                                    "Datadog "
                                                    "Log "
                                                    "Management.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": "datadog-logs-destination",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["filter-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "datadog_logs",
                                                            "description": "The "
                                                            "destination "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`datadog_logs`.",
                                                            "enum": ["datadog_logs"],
                                                            "example": "datadog_logs",
                                                            "type": "string",
                                                            "x-enum-varnames": ["DATADOG_LOGS"],
                                                        },
                                                    },
                                                    "required": ["id", "type", "inputs"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`amazon_s3` "
                                                    "destination "
                                                    "sends "
                                                    "your "
                                                    "logs "
                                                    "in "
                                                    "Datadog-rehydratable "
                                                    "format "
                                                    "to "
                                                    "an "
                                                    "Amazon "
                                                    "S3 "
                                                    "bucket "
                                                    "for "
                                                    "archiving.",
                                                    "properties": {
                                                        "auth": {
                                                            "description": "AWS "
                                                            "authentication "
                                                            "credentials "
                                                            "used "
                                                            "for "
                                                            "accessing "
                                                            "AWS "
                                                            "services "
                                                            "such "
                                                            "as "
                                                            "S3.\n"
                                                            "If "
                                                            "omitted, "
                                                            "the "
                                                            "system’s "
                                                            "default "
                                                            "credentials "
                                                            "are "
                                                            "used "
                                                            "(for "
                                                            "example, "
                                                            "the "
                                                            "IAM "
                                                            "role "
                                                            "and "
                                                            "environment "
                                                            "variables).",
                                                            "properties": {
                                                                "assume_role": {
                                                                    "description": "The "
                                                                    "Amazon "
                                                                    "Resource "
                                                                    "Name "
                                                                    "(ARN) "
                                                                    "of "
                                                                    "the "
                                                                    "role "
                                                                    "to "
                                                                    "assume.",
                                                                    "type": "string",
                                                                },
                                                                "external_id": {
                                                                    "description": "A "
                                                                    "unique "
                                                                    "identifier "
                                                                    "for "
                                                                    "cross-account "
                                                                    "role "
                                                                    "assumption.",
                                                                    "type": "string",
                                                                },
                                                                "session_name": {
                                                                    "description": "A "
                                                                    "session "
                                                                    "identifier "
                                                                    "used "
                                                                    "for "
                                                                    "logging "
                                                                    "and "
                                                                    "tracing "
                                                                    "the "
                                                                    "assumed "
                                                                    "role "
                                                                    "session.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "type": "object",
                                                        },
                                                        "bucket": {
                                                            "description": "S3 bucket name.",
                                                            "example": "error-logs",
                                                            "type": "string",
                                                        },
                                                        "id": {
                                                            "description": "Unique "
                                                            "identifier "
                                                            "for "
                                                            "the "
                                                            "destination "
                                                            "component.",
                                                            "example": "amazon-s3-destination",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["datadog-agent-source"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "key_prefix": {
                                                            "description": "Optional "
                                                            "prefix "
                                                            "for "
                                                            "object "
                                                            "keys.",
                                                            "type": "string",
                                                        },
                                                        "region": {
                                                            "description": "AWS "
                                                            "region "
                                                            "of "
                                                            "the "
                                                            "S3 "
                                                            "bucket.",
                                                            "example": "us-east-1",
                                                            "type": "string",
                                                        },
                                                        "storage_class": {
                                                            "description": "S3 storage class.",
                                                            "enum": [
                                                                "STANDARD",
                                                                "REDUCED_REDUNDANCY",
                                                                "INTELLIGENT_TIERING",
                                                                "STANDARD_IA",
                                                                "EXPRESS_ONEZONE",
                                                                "ONEZONE_IA",
                                                                "GLACIER",
                                                                "GLACIER_IR",
                                                                "DEEP_ARCHIVE",
                                                            ],
                                                            "example": "STANDARD",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "STANDARD",
                                                                "REDUCED_REDUNDANCY",
                                                                "INTELLIGENT_TIERING",
                                                                "STANDARD_IA",
                                                                "EXPRESS_ONEZONE",
                                                                "ONEZONE_IA",
                                                                "GLACIER",
                                                                "GLACIER_IR",
                                                                "DEEP_ARCHIVE",
                                                            ],
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "amazon_s3",
                                                            "description": "The "
                                                            "destination "
                                                            "type. "
                                                            "Always "
                                                            "`amazon_s3`.",
                                                            "enum": ["amazon_s3"],
                                                            "example": "amazon_s3",
                                                            "type": "string",
                                                            "x-enum-varnames": ["AMAZON_S3"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "inputs",
                                                        "bucket",
                                                        "region",
                                                        "storage_class",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`google_cloud_storage` "
                                                    "destination "
                                                    "stores "
                                                    "logs "
                                                    "in "
                                                    "a "
                                                    "Google "
                                                    "Cloud "
                                                    "Storage "
                                                    "(GCS) "
                                                    "bucket.\n"
                                                    "It "
                                                    "requires "
                                                    "a "
                                                    "bucket "
                                                    "name, "
                                                    "GCP "
                                                    "authentication, "
                                                    "and "
                                                    "metadata "
                                                    "fields.",
                                                    "properties": {
                                                        "acl": {
                                                            "description": "Access "
                                                            "control "
                                                            "list "
                                                            "setting "
                                                            "for "
                                                            "objects "
                                                            "written "
                                                            "to "
                                                            "the "
                                                            "bucket.",
                                                            "enum": [
                                                                "private",
                                                                "project-private",
                                                                "public-read",
                                                                "authenticated-read",
                                                                "bucket-owner-read",
                                                                "bucket-owner-full-control",
                                                            ],
                                                            "example": "private",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "PRIVATE",
                                                                "PROJECTNOT_PRIVATE",
                                                                "PUBLICNOT_READ",
                                                                "AUTHENTICATEDNOT_READ",
                                                                "BUCKETNOT_OWNERNOT_READ",
                                                                "BUCKETNOT_OWNERNOT_FULLNOT_CONTROL",
                                                            ],
                                                        },
                                                        "auth": {
                                                            "description": "GCP "
                                                            "credentials "
                                                            "used "
                                                            "to "
                                                            "authenticate "
                                                            "with "
                                                            "Google "
                                                            "Cloud "
                                                            "Storage.",
                                                            "properties": {
                                                                "credentials_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "GCP "
                                                                    "service "
                                                                    "account "
                                                                    "key "
                                                                    "file.",
                                                                    "example": "/var/secrets/gcp-credentials.json",
                                                                    "type": "string",
                                                                }
                                                            },
                                                            "required": ["credentials_file"],
                                                            "type": "object",
                                                        },
                                                        "bucket": {
                                                            "description": "Name "
                                                            "of "
                                                            "the "
                                                            "GCS "
                                                            "bucket.",
                                                            "example": "error-logs",
                                                            "type": "string",
                                                        },
                                                        "id": {
                                                            "description": "Unique "
                                                            "identifier "
                                                            "for "
                                                            "the "
                                                            "destination "
                                                            "component.",
                                                            "example": "gcs-destination",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["datadog-agent-source"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "key_prefix": {
                                                            "description": "Optional "
                                                            "prefix "
                                                            "for "
                                                            "object "
                                                            "keys "
                                                            "within "
                                                            "the "
                                                            "GCS "
                                                            "bucket.",
                                                            "type": "string",
                                                        },
                                                        "metadata": {
                                                            "description": "Custom "
                                                            "metadata "
                                                            "to "
                                                            "attach "
                                                            "to "
                                                            "each "
                                                            "object "
                                                            "uploaded "
                                                            "to "
                                                            "the "
                                                            "GCS "
                                                            "bucket.",
                                                            "items": {
                                                                "description": "A "
                                                                "custom "
                                                                "metadata "
                                                                "entry.",
                                                                "properties": {
                                                                    "name": {
                                                                        "description": "The "
                                                                        "metadata "
                                                                        "key.",
                                                                        "example": "environment",
                                                                        "type": "string",
                                                                    },
                                                                    "value": {
                                                                        "description": "The "
                                                                        "metadata "
                                                                        "value.",
                                                                        "example": "production",
                                                                        "type": "string",
                                                                    },
                                                                },
                                                                "required": ["name", "value"],
                                                                "type": "object",
                                                            },
                                                            "type": "array",
                                                        },
                                                        "storage_class": {
                                                            "description": "Storage "
                                                            "class "
                                                            "used "
                                                            "for "
                                                            "objects "
                                                            "stored "
                                                            "in "
                                                            "GCS.",
                                                            "enum": [
                                                                "STANDARD",
                                                                "NEARLINE",
                                                                "COLDLINE",
                                                                "ARCHIVE",
                                                            ],
                                                            "example": "STANDARD",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "STANDARD",
                                                                "NEARLINE",
                                                                "COLDLINE",
                                                                "ARCHIVE",
                                                            ],
                                                        },
                                                        "type": {
                                                            "default": "google_cloud_storage",
                                                            "description": "The "
                                                            "destination "
                                                            "type. "
                                                            "Always "
                                                            "`google_cloud_storage`.",
                                                            "enum": ["google_cloud_storage"],
                                                            "example": "google_cloud_storage",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "GOOGLE_CLOUD_STORAGE"
                                                            ],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "inputs",
                                                        "bucket",
                                                        "auth",
                                                        "storage_class",
                                                        "acl",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`splunk_hec` "
                                                    "destination "
                                                    "forwards "
                                                    "logs "
                                                    "to "
                                                    "Splunk "
                                                    "using "
                                                    "the "
                                                    "HTTP "
                                                    "Event "
                                                    "Collector "
                                                    "(HEC).",
                                                    "properties": {
                                                        "auto_extract_timestamp": {
                                                            "description": "If "
                                                            "`true`, "
                                                            "Splunk "
                                                            "tries "
                                                            "to "
                                                            "extract "
                                                            "timestamps "
                                                            "from "
                                                            "incoming "
                                                            "log "
                                                            "events.\n"
                                                            "If "
                                                            "`false`, "
                                                            "Splunk "
                                                            "assigns "
                                                            "the "
                                                            "time "
                                                            "the "
                                                            "event "
                                                            "was "
                                                            "received.",
                                                            "example": True,
                                                            "type": "boolean",
                                                        },
                                                        "encoding": {
                                                            "description": "Encoding "
                                                            "format "
                                                            "for "
                                                            "log "
                                                            "events.",
                                                            "enum": ["json", "raw_message"],
                                                            "example": "json",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "JSON",
                                                                "RAW_MESSAGE",
                                                            ],
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(e.g., "
                                                            "as "
                                                            "input "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "splunk-hec-destination",
                                                            "type": "string",
                                                        },
                                                        "index": {
                                                            "description": "Optional "
                                                            "name "
                                                            "of "
                                                            "the "
                                                            "Splunk "
                                                            "index "
                                                            "where "
                                                            "logs "
                                                            "are "
                                                            "written.",
                                                            "example": "main",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["filter-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "sourcetype": {
                                                            "description": "The "
                                                            "Splunk "
                                                            "sourcetype "
                                                            "to "
                                                            "assign "
                                                            "to "
                                                            "log "
                                                            "events.",
                                                            "example": "custom_sourcetype",
                                                            "type": "string",
                                                        },
                                                        "type": {
                                                            "default": "splunk_hec",
                                                            "description": "The "
                                                            "destination "
                                                            "type. "
                                                            "Always "
                                                            "`splunk_hec`.",
                                                            "enum": ["splunk_hec"],
                                                            "example": "splunk_hec",
                                                            "type": "string",
                                                            "x-enum-varnames": ["SPLUNK_HEC"],
                                                        },
                                                    },
                                                    "required": ["id", "type", "inputs"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`sumo_logic` "
                                                    "destination "
                                                    "forwards "
                                                    "logs "
                                                    "to "
                                                    "Sumo "
                                                    "Logic.",
                                                    "properties": {
                                                        "encoding": {
                                                            "description": "The "
                                                            "output "
                                                            "encoding "
                                                            "format.",
                                                            "enum": [
                                                                "json",
                                                                "raw_message",
                                                                "logfmt",
                                                            ],
                                                            "example": "json",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "JSON",
                                                                "RAW_MESSAGE",
                                                                "LOGFMT",
                                                            ],
                                                        },
                                                        "header_custom_fields": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "custom "
                                                            "headers "
                                                            "to "
                                                            "include "
                                                            "in "
                                                            "the "
                                                            "request "
                                                            "to "
                                                            "Sumo "
                                                            "Logic.",
                                                            "items": {
                                                                "description": "Single "
                                                                "key-value "
                                                                "pair "
                                                                "used "
                                                                "as "
                                                                "a "
                                                                "custom "
                                                                "log "
                                                                "header "
                                                                "for "
                                                                "Sumo "
                                                                "Logic.",
                                                                "properties": {
                                                                    "name": {
                                                                        "description": "The "
                                                                        "header "
                                                                        "field "
                                                                        "name.",
                                                                        "example": "X-Sumo-Category",
                                                                        "type": "string",
                                                                    },
                                                                    "value": {
                                                                        "description": "The "
                                                                        "header "
                                                                        "field "
                                                                        "value.",
                                                                        "example": "my-app-logs",
                                                                        "type": "string",
                                                                    },
                                                                },
                                                                "required": ["name", "value"],
                                                                "type": "object",
                                                            },
                                                            "type": "array",
                                                        },
                                                        "header_host_name": {
                                                            "description": "Optional "
                                                            "override "
                                                            "for "
                                                            "the "
                                                            "host "
                                                            "name "
                                                            "header.",
                                                            "example": "host-123",
                                                            "type": "string",
                                                        },
                                                        "header_source_category": {
                                                            "description": "Optional "
                                                            "override "
                                                            "for "
                                                            "the "
                                                            "source "
                                                            "category "
                                                            "header.",
                                                            "example": "source-category",
                                                            "type": "string",
                                                        },
                                                        "header_source_name": {
                                                            "description": "Optional "
                                                            "override "
                                                            "for "
                                                            "the "
                                                            "source "
                                                            "name "
                                                            "header.",
                                                            "example": "source-name",
                                                            "type": "string",
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": "sumo-logic-destination",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["filter-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "sumo_logic",
                                                            "description": "The "
                                                            "destination "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`sumo_logic`.",
                                                            "enum": ["sumo_logic"],
                                                            "example": "sumo_logic",
                                                            "type": "string",
                                                            "x-enum-varnames": ["SUMO_LOGIC"],
                                                        },
                                                    },
                                                    "required": ["id", "type", "inputs"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`elasticsearch` "
                                                    "destination "
                                                    "writes "
                                                    "logs "
                                                    "to "
                                                    "an "
                                                    "Elasticsearch "
                                                    "cluster.",
                                                    "properties": {
                                                        "api_version": {
                                                            "description": "The "
                                                            "Elasticsearch "
                                                            "API "
                                                            "version "
                                                            "to "
                                                            "use. "
                                                            "Set "
                                                            "to "
                                                            "`auto` "
                                                            "to "
                                                            "auto-detect.",
                                                            "enum": ["auto", "v6", "v7", "v8"],
                                                            "example": "auto",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "AUTO",
                                                                "V6",
                                                                "V7",
                                                                "V8",
                                                            ],
                                                        },
                                                        "bulk_index": {
                                                            "description": "The "
                                                            "index "
                                                            "to "
                                                            "write "
                                                            "logs "
                                                            "to "
                                                            "in "
                                                            "Elasticsearch.",
                                                            "example": "logs-index",
                                                            "type": "string",
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": "elasticsearch-destination",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["filter-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "elasticsearch",
                                                            "description": "The "
                                                            "destination "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`elasticsearch`.",
                                                            "enum": ["elasticsearch"],
                                                            "example": "elasticsearch",
                                                            "type": "string",
                                                            "x-enum-varnames": ["ELASTICSEARCH"],
                                                        },
                                                    },
                                                    "required": ["id", "type", "inputs"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`rsyslog` "
                                                    "destination "
                                                    "forwards "
                                                    "logs "
                                                    "to "
                                                    "an "
                                                    "external "
                                                    "`rsyslog` "
                                                    "server "
                                                    "over "
                                                    "TCP "
                                                    "or "
                                                    "UDP "
                                                    "using "
                                                    "the "
                                                    "syslog "
                                                    "protocol.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": "rsyslog-destination",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["filter-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "keepalive": {
                                                            "description": "Optional "
                                                            "socket "
                                                            "keepalive "
                                                            "duration "
                                                            "in "
                                                            "milliseconds.",
                                                            "example": 60000,
                                                            "format": "int64",
                                                            "minimum": 0,
                                                            "type": "integer",
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "rsyslog",
                                                            "description": "The "
                                                            "destination "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`rsyslog`.",
                                                            "enum": ["rsyslog"],
                                                            "example": "rsyslog",
                                                            "type": "string",
                                                            "x-enum-varnames": ["RSYSLOG"],
                                                        },
                                                    },
                                                    "required": ["id", "type", "inputs"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`syslog_ng` "
                                                    "destination "
                                                    "forwards "
                                                    "logs "
                                                    "to "
                                                    "an "
                                                    "external "
                                                    "`syslog-ng` "
                                                    "server "
                                                    "over "
                                                    "TCP "
                                                    "or "
                                                    "UDP "
                                                    "using "
                                                    "the "
                                                    "syslog "
                                                    "protocol.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": "syslog-ng-destination",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["filter-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "keepalive": {
                                                            "description": "Optional "
                                                            "socket "
                                                            "keepalive "
                                                            "duration "
                                                            "in "
                                                            "milliseconds.",
                                                            "example": 60000,
                                                            "format": "int64",
                                                            "minimum": 0,
                                                            "type": "integer",
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "syslog_ng",
                                                            "description": "The "
                                                            "destination "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`syslog_ng`.",
                                                            "enum": ["syslog_ng"],
                                                            "example": "syslog_ng",
                                                            "type": "string",
                                                            "x-enum-varnames": ["SYSLOG_NG"],
                                                        },
                                                    },
                                                    "required": ["id", "type", "inputs"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`azure_storage` "
                                                    "destination "
                                                    "forwards "
                                                    "logs "
                                                    "to "
                                                    "an "
                                                    "Azure "
                                                    "Blob "
                                                    "Storage "
                                                    "container.",
                                                    "properties": {
                                                        "blob_prefix": {
                                                            "description": "Optional "
                                                            "prefix "
                                                            "for "
                                                            "blobs "
                                                            "written "
                                                            "to "
                                                            "the "
                                                            "container.",
                                                            "example": "logs/",
                                                            "type": "string",
                                                        },
                                                        "container_name": {
                                                            "description": "The "
                                                            "name "
                                                            "of "
                                                            "the "
                                                            "Azure "
                                                            "Blob "
                                                            "Storage "
                                                            "container "
                                                            "to "
                                                            "store "
                                                            "logs "
                                                            "in.",
                                                            "example": "my-log-container",
                                                            "type": "string",
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": "azure-storage-destination",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["processor-id"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "azure_storage",
                                                            "description": "The "
                                                            "destination "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`azure_storage`.",
                                                            "enum": ["azure_storage"],
                                                            "example": "azure_storage",
                                                            "type": "string",
                                                            "x-enum-varnames": ["AZURE_STORAGE"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "inputs",
                                                        "container_name",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`microsoft_sentinel` "
                                                    "destination "
                                                    "forwards "
                                                    "logs "
                                                    "to "
                                                    "Microsoft "
                                                    "Sentinel.",
                                                    "properties": {
                                                        "client_id": {
                                                            "description": "Azure "
                                                            "AD "
                                                            "client "
                                                            "ID "
                                                            "used "
                                                            "for "
                                                            "authentication.",
                                                            "example": "a1b2c3d4-5678-90ab-cdef-1234567890ab",
                                                            "type": "string",
                                                        },
                                                        "dcr_immutable_id": {
                                                            "description": "The "
                                                            "immutable "
                                                            "ID "
                                                            "of "
                                                            "the "
                                                            "Data "
                                                            "Collection "
                                                            "Rule "
                                                            "(DCR).",
                                                            "example": "dcr-uuid-1234",
                                                            "type": "string",
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": "sentinel-destination",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["filter-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "table": {
                                                            "description": "The "
                                                            "name "
                                                            "of "
                                                            "the "
                                                            "Log "
                                                            "Analytics "
                                                            "table "
                                                            "where "
                                                            "logs "
                                                            "are "
                                                            "sent.",
                                                            "example": "CustomLogsTable",
                                                            "type": "string",
                                                        },
                                                        "tenant_id": {
                                                            "description": "Azure AD tenant ID.",
                                                            "example": "abcdef12-3456-7890-abcd-ef1234567890",
                                                            "type": "string",
                                                        },
                                                        "type": {
                                                            "default": "microsoft_sentinel",
                                                            "description": "The "
                                                            "destination "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`microsoft_sentinel`.",
                                                            "enum": ["microsoft_sentinel"],
                                                            "example": "microsoft_sentinel",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "MICROSOFT_SENTINEL"
                                                            ],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "inputs",
                                                        "client_id",
                                                        "tenant_id",
                                                        "dcr_immutable_id",
                                                        "table",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`google_chronicle` "
                                                    "destination "
                                                    "sends "
                                                    "logs "
                                                    "to "
                                                    "Google "
                                                    "Chronicle.",
                                                    "properties": {
                                                        "auth": {
                                                            "description": "GCP "
                                                            "credentials "
                                                            "used "
                                                            "to "
                                                            "authenticate "
                                                            "with "
                                                            "Google "
                                                            "Cloud "
                                                            "Storage.",
                                                            "properties": {
                                                                "credentials_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "GCP "
                                                                    "service "
                                                                    "account "
                                                                    "key "
                                                                    "file.",
                                                                    "example": "/var/secrets/gcp-credentials.json",
                                                                    "type": "string",
                                                                }
                                                            },
                                                            "required": ["credentials_file"],
                                                            "type": "object",
                                                        },
                                                        "customer_id": {
                                                            "description": "The "
                                                            "Google "
                                                            "Chronicle "
                                                            "customer "
                                                            "ID.",
                                                            "example": "abcdefg123456789",
                                                            "type": "string",
                                                        },
                                                        "encoding": {
                                                            "description": "The "
                                                            "encoding "
                                                            "format "
                                                            "for "
                                                            "the "
                                                            "logs "
                                                            "sent "
                                                            "to "
                                                            "Chronicle.",
                                                            "enum": ["json", "raw_message"],
                                                            "example": "json",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "JSON",
                                                                "RAW_MESSAGE",
                                                            ],
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": "google-chronicle-destination",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["parse-json-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "log_type": {
                                                            "description": "The "
                                                            "log "
                                                            "type "
                                                            "metadata "
                                                            "associated "
                                                            "with "
                                                            "the "
                                                            "Chronicle "
                                                            "destination.",
                                                            "example": "nginx_logs",
                                                            "type": "string",
                                                        },
                                                        "type": {
                                                            "default": "google_chronicle",
                                                            "description": "The "
                                                            "destination "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`google_chronicle`.",
                                                            "enum": ["google_chronicle"],
                                                            "example": "google_chronicle",
                                                            "type": "string",
                                                            "x-enum-varnames": ["GOOGLE_CHRONICLE"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "inputs",
                                                        "auth",
                                                        "customer_id",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`new_relic` "
                                                    "destination "
                                                    "sends "
                                                    "logs "
                                                    "to "
                                                    "the "
                                                    "New "
                                                    "Relic "
                                                    "platform.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": "new-relic-destination",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["parse-json-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "region": {
                                                            "description": "The New Relic region.",
                                                            "enum": ["us", "eu"],
                                                            "example": "us",
                                                            "type": "string",
                                                            "x-enum-varnames": ["US", "EU"],
                                                        },
                                                        "type": {
                                                            "default": "new_relic",
                                                            "description": "The "
                                                            "destination "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`new_relic`.",
                                                            "enum": ["new_relic"],
                                                            "example": "new_relic",
                                                            "type": "string",
                                                            "x-enum-varnames": ["NEW_RELIC"],
                                                        },
                                                    },
                                                    "required": ["id", "type", "inputs", "region"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`sentinel_one` "
                                                    "destination "
                                                    "sends "
                                                    "logs "
                                                    "to "
                                                    "SentinelOne.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": "sentinelone-destination",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["filter-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "region": {
                                                            "description": "The "
                                                            "SentinelOne "
                                                            "region "
                                                            "to "
                                                            "send "
                                                            "logs "
                                                            "to.",
                                                            "enum": [
                                                                "us",
                                                                "eu",
                                                                "ca",
                                                                "data_set_us",
                                                            ],
                                                            "example": "us",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "US",
                                                                "EU",
                                                                "CA",
                                                                "DATA_SET_US",
                                                            ],
                                                        },
                                                        "type": {
                                                            "default": "sentinel_one",
                                                            "description": "The "
                                                            "destination "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`sentinel_one`.",
                                                            "enum": ["sentinel_one"],
                                                            "example": "sentinel_one",
                                                            "type": "string",
                                                            "x-enum-varnames": ["SENTINEL_ONE"],
                                                        },
                                                    },
                                                    "required": ["id", "type", "inputs", "region"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`opensearch` "
                                                    "destination "
                                                    "writes "
                                                    "logs "
                                                    "to "
                                                    "an "
                                                    "OpenSearch "
                                                    "cluster.",
                                                    "properties": {
                                                        "bulk_index": {
                                                            "description": "The "
                                                            "index "
                                                            "to "
                                                            "write "
                                                            "logs "
                                                            "to.",
                                                            "example": "logs-index",
                                                            "type": "string",
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": "opensearch-destination",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["filter-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "opensearch",
                                                            "description": "The "
                                                            "destination "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`opensearch`.",
                                                            "enum": ["opensearch"],
                                                            "example": "opensearch",
                                                            "type": "string",
                                                            "x-enum-varnames": ["OPENSEARCH"],
                                                        },
                                                    },
                                                    "required": ["id", "type", "inputs"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`amazon_opensearch` "
                                                    "destination "
                                                    "writes "
                                                    "logs "
                                                    "to "
                                                    "Amazon "
                                                    "OpenSearch.",
                                                    "properties": {
                                                        "auth": {
                                                            "description": "Authentication "
                                                            "settings "
                                                            "for "
                                                            "the "
                                                            "Amazon "
                                                            "OpenSearch "
                                                            "destination.\n"
                                                            "The "
                                                            "`strategy` "
                                                            "field "
                                                            "determines "
                                                            "whether "
                                                            "basic "
                                                            "or "
                                                            "AWS-based "
                                                            "authentication "
                                                            "is "
                                                            "used.",
                                                            "properties": {
                                                                "assume_role": {
                                                                    "description": "The "
                                                                    "ARN "
                                                                    "of "
                                                                    "the "
                                                                    "role "
                                                                    "to "
                                                                    "assume "
                                                                    "(used "
                                                                    "with "
                                                                    "`aws` "
                                                                    "strategy).",
                                                                    "type": "string",
                                                                },
                                                                "aws_region": {
                                                                    "description": "AWS region",
                                                                    "type": "string",
                                                                },
                                                                "external_id": {
                                                                    "description": "External "
                                                                    "ID "
                                                                    "for "
                                                                    "the "
                                                                    "assumed "
                                                                    "role "
                                                                    "(used "
                                                                    "with "
                                                                    "`aws` "
                                                                    "strategy).",
                                                                    "type": "string",
                                                                },
                                                                "session_name": {
                                                                    "description": "Session "
                                                                    "name "
                                                                    "for "
                                                                    "the "
                                                                    "assumed "
                                                                    "role "
                                                                    "(used "
                                                                    "with "
                                                                    "`aws` "
                                                                    "strategy).",
                                                                    "type": "string",
                                                                },
                                                                "strategy": {
                                                                    "description": "The "
                                                                    "authentication "
                                                                    "strategy "
                                                                    "to "
                                                                    "use.",
                                                                    "enum": ["basic", "aws"],
                                                                    "example": "aws",
                                                                    "type": "string",
                                                                    "x-enum-varnames": [
                                                                        "BASIC",
                                                                        "AWS",
                                                                    ],
                                                                },
                                                            },
                                                            "required": ["strategy"],
                                                            "type": "object",
                                                        },
                                                        "bulk_index": {
                                                            "description": "The "
                                                            "index "
                                                            "to "
                                                            "write "
                                                            "logs "
                                                            "to.",
                                                            "example": "logs-index",
                                                            "type": "string",
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": "elasticsearch-destination",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["filter-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "amazon_opensearch",
                                                            "description": "The "
                                                            "destination "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`amazon_opensearch`.",
                                                            "enum": ["amazon_opensearch"],
                                                            "example": "amazon_opensearch",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "AMAZON_OPENSEARCH"
                                                            ],
                                                        },
                                                    },
                                                    "required": ["id", "type", "inputs", "auth"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`socket` "
                                                    "destination "
                                                    "sends "
                                                    "logs "
                                                    "over "
                                                    "TCP "
                                                    "or "
                                                    "UDP "
                                                    "to "
                                                    "a "
                                                    "remote "
                                                    "server.",
                                                    "properties": {
                                                        "encoding": {
                                                            "description": "Encoding "
                                                            "format "
                                                            "for "
                                                            "log "
                                                            "events.",
                                                            "enum": ["json", "raw_message"],
                                                            "example": "json",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "JSON",
                                                                "RAW_MESSAGE",
                                                            ],
                                                        },
                                                        "framing": {
                                                            "description": "Framing "
                                                            "method "
                                                            "configuration.",
                                                            "oneOf": [
                                                                {
                                                                    "description": "Each "
                                                                    "log "
                                                                    "event "
                                                                    "is "
                                                                    "delimited "
                                                                    "by "
                                                                    "a "
                                                                    "newline "
                                                                    "character.",
                                                                    "properties": {
                                                                        "method": {
                                                                            "description": "The "
                                                                            "definition "
                                                                            "of "
                                                                            "`ObservabilityPipelineSocketDestinationFramingNewlineDelimitedMethod` "
                                                                            "object.",
                                                                            "enum": [
                                                                                "newline_delimited"
                                                                            ],
                                                                            "example": "newline_delimited",
                                                                            "type": "string",
                                                                            "x-enum-varnames": [
                                                                                "NEWLINE_DELIMITED"
                                                                            ],
                                                                        }
                                                                    },
                                                                    "required": ["method"],
                                                                    "type": "object",
                                                                },
                                                                {
                                                                    "description": "Event "
                                                                    "data "
                                                                    "is "
                                                                    "not "
                                                                    "delimited "
                                                                    "at "
                                                                    "all.",
                                                                    "properties": {
                                                                        "method": {
                                                                            "description": "The "
                                                                            "definition "
                                                                            "of "
                                                                            "`ObservabilityPipelineSocketDestinationFramingBytesMethod` "
                                                                            "object.",
                                                                            "enum": ["bytes"],
                                                                            "example": "bytes",
                                                                            "type": "string",
                                                                            "x-enum-varnames": [
                                                                                "BYTES"
                                                                            ],
                                                                        }
                                                                    },
                                                                    "required": ["method"],
                                                                    "type": "object",
                                                                },
                                                                {
                                                                    "description": "Each "
                                                                    "log "
                                                                    "event "
                                                                    "is "
                                                                    "separated "
                                                                    "using "
                                                                    "the "
                                                                    "specified "
                                                                    "delimiter "
                                                                    "character.",
                                                                    "properties": {
                                                                        "delimiter": {
                                                                            "description": "A "
                                                                            "single "
                                                                            "ASCII "
                                                                            "character "
                                                                            "used "
                                                                            "as "
                                                                            "a "
                                                                            "delimiter.",
                                                                            "example": "|",
                                                                            "maxLength": 1,
                                                                            "minLength": 1,
                                                                            "type": "string",
                                                                        },
                                                                        "method": {
                                                                            "description": "The "
                                                                            "definition "
                                                                            "of "
                                                                            "`ObservabilityPipelineSocketDestinationFramingCharacterDelimitedMethod` "
                                                                            "object.",
                                                                            "enum": [
                                                                                "character_delimited"
                                                                            ],
                                                                            "example": "character_delimited",
                                                                            "type": "string",
                                                                            "x-enum-varnames": [
                                                                                "CHARACTER_DELIMITED"
                                                                            ],
                                                                        },
                                                                    },
                                                                    "required": [
                                                                        "method",
                                                                        "delimiter",
                                                                    ],
                                                                    "type": "object",
                                                                },
                                                            ],
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": "socket-destination",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["filter-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "mode": {
                                                            "description": "Protocol "
                                                            "used "
                                                            "to "
                                                            "send "
                                                            "logs.",
                                                            "enum": ["tcp", "udp"],
                                                            "example": "tcp",
                                                            "type": "string",
                                                            "x-enum-varnames": ["TCP", "UDP"],
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "socket",
                                                            "description": "The "
                                                            "destination "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`socket`.",
                                                            "enum": ["socket"],
                                                            "example": "socket",
                                                            "type": "string",
                                                            "x-enum-varnames": ["SOCKET"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "inputs",
                                                        "encoding",
                                                        "framing",
                                                        "mode",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`amazon_security_lake` "
                                                    "destination "
                                                    "sends "
                                                    "your "
                                                    "logs "
                                                    "to "
                                                    "Amazon "
                                                    "Security "
                                                    "Lake.",
                                                    "properties": {
                                                        "auth": {
                                                            "description": "AWS "
                                                            "authentication "
                                                            "credentials "
                                                            "used "
                                                            "for "
                                                            "accessing "
                                                            "AWS "
                                                            "services "
                                                            "such "
                                                            "as "
                                                            "S3.\n"
                                                            "If "
                                                            "omitted, "
                                                            "the "
                                                            "system’s "
                                                            "default "
                                                            "credentials "
                                                            "are "
                                                            "used "
                                                            "(for "
                                                            "example, "
                                                            "the "
                                                            "IAM "
                                                            "role "
                                                            "and "
                                                            "environment "
                                                            "variables).",
                                                            "properties": {
                                                                "assume_role": {
                                                                    "description": "The "
                                                                    "Amazon "
                                                                    "Resource "
                                                                    "Name "
                                                                    "(ARN) "
                                                                    "of "
                                                                    "the "
                                                                    "role "
                                                                    "to "
                                                                    "assume.",
                                                                    "type": "string",
                                                                },
                                                                "external_id": {
                                                                    "description": "A "
                                                                    "unique "
                                                                    "identifier "
                                                                    "for "
                                                                    "cross-account "
                                                                    "role "
                                                                    "assumption.",
                                                                    "type": "string",
                                                                },
                                                                "session_name": {
                                                                    "description": "A "
                                                                    "session "
                                                                    "identifier "
                                                                    "used "
                                                                    "for "
                                                                    "logging "
                                                                    "and "
                                                                    "tracing "
                                                                    "the "
                                                                    "assumed "
                                                                    "role "
                                                                    "session.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "type": "object",
                                                        },
                                                        "bucket": {
                                                            "description": "Name "
                                                            "of "
                                                            "the "
                                                            "Amazon "
                                                            "S3 "
                                                            "bucket "
                                                            "in "
                                                            "Security "
                                                            "Lake "
                                                            "(3-63 "
                                                            "characters).",
                                                            "example": "security-lake-bucket",
                                                            "type": "string",
                                                        },
                                                        "custom_source_name": {
                                                            "description": "Custom "
                                                            "source "
                                                            "name "
                                                            "for "
                                                            "the "
                                                            "logs "
                                                            "in "
                                                            "Security "
                                                            "Lake.",
                                                            "example": "my-custom-source",
                                                            "type": "string",
                                                        },
                                                        "id": {
                                                            "description": "Unique "
                                                            "identifier "
                                                            "for "
                                                            "the "
                                                            "destination "
                                                            "component.",
                                                            "example": "amazon-security-lake-destination",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["filter-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "region": {
                                                            "description": "AWS "
                                                            "region "
                                                            "of "
                                                            "the "
                                                            "S3 "
                                                            "bucket.",
                                                            "example": "us-east-1",
                                                            "type": "string",
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "amazon_security_lake",
                                                            "description": "The "
                                                            "destination "
                                                            "type. "
                                                            "Always "
                                                            "`amazon_security_lake`.",
                                                            "enum": ["amazon_security_lake"],
                                                            "example": "amazon_security_lake",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "AMAZON_SECURITY_LAKE"
                                                            ],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "inputs",
                                                        "bucket",
                                                        "region",
                                                        "custom_source_name",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`crowdstrike_next_gen_siem` "
                                                    "destination "
                                                    "forwards "
                                                    "logs "
                                                    "to "
                                                    "CrowdStrike "
                                                    "Next "
                                                    "Gen "
                                                    "SIEM.",
                                                    "properties": {
                                                        "compression": {
                                                            "description": "Compression "
                                                            "configuration "
                                                            "for "
                                                            "log "
                                                            "events.",
                                                            "properties": {
                                                                "algorithm": {
                                                                    "description": "Compression "
                                                                    "algorithm "
                                                                    "for "
                                                                    "log "
                                                                    "events.",
                                                                    "enum": ["gzip", "zlib"],
                                                                    "example": "gzip",
                                                                    "type": "string",
                                                                    "x-enum-varnames": [
                                                                        "GZIP",
                                                                        "ZLIB",
                                                                    ],
                                                                },
                                                                "level": {
                                                                    "description": "Compression "
                                                                    "level.",
                                                                    "example": 6,
                                                                    "format": "int64",
                                                                    "type": "integer",
                                                                },
                                                            },
                                                            "required": ["algorithm"],
                                                            "type": "object",
                                                        },
                                                        "encoding": {
                                                            "description": "Encoding "
                                                            "format "
                                                            "for "
                                                            "log "
                                                            "events.",
                                                            "enum": ["json", "raw_message"],
                                                            "example": "json",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "JSON",
                                                                "RAW_MESSAGE",
                                                            ],
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": "crowdstrike-ngsiem-destination",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["filter-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "crowdstrike_next_gen_siem",
                                                            "description": "The "
                                                            "destination "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`crowdstrike_next_gen_siem`.",
                                                            "enum": ["crowdstrike_next_gen_siem"],
                                                            "example": "crowdstrike_next_gen_siem",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "CROWDSTRIKE_NEXT_GEN_SIEM"
                                                            ],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "inputs",
                                                        "encoding",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`google_pubsub` "
                                                    "destination "
                                                    "publishes "
                                                    "logs "
                                                    "to "
                                                    "a "
                                                    "Google "
                                                    "Cloud "
                                                    "Pub/Sub "
                                                    "topic.",
                                                    "properties": {
                                                        "auth": {
                                                            "description": "GCP "
                                                            "credentials "
                                                            "used "
                                                            "to "
                                                            "authenticate "
                                                            "with "
                                                            "Google "
                                                            "Cloud "
                                                            "Storage.",
                                                            "properties": {
                                                                "credentials_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "GCP "
                                                                    "service "
                                                                    "account "
                                                                    "key "
                                                                    "file.",
                                                                    "example": "/var/secrets/gcp-credentials.json",
                                                                    "type": "string",
                                                                }
                                                            },
                                                            "required": ["credentials_file"],
                                                            "type": "object",
                                                        },
                                                        "encoding": {
                                                            "description": "Encoding "
                                                            "format "
                                                            "for "
                                                            "log "
                                                            "events.",
                                                            "enum": ["json", "raw_message"],
                                                            "example": "json",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "JSON",
                                                                "RAW_MESSAGE",
                                                            ],
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": "google-pubsub-destination",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["filter-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "project": {
                                                            "description": "The "
                                                            "GCP "
                                                            "project "
                                                            "ID "
                                                            "that "
                                                            "owns "
                                                            "the "
                                                            "Pub/Sub "
                                                            "topic.",
                                                            "example": "my-gcp-project",
                                                            "type": "string",
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "topic": {
                                                            "description": "The "
                                                            "Pub/Sub "
                                                            "topic "
                                                            "name "
                                                            "to "
                                                            "publish "
                                                            "logs "
                                                            "to.",
                                                            "example": "logs-subscription",
                                                            "type": "string",
                                                        },
                                                        "type": {
                                                            "default": "google_pubsub",
                                                            "description": "The "
                                                            "destination "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`google_pubsub`.",
                                                            "enum": ["google_pubsub"],
                                                            "example": "google_pubsub",
                                                            "type": "string",
                                                            "x-enum-varnames": ["GOOGLE_PUBSUB"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "inputs",
                                                        "encoding",
                                                        "project",
                                                        "topic",
                                                    ],
                                                    "type": "object",
                                                },
                                            ],
                                        },
                                        "type": "array",
                                    },
                                    "processors": {
                                        "description": "A "
                                        "list "
                                        "of "
                                        "processors "
                                        "that "
                                        "transform "
                                        "or "
                                        "enrich "
                                        "log "
                                        "data.",
                                        "example": [
                                            {
                                                "id": "filter-processor",
                                                "include": "service:my-service",
                                                "inputs": ["datadog-agent-source"],
                                                "type": "filter",
                                            }
                                        ],
                                        "items": {
                                            "description": "A processor for the pipeline.",
                                            "oneOf": [
                                                {
                                                    "description": "The "
                                                    "`filter` "
                                                    "processor "
                                                    "allows "
                                                    "conditional "
                                                    "processing "
                                                    "of "
                                                    "logs "
                                                    "based "
                                                    "on "
                                                    "a "
                                                    "Datadog "
                                                    "search "
                                                    "query. "
                                                    "Logs "
                                                    "that "
                                                    "match "
                                                    "the "
                                                    "`include` "
                                                    "query "
                                                    "are "
                                                    "passed "
                                                    "through; "
                                                    "others "
                                                    "are "
                                                    "discarded.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(for "
                                                            "example, "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "filter-processor",
                                                            "type": "string",
                                                        },
                                                        "include": {
                                                            "description": "A "
                                                            "Datadog "
                                                            "search "
                                                            "query "
                                                            "used "
                                                            "to "
                                                            "determine "
                                                            "which "
                                                            "logs "
                                                            "should "
                                                            "pass "
                                                            "through "
                                                            "the "
                                                            "filter. "
                                                            "Logs "
                                                            "that "
                                                            "match "
                                                            "this "
                                                            "query "
                                                            "continue "
                                                            "to "
                                                            "downstream "
                                                            "components; "
                                                            "others "
                                                            "are "
                                                            "dropped.",
                                                            "example": "service:my-service",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["datadog-agent-source"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "filter",
                                                            "description": "The "
                                                            "processor "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`filter`.",
                                                            "enum": ["filter"],
                                                            "example": "filter",
                                                            "type": "string",
                                                            "x-enum-varnames": ["FILTER"],
                                                        },
                                                    },
                                                    "required": ["id", "type", "include", "inputs"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`parse_json` "
                                                    "processor "
                                                    "extracts "
                                                    "JSON "
                                                    "from "
                                                    "a "
                                                    "specified "
                                                    "field "
                                                    "and "
                                                    "flattens "
                                                    "it "
                                                    "into "
                                                    "the "
                                                    "event. "
                                                    "This "
                                                    "is "
                                                    "useful "
                                                    "when "
                                                    "logs "
                                                    "contain "
                                                    "embedded "
                                                    "JSON "
                                                    "as "
                                                    "a "
                                                    "string.",
                                                    "properties": {
                                                        "field": {
                                                            "description": "The "
                                                            "name "
                                                            "of "
                                                            "the "
                                                            "log "
                                                            "field "
                                                            "that "
                                                            "contains "
                                                            "a "
                                                            "JSON "
                                                            "string.",
                                                            "example": "message",
                                                            "type": "string",
                                                        },
                                                        "id": {
                                                            "description": "A "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(e.g., "
                                                            "as "
                                                            "input "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "parse-json-processor",
                                                            "type": "string",
                                                        },
                                                        "include": {
                                                            "description": "A "
                                                            "Datadog "
                                                            "search "
                                                            "query "
                                                            "used "
                                                            "to "
                                                            "determine "
                                                            "which "
                                                            "logs "
                                                            "this "
                                                            "processor "
                                                            "targets.",
                                                            "example": "service:my-service",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["datadog-agent-source"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "parse_json",
                                                            "description": "The "
                                                            "processor "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`parse_json`.",
                                                            "enum": ["parse_json"],
                                                            "example": "parse_json",
                                                            "type": "string",
                                                            "x-enum-varnames": ["PARSE_JSON"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "include",
                                                        "field",
                                                        "inputs",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "Quota "
                                                    "Processor "
                                                    "measures "
                                                    "logging "
                                                    "traffic "
                                                    "for "
                                                    "logs "
                                                    "that "
                                                    "match "
                                                    "a "
                                                    "specified "
                                                    "filter. "
                                                    "When "
                                                    "the "
                                                    "configured "
                                                    "daily "
                                                    "quota "
                                                    "is "
                                                    "met, "
                                                    "the "
                                                    "processor "
                                                    "can "
                                                    "drop "
                                                    "or "
                                                    "alert.",
                                                    "properties": {
                                                        "drop_events": {
                                                            "description": "If "
                                                            "set "
                                                            "to "
                                                            "`true`, "
                                                            "logs "
                                                            "that "
                                                            "matched "
                                                            "the "
                                                            "quota "
                                                            "filter "
                                                            "and "
                                                            "sent "
                                                            "after "
                                                            "the "
                                                            "quota "
                                                            "has "
                                                            "been "
                                                            "met "
                                                            "are "
                                                            "dropped; "
                                                            "only "
                                                            "logs "
                                                            "that "
                                                            "did "
                                                            "not "
                                                            "match "
                                                            "the "
                                                            "filter "
                                                            "query "
                                                            "continue "
                                                            "through "
                                                            "the "
                                                            "pipeline.",
                                                            "example": False,
                                                            "type": "boolean",
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(for "
                                                            "example, "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "quota-processor",
                                                            "type": "string",
                                                        },
                                                        "ignore_when_missing_partitions": {
                                                            "description": "If "
                                                            "`true`, "
                                                            "the "
                                                            "processor "
                                                            "skips "
                                                            "quota "
                                                            "checks "
                                                            "when "
                                                            "partition "
                                                            "fields "
                                                            "are "
                                                            "missing "
                                                            "from "
                                                            "the "
                                                            "logs.",
                                                            "type": "boolean",
                                                        },
                                                        "include": {
                                                            "description": "A "
                                                            "Datadog "
                                                            "search "
                                                            "query "
                                                            "used "
                                                            "to "
                                                            "determine "
                                                            "which "
                                                            "logs "
                                                            "this "
                                                            "processor "
                                                            "targets.",
                                                            "example": "service:my-service",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["datadog-agent-source"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "limit": {
                                                            "description": "The "
                                                            "maximum "
                                                            "amount "
                                                            "of "
                                                            "data "
                                                            "or "
                                                            "number "
                                                            "of "
                                                            "events "
                                                            "allowed "
                                                            "before "
                                                            "the "
                                                            "quota "
                                                            "is "
                                                            "enforced. "
                                                            "Can "
                                                            "be "
                                                            "specified "
                                                            "in "
                                                            "bytes "
                                                            "or "
                                                            "events.",
                                                            "properties": {
                                                                "enforce": {
                                                                    "description": "Unit "
                                                                    "for "
                                                                    "quota "
                                                                    "enforcement "
                                                                    "in "
                                                                    "bytes "
                                                                    "for "
                                                                    "data "
                                                                    "size "
                                                                    "or "
                                                                    "events "
                                                                    "for "
                                                                    "count.",
                                                                    "enum": ["bytes", "events"],
                                                                    "example": "bytes",
                                                                    "type": "string",
                                                                    "x-enum-varnames": [
                                                                        "BYTES",
                                                                        "EVENTS",
                                                                    ],
                                                                },
                                                                "limit": {
                                                                    "description": "The "
                                                                    "limit "
                                                                    "for "
                                                                    "quota "
                                                                    "enforcement.",
                                                                    "example": 1000,
                                                                    "format": "int64",
                                                                    "type": "integer",
                                                                },
                                                            },
                                                            "required": ["enforce", "limit"],
                                                            "type": "object",
                                                        },
                                                        "name": {
                                                            "description": "Name of the quota.",
                                                            "example": "MyQuota",
                                                            "type": "string",
                                                        },
                                                        "overflow_action": {
                                                            "description": "The "
                                                            "action "
                                                            "to "
                                                            "take "
                                                            "when "
                                                            "the "
                                                            "quota "
                                                            "is "
                                                            "exceeded. "
                                                            "Options:\n"
                                                            "- "
                                                            "`drop`: "
                                                            "Drop "
                                                            "the "
                                                            "event.\n"
                                                            "- "
                                                            "`no_action`: "
                                                            "Let "
                                                            "the "
                                                            "event "
                                                            "pass "
                                                            "through.\n"
                                                            "- "
                                                            "`overflow_routing`: "
                                                            "Route "
                                                            "to "
                                                            "an "
                                                            "overflow "
                                                            "destination.",
                                                            "enum": [
                                                                "drop",
                                                                "no_action",
                                                                "overflow_routing",
                                                            ],
                                                            "example": "drop",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "DROP",
                                                                "NO_ACTION",
                                                                "OVERFLOW_ROUTING",
                                                            ],
                                                        },
                                                        "overrides": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "alternate "
                                                            "quota "
                                                            "rules "
                                                            "that "
                                                            "apply "
                                                            "to "
                                                            "specific "
                                                            "sets "
                                                            "of "
                                                            "events, "
                                                            "identified "
                                                            "by "
                                                            "matching "
                                                            "field "
                                                            "values. "
                                                            "Each "
                                                            "override "
                                                            "can "
                                                            "define "
                                                            "a "
                                                            "custom "
                                                            "limit.",
                                                            "items": {
                                                                "description": "Defines "
                                                                "a "
                                                                "custom "
                                                                "quota "
                                                                "limit "
                                                                "that "
                                                                "applies "
                                                                "to "
                                                                "specific "
                                                                "log "
                                                                "events "
                                                                "based "
                                                                "on "
                                                                "matching "
                                                                "field "
                                                                "values.",
                                                                "properties": {
                                                                    "fields": {
                                                                        "description": "A "
                                                                        "list "
                                                                        "of "
                                                                        "field "
                                                                        "matchers "
                                                                        "used "
                                                                        "to "
                                                                        "apply "
                                                                        "a "
                                                                        "specific "
                                                                        "override. "
                                                                        "If "
                                                                        "an "
                                                                        "event "
                                                                        "matches "
                                                                        "all "
                                                                        "listed "
                                                                        "key-value "
                                                                        "pairs, "
                                                                        "the "
                                                                        "corresponding "
                                                                        "override "
                                                                        "limit "
                                                                        "is "
                                                                        "enforced.",
                                                                        "items": {
                                                                            "description": "Represents "
                                                                            "a "
                                                                            "static "
                                                                            "key-value "
                                                                            "pair "
                                                                            "used "
                                                                            "in "
                                                                            "various "
                                                                            "processors.",
                                                                            "properties": {
                                                                                "name": {
                                                                                    "description": "The "
                                                                                    "field "
                                                                                    "name.",
                                                                                    "example": "field_name",
                                                                                    "type": "string",
                                                                                },
                                                                                "value": {
                                                                                    "description": "The "
                                                                                    "field "
                                                                                    "value.",
                                                                                    "example": "field_value",
                                                                                    "type": "string",
                                                                                },
                                                                            },
                                                                            "required": [
                                                                                "name",
                                                                                "value",
                                                                            ],
                                                                            "type": "object",
                                                                        },
                                                                        "type": "array",
                                                                    },
                                                                    "limit": {
                                                                        "description": "The "
                                                                        "maximum "
                                                                        "amount "
                                                                        "of "
                                                                        "data "
                                                                        "or "
                                                                        "number "
                                                                        "of "
                                                                        "events "
                                                                        "allowed "
                                                                        "before "
                                                                        "the "
                                                                        "quota "
                                                                        "is "
                                                                        "enforced. "
                                                                        "Can "
                                                                        "be "
                                                                        "specified "
                                                                        "in "
                                                                        "bytes "
                                                                        "or "
                                                                        "events.",
                                                                        "properties": {
                                                                            "enforce": {
                                                                                "description": "Unit "
                                                                                "for "
                                                                                "quota "
                                                                                "enforcement "
                                                                                "in "
                                                                                "bytes "
                                                                                "for "
                                                                                "data "
                                                                                "size "
                                                                                "or "
                                                                                "events "
                                                                                "for "
                                                                                "count.",
                                                                                "enum": [
                                                                                    "bytes",
                                                                                    "events",
                                                                                ],
                                                                                "example": "bytes",
                                                                                "type": "string",
                                                                                "x-enum-varnames": [
                                                                                    "BYTES",
                                                                                    "EVENTS",
                                                                                ],
                                                                            },
                                                                            "limit": {
                                                                                "description": "The "
                                                                                "limit "
                                                                                "for "
                                                                                "quota "
                                                                                "enforcement.",
                                                                                "example": 1000,
                                                                                "format": "int64",
                                                                                "type": "integer",
                                                                            },
                                                                        },
                                                                        "required": [
                                                                            "enforce",
                                                                            "limit",
                                                                        ],
                                                                        "type": "object",
                                                                    },
                                                                },
                                                                "required": ["fields", "limit"],
                                                                "type": "object",
                                                            },
                                                            "type": "array",
                                                        },
                                                        "partition_fields": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "fields "
                                                            "used "
                                                            "to "
                                                            "segment "
                                                            "log "
                                                            "traffic "
                                                            "for "
                                                            "quota "
                                                            "enforcement. "
                                                            "Quotas "
                                                            "are "
                                                            "tracked "
                                                            "independently "
                                                            "by "
                                                            "unique "
                                                            "combinations "
                                                            "of "
                                                            "these "
                                                            "field "
                                                            "values.",
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "quota",
                                                            "description": "The "
                                                            "processor "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`quota`.",
                                                            "enum": ["quota"],
                                                            "example": "quota",
                                                            "type": "string",
                                                            "x-enum-varnames": ["QUOTA"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "include",
                                                        "name",
                                                        "drop_events",
                                                        "limit",
                                                        "inputs",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`add_fields` "
                                                    "processor "
                                                    "adds "
                                                    "static "
                                                    "key-value "
                                                    "fields "
                                                    "to "
                                                    "logs.",
                                                    "properties": {
                                                        "fields": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "static "
                                                            "fields "
                                                            "(key-value "
                                                            "pairs) "
                                                            "that "
                                                            "is "
                                                            "added "
                                                            "to "
                                                            "each "
                                                            "log "
                                                            "event "
                                                            "processed "
                                                            "by "
                                                            "this "
                                                            "component.",
                                                            "items": {
                                                                "description": "Represents "
                                                                "a "
                                                                "static "
                                                                "key-value "
                                                                "pair "
                                                                "used "
                                                                "in "
                                                                "various "
                                                                "processors.",
                                                                "properties": {
                                                                    "name": {
                                                                        "description": "The "
                                                                        "field "
                                                                        "name.",
                                                                        "example": "field_name",
                                                                        "type": "string",
                                                                    },
                                                                    "value": {
                                                                        "description": "The "
                                                                        "field "
                                                                        "value.",
                                                                        "example": "field_value",
                                                                        "type": "string",
                                                                    },
                                                                },
                                                                "required": ["name", "value"],
                                                                "type": "object",
                                                            },
                                                            "type": "array",
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(for "
                                                            "example, "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "add-fields-processor",
                                                            "type": "string",
                                                        },
                                                        "include": {
                                                            "description": "A "
                                                            "Datadog "
                                                            "search "
                                                            "query "
                                                            "used "
                                                            "to "
                                                            "determine "
                                                            "which "
                                                            "logs "
                                                            "this "
                                                            "processor "
                                                            "targets.",
                                                            "example": "service:my-service",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["datadog-agent-source"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "add_fields",
                                                            "description": "The "
                                                            "processor "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`add_fields`.",
                                                            "enum": ["add_fields"],
                                                            "example": "add_fields",
                                                            "type": "string",
                                                            "x-enum-varnames": ["ADD_FIELDS"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "include",
                                                        "fields",
                                                        "inputs",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`remove_fields` "
                                                    "processor "
                                                    "deletes "
                                                    "specified "
                                                    "fields "
                                                    "from "
                                                    "logs.",
                                                    "properties": {
                                                        "fields": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "field "
                                                            "names "
                                                            "to "
                                                            "be "
                                                            "removed "
                                                            "from "
                                                            "each "
                                                            "log "
                                                            "event.",
                                                            "example": ["field1", "field2"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(e.g., "
                                                            "as "
                                                            "input "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "remove-fields-processor",
                                                            "type": "string",
                                                        },
                                                        "include": {
                                                            "description": "A "
                                                            "Datadog "
                                                            "search "
                                                            "query "
                                                            "used "
                                                            "to "
                                                            "determine "
                                                            "which "
                                                            "logs "
                                                            "this "
                                                            "processor "
                                                            "targets.",
                                                            "example": "service:my-service",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "The "
                                                            "`PipelineRemoveFieldsProcessor` "
                                                            "`inputs`.",
                                                            "example": ["datadog-agent-source"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "remove_fields",
                                                            "description": "The "
                                                            "processor "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`remove_fields`.",
                                                            "enum": ["remove_fields"],
                                                            "example": "remove_fields",
                                                            "type": "string",
                                                            "x-enum-varnames": ["REMOVE_FIELDS"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "include",
                                                        "fields",
                                                        "inputs",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`rename_fields` "
                                                    "processor "
                                                    "changes "
                                                    "field "
                                                    "names.",
                                                    "properties": {
                                                        "fields": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "rename "
                                                            "rules "
                                                            "specifying "
                                                            "which "
                                                            "fields "
                                                            "to "
                                                            "rename "
                                                            "in "
                                                            "the "
                                                            "event, "
                                                            "what "
                                                            "to "
                                                            "rename "
                                                            "them "
                                                            "to, "
                                                            "and "
                                                            "whether "
                                                            "to "
                                                            "preserve "
                                                            "the "
                                                            "original "
                                                            "fields.",
                                                            "items": {
                                                                "description": "Defines "
                                                                "how "
                                                                "to "
                                                                "rename "
                                                                "a "
                                                                "field "
                                                                "in "
                                                                "log "
                                                                "events.",
                                                                "properties": {
                                                                    "destination": {
                                                                        "description": "The "
                                                                        "field "
                                                                        "name "
                                                                        "to "
                                                                        "assign "
                                                                        "the "
                                                                        "renamed "
                                                                        "value "
                                                                        "to.",
                                                                        "example": "destination_field",
                                                                        "type": "string",
                                                                    },
                                                                    "preserve_source": {
                                                                        "description": "Indicates "
                                                                        "whether "
                                                                        "the "
                                                                        "original "
                                                                        "field, "
                                                                        "that "
                                                                        "is "
                                                                        "received "
                                                                        "from "
                                                                        "the "
                                                                        "source, "
                                                                        "should "
                                                                        "be "
                                                                        "kept "
                                                                        "(`true`) "
                                                                        "or "
                                                                        "removed "
                                                                        "(`false`) "
                                                                        "after "
                                                                        "renaming.",
                                                                        "example": False,
                                                                        "type": "boolean",
                                                                    },
                                                                    "source": {
                                                                        "description": "The "
                                                                        "original "
                                                                        "field "
                                                                        "name "
                                                                        "in "
                                                                        "the "
                                                                        "log "
                                                                        "event "
                                                                        "that "
                                                                        "should "
                                                                        "be "
                                                                        "renamed.",
                                                                        "example": "source_field",
                                                                        "type": "string",
                                                                    },
                                                                },
                                                                "required": [
                                                                    "source",
                                                                    "destination",
                                                                    "preserve_source",
                                                                ],
                                                                "type": "object",
                                                            },
                                                            "type": "array",
                                                        },
                                                        "id": {
                                                            "description": "A "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(e.g., "
                                                            "as "
                                                            "input "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "rename-fields-processor",
                                                            "type": "string",
                                                        },
                                                        "include": {
                                                            "description": "A "
                                                            "Datadog "
                                                            "search "
                                                            "query "
                                                            "used "
                                                            "to "
                                                            "determine "
                                                            "which "
                                                            "logs "
                                                            "this "
                                                            "processor "
                                                            "targets.",
                                                            "example": "service:my-service",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["datadog-agent-source"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "rename_fields",
                                                            "description": "The "
                                                            "processor "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`rename_fields`.",
                                                            "enum": ["rename_fields"],
                                                            "example": "rename_fields",
                                                            "type": "string",
                                                            "x-enum-varnames": ["RENAME_FIELDS"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "include",
                                                        "fields",
                                                        "inputs",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`generate_datadog_metrics` "
                                                    "processor "
                                                    "creates "
                                                    "custom "
                                                    "metrics "
                                                    "from "
                                                    "logs "
                                                    "and "
                                                    "sends "
                                                    "them "
                                                    "to "
                                                    "Datadog.\n"
                                                    "Metrics "
                                                    "can "
                                                    "be "
                                                    "counters, "
                                                    "gauges, "
                                                    "or "
                                                    "distributions "
                                                    "and "
                                                    "optionally "
                                                    "grouped "
                                                    "by "
                                                    "log "
                                                    "fields.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline.",
                                                            "example": "generate-metrics-processor",
                                                            "type": "string",
                                                        },
                                                        "include": {
                                                            "description": "A "
                                                            "Datadog "
                                                            "search "
                                                            "query "
                                                            "used "
                                                            "to "
                                                            "determine "
                                                            "which "
                                                            "logs "
                                                            "this "
                                                            "processor "
                                                            "targets.",
                                                            "example": "service:my-service",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "processor.",
                                                            "example": ["source-id"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "metrics": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "generating "
                                                            "individual "
                                                            "metrics.",
                                                            "items": {
                                                                "description": "Defines "
                                                                "a "
                                                                "log-based "
                                                                "custom "
                                                                "metric, "
                                                                "including "
                                                                "its "
                                                                "name, "
                                                                "type, "
                                                                "filter, "
                                                                "value "
                                                                "computation "
                                                                "strategy,\n"
                                                                "and "
                                                                "optional "
                                                                "grouping "
                                                                "fields.",
                                                                "properties": {
                                                                    "group_by": {
                                                                        "description": "Optional "
                                                                        "fields "
                                                                        "used "
                                                                        "to "
                                                                        "group "
                                                                        "the "
                                                                        "metric "
                                                                        "series.",
                                                                        "example": [
                                                                            "service",
                                                                            "env",
                                                                        ],
                                                                        "items": {"type": "string"},
                                                                        "type": "array",
                                                                    },
                                                                    "include": {
                                                                        "description": "Datadog "
                                                                        "filter "
                                                                        "query "
                                                                        "to "
                                                                        "match "
                                                                        "logs "
                                                                        "for "
                                                                        "metric "
                                                                        "generation.",
                                                                        "example": "service:billing",
                                                                        "type": "string",
                                                                    },
                                                                    "metric_type": {
                                                                        "description": "Type "
                                                                        "of "
                                                                        "metric "
                                                                        "to "
                                                                        "create.",
                                                                        "enum": [
                                                                            "count",
                                                                            "gauge",
                                                                            "distribution",
                                                                        ],
                                                                        "example": "count",
                                                                        "type": "string",
                                                                        "x-enum-varnames": [
                                                                            "COUNT",
                                                                            "GAUGE",
                                                                            "DISTRIBUTION",
                                                                        ],
                                                                    },
                                                                    "name": {
                                                                        "description": "Name "
                                                                        "of "
                                                                        "the "
                                                                        "custom "
                                                                        "metric "
                                                                        "to "
                                                                        "be "
                                                                        "created.",
                                                                        "example": "logs.processed",
                                                                        "type": "string",
                                                                    },
                                                                    "value": {
                                                                        "description": "Specifies "
                                                                        "how "
                                                                        "the "
                                                                        "value "
                                                                        "of "
                                                                        "the "
                                                                        "generated "
                                                                        "metric "
                                                                        "is "
                                                                        "computed.",
                                                                        "oneOf": [
                                                                            {
                                                                                "description": "Strategy "
                                                                                "that "
                                                                                "increments "
                                                                                "a "
                                                                                "generated "
                                                                                "metric "
                                                                                "by "
                                                                                "one "
                                                                                "for "
                                                                                "each "
                                                                                "matching "
                                                                                "event.",
                                                                                "properties": {
                                                                                    "strategy": {
                                                                                        "description": "Increments "
                                                                                        "the "
                                                                                        "metric "
                                                                                        "by "
                                                                                        "1 "
                                                                                        "for "
                                                                                        "each "
                                                                                        "matching "
                                                                                        "event.",
                                                                                        "enum": [
                                                                                            "increment_by_one"
                                                                                        ],
                                                                                        "example": "increment_by_one",
                                                                                        "type": "string",
                                                                                        "x-enum-varnames": [
                                                                                            "INCREMENT_BY_ONE"
                                                                                        ],
                                                                                    }
                                                                                },
                                                                                "required": [
                                                                                    "strategy"
                                                                                ],
                                                                                "type": "object",
                                                                            },
                                                                            {
                                                                                "description": "Strategy "
                                                                                "that "
                                                                                "increments "
                                                                                "a "
                                                                                "generated "
                                                                                "metric "
                                                                                "based "
                                                                                "on "
                                                                                "the "
                                                                                "value "
                                                                                "of "
                                                                                "a "
                                                                                "log "
                                                                                "field.",
                                                                                "properties": {
                                                                                    "field": {
                                                                                        "description": "Name "
                                                                                        "of "
                                                                                        "the "
                                                                                        "log "
                                                                                        "field "
                                                                                        "containing "
                                                                                        "the "
                                                                                        "numeric "
                                                                                        "value "
                                                                                        "to "
                                                                                        "increment "
                                                                                        "the "
                                                                                        "metric "
                                                                                        "by.",
                                                                                        "example": "errors",
                                                                                        "type": "string",
                                                                                    },
                                                                                    "strategy": {
                                                                                        "description": "Uses "
                                                                                        "a "
                                                                                        "numeric "
                                                                                        "field "
                                                                                        "in "
                                                                                        "the "
                                                                                        "log "
                                                                                        "event "
                                                                                        "as "
                                                                                        "the "
                                                                                        "metric "
                                                                                        "increment.",
                                                                                        "enum": [
                                                                                            "increment_by_field"
                                                                                        ],
                                                                                        "example": "increment_by_field",
                                                                                        "type": "string",
                                                                                        "x-enum-varnames": [
                                                                                            "INCREMENT_BY_FIELD"
                                                                                        ],
                                                                                    },
                                                                                },
                                                                                "required": [
                                                                                    "strategy",
                                                                                    "field",
                                                                                ],
                                                                                "type": "object",
                                                                            },
                                                                        ],
                                                                    },
                                                                },
                                                                "required": [
                                                                    "name",
                                                                    "include",
                                                                    "metric_type",
                                                                    "value",
                                                                ],
                                                                "type": "object",
                                                            },
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "generate_datadog_metrics",
                                                            "description": "The "
                                                            "processor "
                                                            "type. "
                                                            "Always "
                                                            "`generate_datadog_metrics`.",
                                                            "enum": ["generate_datadog_metrics"],
                                                            "example": "generate_datadog_metrics",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "GENERATE_DATADOG_METRICS"
                                                            ],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "inputs",
                                                        "include",
                                                        "metrics",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`sample` "
                                                    "processor "
                                                    "allows "
                                                    "probabilistic "
                                                    "sampling "
                                                    "of "
                                                    "logs "
                                                    "at "
                                                    "a "
                                                    "fixed "
                                                    "rate.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(for "
                                                            "example, "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "sample-processor",
                                                            "type": "string",
                                                        },
                                                        "include": {
                                                            "description": "A "
                                                            "Datadog "
                                                            "search "
                                                            "query "
                                                            "used "
                                                            "to "
                                                            "determine "
                                                            "which "
                                                            "logs "
                                                            "this "
                                                            "processor "
                                                            "targets.",
                                                            "example": "service:my-service",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["datadog-agent-source"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "percentage": {
                                                            "description": "The "
                                                            "percentage "
                                                            "of "
                                                            "logs "
                                                            "to "
                                                            "sample.",
                                                            "example": 10.0,
                                                            "format": "double",
                                                            "type": "number",
                                                        },
                                                        "rate": {
                                                            "description": "Number "
                                                            "of "
                                                            "events "
                                                            "to "
                                                            "sample "
                                                            "(1 "
                                                            "in "
                                                            "N).",
                                                            "example": 10,
                                                            "format": "int64",
                                                            "minimum": 1,
                                                            "type": "integer",
                                                        },
                                                        "type": {
                                                            "default": "sample",
                                                            "description": "The "
                                                            "processor "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`sample`.",
                                                            "enum": ["sample"],
                                                            "example": "sample",
                                                            "type": "string",
                                                            "x-enum-varnames": ["SAMPLE"],
                                                        },
                                                    },
                                                    "required": ["id", "type", "include", "inputs"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`parse_grok` "
                                                    "processor "
                                                    "extracts "
                                                    "structured "
                                                    "fields "
                                                    "from "
                                                    "unstructured "
                                                    "log "
                                                    "messages "
                                                    "using "
                                                    "Grok "
                                                    "patterns.",
                                                    "properties": {
                                                        "disable_library_rules": {
                                                            "default": False,
                                                            "description": "If "
                                                            "set "
                                                            "to "
                                                            "`true`, "
                                                            "disables "
                                                            "the "
                                                            "default "
                                                            "Grok "
                                                            "rules "
                                                            "provided "
                                                            "by "
                                                            "Datadog.",
                                                            "example": True,
                                                            "type": "boolean",
                                                        },
                                                        "id": {
                                                            "description": "A "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "processor.",
                                                            "example": "parse-grok-processor",
                                                            "type": "string",
                                                        },
                                                        "include": {
                                                            "description": "A "
                                                            "Datadog "
                                                            "search "
                                                            "query "
                                                            "used "
                                                            "to "
                                                            "determine "
                                                            "which "
                                                            "logs "
                                                            "this "
                                                            "processor "
                                                            "targets.",
                                                            "example": "service:my-service",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["datadog-agent-source"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "rules": {
                                                            "description": "The "
                                                            "list "
                                                            "of "
                                                            "Grok "
                                                            "parsing "
                                                            "rules. "
                                                            "If "
                                                            "multiple "
                                                            "matching "
                                                            "rules "
                                                            "are "
                                                            "provided, "
                                                            "they "
                                                            "are "
                                                            "evaluated "
                                                            "in "
                                                            "order. "
                                                            "The "
                                                            "first "
                                                            "successful "
                                                            "match "
                                                            "is "
                                                            "applied.",
                                                            "items": {
                                                                "description": "A "
                                                                "Grok "
                                                                "parsing "
                                                                "rule "
                                                                "used "
                                                                "in "
                                                                "the "
                                                                "`parse_grok` "
                                                                "processor. "
                                                                "Each "
                                                                "rule "
                                                                "defines "
                                                                "how "
                                                                "to "
                                                                "extract "
                                                                "structured "
                                                                "fields\n"
                                                                "from "
                                                                "a "
                                                                "specific "
                                                                "log "
                                                                "field "
                                                                "using "
                                                                "Grok "
                                                                "patterns.",
                                                                "properties": {
                                                                    "match_rules": {
                                                                        "description": "A "
                                                                        "list "
                                                                        "of "
                                                                        "Grok "
                                                                        "parsing "
                                                                        "rules "
                                                                        "that "
                                                                        "define "
                                                                        "how "
                                                                        "to "
                                                                        "extract "
                                                                        "fields "
                                                                        "from "
                                                                        "the "
                                                                        "source "
                                                                        "field.\n"
                                                                        "Each "
                                                                        "rule "
                                                                        "must "
                                                                        "contain "
                                                                        "a "
                                                                        "name "
                                                                        "and "
                                                                        "a "
                                                                        "valid "
                                                                        "Grok "
                                                                        "pattern.",
                                                                        "example": [
                                                                            {
                                                                                "name": "MyParsingRule",
                                                                                "rule": "%{word:user} "
                                                                                "connected "
                                                                                "on "
                                                                                '%{date("MM/dd/yyyy"):date}',
                                                                            }
                                                                        ],
                                                                        "items": {
                                                                            "description": "Defines "
                                                                            "a "
                                                                            "Grok "
                                                                            "parsing "
                                                                            "rule, "
                                                                            "which "
                                                                            "extracts "
                                                                            "structured "
                                                                            "fields "
                                                                            "from "
                                                                            "log "
                                                                            "content "
                                                                            "using "
                                                                            "named "
                                                                            "Grok "
                                                                            "patterns.\n"
                                                                            "Each "
                                                                            "rule "
                                                                            "must "
                                                                            "have "
                                                                            "a "
                                                                            "unique "
                                                                            "name "
                                                                            "and "
                                                                            "a "
                                                                            "valid "
                                                                            "Datadog "
                                                                            "Grok "
                                                                            "pattern "
                                                                            "that "
                                                                            "will "
                                                                            "be "
                                                                            "applied "
                                                                            "to "
                                                                            "the "
                                                                            "source "
                                                                            "field.",
                                                                            "properties": {
                                                                                "name": {
                                                                                    "description": "The "
                                                                                    "name "
                                                                                    "of "
                                                                                    "the "
                                                                                    "rule.",
                                                                                    "example": "MyParsingRule",
                                                                                    "type": "string",
                                                                                },
                                                                                "rule": {
                                                                                    "description": "The "
                                                                                    "definition "
                                                                                    "of "
                                                                                    "the "
                                                                                    "Grok "
                                                                                    "rule.",
                                                                                    "example": "%{word:user} "
                                                                                    "connected "
                                                                                    "on "
                                                                                    '%{date("MM/dd/yyyy"):date}',
                                                                                    "type": "string",
                                                                                },
                                                                            },
                                                                            "required": [
                                                                                "name",
                                                                                "rule",
                                                                            ],
                                                                            "type": "object",
                                                                        },
                                                                        "type": "array",
                                                                    },
                                                                    "source": {
                                                                        "description": "The "
                                                                        "name "
                                                                        "of "
                                                                        "the "
                                                                        "field "
                                                                        "in "
                                                                        "the "
                                                                        "log "
                                                                        "event "
                                                                        "to "
                                                                        "apply "
                                                                        "the "
                                                                        "Grok "
                                                                        "rules "
                                                                        "to.",
                                                                        "example": "message",
                                                                        "type": "string",
                                                                    },
                                                                    "support_rules": {
                                                                        "description": "A "
                                                                        "list "
                                                                        "of "
                                                                        "Grok "
                                                                        "helper "
                                                                        "rules "
                                                                        "that "
                                                                        "can "
                                                                        "be "
                                                                        "referenced "
                                                                        "by "
                                                                        "the "
                                                                        "parsing "
                                                                        "rules.",
                                                                        "example": [
                                                                            {
                                                                                "name": "user",
                                                                                "rule": "%{word:user.name}",
                                                                            }
                                                                        ],
                                                                        "items": {
                                                                            "description": "The "
                                                                            "Grok "
                                                                            "helper "
                                                                            "rule "
                                                                            "referenced "
                                                                            "in "
                                                                            "the "
                                                                            "parsing "
                                                                            "rules.",
                                                                            "properties": {
                                                                                "name": {
                                                                                    "description": "The "
                                                                                    "name "
                                                                                    "of "
                                                                                    "the "
                                                                                    "Grok "
                                                                                    "helper "
                                                                                    "rule.",
                                                                                    "example": "user",
                                                                                    "type": "string",
                                                                                },
                                                                                "rule": {
                                                                                    "description": "The "
                                                                                    "definition "
                                                                                    "of "
                                                                                    "the "
                                                                                    "Grok "
                                                                                    "helper "
                                                                                    "rule.",
                                                                                    "example": " "
                                                                                    "%{word:user.name}",
                                                                                    "type": "string",
                                                                                },
                                                                            },
                                                                            "required": [
                                                                                "name",
                                                                                "rule",
                                                                            ],
                                                                            "type": "object",
                                                                        },
                                                                        "type": "array",
                                                                    },
                                                                },
                                                                "required": [
                                                                    "source",
                                                                    "match_rules",
                                                                ],
                                                                "type": "object",
                                                            },
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "parse_grok",
                                                            "description": "The "
                                                            "processor "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`parse_grok`.",
                                                            "enum": ["parse_grok"],
                                                            "example": "parse_grok",
                                                            "type": "string",
                                                            "x-enum-varnames": ["PARSE_GROK"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "include",
                                                        "inputs",
                                                        "rules",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`sensitive_data_scanner` "
                                                    "processor "
                                                    "detects "
                                                    "and "
                                                    "optionally "
                                                    "redacts "
                                                    "sensitive "
                                                    "data "
                                                    "in "
                                                    "log "
                                                    "events.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(e.g., "
                                                            "as "
                                                            "input "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "sensitive-scanner",
                                                            "type": "string",
                                                        },
                                                        "include": {
                                                            "description": "A "
                                                            "Datadog "
                                                            "search "
                                                            "query "
                                                            "used "
                                                            "to "
                                                            "determine "
                                                            "which "
                                                            "logs "
                                                            "this "
                                                            "processor "
                                                            "targets.",
                                                            "example": "source:prod",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["parse-json-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "rules": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "rules "
                                                            "for "
                                                            "identifying "
                                                            "and "
                                                            "acting "
                                                            "on "
                                                            "sensitive "
                                                            "data "
                                                            "patterns.",
                                                            "items": {
                                                                "description": "Defines "
                                                                "a "
                                                                "rule "
                                                                "for "
                                                                "detecting "
                                                                "sensitive "
                                                                "data, "
                                                                "including "
                                                                "matching "
                                                                "pattern, "
                                                                "scope, "
                                                                "and "
                                                                "the "
                                                                "action "
                                                                "to "
                                                                "take.",
                                                                "properties": {
                                                                    "keyword_options": {
                                                                        "description": "Configuration "
                                                                        "for "
                                                                        "keywords "
                                                                        "used "
                                                                        "to "
                                                                        "reinforce "
                                                                        "sensitive "
                                                                        "data "
                                                                        "pattern "
                                                                        "detection.",
                                                                        "properties": {
                                                                            "keywords": {
                                                                                "description": "A "
                                                                                "list "
                                                                                "of "
                                                                                "keywords "
                                                                                "to "
                                                                                "match "
                                                                                "near "
                                                                                "the "
                                                                                "sensitive "
                                                                                "pattern.",
                                                                                "example": [
                                                                                    "ssn",
                                                                                    "card",
                                                                                    "account",
                                                                                ],
                                                                                "items": {
                                                                                    "type": "string"
                                                                                },
                                                                                "type": "array",
                                                                            },
                                                                            "proximity": {
                                                                                "description": "Maximum "
                                                                                "number "
                                                                                "of "
                                                                                "tokens "
                                                                                "between "
                                                                                "a "
                                                                                "keyword "
                                                                                "and "
                                                                                "a "
                                                                                "sensitive "
                                                                                "value "
                                                                                "match.",
                                                                                "example": 5,
                                                                                "format": "int64",
                                                                                "type": "integer",
                                                                            },
                                                                        },
                                                                        "required": [
                                                                            "keywords",
                                                                            "proximity",
                                                                        ],
                                                                        "type": "object",
                                                                    },
                                                                    "name": {
                                                                        "description": "A "
                                                                        "name "
                                                                        "identifying "
                                                                        "the "
                                                                        "rule.",
                                                                        "example": "Redact "
                                                                        "Credit "
                                                                        "Card "
                                                                        "Numbers",
                                                                        "type": "string",
                                                                    },
                                                                    "on_match": {
                                                                        "description": "Defines "
                                                                        "what "
                                                                        "action "
                                                                        "to "
                                                                        "take "
                                                                        "when "
                                                                        "sensitive "
                                                                        "data "
                                                                        "is "
                                                                        "matched.",
                                                                        "oneOf": [
                                                                            {
                                                                                "description": "Configuration "
                                                                                "for "
                                                                                "completely "
                                                                                "redacting "
                                                                                "matched "
                                                                                "sensitive "
                                                                                "data.",
                                                                                "properties": {
                                                                                    "action": {
                                                                                        "description": "Action "
                                                                                        "type "
                                                                                        "that "
                                                                                        "completely "
                                                                                        "replaces "
                                                                                        "the "
                                                                                        "matched "
                                                                                        "sensitive "
                                                                                        "data "
                                                                                        "with "
                                                                                        "a "
                                                                                        "fixed "
                                                                                        "replacement "
                                                                                        "string "
                                                                                        "to "
                                                                                        "remove "
                                                                                        "all "
                                                                                        "visibility.",
                                                                                        "enum": [
                                                                                            "redact"
                                                                                        ],
                                                                                        "example": "redact",
                                                                                        "type": "string",
                                                                                        "x-enum-varnames": [
                                                                                            "REDACT"
                                                                                        ],
                                                                                    },
                                                                                    "options": {
                                                                                        "description": "Configuration "
                                                                                        "for "
                                                                                        "fully "
                                                                                        "redacting "
                                                                                        "sensitive "
                                                                                        "data.",
                                                                                        "properties": {
                                                                                            "replace": {
                                                                                                "description": "The "
                                                                                                "`ObservabilityPipelineSensitiveDataScannerProcessorActionRedactOptions` "
                                                                                                "`replace`.",
                                                                                                "example": "***",
                                                                                                "type": "string",
                                                                                            }
                                                                                        },
                                                                                        "required": [
                                                                                            "replace"
                                                                                        ],
                                                                                        "type": "object",
                                                                                    },
                                                                                },
                                                                                "required": [
                                                                                    "action",
                                                                                    "options",
                                                                                ],
                                                                                "type": "object",
                                                                            },
                                                                            {
                                                                                "description": "Configuration "
                                                                                "for "
                                                                                "hashing "
                                                                                "matched "
                                                                                "sensitive "
                                                                                "values.",
                                                                                "properties": {
                                                                                    "action": {
                                                                                        "description": "Action "
                                                                                        "type "
                                                                                        "that "
                                                                                        "replaces "
                                                                                        "the "
                                                                                        "matched "
                                                                                        "sensitive "
                                                                                        "data "
                                                                                        "with "
                                                                                        "a "
                                                                                        "hashed "
                                                                                        "representation, "
                                                                                        "preserving "
                                                                                        "structure "
                                                                                        "while "
                                                                                        "securing "
                                                                                        "content.",
                                                                                        "enum": [
                                                                                            "hash"
                                                                                        ],
                                                                                        "example": "hash",
                                                                                        "type": "string",
                                                                                        "x-enum-varnames": [
                                                                                            "HASH"
                                                                                        ],
                                                                                    },
                                                                                    "options": {
                                                                                        "description": "The "
                                                                                        "`ObservabilityPipelineSensitiveDataScannerProcessorActionHash` "
                                                                                        "`options`.",
                                                                                        "type": "object",
                                                                                    },
                                                                                },
                                                                                "required": [
                                                                                    "action"
                                                                                ],
                                                                                "type": "object",
                                                                            },
                                                                            {
                                                                                "description": "Configuration "
                                                                                "for "
                                                                                "partially "
                                                                                "redacting "
                                                                                "matched "
                                                                                "sensitive "
                                                                                "data.",
                                                                                "properties": {
                                                                                    "action": {
                                                                                        "description": "Action "
                                                                                        "type "
                                                                                        "that "
                                                                                        "redacts "
                                                                                        "part "
                                                                                        "of "
                                                                                        "the "
                                                                                        "sensitive "
                                                                                        "data "
                                                                                        "while "
                                                                                        "preserving "
                                                                                        "a "
                                                                                        "configurable "
                                                                                        "number "
                                                                                        "of "
                                                                                        "characters, "
                                                                                        "typically "
                                                                                        "used "
                                                                                        "for "
                                                                                        "masking "
                                                                                        "purposes "
                                                                                        "(e.g., "
                                                                                        "show "
                                                                                        "last "
                                                                                        "4 "
                                                                                        "digits "
                                                                                        "of "
                                                                                        "a "
                                                                                        "credit "
                                                                                        "card).",
                                                                                        "enum": [
                                                                                            "partial_redact"
                                                                                        ],
                                                                                        "example": "partial_redact",
                                                                                        "type": "string",
                                                                                        "x-enum-varnames": [
                                                                                            "PARTIAL_REDACT"
                                                                                        ],
                                                                                    },
                                                                                    "options": {
                                                                                        "description": "Controls "
                                                                                        "how "
                                                                                        "partial "
                                                                                        "redaction "
                                                                                        "is "
                                                                                        "applied, "
                                                                                        "including "
                                                                                        "character "
                                                                                        "count "
                                                                                        "and "
                                                                                        "direction.",
                                                                                        "properties": {
                                                                                            "characters": {
                                                                                                "description": "The "
                                                                                                "`ObservabilityPipelineSensitiveDataScannerProcessorActionPartialRedactOptions` "
                                                                                                "`characters`.",
                                                                                                "example": 4,
                                                                                                "format": "int64",
                                                                                                "type": "integer",
                                                                                            },
                                                                                            "direction": {
                                                                                                "description": "Indicates "
                                                                                                "whether "
                                                                                                "to "
                                                                                                "redact "
                                                                                                "characters "
                                                                                                "from "
                                                                                                "the "
                                                                                                "first "
                                                                                                "or "
                                                                                                "last "
                                                                                                "part "
                                                                                                "of "
                                                                                                "the "
                                                                                                "matched "
                                                                                                "value.",
                                                                                                "enum": [
                                                                                                    "first",
                                                                                                    "last",
                                                                                                ],
                                                                                                "example": "last",
                                                                                                "type": "string",
                                                                                                "x-enum-varnames": [
                                                                                                    "FIRST",
                                                                                                    "LAST",
                                                                                                ],
                                                                                            },
                                                                                        },
                                                                                        "required": [
                                                                                            "characters",
                                                                                            "direction",
                                                                                        ],
                                                                                        "type": "object",
                                                                                    },
                                                                                },
                                                                                "required": [
                                                                                    "action",
                                                                                    "options",
                                                                                ],
                                                                                "type": "object",
                                                                            },
                                                                        ],
                                                                    },
                                                                    "pattern": {
                                                                        "description": "Pattern "
                                                                        "detection "
                                                                        "configuration "
                                                                        "for "
                                                                        "identifying "
                                                                        "sensitive "
                                                                        "data "
                                                                        "using "
                                                                        "either "
                                                                        "a "
                                                                        "custom "
                                                                        "regex "
                                                                        "or "
                                                                        "a "
                                                                        "library "
                                                                        "reference.",
                                                                        "oneOf": [
                                                                            {
                                                                                "description": "Defines "
                                                                                "a "
                                                                                "custom "
                                                                                "regex-based "
                                                                                "pattern "
                                                                                "for "
                                                                                "identifying "
                                                                                "sensitive "
                                                                                "data "
                                                                                "in "
                                                                                "logs.",
                                                                                "properties": {
                                                                                    "options": {
                                                                                        "description": "Options "
                                                                                        "for "
                                                                                        "defining "
                                                                                        "a "
                                                                                        "custom "
                                                                                        "regex "
                                                                                        "pattern.",
                                                                                        "properties": {
                                                                                            "rule": {
                                                                                                "description": "A "
                                                                                                "regular "
                                                                                                "expression "
                                                                                                "used "
                                                                                                "to "
                                                                                                "detect "
                                                                                                "sensitive "
                                                                                                "values. "
                                                                                                "Must "
                                                                                                "be "
                                                                                                "a "
                                                                                                "valid "
                                                                                                "regex.",
                                                                                                "example": "\\b\\d{16}\\b",
                                                                                                "type": "string",
                                                                                            }
                                                                                        },
                                                                                        "required": [
                                                                                            "rule"
                                                                                        ],
                                                                                        "type": "object",
                                                                                    },
                                                                                    "type": {
                                                                                        "description": "Indicates "
                                                                                        "a "
                                                                                        "custom "
                                                                                        "regular "
                                                                                        "expression "
                                                                                        "is "
                                                                                        "used "
                                                                                        "for "
                                                                                        "matching.",
                                                                                        "enum": [
                                                                                            "custom"
                                                                                        ],
                                                                                        "example": "custom",
                                                                                        "type": "string",
                                                                                        "x-enum-varnames": [
                                                                                            "CUSTOM"
                                                                                        ],
                                                                                    },
                                                                                },
                                                                                "required": [
                                                                                    "type",
                                                                                    "options",
                                                                                ],
                                                                                "type": "object",
                                                                            },
                                                                            {
                                                                                "description": "Specifies "
                                                                                "a "
                                                                                "pattern "
                                                                                "from "
                                                                                "Datadog’s "
                                                                                "sensitive "
                                                                                "data "
                                                                                "detection "
                                                                                "library "
                                                                                "to "
                                                                                "match "
                                                                                "known "
                                                                                "sensitive "
                                                                                "data "
                                                                                "types.",
                                                                                "properties": {
                                                                                    "options": {
                                                                                        "description": "Options "
                                                                                        "for "
                                                                                        "selecting "
                                                                                        "a "
                                                                                        "predefined "
                                                                                        "library "
                                                                                        "pattern "
                                                                                        "and "
                                                                                        "enabling "
                                                                                        "keyword "
                                                                                        "support.",
                                                                                        "properties": {
                                                                                            "id": {
                                                                                                "description": "Identifier "
                                                                                                "for "
                                                                                                "a "
                                                                                                "predefined "
                                                                                                "pattern "
                                                                                                "from "
                                                                                                "the "
                                                                                                "sensitive "
                                                                                                "data "
                                                                                                "scanner "
                                                                                                "pattern "
                                                                                                "library.",
                                                                                                "example": "credit_card",
                                                                                                "type": "string",
                                                                                            },
                                                                                            "use_recommended_keywords": {
                                                                                                "description": "Whether "
                                                                                                "to "
                                                                                                "augment "
                                                                                                "the "
                                                                                                "pattern "
                                                                                                "with "
                                                                                                "recommended "
                                                                                                "keywords "
                                                                                                "(optional).",
                                                                                                "type": "boolean",
                                                                                            },
                                                                                        },
                                                                                        "required": [
                                                                                            "id"
                                                                                        ],
                                                                                        "type": "object",
                                                                                    },
                                                                                    "type": {
                                                                                        "description": "Indicates "
                                                                                        "that "
                                                                                        "a "
                                                                                        "predefined "
                                                                                        "library "
                                                                                        "pattern "
                                                                                        "is "
                                                                                        "used.",
                                                                                        "enum": [
                                                                                            "library"
                                                                                        ],
                                                                                        "example": "library",
                                                                                        "type": "string",
                                                                                        "x-enum-varnames": [
                                                                                            "LIBRARY"
                                                                                        ],
                                                                                    },
                                                                                },
                                                                                "required": [
                                                                                    "type",
                                                                                    "options",
                                                                                ],
                                                                                "type": "object",
                                                                            },
                                                                        ],
                                                                    },
                                                                    "scope": {
                                                                        "description": "Determines "
                                                                        "which "
                                                                        "parts "
                                                                        "of "
                                                                        "the "
                                                                        "log "
                                                                        "the "
                                                                        "pattern-matching "
                                                                        "rule "
                                                                        "should "
                                                                        "be "
                                                                        "applied "
                                                                        "to.",
                                                                        "oneOf": [
                                                                            {
                                                                                "description": "Includes "
                                                                                "only "
                                                                                "specific "
                                                                                "fields "
                                                                                "for "
                                                                                "sensitive "
                                                                                "data "
                                                                                "scanning.",
                                                                                "properties": {
                                                                                    "options": {
                                                                                        "description": "Fields "
                                                                                        "to "
                                                                                        "which "
                                                                                        "the "
                                                                                        "scope "
                                                                                        "rule "
                                                                                        "applies.",
                                                                                        "properties": {
                                                                                            "fields": {
                                                                                                "description": "The "
                                                                                                "`ObservabilityPipelineSensitiveDataScannerProcessorScopeOptions` "
                                                                                                "`fields`.",
                                                                                                "example": [
                                                                                                    ""
                                                                                                ],
                                                                                                "items": {
                                                                                                    "type": "string"
                                                                                                },
                                                                                                "type": "array",
                                                                                            }
                                                                                        },
                                                                                        "required": [
                                                                                            "fields"
                                                                                        ],
                                                                                        "type": "object",
                                                                                    },
                                                                                    "target": {
                                                                                        "description": "Applies "
                                                                                        "the "
                                                                                        "rule "
                                                                                        "only "
                                                                                        "to "
                                                                                        "included "
                                                                                        "fields.",
                                                                                        "enum": [
                                                                                            "include"
                                                                                        ],
                                                                                        "example": "include",
                                                                                        "type": "string",
                                                                                        "x-enum-varnames": [
                                                                                            "INCLUDE"
                                                                                        ],
                                                                                    },
                                                                                },
                                                                                "required": [
                                                                                    "target",
                                                                                    "options",
                                                                                ],
                                                                                "type": "object",
                                                                            },
                                                                            {
                                                                                "description": "Excludes "
                                                                                "specific "
                                                                                "fields "
                                                                                "from "
                                                                                "sensitive "
                                                                                "data "
                                                                                "scanning.",
                                                                                "properties": {
                                                                                    "options": {
                                                                                        "description": "Fields "
                                                                                        "to "
                                                                                        "which "
                                                                                        "the "
                                                                                        "scope "
                                                                                        "rule "
                                                                                        "applies.",
                                                                                        "properties": {
                                                                                            "fields": {
                                                                                                "description": "The "
                                                                                                "`ObservabilityPipelineSensitiveDataScannerProcessorScopeOptions` "
                                                                                                "`fields`.",
                                                                                                "example": [
                                                                                                    ""
                                                                                                ],
                                                                                                "items": {
                                                                                                    "type": "string"
                                                                                                },
                                                                                                "type": "array",
                                                                                            }
                                                                                        },
                                                                                        "required": [
                                                                                            "fields"
                                                                                        ],
                                                                                        "type": "object",
                                                                                    },
                                                                                    "target": {
                                                                                        "description": "Excludes "
                                                                                        "specific "
                                                                                        "fields "
                                                                                        "from "
                                                                                        "processing.",
                                                                                        "enum": [
                                                                                            "exclude"
                                                                                        ],
                                                                                        "example": "exclude",
                                                                                        "type": "string",
                                                                                        "x-enum-varnames": [
                                                                                            "EXCLUDE"
                                                                                        ],
                                                                                    },
                                                                                },
                                                                                "required": [
                                                                                    "target",
                                                                                    "options",
                                                                                ],
                                                                                "type": "object",
                                                                            },
                                                                            {
                                                                                "description": "Applies "
                                                                                "scanning "
                                                                                "across "
                                                                                "all "
                                                                                "available "
                                                                                "fields.",
                                                                                "properties": {
                                                                                    "target": {
                                                                                        "description": "Applies "
                                                                                        "the "
                                                                                        "rule "
                                                                                        "to "
                                                                                        "all "
                                                                                        "fields.",
                                                                                        "enum": [
                                                                                            "all"
                                                                                        ],
                                                                                        "example": "all",
                                                                                        "type": "string",
                                                                                        "x-enum-varnames": [
                                                                                            "ALL"
                                                                                        ],
                                                                                    }
                                                                                },
                                                                                "required": [
                                                                                    "target"
                                                                                ],
                                                                                "type": "object",
                                                                            },
                                                                        ],
                                                                    },
                                                                    "tags": {
                                                                        "description": "Tags "
                                                                        "assigned "
                                                                        "to "
                                                                        "this "
                                                                        "rule "
                                                                        "for "
                                                                        "filtering "
                                                                        "and "
                                                                        "classification.",
                                                                        "example": ["pii", "ccn"],
                                                                        "items": {"type": "string"},
                                                                        "type": "array",
                                                                    },
                                                                },
                                                                "required": [
                                                                    "name",
                                                                    "tags",
                                                                    "pattern",
                                                                    "scope",
                                                                    "on_match",
                                                                ],
                                                                "type": "object",
                                                            },
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "sensitive_data_scanner",
                                                            "description": "The "
                                                            "processor "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`sensitive_data_scanner`.",
                                                            "enum": ["sensitive_data_scanner"],
                                                            "example": "sensitive_data_scanner",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "SENSITIVE_DATA_SCANNER"
                                                            ],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "include",
                                                        "inputs",
                                                        "rules",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`ocsf_mapper` "
                                                    "processor "
                                                    "transforms "
                                                    "logs "
                                                    "into "
                                                    "the "
                                                    "OCSF "
                                                    "schema "
                                                    "using "
                                                    "a "
                                                    "predefined "
                                                    "mapping "
                                                    "configuration.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline.",
                                                            "example": "ocsf-mapper-processor",
                                                            "type": "string",
                                                        },
                                                        "include": {
                                                            "description": "A "
                                                            "Datadog "
                                                            "search "
                                                            "query "
                                                            "used "
                                                            "to "
                                                            "determine "
                                                            "which "
                                                            "logs "
                                                            "this "
                                                            "processor "
                                                            "targets.",
                                                            "example": "service:my-service",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "processor.",
                                                            "example": ["filter-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "mappings": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "mapping "
                                                            "rules "
                                                            "to "
                                                            "convert "
                                                            "events "
                                                            "to "
                                                            "the "
                                                            "OCSF "
                                                            "format.",
                                                            "items": {
                                                                "description": "Defines "
                                                                "how "
                                                                "specific "
                                                                "events "
                                                                "are "
                                                                "transformed "
                                                                "to "
                                                                "OCSF "
                                                                "using "
                                                                "a "
                                                                "mapping "
                                                                "configuration.",
                                                                "properties": {
                                                                    "include": {
                                                                        "description": "A "
                                                                        "Datadog "
                                                                        "search "
                                                                        "query "
                                                                        "used "
                                                                        "to "
                                                                        "select "
                                                                        "the "
                                                                        "logs "
                                                                        "that "
                                                                        "this "
                                                                        "mapping "
                                                                        "should "
                                                                        "apply "
                                                                        "to.",
                                                                        "example": "service:my-service",
                                                                        "type": "string",
                                                                    },
                                                                    "mapping": {
                                                                        "description": "Defines "
                                                                        "a "
                                                                        "single "
                                                                        "mapping "
                                                                        "rule "
                                                                        "for "
                                                                        "transforming "
                                                                        "logs "
                                                                        "into "
                                                                        "the "
                                                                        "OCSF "
                                                                        "schema.",
                                                                        "oneOf": [
                                                                            {
                                                                                "description": "Predefined "
                                                                                "library "
                                                                                "mappings "
                                                                                "for "
                                                                                "common "
                                                                                "log "
                                                                                "formats.",
                                                                                "enum": [
                                                                                    "CloudTrail "
                                                                                    "Account "
                                                                                    "Change",
                                                                                    "GCP "
                                                                                    "Cloud "
                                                                                    "Audit "
                                                                                    "CreateBucket",
                                                                                    "GCP "
                                                                                    "Cloud "
                                                                                    "Audit "
                                                                                    "CreateSink",
                                                                                    "GCP "
                                                                                    "Cloud "
                                                                                    "Audit "
                                                                                    "SetIamPolicy",
                                                                                    "GCP "
                                                                                    "Cloud "
                                                                                    "Audit "
                                                                                    "UpdateSink",
                                                                                    "Github "
                                                                                    "Audit "
                                                                                    "Log "
                                                                                    "API "
                                                                                    "Activity",
                                                                                    "Google "
                                                                                    "Workspace "
                                                                                    "Admin "
                                                                                    "Audit "
                                                                                    "addPrivilege",
                                                                                    "Microsoft "
                                                                                    "365 "
                                                                                    "Defender "
                                                                                    "Incident",
                                                                                    "Microsoft "
                                                                                    "365 "
                                                                                    "Defender "
                                                                                    "UserLoggedIn",
                                                                                    "Okta "
                                                                                    "System "
                                                                                    "Log "
                                                                                    "Authentication",
                                                                                    "Palo "
                                                                                    "Alto "
                                                                                    "Networks "
                                                                                    "Firewall "
                                                                                    "Traffic",
                                                                                ],
                                                                                "example": "CloudTrail "
                                                                                "Account "
                                                                                "Change",
                                                                                "type": "string",
                                                                                "x-enum-varnames": [
                                                                                    "CLOUDTRAIL_ACCOUNT_CHANGE",
                                                                                    "GCP_CLOUD_AUDIT_CREATEBUCKET",
                                                                                    "GCP_CLOUD_AUDIT_CREATESINK",
                                                                                    "GCP_CLOUD_AUDIT_SETIAMPOLICY",
                                                                                    "GCP_CLOUD_AUDIT_UPDATESINK",
                                                                                    "GITHUB_AUDIT_LOG_API_ACTIVITY",
                                                                                    "GOOGLE_WORKSPACE_ADMIN_AUDIT_ADDPRIVILEGE",
                                                                                    "MICROSOFT_365_DEFENDER_INCIDENT",
                                                                                    "MICROSOFT_365_DEFENDER_USERLOGGEDIN",
                                                                                    "OKTA_SYSTEM_LOG_AUTHENTICATION",
                                                                                    "PALO_ALTO_NETWORKS_FIREWALL_TRAFFIC",
                                                                                ],
                                                                            }
                                                                        ],
                                                                    },
                                                                },
                                                                "required": ["include", "mapping"],
                                                                "type": "object",
                                                            },
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "ocsf_mapper",
                                                            "description": "The "
                                                            "processor "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`ocsf_mapper`.",
                                                            "enum": ["ocsf_mapper"],
                                                            "example": "ocsf_mapper",
                                                            "type": "string",
                                                            "x-enum-varnames": ["OCSF_MAPPER"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "include",
                                                        "inputs",
                                                        "mappings",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`add_env_vars` "
                                                    "processor "
                                                    "adds "
                                                    "environment "
                                                    "variable "
                                                    "values "
                                                    "to "
                                                    "log "
                                                    "events.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "processor "
                                                            "in "
                                                            "the "
                                                            "pipeline.",
                                                            "example": "add-env-vars-processor",
                                                            "type": "string",
                                                        },
                                                        "include": {
                                                            "description": "A "
                                                            "Datadog "
                                                            "search "
                                                            "query "
                                                            "used "
                                                            "to "
                                                            "determine "
                                                            "which "
                                                            "logs "
                                                            "this "
                                                            "processor "
                                                            "targets.",
                                                            "example": "service:my-service",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "input "
                                                            "for "
                                                            "this "
                                                            "processor.",
                                                            "example": ["datadog-agent-source"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "add_env_vars",
                                                            "description": "The "
                                                            "processor "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`add_env_vars`.",
                                                            "enum": ["add_env_vars"],
                                                            "example": "add_env_vars",
                                                            "type": "string",
                                                            "x-enum-varnames": ["ADD_ENV_VARS"],
                                                        },
                                                        "variables": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "environment "
                                                            "variable "
                                                            "mappings "
                                                            "to "
                                                            "apply "
                                                            "to "
                                                            "log "
                                                            "fields.",
                                                            "items": {
                                                                "description": "Defines "
                                                                "a "
                                                                "mapping "
                                                                "between "
                                                                "an "
                                                                "environment "
                                                                "variable "
                                                                "and "
                                                                "a "
                                                                "log "
                                                                "field.",
                                                                "properties": {
                                                                    "field": {
                                                                        "description": "The "
                                                                        "target "
                                                                        "field "
                                                                        "in "
                                                                        "the "
                                                                        "log "
                                                                        "event.",
                                                                        "example": "log.environment.region",
                                                                        "type": "string",
                                                                    },
                                                                    "name": {
                                                                        "description": "The "
                                                                        "name "
                                                                        "of "
                                                                        "the "
                                                                        "environment "
                                                                        "variable "
                                                                        "to "
                                                                        "read.",
                                                                        "example": "AWS_REGION",
                                                                        "type": "string",
                                                                    },
                                                                },
                                                                "required": ["field", "name"],
                                                                "type": "object",
                                                            },
                                                            "type": "array",
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "include",
                                                        "inputs",
                                                        "variables",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`dedupe` "
                                                    "processor "
                                                    "removes "
                                                    "duplicate "
                                                    "fields "
                                                    "in "
                                                    "log "
                                                    "events.",
                                                    "properties": {
                                                        "fields": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "log "
                                                            "field "
                                                            "paths "
                                                            "to "
                                                            "check "
                                                            "for "
                                                            "duplicates.",
                                                            "example": ["log.message", "log.error"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "processor.",
                                                            "example": "dedupe-processor",
                                                            "type": "string",
                                                        },
                                                        "include": {
                                                            "description": "A "
                                                            "Datadog "
                                                            "search "
                                                            "query "
                                                            "used "
                                                            "to "
                                                            "determine "
                                                            "which "
                                                            "logs "
                                                            "this "
                                                            "processor "
                                                            "targets.",
                                                            "example": "service:my-service",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "input "
                                                            "for "
                                                            "this "
                                                            "processor.",
                                                            "example": ["parse-json-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "mode": {
                                                            "description": "The "
                                                            "deduplication "
                                                            "mode "
                                                            "to "
                                                            "apply "
                                                            "to "
                                                            "the "
                                                            "fields.",
                                                            "enum": ["match", "ignore"],
                                                            "example": "match",
                                                            "type": "string",
                                                            "x-enum-varnames": ["MATCH", "IGNORE"],
                                                        },
                                                        "type": {
                                                            "default": "dedupe",
                                                            "description": "The "
                                                            "processor "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`dedupe`.",
                                                            "enum": ["dedupe"],
                                                            "example": "dedupe",
                                                            "type": "string",
                                                            "x-enum-varnames": ["DEDUPE"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "include",
                                                        "inputs",
                                                        "fields",
                                                        "mode",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`enrichment_table` "
                                                    "processor "
                                                    "enriches "
                                                    "logs "
                                                    "using "
                                                    "a "
                                                    "static "
                                                    "CSV "
                                                    "file "
                                                    "or "
                                                    "GeoIP "
                                                    "database.",
                                                    "properties": {
                                                        "file": {
                                                            "description": "Defines "
                                                            "a "
                                                            "static "
                                                            "enrichment "
                                                            "table "
                                                            "loaded "
                                                            "from "
                                                            "a "
                                                            "CSV "
                                                            "file.",
                                                            "properties": {
                                                                "encoding": {
                                                                    "description": "File "
                                                                    "encoding "
                                                                    "format.",
                                                                    "properties": {
                                                                        "delimiter": {
                                                                            "description": "The "
                                                                            "`encoding` "
                                                                            "`delimiter`.",
                                                                            "example": ",",
                                                                            "type": "string",
                                                                        },
                                                                        "includes_headers": {
                                                                            "description": "The "
                                                                            "`encoding` "
                                                                            "`includes_headers`.",
                                                                            "example": True,
                                                                            "type": "boolean",
                                                                        },
                                                                        "type": {
                                                                            "description": "Specifies "
                                                                            "the "
                                                                            "encoding "
                                                                            "format "
                                                                            "(e.g., "
                                                                            "CSV) "
                                                                            "used "
                                                                            "for "
                                                                            "enrichment "
                                                                            "tables.",
                                                                            "enum": ["csv"],
                                                                            "example": "csv",
                                                                            "type": "string",
                                                                            "x-enum-varnames": [
                                                                                "CSV"
                                                                            ],
                                                                        },
                                                                    },
                                                                    "required": [
                                                                        "type",
                                                                        "delimiter",
                                                                        "includes_headers",
                                                                    ],
                                                                    "type": "object",
                                                                },
                                                                "key": {
                                                                    "description": "Key "
                                                                    "fields "
                                                                    "used "
                                                                    "to "
                                                                    "look "
                                                                    "up "
                                                                    "enrichment "
                                                                    "values.",
                                                                    "items": {
                                                                        "description": "Defines "
                                                                        "how "
                                                                        "to "
                                                                        "map "
                                                                        "log "
                                                                        "fields "
                                                                        "to "
                                                                        "enrichment "
                                                                        "table "
                                                                        "columns "
                                                                        "during "
                                                                        "lookups.",
                                                                        "properties": {
                                                                            "column": {
                                                                                "description": "The "
                                                                                "`items` "
                                                                                "`column`.",
                                                                                "example": "user_id",
                                                                                "type": "string",
                                                                            },
                                                                            "comparison": {
                                                                                "description": "Defines "
                                                                                "how "
                                                                                "to "
                                                                                "compare "
                                                                                "key "
                                                                                "fields "
                                                                                "for "
                                                                                "enrichment "
                                                                                "table "
                                                                                "lookups.",
                                                                                "enum": ["equals"],
                                                                                "example": "equals",
                                                                                "type": "string",
                                                                                "x-enum-varnames": [
                                                                                    "EQUALS"
                                                                                ],
                                                                            },
                                                                            "field": {
                                                                                "description": "The "
                                                                                "`items` "
                                                                                "`field`.",
                                                                                "example": "log.user.id",
                                                                                "type": "string",
                                                                            },
                                                                        },
                                                                        "required": [
                                                                            "column",
                                                                            "comparison",
                                                                            "field",
                                                                        ],
                                                                        "type": "object",
                                                                    },
                                                                    "type": "array",
                                                                },
                                                                "path": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "CSV "
                                                                    "file.",
                                                                    "example": "/etc/enrichment/lookup.csv",
                                                                    "type": "string",
                                                                },
                                                                "schema": {
                                                                    "description": "Schema "
                                                                    "defining "
                                                                    "column "
                                                                    "names "
                                                                    "and "
                                                                    "their "
                                                                    "types.",
                                                                    "items": {
                                                                        "description": "Describes "
                                                                        "a "
                                                                        "single "
                                                                        "column "
                                                                        "and "
                                                                        "its "
                                                                        "type "
                                                                        "in "
                                                                        "an "
                                                                        "enrichment "
                                                                        "table "
                                                                        "schema.",
                                                                        "properties": {
                                                                            "column": {
                                                                                "description": "The "
                                                                                "`items` "
                                                                                "`column`.",
                                                                                "example": "region",
                                                                                "type": "string",
                                                                            },
                                                                            "type": {
                                                                                "description": "Declares "
                                                                                "allowed "
                                                                                "data "
                                                                                "types "
                                                                                "for "
                                                                                "enrichment "
                                                                                "table "
                                                                                "columns.",
                                                                                "enum": [
                                                                                    "string",
                                                                                    "boolean",
                                                                                    "integer",
                                                                                    "float",
                                                                                    "date",
                                                                                    "timestamp",
                                                                                ],
                                                                                "example": "string",
                                                                                "type": "string",
                                                                                "x-enum-varnames": [
                                                                                    "STRING",
                                                                                    "BOOLEAN",
                                                                                    "INTEGER",
                                                                                    "FLOAT",
                                                                                    "DATE",
                                                                                    "TIMESTAMP",
                                                                                ],
                                                                            },
                                                                        },
                                                                        "required": [
                                                                            "column",
                                                                            "type",
                                                                        ],
                                                                        "type": "object",
                                                                    },
                                                                    "type": "array",
                                                                },
                                                            },
                                                            "required": [
                                                                "encoding",
                                                                "key",
                                                                "path",
                                                                "schema",
                                                            ],
                                                            "type": "object",
                                                        },
                                                        "geoip": {
                                                            "description": "Uses "
                                                            "a "
                                                            "GeoIP "
                                                            "database "
                                                            "to "
                                                            "enrich "
                                                            "logs "
                                                            "based "
                                                            "on "
                                                            "an "
                                                            "IP "
                                                            "field.",
                                                            "properties": {
                                                                "key_field": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "IP "
                                                                    "field "
                                                                    "in "
                                                                    "the "
                                                                    "log.",
                                                                    "example": "log.source.ip",
                                                                    "type": "string",
                                                                },
                                                                "locale": {
                                                                    "description": "Locale "
                                                                    "used "
                                                                    "to "
                                                                    "resolve "
                                                                    "geographical "
                                                                    "names.",
                                                                    "example": "en",
                                                                    "type": "string",
                                                                },
                                                                "path": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "GeoIP "
                                                                    "database "
                                                                    "file.",
                                                                    "example": "/etc/geoip/GeoLite2-City.mmdb",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": [
                                                                "key_field",
                                                                "locale",
                                                                "path",
                                                            ],
                                                            "type": "object",
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "processor.",
                                                            "example": "enrichment-table-processor",
                                                            "type": "string",
                                                        },
                                                        "include": {
                                                            "description": "A "
                                                            "Datadog "
                                                            "search "
                                                            "query "
                                                            "used "
                                                            "to "
                                                            "determine "
                                                            "which "
                                                            "logs "
                                                            "this "
                                                            "processor "
                                                            "targets.",
                                                            "example": "source:my-source",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "input "
                                                            "for "
                                                            "this "
                                                            "processor.",
                                                            "example": ["add-fields-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "target": {
                                                            "description": "Path "
                                                            "where "
                                                            "enrichment "
                                                            "results "
                                                            "should "
                                                            "be "
                                                            "stored "
                                                            "in "
                                                            "the "
                                                            "log.",
                                                            "example": "enriched.geoip",
                                                            "type": "string",
                                                        },
                                                        "type": {
                                                            "default": "enrichment_table",
                                                            "description": "The "
                                                            "processor "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`enrichment_table`.",
                                                            "enum": ["enrichment_table"],
                                                            "example": "enrichment_table",
                                                            "type": "string",
                                                            "x-enum-varnames": ["ENRICHMENT_TABLE"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "include",
                                                        "inputs",
                                                        "target",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`reduce` "
                                                    "processor "
                                                    "aggregates "
                                                    "and "
                                                    "merges "
                                                    "logs "
                                                    "based "
                                                    "on "
                                                    "matching "
                                                    "keys "
                                                    "and "
                                                    "merge "
                                                    "strategies.",
                                                    "properties": {
                                                        "group_by": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "fields "
                                                            "used "
                                                            "to "
                                                            "group "
                                                            "log "
                                                            "events "
                                                            "for "
                                                            "merging.",
                                                            "example": [
                                                                "log.user.id",
                                                                "log.device.id",
                                                            ],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "processor.",
                                                            "example": "reduce-processor",
                                                            "type": "string",
                                                        },
                                                        "include": {
                                                            "description": "A "
                                                            "Datadog "
                                                            "search "
                                                            "query "
                                                            "used "
                                                            "to "
                                                            "determine "
                                                            "which "
                                                            "logs "
                                                            "this "
                                                            "processor "
                                                            "targets.",
                                                            "example": "env:prod",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "input "
                                                            "for "
                                                            "this "
                                                            "processor.",
                                                            "example": ["parse-json-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "merge_strategies": {
                                                            "description": "List "
                                                            "of "
                                                            "merge "
                                                            "strategies "
                                                            "defining "
                                                            "how "
                                                            "values "
                                                            "from "
                                                            "grouped "
                                                            "events "
                                                            "should "
                                                            "be "
                                                            "combined.",
                                                            "items": {
                                                                "description": "Defines "
                                                                "how "
                                                                "a "
                                                                "specific "
                                                                "field "
                                                                "should "
                                                                "be "
                                                                "merged "
                                                                "across "
                                                                "grouped "
                                                                "events.",
                                                                "properties": {
                                                                    "path": {
                                                                        "description": "The "
                                                                        "field "
                                                                        "path "
                                                                        "in "
                                                                        "the "
                                                                        "log "
                                                                        "event.",
                                                                        "example": "log.user.roles",
                                                                        "type": "string",
                                                                    },
                                                                    "strategy": {
                                                                        "description": "The "
                                                                        "merge "
                                                                        "strategy "
                                                                        "to "
                                                                        "apply.",
                                                                        "enum": [
                                                                            "discard",
                                                                            "retain",
                                                                            "sum",
                                                                            "max",
                                                                            "min",
                                                                            "array",
                                                                            "concat",
                                                                            "concat_newline",
                                                                            "concat_raw",
                                                                            "shortest_array",
                                                                            "longest_array",
                                                                            "flat_unique",
                                                                        ],
                                                                        "example": "flat_unique",
                                                                        "type": "string",
                                                                        "x-enum-varnames": [
                                                                            "DISCARD",
                                                                            "RETAIN",
                                                                            "SUM",
                                                                            "MAX",
                                                                            "MIN",
                                                                            "ARRAY",
                                                                            "CONCAT",
                                                                            "CONCAT_NEWLINE",
                                                                            "CONCAT_RAW",
                                                                            "SHORTEST_ARRAY",
                                                                            "LONGEST_ARRAY",
                                                                            "FLAT_UNIQUE",
                                                                        ],
                                                                    },
                                                                },
                                                                "required": ["path", "strategy"],
                                                                "type": "object",
                                                            },
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "reduce",
                                                            "description": "The "
                                                            "processor "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`reduce`.",
                                                            "enum": ["reduce"],
                                                            "example": "reduce",
                                                            "type": "string",
                                                            "x-enum-varnames": ["REDUCE"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "include",
                                                        "inputs",
                                                        "group_by",
                                                        "merge_strategies",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`throttle` "
                                                    "processor "
                                                    "limits "
                                                    "the "
                                                    "number "
                                                    "of "
                                                    "events "
                                                    "that "
                                                    "pass "
                                                    "through "
                                                    "over "
                                                    "a "
                                                    "given "
                                                    "time "
                                                    "window.",
                                                    "properties": {
                                                        "group_by": {
                                                            "description": "Optional "
                                                            "list "
                                                            "of "
                                                            "fields "
                                                            "used "
                                                            "to "
                                                            "group "
                                                            "events "
                                                            "before "
                                                            "the "
                                                            "threshold "
                                                            "has "
                                                            "been "
                                                            "reached.",
                                                            "example": ["log.user.id"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "processor.",
                                                            "example": "throttle-processor",
                                                            "type": "string",
                                                        },
                                                        "include": {
                                                            "description": "A "
                                                            "Datadog "
                                                            "search "
                                                            "query "
                                                            "used "
                                                            "to "
                                                            "determine "
                                                            "which "
                                                            "logs "
                                                            "this "
                                                            "processor "
                                                            "targets.",
                                                            "example": "env:prod",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "input "
                                                            "for "
                                                            "this "
                                                            "processor.",
                                                            "example": ["datadog-agent-source"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "threshold": {
                                                            "description": "the "
                                                            "number "
                                                            "of "
                                                            "events "
                                                            "allowed "
                                                            "in "
                                                            "a "
                                                            "given "
                                                            "time "
                                                            "window. "
                                                            "Events "
                                                            "sent "
                                                            "after "
                                                            "the "
                                                            "threshold "
                                                            "has "
                                                            "been "
                                                            "reached, "
                                                            "are "
                                                            "dropped.",
                                                            "example": 1000,
                                                            "format": "int64",
                                                            "type": "integer",
                                                        },
                                                        "type": {
                                                            "default": "throttle",
                                                            "description": "The "
                                                            "processor "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`throttle`.",
                                                            "enum": ["throttle"],
                                                            "example": "throttle",
                                                            "type": "string",
                                                            "x-enum-varnames": ["THROTTLE"],
                                                        },
                                                        "window": {
                                                            "description": "The "
                                                            "time "
                                                            "window "
                                                            "in "
                                                            "seconds "
                                                            "over "
                                                            "which "
                                                            "the "
                                                            "threshold "
                                                            "applies.",
                                                            "example": 60.0,
                                                            "format": "double",
                                                            "type": "number",
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "include",
                                                        "inputs",
                                                        "threshold",
                                                        "window",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`custom_processor` "
                                                    "processor "
                                                    "transforms "
                                                    "events "
                                                    "using "
                                                    "[Vector "
                                                    "Remap "
                                                    "Language "
                                                    "(VRL)](https://vector.dev/docs/reference/vrl/) "
                                                    "scripts "
                                                    "with "
                                                    "advanced "
                                                    "filtering "
                                                    "capabilities.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "processor.",
                                                            "example": "remap-vrl-processor",
                                                            "type": "string",
                                                        },
                                                        "include": {
                                                            "default": "*",
                                                            "description": "A "
                                                            "Datadog "
                                                            "search "
                                                            "query "
                                                            "used "
                                                            "to "
                                                            "determine "
                                                            "which "
                                                            "logs "
                                                            "this "
                                                            "processor "
                                                            "targets. "
                                                            "This "
                                                            "field "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "set "
                                                            "to "
                                                            "`*` "
                                                            "for "
                                                            "the "
                                                            "custom_processor "
                                                            "processor.",
                                                            "example": "*",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "input "
                                                            "for "
                                                            "this "
                                                            "processor.",
                                                            "example": ["datadog-agent-source"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "remaps": {
                                                            "description": "Array "
                                                            "of "
                                                            "VRL "
                                                            "remap "
                                                            "rules.",
                                                            "items": {
                                                                "description": "Defines "
                                                                "a "
                                                                "single "
                                                                "VRL "
                                                                "remap "
                                                                "rule "
                                                                "with "
                                                                "its "
                                                                "own "
                                                                "filtering "
                                                                "and "
                                                                "transformation "
                                                                "logic.",
                                                                "properties": {
                                                                    "drop_on_error": {
                                                                        "description": "Whether "
                                                                        "to "
                                                                        "drop "
                                                                        "events "
                                                                        "that "
                                                                        "caused "
                                                                        "errors "
                                                                        "during "
                                                                        "processing.",
                                                                        "example": False,
                                                                        "type": "boolean",
                                                                    },
                                                                    "enabled": {
                                                                        "description": "Whether "
                                                                        "this "
                                                                        "remap "
                                                                        "rule "
                                                                        "is "
                                                                        "enabled.",
                                                                        "example": True,
                                                                        "type": "boolean",
                                                                    },
                                                                    "include": {
                                                                        "description": "A "
                                                                        "Datadog "
                                                                        "search "
                                                                        "query "
                                                                        "used "
                                                                        "to "
                                                                        "filter "
                                                                        "events "
                                                                        "for "
                                                                        "this "
                                                                        "specific "
                                                                        "remap "
                                                                        "rule.",
                                                                        "example": "service:web",
                                                                        "type": "string",
                                                                    },
                                                                    "name": {
                                                                        "description": "A "
                                                                        "descriptive "
                                                                        "name "
                                                                        "for "
                                                                        "this "
                                                                        "remap "
                                                                        "rule.",
                                                                        "example": "Parse "
                                                                        "JSON "
                                                                        "from "
                                                                        "message "
                                                                        "field",
                                                                        "type": "string",
                                                                    },
                                                                    "source": {
                                                                        "description": "The "
                                                                        "VRL "
                                                                        "script "
                                                                        "source "
                                                                        "code "
                                                                        "that "
                                                                        "defines "
                                                                        "the "
                                                                        "processing "
                                                                        "logic.",
                                                                        "example": ". "
                                                                        "= "
                                                                        "parse_json!(.message)",
                                                                        "type": "string",
                                                                    },
                                                                },
                                                                "required": [
                                                                    "include",
                                                                    "name",
                                                                    "source",
                                                                    "enabled",
                                                                    "drop_on_error",
                                                                ],
                                                                "type": "object",
                                                            },
                                                            "minItems": 1,
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "custom_processor",
                                                            "description": "The "
                                                            "processor "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`custom_processor`.",
                                                            "enum": ["custom_processor"],
                                                            "example": "custom_processor",
                                                            "type": "string",
                                                            "x-enum-varnames": ["CUSTOM_PROCESSOR"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "include",
                                                        "remaps",
                                                        "inputs",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`datadog_tags` "
                                                    "processor "
                                                    "includes "
                                                    "or "
                                                    "excludes "
                                                    "specific "
                                                    "Datadog "
                                                    "tags "
                                                    "in "
                                                    "your "
                                                    "logs.",
                                                    "properties": {
                                                        "action": {
                                                            "description": "The "
                                                            "action "
                                                            "to "
                                                            "take "
                                                            "on "
                                                            "tags "
                                                            "with "
                                                            "matching "
                                                            "keys.",
                                                            "enum": ["include", "exclude"],
                                                            "example": "include",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "INCLUDE",
                                                                "EXCLUDE",
                                                            ],
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(for "
                                                            "example, "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "datadog-tags-processor",
                                                            "type": "string",
                                                        },
                                                        "include": {
                                                            "description": "A "
                                                            "Datadog "
                                                            "search "
                                                            "query "
                                                            "used "
                                                            "to "
                                                            "determine "
                                                            "which "
                                                            "logs "
                                                            "this "
                                                            "processor "
                                                            "targets.",
                                                            "example": "service:my-service",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["datadog-agent-source"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "keys": {
                                                            "description": "A list of tag keys.",
                                                            "example": [
                                                                "env",
                                                                "service",
                                                                "version",
                                                            ],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "mode": {
                                                            "description": "The processing mode.",
                                                            "enum": ["filter"],
                                                            "example": "filter",
                                                            "type": "string",
                                                            "x-enum-varnames": ["FILTER"],
                                                        },
                                                        "type": {
                                                            "default": "datadog_tags",
                                                            "description": "The "
                                                            "processor "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`datadog_tags`.",
                                                            "enum": ["datadog_tags"],
                                                            "example": "datadog_tags",
                                                            "type": "string",
                                                            "x-enum-varnames": ["DATADOG_TAGS"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "include",
                                                        "mode",
                                                        "action",
                                                        "keys",
                                                        "inputs",
                                                    ],
                                                    "type": "object",
                                                },
                                            ],
                                        },
                                        "type": "array",
                                    },
                                    "sources": {
                                        "description": "A "
                                        "list "
                                        "of "
                                        "configured "
                                        "data "
                                        "sources "
                                        "for "
                                        "the "
                                        "pipeline.",
                                        "example": [
                                            {"id": "datadog-agent-source", "type": "datadog_agent"}
                                        ],
                                        "items": {
                                            "description": "A data source for the pipeline.",
                                            "oneOf": [
                                                {
                                                    "description": "The "
                                                    "`kafka` "
                                                    "source "
                                                    "ingests "
                                                    "data "
                                                    "from "
                                                    "Apache "
                                                    "Kafka "
                                                    "topics.",
                                                    "properties": {
                                                        "group_id": {
                                                            "description": "Consumer "
                                                            "group "
                                                            "ID "
                                                            "used "
                                                            "by "
                                                            "the "
                                                            "Kafka "
                                                            "client.",
                                                            "example": "consumer-group-0",
                                                            "type": "string",
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(e.g., "
                                                            "as "
                                                            "input "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "kafka-source",
                                                            "type": "string",
                                                        },
                                                        "librdkafka_options": {
                                                            "description": "Optional "
                                                            "list "
                                                            "of "
                                                            "advanced "
                                                            "Kafka "
                                                            "client "
                                                            "configuration "
                                                            "options, "
                                                            "defined "
                                                            "as "
                                                            "key-value "
                                                            "pairs.",
                                                            "items": {
                                                                "description": "Represents "
                                                                "a "
                                                                "key-value "
                                                                "pair "
                                                                "used "
                                                                "to "
                                                                "configure "
                                                                "low-level "
                                                                "`librdkafka` "
                                                                "client "
                                                                "options "
                                                                "for "
                                                                "Kafka "
                                                                "sources, "
                                                                "such "
                                                                "as "
                                                                "timeouts, "
                                                                "buffer "
                                                                "sizes, "
                                                                "and "
                                                                "security "
                                                                "settings.",
                                                                "properties": {
                                                                    "name": {
                                                                        "description": "The "
                                                                        "name "
                                                                        "of "
                                                                        "the "
                                                                        "`librdkafka` "
                                                                        "configuration "
                                                                        "option "
                                                                        "to "
                                                                        "set.",
                                                                        "example": "fetch.message.max.bytes",
                                                                        "type": "string",
                                                                    },
                                                                    "value": {
                                                                        "description": "The "
                                                                        "value "
                                                                        "assigned "
                                                                        "to "
                                                                        "the "
                                                                        "specified "
                                                                        "`librdkafka` "
                                                                        "configuration "
                                                                        "option.",
                                                                        "example": "1048576",
                                                                        "type": "string",
                                                                    },
                                                                },
                                                                "required": ["name", "value"],
                                                                "type": "object",
                                                            },
                                                            "type": "array",
                                                        },
                                                        "sasl": {
                                                            "description": "Specifies "
                                                            "the "
                                                            "SASL "
                                                            "mechanism "
                                                            "for "
                                                            "authenticating "
                                                            "with "
                                                            "a "
                                                            "Kafka "
                                                            "cluster.",
                                                            "properties": {
                                                                "mechanism": {
                                                                    "description": "SASL "
                                                                    "mechanism "
                                                                    "used "
                                                                    "for "
                                                                    "Kafka "
                                                                    "authentication.",
                                                                    "enum": [
                                                                        "PLAIN",
                                                                        "SCRAM-SHA-256",
                                                                        "SCRAM-SHA-512",
                                                                    ],
                                                                    "type": "string",
                                                                    "x-enum-varnames": [
                                                                        "PLAIN",
                                                                        "SCRAMNOT_SHANOT_256",
                                                                        "SCRAMNOT_SHANOT_512",
                                                                    ],
                                                                }
                                                            },
                                                            "type": "object",
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "topics": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "Kafka "
                                                            "topic "
                                                            "names "
                                                            "to "
                                                            "subscribe "
                                                            "to. "
                                                            "The "
                                                            "source "
                                                            "ingests "
                                                            "messages "
                                                            "from "
                                                            "each "
                                                            "topic "
                                                            "specified.",
                                                            "example": ["topic1", "topic2"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "kafka",
                                                            "description": "The "
                                                            "source "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`kafka`.",
                                                            "enum": ["kafka"],
                                                            "example": "kafka",
                                                            "type": "string",
                                                            "x-enum-varnames": ["KAFKA"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "group_id",
                                                        "topics",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`datadog_agent` "
                                                    "source "
                                                    "collects "
                                                    "logs "
                                                    "from "
                                                    "the "
                                                    "Datadog "
                                                    "Agent.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(e.g., "
                                                            "as "
                                                            "input "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "datadog-agent-source",
                                                            "type": "string",
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "datadog_agent",
                                                            "description": "The "
                                                            "source "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`datadog_agent`.",
                                                            "enum": ["datadog_agent"],
                                                            "example": "datadog_agent",
                                                            "type": "string",
                                                            "x-enum-varnames": ["DATADOG_AGENT"],
                                                        },
                                                    },
                                                    "required": ["id", "type"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`splunk_tcp` "
                                                    "source "
                                                    "receives "
                                                    "logs "
                                                    "from "
                                                    "a "
                                                    "Splunk "
                                                    "Universal "
                                                    "Forwarder "
                                                    "over "
                                                    "TCP.\n"
                                                    "TLS "
                                                    "is "
                                                    "supported "
                                                    "for "
                                                    "secure "
                                                    "transmission.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(e.g., "
                                                            "as "
                                                            "input "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "splunk-tcp-source",
                                                            "type": "string",
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "splunk_tcp",
                                                            "description": "The "
                                                            "source "
                                                            "type. "
                                                            "Always "
                                                            "`splunk_tcp`.",
                                                            "enum": ["splunk_tcp"],
                                                            "example": "splunk_tcp",
                                                            "type": "string",
                                                            "x-enum-varnames": ["SPLUNK_TCP"],
                                                        },
                                                    },
                                                    "required": ["id", "type"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`splunk_hec` "
                                                    "source "
                                                    "implements "
                                                    "the "
                                                    "Splunk "
                                                    "HTTP "
                                                    "Event "
                                                    "Collector "
                                                    "(HEC) "
                                                    "API.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(e.g., "
                                                            "as "
                                                            "input "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "splunk-hec-source",
                                                            "type": "string",
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "splunk_hec",
                                                            "description": "The "
                                                            "source "
                                                            "type. "
                                                            "Always "
                                                            "`splunk_hec`.",
                                                            "enum": ["splunk_hec"],
                                                            "example": "splunk_hec",
                                                            "type": "string",
                                                            "x-enum-varnames": ["SPLUNK_HEC"],
                                                        },
                                                    },
                                                    "required": ["id", "type"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`amazon_s3` "
                                                    "source "
                                                    "ingests "
                                                    "logs "
                                                    "from "
                                                    "an "
                                                    "Amazon "
                                                    "S3 "
                                                    "bucket.\n"
                                                    "It "
                                                    "supports "
                                                    "AWS "
                                                    "authentication "
                                                    "and "
                                                    "TLS "
                                                    "encryption.",
                                                    "properties": {
                                                        "auth": {
                                                            "description": "AWS "
                                                            "authentication "
                                                            "credentials "
                                                            "used "
                                                            "for "
                                                            "accessing "
                                                            "AWS "
                                                            "services "
                                                            "such "
                                                            "as "
                                                            "S3.\n"
                                                            "If "
                                                            "omitted, "
                                                            "the "
                                                            "system’s "
                                                            "default "
                                                            "credentials "
                                                            "are "
                                                            "used "
                                                            "(for "
                                                            "example, "
                                                            "the "
                                                            "IAM "
                                                            "role "
                                                            "and "
                                                            "environment "
                                                            "variables).",
                                                            "properties": {
                                                                "assume_role": {
                                                                    "description": "The "
                                                                    "Amazon "
                                                                    "Resource "
                                                                    "Name "
                                                                    "(ARN) "
                                                                    "of "
                                                                    "the "
                                                                    "role "
                                                                    "to "
                                                                    "assume.",
                                                                    "type": "string",
                                                                },
                                                                "external_id": {
                                                                    "description": "A "
                                                                    "unique "
                                                                    "identifier "
                                                                    "for "
                                                                    "cross-account "
                                                                    "role "
                                                                    "assumption.",
                                                                    "type": "string",
                                                                },
                                                                "session_name": {
                                                                    "description": "A "
                                                                    "session "
                                                                    "identifier "
                                                                    "used "
                                                                    "for "
                                                                    "logging "
                                                                    "and "
                                                                    "tracing "
                                                                    "the "
                                                                    "assumed "
                                                                    "role "
                                                                    "session.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "type": "object",
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(e.g., "
                                                            "as "
                                                            "input "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "aws-s3-source",
                                                            "type": "string",
                                                        },
                                                        "region": {
                                                            "description": "AWS "
                                                            "region "
                                                            "where "
                                                            "the "
                                                            "S3 "
                                                            "bucket "
                                                            "resides.",
                                                            "example": "us-east-1",
                                                            "type": "string",
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "amazon_s3",
                                                            "description": "The "
                                                            "source "
                                                            "type. "
                                                            "Always "
                                                            "`amazon_s3`.",
                                                            "enum": ["amazon_s3"],
                                                            "example": "amazon_s3",
                                                            "type": "string",
                                                            "x-enum-varnames": ["AMAZON_S3"],
                                                        },
                                                    },
                                                    "required": ["id", "type", "region"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`fluentd` "
                                                    "source "
                                                    "ingests "
                                                    "logs "
                                                    "from "
                                                    "a "
                                                    "Fluentd-compatible "
                                                    "service.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(for "
                                                            "example, "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "fluent-source",
                                                            "type": "string",
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "fluentd",
                                                            "description": "The "
                                                            "source "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`fluentd.",
                                                            "enum": ["fluentd"],
                                                            "example": "fluentd",
                                                            "type": "string",
                                                            "x-enum-varnames": ["FLUENTD"],
                                                        },
                                                    },
                                                    "required": ["id", "type"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`fluent_bit` "
                                                    "source "
                                                    "ingests "
                                                    "logs "
                                                    "from "
                                                    "Fluent "
                                                    "Bit.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(for "
                                                            "example, "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "fluent-source",
                                                            "type": "string",
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "fluent_bit",
                                                            "description": "The "
                                                            "source "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`fluent_bit`.",
                                                            "enum": ["fluent_bit"],
                                                            "example": "fluent_bit",
                                                            "type": "string",
                                                            "x-enum-varnames": ["FLUENT_BIT"],
                                                        },
                                                    },
                                                    "required": ["id", "type"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`http_server` "
                                                    "source "
                                                    "collects "
                                                    "logs "
                                                    "over "
                                                    "HTTP "
                                                    "POST "
                                                    "from "
                                                    "external "
                                                    "services.",
                                                    "properties": {
                                                        "auth_strategy": {
                                                            "description": "HTTP "
                                                            "authentication "
                                                            "method.",
                                                            "enum": ["none", "plain"],
                                                            "example": "plain",
                                                            "type": "string",
                                                            "x-enum-varnames": ["NONE", "PLAIN"],
                                                        },
                                                        "decoding": {
                                                            "description": "The "
                                                            "decoding "
                                                            "format "
                                                            "used "
                                                            "to "
                                                            "interpret "
                                                            "incoming "
                                                            "logs.",
                                                            "enum": [
                                                                "bytes",
                                                                "gelf",
                                                                "json",
                                                                "syslog",
                                                            ],
                                                            "example": "json",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "DECODE_BYTES",
                                                                "DECODE_GELF",
                                                                "DECODE_JSON",
                                                                "DECODE_SYSLOG",
                                                            ],
                                                        },
                                                        "id": {
                                                            "description": "Unique "
                                                            "ID "
                                                            "for "
                                                            "the "
                                                            "HTTP "
                                                            "server "
                                                            "source.",
                                                            "example": "http-server-source",
                                                            "type": "string",
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "http_server",
                                                            "description": "The "
                                                            "source "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`http_server`.",
                                                            "enum": ["http_server"],
                                                            "example": "http_server",
                                                            "type": "string",
                                                            "x-enum-varnames": ["HTTP_SERVER"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "auth_strategy",
                                                        "decoding",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`sumo_logic` "
                                                    "source "
                                                    "receives "
                                                    "logs "
                                                    "from "
                                                    "Sumo "
                                                    "Logic "
                                                    "collectors.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(e.g., "
                                                            "as "
                                                            "input "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "sumo-logic-source",
                                                            "type": "string",
                                                        },
                                                        "type": {
                                                            "default": "sumo_logic",
                                                            "description": "The "
                                                            "source "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`sumo_logic`.",
                                                            "enum": ["sumo_logic"],
                                                            "example": "sumo_logic",
                                                            "type": "string",
                                                            "x-enum-varnames": ["SUMO_LOGIC"],
                                                        },
                                                    },
                                                    "required": ["id", "type"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`rsyslog` "
                                                    "source "
                                                    "listens "
                                                    "for "
                                                    "logs "
                                                    "over "
                                                    "TCP "
                                                    "or "
                                                    "UDP "
                                                    "from "
                                                    "an "
                                                    "`rsyslog` "
                                                    "server "
                                                    "using "
                                                    "the "
                                                    "syslog "
                                                    "protocol.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(e.g., "
                                                            "as "
                                                            "input "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "rsyslog-source",
                                                            "type": "string",
                                                        },
                                                        "mode": {
                                                            "description": "Protocol "
                                                            "used "
                                                            "by "
                                                            "the "
                                                            "syslog "
                                                            "source "
                                                            "to "
                                                            "receive "
                                                            "messages.",
                                                            "enum": ["tcp", "udp"],
                                                            "example": "tcp",
                                                            "type": "string",
                                                            "x-enum-varnames": ["TCP", "UDP"],
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "rsyslog",
                                                            "description": "The "
                                                            "source "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`rsyslog`.",
                                                            "enum": ["rsyslog"],
                                                            "example": "rsyslog",
                                                            "type": "string",
                                                            "x-enum-varnames": ["RSYSLOG"],
                                                        },
                                                    },
                                                    "required": ["id", "type", "mode"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`syslog_ng` "
                                                    "source "
                                                    "listens "
                                                    "for "
                                                    "logs "
                                                    "over "
                                                    "TCP "
                                                    "or "
                                                    "UDP "
                                                    "from "
                                                    "a "
                                                    "`syslog-ng` "
                                                    "server "
                                                    "using "
                                                    "the "
                                                    "syslog "
                                                    "protocol.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(e.g., "
                                                            "as "
                                                            "input "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "syslog-ng-source",
                                                            "type": "string",
                                                        },
                                                        "mode": {
                                                            "description": "Protocol "
                                                            "used "
                                                            "by "
                                                            "the "
                                                            "syslog "
                                                            "source "
                                                            "to "
                                                            "receive "
                                                            "messages.",
                                                            "enum": ["tcp", "udp"],
                                                            "example": "tcp",
                                                            "type": "string",
                                                            "x-enum-varnames": ["TCP", "UDP"],
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "syslog_ng",
                                                            "description": "The "
                                                            "source "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`syslog_ng`.",
                                                            "enum": ["syslog_ng"],
                                                            "example": "syslog_ng",
                                                            "type": "string",
                                                            "x-enum-varnames": ["SYSLOG_NG"],
                                                        },
                                                    },
                                                    "required": ["id", "type", "mode"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`amazon_data_firehose` "
                                                    "source "
                                                    "ingests "
                                                    "logs "
                                                    "from "
                                                    "AWS "
                                                    "Data "
                                                    "Firehose.",
                                                    "properties": {
                                                        "auth": {
                                                            "description": "AWS "
                                                            "authentication "
                                                            "credentials "
                                                            "used "
                                                            "for "
                                                            "accessing "
                                                            "AWS "
                                                            "services "
                                                            "such "
                                                            "as "
                                                            "S3.\n"
                                                            "If "
                                                            "omitted, "
                                                            "the "
                                                            "system’s "
                                                            "default "
                                                            "credentials "
                                                            "are "
                                                            "used "
                                                            "(for "
                                                            "example, "
                                                            "the "
                                                            "IAM "
                                                            "role "
                                                            "and "
                                                            "environment "
                                                            "variables).",
                                                            "properties": {
                                                                "assume_role": {
                                                                    "description": "The "
                                                                    "Amazon "
                                                                    "Resource "
                                                                    "Name "
                                                                    "(ARN) "
                                                                    "of "
                                                                    "the "
                                                                    "role "
                                                                    "to "
                                                                    "assume.",
                                                                    "type": "string",
                                                                },
                                                                "external_id": {
                                                                    "description": "A "
                                                                    "unique "
                                                                    "identifier "
                                                                    "for "
                                                                    "cross-account "
                                                                    "role "
                                                                    "assumption.",
                                                                    "type": "string",
                                                                },
                                                                "session_name": {
                                                                    "description": "A "
                                                                    "session "
                                                                    "identifier "
                                                                    "used "
                                                                    "for "
                                                                    "logging "
                                                                    "and "
                                                                    "tracing "
                                                                    "the "
                                                                    "assumed "
                                                                    "role "
                                                                    "session.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "type": "object",
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(e.g., "
                                                            "as "
                                                            "input "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "amazon-firehose-source",
                                                            "type": "string",
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "amazon_data_firehose",
                                                            "description": "The "
                                                            "source "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`amazon_data_firehose`.",
                                                            "enum": ["amazon_data_firehose"],
                                                            "example": "amazon_data_firehose",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "AMAZON_DATA_FIREHOSE"
                                                            ],
                                                        },
                                                    },
                                                    "required": ["id", "type"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`google_pubsub` "
                                                    "source "
                                                    "ingests "
                                                    "logs "
                                                    "from "
                                                    "a "
                                                    "Google "
                                                    "Cloud "
                                                    "Pub/Sub "
                                                    "subscription.",
                                                    "properties": {
                                                        "auth": {
                                                            "description": "GCP "
                                                            "credentials "
                                                            "used "
                                                            "to "
                                                            "authenticate "
                                                            "with "
                                                            "Google "
                                                            "Cloud "
                                                            "Storage.",
                                                            "properties": {
                                                                "credentials_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "GCP "
                                                                    "service "
                                                                    "account "
                                                                    "key "
                                                                    "file.",
                                                                    "example": "/var/secrets/gcp-credentials.json",
                                                                    "type": "string",
                                                                }
                                                            },
                                                            "required": ["credentials_file"],
                                                            "type": "object",
                                                        },
                                                        "decoding": {
                                                            "description": "The "
                                                            "decoding "
                                                            "format "
                                                            "used "
                                                            "to "
                                                            "interpret "
                                                            "incoming "
                                                            "logs.",
                                                            "enum": [
                                                                "bytes",
                                                                "gelf",
                                                                "json",
                                                                "syslog",
                                                            ],
                                                            "example": "json",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "DECODE_BYTES",
                                                                "DECODE_GELF",
                                                                "DECODE_JSON",
                                                                "DECODE_SYSLOG",
                                                            ],
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(e.g., "
                                                            "as "
                                                            "input "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "google-pubsub-source",
                                                            "type": "string",
                                                        },
                                                        "project": {
                                                            "description": "The "
                                                            "GCP "
                                                            "project "
                                                            "ID "
                                                            "that "
                                                            "owns "
                                                            "the "
                                                            "Pub/Sub "
                                                            "subscription.",
                                                            "example": "my-gcp-project",
                                                            "type": "string",
                                                        },
                                                        "subscription": {
                                                            "description": "The "
                                                            "Pub/Sub "
                                                            "subscription "
                                                            "name "
                                                            "from "
                                                            "which "
                                                            "messages "
                                                            "are "
                                                            "consumed.",
                                                            "example": "logs-subscription",
                                                            "type": "string",
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "google_pubsub",
                                                            "description": "The "
                                                            "source "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`google_pubsub`.",
                                                            "enum": ["google_pubsub"],
                                                            "example": "google_pubsub",
                                                            "type": "string",
                                                            "x-enum-varnames": ["GOOGLE_PUBSUB"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "auth",
                                                        "decoding",
                                                        "project",
                                                        "subscription",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`http_client` "
                                                    "source "
                                                    "scrapes "
                                                    "logs "
                                                    "from "
                                                    "HTTP "
                                                    "endpoints "
                                                    "at "
                                                    "regular "
                                                    "intervals.",
                                                    "properties": {
                                                        "auth_strategy": {
                                                            "description": "Optional "
                                                            "authentication "
                                                            "strategy "
                                                            "for "
                                                            "HTTP "
                                                            "requests.",
                                                            "enum": ["basic", "bearer"],
                                                            "example": "basic",
                                                            "type": "string",
                                                            "x-enum-varnames": ["BASIC", "BEARER"],
                                                        },
                                                        "decoding": {
                                                            "description": "The "
                                                            "decoding "
                                                            "format "
                                                            "used "
                                                            "to "
                                                            "interpret "
                                                            "incoming "
                                                            "logs.",
                                                            "enum": [
                                                                "bytes",
                                                                "gelf",
                                                                "json",
                                                                "syslog",
                                                            ],
                                                            "example": "json",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "DECODE_BYTES",
                                                                "DECODE_GELF",
                                                                "DECODE_JSON",
                                                                "DECODE_SYSLOG",
                                                            ],
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(e.g., "
                                                            "as "
                                                            "input "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "http-client-source",
                                                            "type": "string",
                                                        },
                                                        "scrape_interval_secs": {
                                                            "description": "The "
                                                            "interval "
                                                            "(in "
                                                            "seconds) "
                                                            "between "
                                                            "HTTP "
                                                            "scrape "
                                                            "requests.",
                                                            "example": 60,
                                                            "format": "int64",
                                                            "type": "integer",
                                                        },
                                                        "scrape_timeout_secs": {
                                                            "description": "The "
                                                            "timeout "
                                                            "(in "
                                                            "seconds) "
                                                            "for "
                                                            "each "
                                                            "scrape "
                                                            "request.",
                                                            "example": 10,
                                                            "format": "int64",
                                                            "type": "integer",
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "http_client",
                                                            "description": "The "
                                                            "source "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`http_client`.",
                                                            "enum": ["http_client"],
                                                            "example": "http_client",
                                                            "type": "string",
                                                            "x-enum-varnames": ["HTTP_CLIENT"],
                                                        },
                                                    },
                                                    "required": ["id", "type", "decoding"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`logstash` "
                                                    "source "
                                                    "ingests "
                                                    "logs "
                                                    "from "
                                                    "a "
                                                    "Logstash "
                                                    "forwarder.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(e.g., "
                                                            "as "
                                                            "input "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "logstash-source",
                                                            "type": "string",
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "logstash",
                                                            "description": "The "
                                                            "source "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`logstash`.",
                                                            "enum": ["logstash"],
                                                            "example": "logstash",
                                                            "type": "string",
                                                            "x-enum-varnames": ["LOGSTASH"],
                                                        },
                                                    },
                                                    "required": ["id", "type"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`socket` "
                                                    "source "
                                                    "ingests "
                                                    "logs "
                                                    "over "
                                                    "TCP "
                                                    "or "
                                                    "UDP.",
                                                    "properties": {
                                                        "framing": {
                                                            "description": "Framing "
                                                            "method "
                                                            "configuration "
                                                            "for "
                                                            "the "
                                                            "socket "
                                                            "source.",
                                                            "oneOf": [
                                                                {
                                                                    "description": "Byte "
                                                                    "frames "
                                                                    "which "
                                                                    "are "
                                                                    "delimited "
                                                                    "by "
                                                                    "a "
                                                                    "newline "
                                                                    "character.",
                                                                    "properties": {
                                                                        "method": {
                                                                            "description": "Byte "
                                                                            "frames "
                                                                            "which "
                                                                            "are "
                                                                            "delimited "
                                                                            "by "
                                                                            "a "
                                                                            "newline "
                                                                            "character.",
                                                                            "enum": [
                                                                                "newline_delimited"
                                                                            ],
                                                                            "example": "newline_delimited",
                                                                            "type": "string",
                                                                            "x-enum-varnames": [
                                                                                "NEWLINE_DELIMITED"
                                                                            ],
                                                                        }
                                                                    },
                                                                    "required": ["method"],
                                                                    "type": "object",
                                                                },
                                                                {
                                                                    "description": "Byte "
                                                                    "frames "
                                                                    "are "
                                                                    "passed "
                                                                    "through "
                                                                    "as-is "
                                                                    "according "
                                                                    "to "
                                                                    "the "
                                                                    "underlying "
                                                                    "I/O "
                                                                    "boundaries "
                                                                    "(for "
                                                                    "example, "
                                                                    "split "
                                                                    "between "
                                                                    "messages "
                                                                    "or "
                                                                    "stream "
                                                                    "segments).",
                                                                    "properties": {
                                                                        "method": {
                                                                            "description": "Byte "
                                                                            "frames "
                                                                            "are "
                                                                            "passed "
                                                                            "through "
                                                                            "as-is "
                                                                            "according "
                                                                            "to "
                                                                            "the "
                                                                            "underlying "
                                                                            "I/O "
                                                                            "boundaries "
                                                                            "(for "
                                                                            "example, "
                                                                            "split "
                                                                            "between "
                                                                            "messages "
                                                                            "or "
                                                                            "stream "
                                                                            "segments).",
                                                                            "enum": ["bytes"],
                                                                            "example": "bytes",
                                                                            "type": "string",
                                                                            "x-enum-varnames": [
                                                                                "BYTES"
                                                                            ],
                                                                        }
                                                                    },
                                                                    "required": ["method"],
                                                                    "type": "object",
                                                                },
                                                                {
                                                                    "description": "Byte "
                                                                    "frames "
                                                                    "which "
                                                                    "are "
                                                                    "delimited "
                                                                    "by "
                                                                    "a "
                                                                    "chosen "
                                                                    "character.",
                                                                    "properties": {
                                                                        "delimiter": {
                                                                            "description": "A "
                                                                            "single "
                                                                            "ASCII "
                                                                            "character "
                                                                            "used "
                                                                            "to "
                                                                            "delimit "
                                                                            "events.",
                                                                            "example": "|",
                                                                            "maxLength": 1,
                                                                            "minLength": 1,
                                                                            "type": "string",
                                                                        },
                                                                        "method": {
                                                                            "description": "Byte "
                                                                            "frames "
                                                                            "which "
                                                                            "are "
                                                                            "delimited "
                                                                            "by "
                                                                            "a "
                                                                            "chosen "
                                                                            "character.",
                                                                            "enum": [
                                                                                "character_delimited"
                                                                            ],
                                                                            "example": "character_delimited",
                                                                            "type": "string",
                                                                            "x-enum-varnames": [
                                                                                "CHARACTER_DELIMITED"
                                                                            ],
                                                                        },
                                                                    },
                                                                    "required": [
                                                                        "method",
                                                                        "delimiter",
                                                                    ],
                                                                    "type": "object",
                                                                },
                                                                {
                                                                    "description": "Byte "
                                                                    "frames "
                                                                    "according "
                                                                    "to "
                                                                    "the "
                                                                    "octet "
                                                                    "counting "
                                                                    "format "
                                                                    "as "
                                                                    "per "
                                                                    "RFC6587.",
                                                                    "properties": {
                                                                        "method": {
                                                                            "description": "Byte "
                                                                            "frames "
                                                                            "according "
                                                                            "to "
                                                                            "the "
                                                                            "octet "
                                                                            "counting "
                                                                            "format "
                                                                            "as "
                                                                            "per "
                                                                            "RFC6587.",
                                                                            "enum": [
                                                                                "octet_counting"
                                                                            ],
                                                                            "example": "octet_counting",
                                                                            "type": "string",
                                                                            "x-enum-varnames": [
                                                                                "OCTET_COUNTING"
                                                                            ],
                                                                        }
                                                                    },
                                                                    "required": ["method"],
                                                                    "type": "object",
                                                                },
                                                                {
                                                                    "description": "Byte "
                                                                    "frames "
                                                                    "which "
                                                                    "are "
                                                                    "chunked "
                                                                    "GELF "
                                                                    "messages.",
                                                                    "properties": {
                                                                        "method": {
                                                                            "description": "Byte "
                                                                            "frames "
                                                                            "which "
                                                                            "are "
                                                                            "chunked "
                                                                            "GELF "
                                                                            "messages.",
                                                                            "enum": [
                                                                                "chunked_gelf"
                                                                            ],
                                                                            "example": "chunked_gelf",
                                                                            "type": "string",
                                                                            "x-enum-varnames": [
                                                                                "CHUNKED_GELF"
                                                                            ],
                                                                        }
                                                                    },
                                                                    "required": ["method"],
                                                                    "type": "object",
                                                                },
                                                            ],
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(e.g., "
                                                            "as "
                                                            "input "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "socket-source",
                                                            "type": "string",
                                                        },
                                                        "mode": {
                                                            "description": "Protocol "
                                                            "used "
                                                            "to "
                                                            "receive "
                                                            "logs.",
                                                            "enum": ["tcp", "udp"],
                                                            "example": "tcp",
                                                            "type": "string",
                                                            "x-enum-varnames": ["TCP", "UDP"],
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "socket",
                                                            "description": "The "
                                                            "source "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`socket`.",
                                                            "enum": ["socket"],
                                                            "example": "socket",
                                                            "type": "string",
                                                            "x-enum-varnames": ["SOCKET"],
                                                        },
                                                    },
                                                    "required": ["id", "type", "mode", "framing"],
                                                    "type": "object",
                                                },
                                            ],
                                        },
                                        "type": "array",
                                    },
                                },
                                "required": ["sources", "destinations"],
                                "type": "object",
                            },
                            "name": {
                                "description": "Name of the pipeline.",
                                "example": "Main Observability Pipeline",
                                "type": "string",
                            },
                        },
                        "required": ["name", "config"],
                        "type": "object",
                    },
                    "type": {
                        "default": "pipelines",
                        "description": "The resource type "
                        "identifier. For "
                        "pipeline resources, "
                        "this should always be "
                        "set to `pipelines`.",
                        "example": "pipelines",
                        "type": "string",
                    },
                },
                "required": ["type", "attributes"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "UPDATEPIPELINE_REQUEST_BODY_SCHEMA": {
        "description": "Top-level schema representing a pipeline.",
        "properties": {
            "data": {
                "description": "Contains the pipeline’s ID, type, and configuration attributes.",
                "properties": {
                    "attributes": {
                        "description": "Defines the "
                        "pipeline’s name "
                        "and its "
                        "components "
                        "(sources, "
                        "processors, and "
                        "destinations).",
                        "properties": {
                            "config": {
                                "description": "Specifies "
                                "the "
                                "pipeline's "
                                "configuration, "
                                "including "
                                "its "
                                "sources, "
                                "processors, "
                                "and "
                                "destinations.",
                                "properties": {
                                    "destinations": {
                                        "description": "A "
                                        "list "
                                        "of "
                                        "destination "
                                        "components "
                                        "where "
                                        "processed "
                                        "logs "
                                        "are "
                                        "sent.",
                                        "example": [
                                            {
                                                "id": "datadog-logs-destination",
                                                "inputs": ["filter-processor"],
                                                "type": "datadog_logs",
                                            }
                                        ],
                                        "items": {
                                            "description": "A destination for the pipeline.",
                                            "oneOf": [
                                                {
                                                    "description": "The "
                                                    "`datadog_logs` "
                                                    "destination "
                                                    "forwards "
                                                    "logs "
                                                    "to "
                                                    "Datadog "
                                                    "Log "
                                                    "Management.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": "datadog-logs-destination",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["filter-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "datadog_logs",
                                                            "description": "The "
                                                            "destination "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`datadog_logs`.",
                                                            "enum": ["datadog_logs"],
                                                            "example": "datadog_logs",
                                                            "type": "string",
                                                            "x-enum-varnames": ["DATADOG_LOGS"],
                                                        },
                                                    },
                                                    "required": ["id", "type", "inputs"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`amazon_s3` "
                                                    "destination "
                                                    "sends "
                                                    "your "
                                                    "logs "
                                                    "in "
                                                    "Datadog-rehydratable "
                                                    "format "
                                                    "to "
                                                    "an "
                                                    "Amazon "
                                                    "S3 "
                                                    "bucket "
                                                    "for "
                                                    "archiving.",
                                                    "properties": {
                                                        "auth": {
                                                            "description": "AWS "
                                                            "authentication "
                                                            "credentials "
                                                            "used "
                                                            "for "
                                                            "accessing "
                                                            "AWS "
                                                            "services "
                                                            "such "
                                                            "as "
                                                            "S3.\n"
                                                            "If "
                                                            "omitted, "
                                                            "the "
                                                            "system’s "
                                                            "default "
                                                            "credentials "
                                                            "are "
                                                            "used "
                                                            "(for "
                                                            "example, "
                                                            "the "
                                                            "IAM "
                                                            "role "
                                                            "and "
                                                            "environment "
                                                            "variables).",
                                                            "properties": {
                                                                "assume_role": {
                                                                    "description": "The "
                                                                    "Amazon "
                                                                    "Resource "
                                                                    "Name "
                                                                    "(ARN) "
                                                                    "of "
                                                                    "the "
                                                                    "role "
                                                                    "to "
                                                                    "assume.",
                                                                    "type": "string",
                                                                },
                                                                "external_id": {
                                                                    "description": "A "
                                                                    "unique "
                                                                    "identifier "
                                                                    "for "
                                                                    "cross-account "
                                                                    "role "
                                                                    "assumption.",
                                                                    "type": "string",
                                                                },
                                                                "session_name": {
                                                                    "description": "A "
                                                                    "session "
                                                                    "identifier "
                                                                    "used "
                                                                    "for "
                                                                    "logging "
                                                                    "and "
                                                                    "tracing "
                                                                    "the "
                                                                    "assumed "
                                                                    "role "
                                                                    "session.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "type": "object",
                                                        },
                                                        "bucket": {
                                                            "description": "S3 bucket name.",
                                                            "example": "error-logs",
                                                            "type": "string",
                                                        },
                                                        "id": {
                                                            "description": "Unique "
                                                            "identifier "
                                                            "for "
                                                            "the "
                                                            "destination "
                                                            "component.",
                                                            "example": "amazon-s3-destination",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["datadog-agent-source"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "key_prefix": {
                                                            "description": "Optional "
                                                            "prefix "
                                                            "for "
                                                            "object "
                                                            "keys.",
                                                            "type": "string",
                                                        },
                                                        "region": {
                                                            "description": "AWS "
                                                            "region "
                                                            "of "
                                                            "the "
                                                            "S3 "
                                                            "bucket.",
                                                            "example": "us-east-1",
                                                            "type": "string",
                                                        },
                                                        "storage_class": {
                                                            "description": "S3 storage class.",
                                                            "enum": [
                                                                "STANDARD",
                                                                "REDUCED_REDUNDANCY",
                                                                "INTELLIGENT_TIERING",
                                                                "STANDARD_IA",
                                                                "EXPRESS_ONEZONE",
                                                                "ONEZONE_IA",
                                                                "GLACIER",
                                                                "GLACIER_IR",
                                                                "DEEP_ARCHIVE",
                                                            ],
                                                            "example": "STANDARD",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "STANDARD",
                                                                "REDUCED_REDUNDANCY",
                                                                "INTELLIGENT_TIERING",
                                                                "STANDARD_IA",
                                                                "EXPRESS_ONEZONE",
                                                                "ONEZONE_IA",
                                                                "GLACIER",
                                                                "GLACIER_IR",
                                                                "DEEP_ARCHIVE",
                                                            ],
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "amazon_s3",
                                                            "description": "The "
                                                            "destination "
                                                            "type. "
                                                            "Always "
                                                            "`amazon_s3`.",
                                                            "enum": ["amazon_s3"],
                                                            "example": "amazon_s3",
                                                            "type": "string",
                                                            "x-enum-varnames": ["AMAZON_S3"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "inputs",
                                                        "bucket",
                                                        "region",
                                                        "storage_class",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`google_cloud_storage` "
                                                    "destination "
                                                    "stores "
                                                    "logs "
                                                    "in "
                                                    "a "
                                                    "Google "
                                                    "Cloud "
                                                    "Storage "
                                                    "(GCS) "
                                                    "bucket.\n"
                                                    "It "
                                                    "requires "
                                                    "a "
                                                    "bucket "
                                                    "name, "
                                                    "GCP "
                                                    "authentication, "
                                                    "and "
                                                    "metadata "
                                                    "fields.",
                                                    "properties": {
                                                        "acl": {
                                                            "description": "Access "
                                                            "control "
                                                            "list "
                                                            "setting "
                                                            "for "
                                                            "objects "
                                                            "written "
                                                            "to "
                                                            "the "
                                                            "bucket.",
                                                            "enum": [
                                                                "private",
                                                                "project-private",
                                                                "public-read",
                                                                "authenticated-read",
                                                                "bucket-owner-read",
                                                                "bucket-owner-full-control",
                                                            ],
                                                            "example": "private",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "PRIVATE",
                                                                "PROJECTNOT_PRIVATE",
                                                                "PUBLICNOT_READ",
                                                                "AUTHENTICATEDNOT_READ",
                                                                "BUCKETNOT_OWNERNOT_READ",
                                                                "BUCKETNOT_OWNERNOT_FULLNOT_CONTROL",
                                                            ],
                                                        },
                                                        "auth": {
                                                            "description": "GCP "
                                                            "credentials "
                                                            "used "
                                                            "to "
                                                            "authenticate "
                                                            "with "
                                                            "Google "
                                                            "Cloud "
                                                            "Storage.",
                                                            "properties": {
                                                                "credentials_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "GCP "
                                                                    "service "
                                                                    "account "
                                                                    "key "
                                                                    "file.",
                                                                    "example": "/var/secrets/gcp-credentials.json",
                                                                    "type": "string",
                                                                }
                                                            },
                                                            "required": ["credentials_file"],
                                                            "type": "object",
                                                        },
                                                        "bucket": {
                                                            "description": "Name "
                                                            "of "
                                                            "the "
                                                            "GCS "
                                                            "bucket.",
                                                            "example": "error-logs",
                                                            "type": "string",
                                                        },
                                                        "id": {
                                                            "description": "Unique "
                                                            "identifier "
                                                            "for "
                                                            "the "
                                                            "destination "
                                                            "component.",
                                                            "example": "gcs-destination",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["datadog-agent-source"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "key_prefix": {
                                                            "description": "Optional "
                                                            "prefix "
                                                            "for "
                                                            "object "
                                                            "keys "
                                                            "within "
                                                            "the "
                                                            "GCS "
                                                            "bucket.",
                                                            "type": "string",
                                                        },
                                                        "metadata": {
                                                            "description": "Custom "
                                                            "metadata "
                                                            "to "
                                                            "attach "
                                                            "to "
                                                            "each "
                                                            "object "
                                                            "uploaded "
                                                            "to "
                                                            "the "
                                                            "GCS "
                                                            "bucket.",
                                                            "items": {
                                                                "description": "A "
                                                                "custom "
                                                                "metadata "
                                                                "entry.",
                                                                "properties": {
                                                                    "name": {
                                                                        "description": "The "
                                                                        "metadata "
                                                                        "key.",
                                                                        "example": "environment",
                                                                        "type": "string",
                                                                    },
                                                                    "value": {
                                                                        "description": "The "
                                                                        "metadata "
                                                                        "value.",
                                                                        "example": "production",
                                                                        "type": "string",
                                                                    },
                                                                },
                                                                "required": ["name", "value"],
                                                                "type": "object",
                                                            },
                                                            "type": "array",
                                                        },
                                                        "storage_class": {
                                                            "description": "Storage "
                                                            "class "
                                                            "used "
                                                            "for "
                                                            "objects "
                                                            "stored "
                                                            "in "
                                                            "GCS.",
                                                            "enum": [
                                                                "STANDARD",
                                                                "NEARLINE",
                                                                "COLDLINE",
                                                                "ARCHIVE",
                                                            ],
                                                            "example": "STANDARD",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "STANDARD",
                                                                "NEARLINE",
                                                                "COLDLINE",
                                                                "ARCHIVE",
                                                            ],
                                                        },
                                                        "type": {
                                                            "default": "google_cloud_storage",
                                                            "description": "The "
                                                            "destination "
                                                            "type. "
                                                            "Always "
                                                            "`google_cloud_storage`.",
                                                            "enum": ["google_cloud_storage"],
                                                            "example": "google_cloud_storage",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "GOOGLE_CLOUD_STORAGE"
                                                            ],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "inputs",
                                                        "bucket",
                                                        "auth",
                                                        "storage_class",
                                                        "acl",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`splunk_hec` "
                                                    "destination "
                                                    "forwards "
                                                    "logs "
                                                    "to "
                                                    "Splunk "
                                                    "using "
                                                    "the "
                                                    "HTTP "
                                                    "Event "
                                                    "Collector "
                                                    "(HEC).",
                                                    "properties": {
                                                        "auto_extract_timestamp": {
                                                            "description": "If "
                                                            "`true`, "
                                                            "Splunk "
                                                            "tries "
                                                            "to "
                                                            "extract "
                                                            "timestamps "
                                                            "from "
                                                            "incoming "
                                                            "log "
                                                            "events.\n"
                                                            "If "
                                                            "`false`, "
                                                            "Splunk "
                                                            "assigns "
                                                            "the "
                                                            "time "
                                                            "the "
                                                            "event "
                                                            "was "
                                                            "received.",
                                                            "example": True,
                                                            "type": "boolean",
                                                        },
                                                        "encoding": {
                                                            "description": "Encoding "
                                                            "format "
                                                            "for "
                                                            "log "
                                                            "events.",
                                                            "enum": ["json", "raw_message"],
                                                            "example": "json",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "JSON",
                                                                "RAW_MESSAGE",
                                                            ],
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(e.g., "
                                                            "as "
                                                            "input "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "splunk-hec-destination",
                                                            "type": "string",
                                                        },
                                                        "index": {
                                                            "description": "Optional "
                                                            "name "
                                                            "of "
                                                            "the "
                                                            "Splunk "
                                                            "index "
                                                            "where "
                                                            "logs "
                                                            "are "
                                                            "written.",
                                                            "example": "main",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["filter-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "sourcetype": {
                                                            "description": "The "
                                                            "Splunk "
                                                            "sourcetype "
                                                            "to "
                                                            "assign "
                                                            "to "
                                                            "log "
                                                            "events.",
                                                            "example": "custom_sourcetype",
                                                            "type": "string",
                                                        },
                                                        "type": {
                                                            "default": "splunk_hec",
                                                            "description": "The "
                                                            "destination "
                                                            "type. "
                                                            "Always "
                                                            "`splunk_hec`.",
                                                            "enum": ["splunk_hec"],
                                                            "example": "splunk_hec",
                                                            "type": "string",
                                                            "x-enum-varnames": ["SPLUNK_HEC"],
                                                        },
                                                    },
                                                    "required": ["id", "type", "inputs"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`sumo_logic` "
                                                    "destination "
                                                    "forwards "
                                                    "logs "
                                                    "to "
                                                    "Sumo "
                                                    "Logic.",
                                                    "properties": {
                                                        "encoding": {
                                                            "description": "The "
                                                            "output "
                                                            "encoding "
                                                            "format.",
                                                            "enum": [
                                                                "json",
                                                                "raw_message",
                                                                "logfmt",
                                                            ],
                                                            "example": "json",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "JSON",
                                                                "RAW_MESSAGE",
                                                                "LOGFMT",
                                                            ],
                                                        },
                                                        "header_custom_fields": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "custom "
                                                            "headers "
                                                            "to "
                                                            "include "
                                                            "in "
                                                            "the "
                                                            "request "
                                                            "to "
                                                            "Sumo "
                                                            "Logic.",
                                                            "items": {
                                                                "description": "Single "
                                                                "key-value "
                                                                "pair "
                                                                "used "
                                                                "as "
                                                                "a "
                                                                "custom "
                                                                "log "
                                                                "header "
                                                                "for "
                                                                "Sumo "
                                                                "Logic.",
                                                                "properties": {
                                                                    "name": {
                                                                        "description": "The "
                                                                        "header "
                                                                        "field "
                                                                        "name.",
                                                                        "example": "X-Sumo-Category",
                                                                        "type": "string",
                                                                    },
                                                                    "value": {
                                                                        "description": "The "
                                                                        "header "
                                                                        "field "
                                                                        "value.",
                                                                        "example": "my-app-logs",
                                                                        "type": "string",
                                                                    },
                                                                },
                                                                "required": ["name", "value"],
                                                                "type": "object",
                                                            },
                                                            "type": "array",
                                                        },
                                                        "header_host_name": {
                                                            "description": "Optional "
                                                            "override "
                                                            "for "
                                                            "the "
                                                            "host "
                                                            "name "
                                                            "header.",
                                                            "example": "host-123",
                                                            "type": "string",
                                                        },
                                                        "header_source_category": {
                                                            "description": "Optional "
                                                            "override "
                                                            "for "
                                                            "the "
                                                            "source "
                                                            "category "
                                                            "header.",
                                                            "example": "source-category",
                                                            "type": "string",
                                                        },
                                                        "header_source_name": {
                                                            "description": "Optional "
                                                            "override "
                                                            "for "
                                                            "the "
                                                            "source "
                                                            "name "
                                                            "header.",
                                                            "example": "source-name",
                                                            "type": "string",
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": "sumo-logic-destination",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["filter-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "sumo_logic",
                                                            "description": "The "
                                                            "destination "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`sumo_logic`.",
                                                            "enum": ["sumo_logic"],
                                                            "example": "sumo_logic",
                                                            "type": "string",
                                                            "x-enum-varnames": ["SUMO_LOGIC"],
                                                        },
                                                    },
                                                    "required": ["id", "type", "inputs"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`elasticsearch` "
                                                    "destination "
                                                    "writes "
                                                    "logs "
                                                    "to "
                                                    "an "
                                                    "Elasticsearch "
                                                    "cluster.",
                                                    "properties": {
                                                        "api_version": {
                                                            "description": "The "
                                                            "Elasticsearch "
                                                            "API "
                                                            "version "
                                                            "to "
                                                            "use. "
                                                            "Set "
                                                            "to "
                                                            "`auto` "
                                                            "to "
                                                            "auto-detect.",
                                                            "enum": ["auto", "v6", "v7", "v8"],
                                                            "example": "auto",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "AUTO",
                                                                "V6",
                                                                "V7",
                                                                "V8",
                                                            ],
                                                        },
                                                        "bulk_index": {
                                                            "description": "The "
                                                            "index "
                                                            "to "
                                                            "write "
                                                            "logs "
                                                            "to "
                                                            "in "
                                                            "Elasticsearch.",
                                                            "example": "logs-index",
                                                            "type": "string",
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": "elasticsearch-destination",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["filter-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "elasticsearch",
                                                            "description": "The "
                                                            "destination "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`elasticsearch`.",
                                                            "enum": ["elasticsearch"],
                                                            "example": "elasticsearch",
                                                            "type": "string",
                                                            "x-enum-varnames": ["ELASTICSEARCH"],
                                                        },
                                                    },
                                                    "required": ["id", "type", "inputs"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`rsyslog` "
                                                    "destination "
                                                    "forwards "
                                                    "logs "
                                                    "to "
                                                    "an "
                                                    "external "
                                                    "`rsyslog` "
                                                    "server "
                                                    "over "
                                                    "TCP "
                                                    "or "
                                                    "UDP "
                                                    "using "
                                                    "the "
                                                    "syslog "
                                                    "protocol.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": "rsyslog-destination",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["filter-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "keepalive": {
                                                            "description": "Optional "
                                                            "socket "
                                                            "keepalive "
                                                            "duration "
                                                            "in "
                                                            "milliseconds.",
                                                            "example": 60000,
                                                            "format": "int64",
                                                            "minimum": 0,
                                                            "type": "integer",
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "rsyslog",
                                                            "description": "The "
                                                            "destination "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`rsyslog`.",
                                                            "enum": ["rsyslog"],
                                                            "example": "rsyslog",
                                                            "type": "string",
                                                            "x-enum-varnames": ["RSYSLOG"],
                                                        },
                                                    },
                                                    "required": ["id", "type", "inputs"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`syslog_ng` "
                                                    "destination "
                                                    "forwards "
                                                    "logs "
                                                    "to "
                                                    "an "
                                                    "external "
                                                    "`syslog-ng` "
                                                    "server "
                                                    "over "
                                                    "TCP "
                                                    "or "
                                                    "UDP "
                                                    "using "
                                                    "the "
                                                    "syslog "
                                                    "protocol.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": "syslog-ng-destination",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["filter-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "keepalive": {
                                                            "description": "Optional "
                                                            "socket "
                                                            "keepalive "
                                                            "duration "
                                                            "in "
                                                            "milliseconds.",
                                                            "example": 60000,
                                                            "format": "int64",
                                                            "minimum": 0,
                                                            "type": "integer",
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "syslog_ng",
                                                            "description": "The "
                                                            "destination "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`syslog_ng`.",
                                                            "enum": ["syslog_ng"],
                                                            "example": "syslog_ng",
                                                            "type": "string",
                                                            "x-enum-varnames": ["SYSLOG_NG"],
                                                        },
                                                    },
                                                    "required": ["id", "type", "inputs"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`azure_storage` "
                                                    "destination "
                                                    "forwards "
                                                    "logs "
                                                    "to "
                                                    "an "
                                                    "Azure "
                                                    "Blob "
                                                    "Storage "
                                                    "container.",
                                                    "properties": {
                                                        "blob_prefix": {
                                                            "description": "Optional "
                                                            "prefix "
                                                            "for "
                                                            "blobs "
                                                            "written "
                                                            "to "
                                                            "the "
                                                            "container.",
                                                            "example": "logs/",
                                                            "type": "string",
                                                        },
                                                        "container_name": {
                                                            "description": "The "
                                                            "name "
                                                            "of "
                                                            "the "
                                                            "Azure "
                                                            "Blob "
                                                            "Storage "
                                                            "container "
                                                            "to "
                                                            "store "
                                                            "logs "
                                                            "in.",
                                                            "example": "my-log-container",
                                                            "type": "string",
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": "azure-storage-destination",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["processor-id"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "azure_storage",
                                                            "description": "The "
                                                            "destination "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`azure_storage`.",
                                                            "enum": ["azure_storage"],
                                                            "example": "azure_storage",
                                                            "type": "string",
                                                            "x-enum-varnames": ["AZURE_STORAGE"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "inputs",
                                                        "container_name",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`microsoft_sentinel` "
                                                    "destination "
                                                    "forwards "
                                                    "logs "
                                                    "to "
                                                    "Microsoft "
                                                    "Sentinel.",
                                                    "properties": {
                                                        "client_id": {
                                                            "description": "Azure "
                                                            "AD "
                                                            "client "
                                                            "ID "
                                                            "used "
                                                            "for "
                                                            "authentication.",
                                                            "example": "a1b2c3d4-5678-90ab-cdef-1234567890ab",
                                                            "type": "string",
                                                        },
                                                        "dcr_immutable_id": {
                                                            "description": "The "
                                                            "immutable "
                                                            "ID "
                                                            "of "
                                                            "the "
                                                            "Data "
                                                            "Collection "
                                                            "Rule "
                                                            "(DCR).",
                                                            "example": "dcr-uuid-1234",
                                                            "type": "string",
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": "sentinel-destination",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["filter-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "table": {
                                                            "description": "The "
                                                            "name "
                                                            "of "
                                                            "the "
                                                            "Log "
                                                            "Analytics "
                                                            "table "
                                                            "where "
                                                            "logs "
                                                            "are "
                                                            "sent.",
                                                            "example": "CustomLogsTable",
                                                            "type": "string",
                                                        },
                                                        "tenant_id": {
                                                            "description": "Azure AD tenant ID.",
                                                            "example": "abcdef12-3456-7890-abcd-ef1234567890",
                                                            "type": "string",
                                                        },
                                                        "type": {
                                                            "default": "microsoft_sentinel",
                                                            "description": "The "
                                                            "destination "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`microsoft_sentinel`.",
                                                            "enum": ["microsoft_sentinel"],
                                                            "example": "microsoft_sentinel",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "MICROSOFT_SENTINEL"
                                                            ],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "inputs",
                                                        "client_id",
                                                        "tenant_id",
                                                        "dcr_immutable_id",
                                                        "table",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`google_chronicle` "
                                                    "destination "
                                                    "sends "
                                                    "logs "
                                                    "to "
                                                    "Google "
                                                    "Chronicle.",
                                                    "properties": {
                                                        "auth": {
                                                            "description": "GCP "
                                                            "credentials "
                                                            "used "
                                                            "to "
                                                            "authenticate "
                                                            "with "
                                                            "Google "
                                                            "Cloud "
                                                            "Storage.",
                                                            "properties": {
                                                                "credentials_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "GCP "
                                                                    "service "
                                                                    "account "
                                                                    "key "
                                                                    "file.",
                                                                    "example": "/var/secrets/gcp-credentials.json",
                                                                    "type": "string",
                                                                }
                                                            },
                                                            "required": ["credentials_file"],
                                                            "type": "object",
                                                        },
                                                        "customer_id": {
                                                            "description": "The "
                                                            "Google "
                                                            "Chronicle "
                                                            "customer "
                                                            "ID.",
                                                            "example": "abcdefg123456789",
                                                            "type": "string",
                                                        },
                                                        "encoding": {
                                                            "description": "The "
                                                            "encoding "
                                                            "format "
                                                            "for "
                                                            "the "
                                                            "logs "
                                                            "sent "
                                                            "to "
                                                            "Chronicle.",
                                                            "enum": ["json", "raw_message"],
                                                            "example": "json",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "JSON",
                                                                "RAW_MESSAGE",
                                                            ],
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": "google-chronicle-destination",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["parse-json-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "log_type": {
                                                            "description": "The "
                                                            "log "
                                                            "type "
                                                            "metadata "
                                                            "associated "
                                                            "with "
                                                            "the "
                                                            "Chronicle "
                                                            "destination.",
                                                            "example": "nginx_logs",
                                                            "type": "string",
                                                        },
                                                        "type": {
                                                            "default": "google_chronicle",
                                                            "description": "The "
                                                            "destination "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`google_chronicle`.",
                                                            "enum": ["google_chronicle"],
                                                            "example": "google_chronicle",
                                                            "type": "string",
                                                            "x-enum-varnames": ["GOOGLE_CHRONICLE"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "inputs",
                                                        "auth",
                                                        "customer_id",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`new_relic` "
                                                    "destination "
                                                    "sends "
                                                    "logs "
                                                    "to "
                                                    "the "
                                                    "New "
                                                    "Relic "
                                                    "platform.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": "new-relic-destination",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["parse-json-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "region": {
                                                            "description": "The New Relic region.",
                                                            "enum": ["us", "eu"],
                                                            "example": "us",
                                                            "type": "string",
                                                            "x-enum-varnames": ["US", "EU"],
                                                        },
                                                        "type": {
                                                            "default": "new_relic",
                                                            "description": "The "
                                                            "destination "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`new_relic`.",
                                                            "enum": ["new_relic"],
                                                            "example": "new_relic",
                                                            "type": "string",
                                                            "x-enum-varnames": ["NEW_RELIC"],
                                                        },
                                                    },
                                                    "required": ["id", "type", "inputs", "region"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`sentinel_one` "
                                                    "destination "
                                                    "sends "
                                                    "logs "
                                                    "to "
                                                    "SentinelOne.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": "sentinelone-destination",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["filter-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "region": {
                                                            "description": "The "
                                                            "SentinelOne "
                                                            "region "
                                                            "to "
                                                            "send "
                                                            "logs "
                                                            "to.",
                                                            "enum": [
                                                                "us",
                                                                "eu",
                                                                "ca",
                                                                "data_set_us",
                                                            ],
                                                            "example": "us",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "US",
                                                                "EU",
                                                                "CA",
                                                                "DATA_SET_US",
                                                            ],
                                                        },
                                                        "type": {
                                                            "default": "sentinel_one",
                                                            "description": "The "
                                                            "destination "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`sentinel_one`.",
                                                            "enum": ["sentinel_one"],
                                                            "example": "sentinel_one",
                                                            "type": "string",
                                                            "x-enum-varnames": ["SENTINEL_ONE"],
                                                        },
                                                    },
                                                    "required": ["id", "type", "inputs", "region"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`opensearch` "
                                                    "destination "
                                                    "writes "
                                                    "logs "
                                                    "to "
                                                    "an "
                                                    "OpenSearch "
                                                    "cluster.",
                                                    "properties": {
                                                        "bulk_index": {
                                                            "description": "The "
                                                            "index "
                                                            "to "
                                                            "write "
                                                            "logs "
                                                            "to.",
                                                            "example": "logs-index",
                                                            "type": "string",
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": "opensearch-destination",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["filter-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "opensearch",
                                                            "description": "The "
                                                            "destination "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`opensearch`.",
                                                            "enum": ["opensearch"],
                                                            "example": "opensearch",
                                                            "type": "string",
                                                            "x-enum-varnames": ["OPENSEARCH"],
                                                        },
                                                    },
                                                    "required": ["id", "type", "inputs"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`amazon_opensearch` "
                                                    "destination "
                                                    "writes "
                                                    "logs "
                                                    "to "
                                                    "Amazon "
                                                    "OpenSearch.",
                                                    "properties": {
                                                        "auth": {
                                                            "description": "Authentication "
                                                            "settings "
                                                            "for "
                                                            "the "
                                                            "Amazon "
                                                            "OpenSearch "
                                                            "destination.\n"
                                                            "The "
                                                            "`strategy` "
                                                            "field "
                                                            "determines "
                                                            "whether "
                                                            "basic "
                                                            "or "
                                                            "AWS-based "
                                                            "authentication "
                                                            "is "
                                                            "used.",
                                                            "properties": {
                                                                "assume_role": {
                                                                    "description": "The "
                                                                    "ARN "
                                                                    "of "
                                                                    "the "
                                                                    "role "
                                                                    "to "
                                                                    "assume "
                                                                    "(used "
                                                                    "with "
                                                                    "`aws` "
                                                                    "strategy).",
                                                                    "type": "string",
                                                                },
                                                                "aws_region": {
                                                                    "description": "AWS region",
                                                                    "type": "string",
                                                                },
                                                                "external_id": {
                                                                    "description": "External "
                                                                    "ID "
                                                                    "for "
                                                                    "the "
                                                                    "assumed "
                                                                    "role "
                                                                    "(used "
                                                                    "with "
                                                                    "`aws` "
                                                                    "strategy).",
                                                                    "type": "string",
                                                                },
                                                                "session_name": {
                                                                    "description": "Session "
                                                                    "name "
                                                                    "for "
                                                                    "the "
                                                                    "assumed "
                                                                    "role "
                                                                    "(used "
                                                                    "with "
                                                                    "`aws` "
                                                                    "strategy).",
                                                                    "type": "string",
                                                                },
                                                                "strategy": {
                                                                    "description": "The "
                                                                    "authentication "
                                                                    "strategy "
                                                                    "to "
                                                                    "use.",
                                                                    "enum": ["basic", "aws"],
                                                                    "example": "aws",
                                                                    "type": "string",
                                                                    "x-enum-varnames": [
                                                                        "BASIC",
                                                                        "AWS",
                                                                    ],
                                                                },
                                                            },
                                                            "required": ["strategy"],
                                                            "type": "object",
                                                        },
                                                        "bulk_index": {
                                                            "description": "The "
                                                            "index "
                                                            "to "
                                                            "write "
                                                            "logs "
                                                            "to.",
                                                            "example": "logs-index",
                                                            "type": "string",
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": "elasticsearch-destination",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["filter-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "amazon_opensearch",
                                                            "description": "The "
                                                            "destination "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`amazon_opensearch`.",
                                                            "enum": ["amazon_opensearch"],
                                                            "example": "amazon_opensearch",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "AMAZON_OPENSEARCH"
                                                            ],
                                                        },
                                                    },
                                                    "required": ["id", "type", "inputs", "auth"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`socket` "
                                                    "destination "
                                                    "sends "
                                                    "logs "
                                                    "over "
                                                    "TCP "
                                                    "or "
                                                    "UDP "
                                                    "to "
                                                    "a "
                                                    "remote "
                                                    "server.",
                                                    "properties": {
                                                        "encoding": {
                                                            "description": "Encoding "
                                                            "format "
                                                            "for "
                                                            "log "
                                                            "events.",
                                                            "enum": ["json", "raw_message"],
                                                            "example": "json",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "JSON",
                                                                "RAW_MESSAGE",
                                                            ],
                                                        },
                                                        "framing": {
                                                            "description": "Framing "
                                                            "method "
                                                            "configuration.",
                                                            "oneOf": [
                                                                {
                                                                    "description": "Each "
                                                                    "log "
                                                                    "event "
                                                                    "is "
                                                                    "delimited "
                                                                    "by "
                                                                    "a "
                                                                    "newline "
                                                                    "character.",
                                                                    "properties": {
                                                                        "method": {
                                                                            "description": "The "
                                                                            "definition "
                                                                            "of "
                                                                            "`ObservabilityPipelineSocketDestinationFramingNewlineDelimitedMethod` "
                                                                            "object.",
                                                                            "enum": [
                                                                                "newline_delimited"
                                                                            ],
                                                                            "example": "newline_delimited",
                                                                            "type": "string",
                                                                            "x-enum-varnames": [
                                                                                "NEWLINE_DELIMITED"
                                                                            ],
                                                                        }
                                                                    },
                                                                    "required": ["method"],
                                                                    "type": "object",
                                                                },
                                                                {
                                                                    "description": "Event "
                                                                    "data "
                                                                    "is "
                                                                    "not "
                                                                    "delimited "
                                                                    "at "
                                                                    "all.",
                                                                    "properties": {
                                                                        "method": {
                                                                            "description": "The "
                                                                            "definition "
                                                                            "of "
                                                                            "`ObservabilityPipelineSocketDestinationFramingBytesMethod` "
                                                                            "object.",
                                                                            "enum": ["bytes"],
                                                                            "example": "bytes",
                                                                            "type": "string",
                                                                            "x-enum-varnames": [
                                                                                "BYTES"
                                                                            ],
                                                                        }
                                                                    },
                                                                    "required": ["method"],
                                                                    "type": "object",
                                                                },
                                                                {
                                                                    "description": "Each "
                                                                    "log "
                                                                    "event "
                                                                    "is "
                                                                    "separated "
                                                                    "using "
                                                                    "the "
                                                                    "specified "
                                                                    "delimiter "
                                                                    "character.",
                                                                    "properties": {
                                                                        "delimiter": {
                                                                            "description": "A "
                                                                            "single "
                                                                            "ASCII "
                                                                            "character "
                                                                            "used "
                                                                            "as "
                                                                            "a "
                                                                            "delimiter.",
                                                                            "example": "|",
                                                                            "maxLength": 1,
                                                                            "minLength": 1,
                                                                            "type": "string",
                                                                        },
                                                                        "method": {
                                                                            "description": "The "
                                                                            "definition "
                                                                            "of "
                                                                            "`ObservabilityPipelineSocketDestinationFramingCharacterDelimitedMethod` "
                                                                            "object.",
                                                                            "enum": [
                                                                                "character_delimited"
                                                                            ],
                                                                            "example": "character_delimited",
                                                                            "type": "string",
                                                                            "x-enum-varnames": [
                                                                                "CHARACTER_DELIMITED"
                                                                            ],
                                                                        },
                                                                    },
                                                                    "required": [
                                                                        "method",
                                                                        "delimiter",
                                                                    ],
                                                                    "type": "object",
                                                                },
                                                            ],
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": "socket-destination",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["filter-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "mode": {
                                                            "description": "Protocol "
                                                            "used "
                                                            "to "
                                                            "send "
                                                            "logs.",
                                                            "enum": ["tcp", "udp"],
                                                            "example": "tcp",
                                                            "type": "string",
                                                            "x-enum-varnames": ["TCP", "UDP"],
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "socket",
                                                            "description": "The "
                                                            "destination "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`socket`.",
                                                            "enum": ["socket"],
                                                            "example": "socket",
                                                            "type": "string",
                                                            "x-enum-varnames": ["SOCKET"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "inputs",
                                                        "encoding",
                                                        "framing",
                                                        "mode",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`amazon_security_lake` "
                                                    "destination "
                                                    "sends "
                                                    "your "
                                                    "logs "
                                                    "to "
                                                    "Amazon "
                                                    "Security "
                                                    "Lake.",
                                                    "properties": {
                                                        "auth": {
                                                            "description": "AWS "
                                                            "authentication "
                                                            "credentials "
                                                            "used "
                                                            "for "
                                                            "accessing "
                                                            "AWS "
                                                            "services "
                                                            "such "
                                                            "as "
                                                            "S3.\n"
                                                            "If "
                                                            "omitted, "
                                                            "the "
                                                            "system’s "
                                                            "default "
                                                            "credentials "
                                                            "are "
                                                            "used "
                                                            "(for "
                                                            "example, "
                                                            "the "
                                                            "IAM "
                                                            "role "
                                                            "and "
                                                            "environment "
                                                            "variables).",
                                                            "properties": {
                                                                "assume_role": {
                                                                    "description": "The "
                                                                    "Amazon "
                                                                    "Resource "
                                                                    "Name "
                                                                    "(ARN) "
                                                                    "of "
                                                                    "the "
                                                                    "role "
                                                                    "to "
                                                                    "assume.",
                                                                    "type": "string",
                                                                },
                                                                "external_id": {
                                                                    "description": "A "
                                                                    "unique "
                                                                    "identifier "
                                                                    "for "
                                                                    "cross-account "
                                                                    "role "
                                                                    "assumption.",
                                                                    "type": "string",
                                                                },
                                                                "session_name": {
                                                                    "description": "A "
                                                                    "session "
                                                                    "identifier "
                                                                    "used "
                                                                    "for "
                                                                    "logging "
                                                                    "and "
                                                                    "tracing "
                                                                    "the "
                                                                    "assumed "
                                                                    "role "
                                                                    "session.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "type": "object",
                                                        },
                                                        "bucket": {
                                                            "description": "Name "
                                                            "of "
                                                            "the "
                                                            "Amazon "
                                                            "S3 "
                                                            "bucket "
                                                            "in "
                                                            "Security "
                                                            "Lake "
                                                            "(3-63 "
                                                            "characters).",
                                                            "example": "security-lake-bucket",
                                                            "type": "string",
                                                        },
                                                        "custom_source_name": {
                                                            "description": "Custom "
                                                            "source "
                                                            "name "
                                                            "for "
                                                            "the "
                                                            "logs "
                                                            "in "
                                                            "Security "
                                                            "Lake.",
                                                            "example": "my-custom-source",
                                                            "type": "string",
                                                        },
                                                        "id": {
                                                            "description": "Unique "
                                                            "identifier "
                                                            "for "
                                                            "the "
                                                            "destination "
                                                            "component.",
                                                            "example": "amazon-security-lake-destination",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["filter-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "region": {
                                                            "description": "AWS "
                                                            "region "
                                                            "of "
                                                            "the "
                                                            "S3 "
                                                            "bucket.",
                                                            "example": "us-east-1",
                                                            "type": "string",
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "amazon_security_lake",
                                                            "description": "The "
                                                            "destination "
                                                            "type. "
                                                            "Always "
                                                            "`amazon_security_lake`.",
                                                            "enum": ["amazon_security_lake"],
                                                            "example": "amazon_security_lake",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "AMAZON_SECURITY_LAKE"
                                                            ],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "inputs",
                                                        "bucket",
                                                        "region",
                                                        "custom_source_name",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`crowdstrike_next_gen_siem` "
                                                    "destination "
                                                    "forwards "
                                                    "logs "
                                                    "to "
                                                    "CrowdStrike "
                                                    "Next "
                                                    "Gen "
                                                    "SIEM.",
                                                    "properties": {
                                                        "compression": {
                                                            "description": "Compression "
                                                            "configuration "
                                                            "for "
                                                            "log "
                                                            "events.",
                                                            "properties": {
                                                                "algorithm": {
                                                                    "description": "Compression "
                                                                    "algorithm "
                                                                    "for "
                                                                    "log "
                                                                    "events.",
                                                                    "enum": ["gzip", "zlib"],
                                                                    "example": "gzip",
                                                                    "type": "string",
                                                                    "x-enum-varnames": [
                                                                        "GZIP",
                                                                        "ZLIB",
                                                                    ],
                                                                },
                                                                "level": {
                                                                    "description": "Compression "
                                                                    "level.",
                                                                    "example": 6,
                                                                    "format": "int64",
                                                                    "type": "integer",
                                                                },
                                                            },
                                                            "required": ["algorithm"],
                                                            "type": "object",
                                                        },
                                                        "encoding": {
                                                            "description": "Encoding "
                                                            "format "
                                                            "for "
                                                            "log "
                                                            "events.",
                                                            "enum": ["json", "raw_message"],
                                                            "example": "json",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "JSON",
                                                                "RAW_MESSAGE",
                                                            ],
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": "crowdstrike-ngsiem-destination",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["filter-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "crowdstrike_next_gen_siem",
                                                            "description": "The "
                                                            "destination "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`crowdstrike_next_gen_siem`.",
                                                            "enum": ["crowdstrike_next_gen_siem"],
                                                            "example": "crowdstrike_next_gen_siem",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "CROWDSTRIKE_NEXT_GEN_SIEM"
                                                            ],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "inputs",
                                                        "encoding",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`google_pubsub` "
                                                    "destination "
                                                    "publishes "
                                                    "logs "
                                                    "to "
                                                    "a "
                                                    "Google "
                                                    "Cloud "
                                                    "Pub/Sub "
                                                    "topic.",
                                                    "properties": {
                                                        "auth": {
                                                            "description": "GCP "
                                                            "credentials "
                                                            "used "
                                                            "to "
                                                            "authenticate "
                                                            "with "
                                                            "Google "
                                                            "Cloud "
                                                            "Storage.",
                                                            "properties": {
                                                                "credentials_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "GCP "
                                                                    "service "
                                                                    "account "
                                                                    "key "
                                                                    "file.",
                                                                    "example": "/var/secrets/gcp-credentials.json",
                                                                    "type": "string",
                                                                }
                                                            },
                                                            "required": ["credentials_file"],
                                                            "type": "object",
                                                        },
                                                        "encoding": {
                                                            "description": "Encoding "
                                                            "format "
                                                            "for "
                                                            "log "
                                                            "events.",
                                                            "enum": ["json", "raw_message"],
                                                            "example": "json",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "JSON",
                                                                "RAW_MESSAGE",
                                                            ],
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": "google-pubsub-destination",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["filter-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "project": {
                                                            "description": "The "
                                                            "GCP "
                                                            "project "
                                                            "ID "
                                                            "that "
                                                            "owns "
                                                            "the "
                                                            "Pub/Sub "
                                                            "topic.",
                                                            "example": "my-gcp-project",
                                                            "type": "string",
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "topic": {
                                                            "description": "The "
                                                            "Pub/Sub "
                                                            "topic "
                                                            "name "
                                                            "to "
                                                            "publish "
                                                            "logs "
                                                            "to.",
                                                            "example": "logs-subscription",
                                                            "type": "string",
                                                        },
                                                        "type": {
                                                            "default": "google_pubsub",
                                                            "description": "The "
                                                            "destination "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`google_pubsub`.",
                                                            "enum": ["google_pubsub"],
                                                            "example": "google_pubsub",
                                                            "type": "string",
                                                            "x-enum-varnames": ["GOOGLE_PUBSUB"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "inputs",
                                                        "encoding",
                                                        "project",
                                                        "topic",
                                                    ],
                                                    "type": "object",
                                                },
                                            ],
                                        },
                                        "type": "array",
                                    },
                                    "processors": {
                                        "description": "A "
                                        "list "
                                        "of "
                                        "processors "
                                        "that "
                                        "transform "
                                        "or "
                                        "enrich "
                                        "log "
                                        "data.",
                                        "example": [
                                            {
                                                "id": "filter-processor",
                                                "include": "service:my-service",
                                                "inputs": ["datadog-agent-source"],
                                                "type": "filter",
                                            }
                                        ],
                                        "items": {
                                            "description": "A processor for the pipeline.",
                                            "oneOf": [
                                                {
                                                    "description": "The "
                                                    "`filter` "
                                                    "processor "
                                                    "allows "
                                                    "conditional "
                                                    "processing "
                                                    "of "
                                                    "logs "
                                                    "based "
                                                    "on "
                                                    "a "
                                                    "Datadog "
                                                    "search "
                                                    "query. "
                                                    "Logs "
                                                    "that "
                                                    "match "
                                                    "the "
                                                    "`include` "
                                                    "query "
                                                    "are "
                                                    "passed "
                                                    "through; "
                                                    "others "
                                                    "are "
                                                    "discarded.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(for "
                                                            "example, "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "filter-processor",
                                                            "type": "string",
                                                        },
                                                        "include": {
                                                            "description": "A "
                                                            "Datadog "
                                                            "search "
                                                            "query "
                                                            "used "
                                                            "to "
                                                            "determine "
                                                            "which "
                                                            "logs "
                                                            "should "
                                                            "pass "
                                                            "through "
                                                            "the "
                                                            "filter. "
                                                            "Logs "
                                                            "that "
                                                            "match "
                                                            "this "
                                                            "query "
                                                            "continue "
                                                            "to "
                                                            "downstream "
                                                            "components; "
                                                            "others "
                                                            "are "
                                                            "dropped.",
                                                            "example": "service:my-service",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["datadog-agent-source"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "filter",
                                                            "description": "The "
                                                            "processor "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`filter`.",
                                                            "enum": ["filter"],
                                                            "example": "filter",
                                                            "type": "string",
                                                            "x-enum-varnames": ["FILTER"],
                                                        },
                                                    },
                                                    "required": ["id", "type", "include", "inputs"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`parse_json` "
                                                    "processor "
                                                    "extracts "
                                                    "JSON "
                                                    "from "
                                                    "a "
                                                    "specified "
                                                    "field "
                                                    "and "
                                                    "flattens "
                                                    "it "
                                                    "into "
                                                    "the "
                                                    "event. "
                                                    "This "
                                                    "is "
                                                    "useful "
                                                    "when "
                                                    "logs "
                                                    "contain "
                                                    "embedded "
                                                    "JSON "
                                                    "as "
                                                    "a "
                                                    "string.",
                                                    "properties": {
                                                        "field": {
                                                            "description": "The "
                                                            "name "
                                                            "of "
                                                            "the "
                                                            "log "
                                                            "field "
                                                            "that "
                                                            "contains "
                                                            "a "
                                                            "JSON "
                                                            "string.",
                                                            "example": "message",
                                                            "type": "string",
                                                        },
                                                        "id": {
                                                            "description": "A "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(e.g., "
                                                            "as "
                                                            "input "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "parse-json-processor",
                                                            "type": "string",
                                                        },
                                                        "include": {
                                                            "description": "A "
                                                            "Datadog "
                                                            "search "
                                                            "query "
                                                            "used "
                                                            "to "
                                                            "determine "
                                                            "which "
                                                            "logs "
                                                            "this "
                                                            "processor "
                                                            "targets.",
                                                            "example": "service:my-service",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["datadog-agent-source"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "parse_json",
                                                            "description": "The "
                                                            "processor "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`parse_json`.",
                                                            "enum": ["parse_json"],
                                                            "example": "parse_json",
                                                            "type": "string",
                                                            "x-enum-varnames": ["PARSE_JSON"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "include",
                                                        "field",
                                                        "inputs",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "Quota "
                                                    "Processor "
                                                    "measures "
                                                    "logging "
                                                    "traffic "
                                                    "for "
                                                    "logs "
                                                    "that "
                                                    "match "
                                                    "a "
                                                    "specified "
                                                    "filter. "
                                                    "When "
                                                    "the "
                                                    "configured "
                                                    "daily "
                                                    "quota "
                                                    "is "
                                                    "met, "
                                                    "the "
                                                    "processor "
                                                    "can "
                                                    "drop "
                                                    "or "
                                                    "alert.",
                                                    "properties": {
                                                        "drop_events": {
                                                            "description": "If "
                                                            "set "
                                                            "to "
                                                            "`true`, "
                                                            "logs "
                                                            "that "
                                                            "matched "
                                                            "the "
                                                            "quota "
                                                            "filter "
                                                            "and "
                                                            "sent "
                                                            "after "
                                                            "the "
                                                            "quota "
                                                            "has "
                                                            "been "
                                                            "met "
                                                            "are "
                                                            "dropped; "
                                                            "only "
                                                            "logs "
                                                            "that "
                                                            "did "
                                                            "not "
                                                            "match "
                                                            "the "
                                                            "filter "
                                                            "query "
                                                            "continue "
                                                            "through "
                                                            "the "
                                                            "pipeline.",
                                                            "example": False,
                                                            "type": "boolean",
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(for "
                                                            "example, "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "quota-processor",
                                                            "type": "string",
                                                        },
                                                        "ignore_when_missing_partitions": {
                                                            "description": "If "
                                                            "`true`, "
                                                            "the "
                                                            "processor "
                                                            "skips "
                                                            "quota "
                                                            "checks "
                                                            "when "
                                                            "partition "
                                                            "fields "
                                                            "are "
                                                            "missing "
                                                            "from "
                                                            "the "
                                                            "logs.",
                                                            "type": "boolean",
                                                        },
                                                        "include": {
                                                            "description": "A "
                                                            "Datadog "
                                                            "search "
                                                            "query "
                                                            "used "
                                                            "to "
                                                            "determine "
                                                            "which "
                                                            "logs "
                                                            "this "
                                                            "processor "
                                                            "targets.",
                                                            "example": "service:my-service",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["datadog-agent-source"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "limit": {
                                                            "description": "The "
                                                            "maximum "
                                                            "amount "
                                                            "of "
                                                            "data "
                                                            "or "
                                                            "number "
                                                            "of "
                                                            "events "
                                                            "allowed "
                                                            "before "
                                                            "the "
                                                            "quota "
                                                            "is "
                                                            "enforced. "
                                                            "Can "
                                                            "be "
                                                            "specified "
                                                            "in "
                                                            "bytes "
                                                            "or "
                                                            "events.",
                                                            "properties": {
                                                                "enforce": {
                                                                    "description": "Unit "
                                                                    "for "
                                                                    "quota "
                                                                    "enforcement "
                                                                    "in "
                                                                    "bytes "
                                                                    "for "
                                                                    "data "
                                                                    "size "
                                                                    "or "
                                                                    "events "
                                                                    "for "
                                                                    "count.",
                                                                    "enum": ["bytes", "events"],
                                                                    "example": "bytes",
                                                                    "type": "string",
                                                                    "x-enum-varnames": [
                                                                        "BYTES",
                                                                        "EVENTS",
                                                                    ],
                                                                },
                                                                "limit": {
                                                                    "description": "The "
                                                                    "limit "
                                                                    "for "
                                                                    "quota "
                                                                    "enforcement.",
                                                                    "example": 1000,
                                                                    "format": "int64",
                                                                    "type": "integer",
                                                                },
                                                            },
                                                            "required": ["enforce", "limit"],
                                                            "type": "object",
                                                        },
                                                        "name": {
                                                            "description": "Name of the quota.",
                                                            "example": "MyQuota",
                                                            "type": "string",
                                                        },
                                                        "overflow_action": {
                                                            "description": "The "
                                                            "action "
                                                            "to "
                                                            "take "
                                                            "when "
                                                            "the "
                                                            "quota "
                                                            "is "
                                                            "exceeded. "
                                                            "Options:\n"
                                                            "- "
                                                            "`drop`: "
                                                            "Drop "
                                                            "the "
                                                            "event.\n"
                                                            "- "
                                                            "`no_action`: "
                                                            "Let "
                                                            "the "
                                                            "event "
                                                            "pass "
                                                            "through.\n"
                                                            "- "
                                                            "`overflow_routing`: "
                                                            "Route "
                                                            "to "
                                                            "an "
                                                            "overflow "
                                                            "destination.",
                                                            "enum": [
                                                                "drop",
                                                                "no_action",
                                                                "overflow_routing",
                                                            ],
                                                            "example": "drop",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "DROP",
                                                                "NO_ACTION",
                                                                "OVERFLOW_ROUTING",
                                                            ],
                                                        },
                                                        "overrides": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "alternate "
                                                            "quota "
                                                            "rules "
                                                            "that "
                                                            "apply "
                                                            "to "
                                                            "specific "
                                                            "sets "
                                                            "of "
                                                            "events, "
                                                            "identified "
                                                            "by "
                                                            "matching "
                                                            "field "
                                                            "values. "
                                                            "Each "
                                                            "override "
                                                            "can "
                                                            "define "
                                                            "a "
                                                            "custom "
                                                            "limit.",
                                                            "items": {
                                                                "description": "Defines "
                                                                "a "
                                                                "custom "
                                                                "quota "
                                                                "limit "
                                                                "that "
                                                                "applies "
                                                                "to "
                                                                "specific "
                                                                "log "
                                                                "events "
                                                                "based "
                                                                "on "
                                                                "matching "
                                                                "field "
                                                                "values.",
                                                                "properties": {
                                                                    "fields": {
                                                                        "description": "A "
                                                                        "list "
                                                                        "of "
                                                                        "field "
                                                                        "matchers "
                                                                        "used "
                                                                        "to "
                                                                        "apply "
                                                                        "a "
                                                                        "specific "
                                                                        "override. "
                                                                        "If "
                                                                        "an "
                                                                        "event "
                                                                        "matches "
                                                                        "all "
                                                                        "listed "
                                                                        "key-value "
                                                                        "pairs, "
                                                                        "the "
                                                                        "corresponding "
                                                                        "override "
                                                                        "limit "
                                                                        "is "
                                                                        "enforced.",
                                                                        "items": {
                                                                            "description": "Represents "
                                                                            "a "
                                                                            "static "
                                                                            "key-value "
                                                                            "pair "
                                                                            "used "
                                                                            "in "
                                                                            "various "
                                                                            "processors.",
                                                                            "properties": {
                                                                                "name": {
                                                                                    "description": "The "
                                                                                    "field "
                                                                                    "name.",
                                                                                    "example": "field_name",
                                                                                    "type": "string",
                                                                                },
                                                                                "value": {
                                                                                    "description": "The "
                                                                                    "field "
                                                                                    "value.",
                                                                                    "example": "field_value",
                                                                                    "type": "string",
                                                                                },
                                                                            },
                                                                            "required": [
                                                                                "name",
                                                                                "value",
                                                                            ],
                                                                            "type": "object",
                                                                        },
                                                                        "type": "array",
                                                                    },
                                                                    "limit": {
                                                                        "description": "The "
                                                                        "maximum "
                                                                        "amount "
                                                                        "of "
                                                                        "data "
                                                                        "or "
                                                                        "number "
                                                                        "of "
                                                                        "events "
                                                                        "allowed "
                                                                        "before "
                                                                        "the "
                                                                        "quota "
                                                                        "is "
                                                                        "enforced. "
                                                                        "Can "
                                                                        "be "
                                                                        "specified "
                                                                        "in "
                                                                        "bytes "
                                                                        "or "
                                                                        "events.",
                                                                        "properties": {
                                                                            "enforce": {
                                                                                "description": "Unit "
                                                                                "for "
                                                                                "quota "
                                                                                "enforcement "
                                                                                "in "
                                                                                "bytes "
                                                                                "for "
                                                                                "data "
                                                                                "size "
                                                                                "or "
                                                                                "events "
                                                                                "for "
                                                                                "count.",
                                                                                "enum": [
                                                                                    "bytes",
                                                                                    "events",
                                                                                ],
                                                                                "example": "bytes",
                                                                                "type": "string",
                                                                                "x-enum-varnames": [
                                                                                    "BYTES",
                                                                                    "EVENTS",
                                                                                ],
                                                                            },
                                                                            "limit": {
                                                                                "description": "The "
                                                                                "limit "
                                                                                "for "
                                                                                "quota "
                                                                                "enforcement.",
                                                                                "example": 1000,
                                                                                "format": "int64",
                                                                                "type": "integer",
                                                                            },
                                                                        },
                                                                        "required": [
                                                                            "enforce",
                                                                            "limit",
                                                                        ],
                                                                        "type": "object",
                                                                    },
                                                                },
                                                                "required": ["fields", "limit"],
                                                                "type": "object",
                                                            },
                                                            "type": "array",
                                                        },
                                                        "partition_fields": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "fields "
                                                            "used "
                                                            "to "
                                                            "segment "
                                                            "log "
                                                            "traffic "
                                                            "for "
                                                            "quota "
                                                            "enforcement. "
                                                            "Quotas "
                                                            "are "
                                                            "tracked "
                                                            "independently "
                                                            "by "
                                                            "unique "
                                                            "combinations "
                                                            "of "
                                                            "these "
                                                            "field "
                                                            "values.",
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "quota",
                                                            "description": "The "
                                                            "processor "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`quota`.",
                                                            "enum": ["quota"],
                                                            "example": "quota",
                                                            "type": "string",
                                                            "x-enum-varnames": ["QUOTA"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "include",
                                                        "name",
                                                        "drop_events",
                                                        "limit",
                                                        "inputs",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`add_fields` "
                                                    "processor "
                                                    "adds "
                                                    "static "
                                                    "key-value "
                                                    "fields "
                                                    "to "
                                                    "logs.",
                                                    "properties": {
                                                        "fields": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "static "
                                                            "fields "
                                                            "(key-value "
                                                            "pairs) "
                                                            "that "
                                                            "is "
                                                            "added "
                                                            "to "
                                                            "each "
                                                            "log "
                                                            "event "
                                                            "processed "
                                                            "by "
                                                            "this "
                                                            "component.",
                                                            "items": {
                                                                "description": "Represents "
                                                                "a "
                                                                "static "
                                                                "key-value "
                                                                "pair "
                                                                "used "
                                                                "in "
                                                                "various "
                                                                "processors.",
                                                                "properties": {
                                                                    "name": {
                                                                        "description": "The "
                                                                        "field "
                                                                        "name.",
                                                                        "example": "field_name",
                                                                        "type": "string",
                                                                    },
                                                                    "value": {
                                                                        "description": "The "
                                                                        "field "
                                                                        "value.",
                                                                        "example": "field_value",
                                                                        "type": "string",
                                                                    },
                                                                },
                                                                "required": ["name", "value"],
                                                                "type": "object",
                                                            },
                                                            "type": "array",
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(for "
                                                            "example, "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "add-fields-processor",
                                                            "type": "string",
                                                        },
                                                        "include": {
                                                            "description": "A "
                                                            "Datadog "
                                                            "search "
                                                            "query "
                                                            "used "
                                                            "to "
                                                            "determine "
                                                            "which "
                                                            "logs "
                                                            "this "
                                                            "processor "
                                                            "targets.",
                                                            "example": "service:my-service",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["datadog-agent-source"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "add_fields",
                                                            "description": "The "
                                                            "processor "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`add_fields`.",
                                                            "enum": ["add_fields"],
                                                            "example": "add_fields",
                                                            "type": "string",
                                                            "x-enum-varnames": ["ADD_FIELDS"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "include",
                                                        "fields",
                                                        "inputs",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`remove_fields` "
                                                    "processor "
                                                    "deletes "
                                                    "specified "
                                                    "fields "
                                                    "from "
                                                    "logs.",
                                                    "properties": {
                                                        "fields": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "field "
                                                            "names "
                                                            "to "
                                                            "be "
                                                            "removed "
                                                            "from "
                                                            "each "
                                                            "log "
                                                            "event.",
                                                            "example": ["field1", "field2"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(e.g., "
                                                            "as "
                                                            "input "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "remove-fields-processor",
                                                            "type": "string",
                                                        },
                                                        "include": {
                                                            "description": "A "
                                                            "Datadog "
                                                            "search "
                                                            "query "
                                                            "used "
                                                            "to "
                                                            "determine "
                                                            "which "
                                                            "logs "
                                                            "this "
                                                            "processor "
                                                            "targets.",
                                                            "example": "service:my-service",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "The "
                                                            "`PipelineRemoveFieldsProcessor` "
                                                            "`inputs`.",
                                                            "example": ["datadog-agent-source"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "remove_fields",
                                                            "description": "The "
                                                            "processor "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`remove_fields`.",
                                                            "enum": ["remove_fields"],
                                                            "example": "remove_fields",
                                                            "type": "string",
                                                            "x-enum-varnames": ["REMOVE_FIELDS"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "include",
                                                        "fields",
                                                        "inputs",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`rename_fields` "
                                                    "processor "
                                                    "changes "
                                                    "field "
                                                    "names.",
                                                    "properties": {
                                                        "fields": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "rename "
                                                            "rules "
                                                            "specifying "
                                                            "which "
                                                            "fields "
                                                            "to "
                                                            "rename "
                                                            "in "
                                                            "the "
                                                            "event, "
                                                            "what "
                                                            "to "
                                                            "rename "
                                                            "them "
                                                            "to, "
                                                            "and "
                                                            "whether "
                                                            "to "
                                                            "preserve "
                                                            "the "
                                                            "original "
                                                            "fields.",
                                                            "items": {
                                                                "description": "Defines "
                                                                "how "
                                                                "to "
                                                                "rename "
                                                                "a "
                                                                "field "
                                                                "in "
                                                                "log "
                                                                "events.",
                                                                "properties": {
                                                                    "destination": {
                                                                        "description": "The "
                                                                        "field "
                                                                        "name "
                                                                        "to "
                                                                        "assign "
                                                                        "the "
                                                                        "renamed "
                                                                        "value "
                                                                        "to.",
                                                                        "example": "destination_field",
                                                                        "type": "string",
                                                                    },
                                                                    "preserve_source": {
                                                                        "description": "Indicates "
                                                                        "whether "
                                                                        "the "
                                                                        "original "
                                                                        "field, "
                                                                        "that "
                                                                        "is "
                                                                        "received "
                                                                        "from "
                                                                        "the "
                                                                        "source, "
                                                                        "should "
                                                                        "be "
                                                                        "kept "
                                                                        "(`true`) "
                                                                        "or "
                                                                        "removed "
                                                                        "(`false`) "
                                                                        "after "
                                                                        "renaming.",
                                                                        "example": False,
                                                                        "type": "boolean",
                                                                    },
                                                                    "source": {
                                                                        "description": "The "
                                                                        "original "
                                                                        "field "
                                                                        "name "
                                                                        "in "
                                                                        "the "
                                                                        "log "
                                                                        "event "
                                                                        "that "
                                                                        "should "
                                                                        "be "
                                                                        "renamed.",
                                                                        "example": "source_field",
                                                                        "type": "string",
                                                                    },
                                                                },
                                                                "required": [
                                                                    "source",
                                                                    "destination",
                                                                    "preserve_source",
                                                                ],
                                                                "type": "object",
                                                            },
                                                            "type": "array",
                                                        },
                                                        "id": {
                                                            "description": "A "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(e.g., "
                                                            "as "
                                                            "input "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "rename-fields-processor",
                                                            "type": "string",
                                                        },
                                                        "include": {
                                                            "description": "A "
                                                            "Datadog "
                                                            "search "
                                                            "query "
                                                            "used "
                                                            "to "
                                                            "determine "
                                                            "which "
                                                            "logs "
                                                            "this "
                                                            "processor "
                                                            "targets.",
                                                            "example": "service:my-service",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["datadog-agent-source"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "rename_fields",
                                                            "description": "The "
                                                            "processor "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`rename_fields`.",
                                                            "enum": ["rename_fields"],
                                                            "example": "rename_fields",
                                                            "type": "string",
                                                            "x-enum-varnames": ["RENAME_FIELDS"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "include",
                                                        "fields",
                                                        "inputs",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`generate_datadog_metrics` "
                                                    "processor "
                                                    "creates "
                                                    "custom "
                                                    "metrics "
                                                    "from "
                                                    "logs "
                                                    "and "
                                                    "sends "
                                                    "them "
                                                    "to "
                                                    "Datadog.\n"
                                                    "Metrics "
                                                    "can "
                                                    "be "
                                                    "counters, "
                                                    "gauges, "
                                                    "or "
                                                    "distributions "
                                                    "and "
                                                    "optionally "
                                                    "grouped "
                                                    "by "
                                                    "log "
                                                    "fields.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline.",
                                                            "example": "generate-metrics-processor",
                                                            "type": "string",
                                                        },
                                                        "include": {
                                                            "description": "A "
                                                            "Datadog "
                                                            "search "
                                                            "query "
                                                            "used "
                                                            "to "
                                                            "determine "
                                                            "which "
                                                            "logs "
                                                            "this "
                                                            "processor "
                                                            "targets.",
                                                            "example": "service:my-service",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "processor.",
                                                            "example": ["source-id"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "metrics": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "generating "
                                                            "individual "
                                                            "metrics.",
                                                            "items": {
                                                                "description": "Defines "
                                                                "a "
                                                                "log-based "
                                                                "custom "
                                                                "metric, "
                                                                "including "
                                                                "its "
                                                                "name, "
                                                                "type, "
                                                                "filter, "
                                                                "value "
                                                                "computation "
                                                                "strategy,\n"
                                                                "and "
                                                                "optional "
                                                                "grouping "
                                                                "fields.",
                                                                "properties": {
                                                                    "group_by": {
                                                                        "description": "Optional "
                                                                        "fields "
                                                                        "used "
                                                                        "to "
                                                                        "group "
                                                                        "the "
                                                                        "metric "
                                                                        "series.",
                                                                        "example": [
                                                                            "service",
                                                                            "env",
                                                                        ],
                                                                        "items": {"type": "string"},
                                                                        "type": "array",
                                                                    },
                                                                    "include": {
                                                                        "description": "Datadog "
                                                                        "filter "
                                                                        "query "
                                                                        "to "
                                                                        "match "
                                                                        "logs "
                                                                        "for "
                                                                        "metric "
                                                                        "generation.",
                                                                        "example": "service:billing",
                                                                        "type": "string",
                                                                    },
                                                                    "metric_type": {
                                                                        "description": "Type "
                                                                        "of "
                                                                        "metric "
                                                                        "to "
                                                                        "create.",
                                                                        "enum": [
                                                                            "count",
                                                                            "gauge",
                                                                            "distribution",
                                                                        ],
                                                                        "example": "count",
                                                                        "type": "string",
                                                                        "x-enum-varnames": [
                                                                            "COUNT",
                                                                            "GAUGE",
                                                                            "DISTRIBUTION",
                                                                        ],
                                                                    },
                                                                    "name": {
                                                                        "description": "Name "
                                                                        "of "
                                                                        "the "
                                                                        "custom "
                                                                        "metric "
                                                                        "to "
                                                                        "be "
                                                                        "created.",
                                                                        "example": "logs.processed",
                                                                        "type": "string",
                                                                    },
                                                                    "value": {
                                                                        "description": "Specifies "
                                                                        "how "
                                                                        "the "
                                                                        "value "
                                                                        "of "
                                                                        "the "
                                                                        "generated "
                                                                        "metric "
                                                                        "is "
                                                                        "computed.",
                                                                        "oneOf": [
                                                                            {
                                                                                "description": "Strategy "
                                                                                "that "
                                                                                "increments "
                                                                                "a "
                                                                                "generated "
                                                                                "metric "
                                                                                "by "
                                                                                "one "
                                                                                "for "
                                                                                "each "
                                                                                "matching "
                                                                                "event.",
                                                                                "properties": {
                                                                                    "strategy": {
                                                                                        "description": "Increments "
                                                                                        "the "
                                                                                        "metric "
                                                                                        "by "
                                                                                        "1 "
                                                                                        "for "
                                                                                        "each "
                                                                                        "matching "
                                                                                        "event.",
                                                                                        "enum": [
                                                                                            "increment_by_one"
                                                                                        ],
                                                                                        "example": "increment_by_one",
                                                                                        "type": "string",
                                                                                        "x-enum-varnames": [
                                                                                            "INCREMENT_BY_ONE"
                                                                                        ],
                                                                                    }
                                                                                },
                                                                                "required": [
                                                                                    "strategy"
                                                                                ],
                                                                                "type": "object",
                                                                            },
                                                                            {
                                                                                "description": "Strategy "
                                                                                "that "
                                                                                "increments "
                                                                                "a "
                                                                                "generated "
                                                                                "metric "
                                                                                "based "
                                                                                "on "
                                                                                "the "
                                                                                "value "
                                                                                "of "
                                                                                "a "
                                                                                "log "
                                                                                "field.",
                                                                                "properties": {
                                                                                    "field": {
                                                                                        "description": "Name "
                                                                                        "of "
                                                                                        "the "
                                                                                        "log "
                                                                                        "field "
                                                                                        "containing "
                                                                                        "the "
                                                                                        "numeric "
                                                                                        "value "
                                                                                        "to "
                                                                                        "increment "
                                                                                        "the "
                                                                                        "metric "
                                                                                        "by.",
                                                                                        "example": "errors",
                                                                                        "type": "string",
                                                                                    },
                                                                                    "strategy": {
                                                                                        "description": "Uses "
                                                                                        "a "
                                                                                        "numeric "
                                                                                        "field "
                                                                                        "in "
                                                                                        "the "
                                                                                        "log "
                                                                                        "event "
                                                                                        "as "
                                                                                        "the "
                                                                                        "metric "
                                                                                        "increment.",
                                                                                        "enum": [
                                                                                            "increment_by_field"
                                                                                        ],
                                                                                        "example": "increment_by_field",
                                                                                        "type": "string",
                                                                                        "x-enum-varnames": [
                                                                                            "INCREMENT_BY_FIELD"
                                                                                        ],
                                                                                    },
                                                                                },
                                                                                "required": [
                                                                                    "strategy",
                                                                                    "field",
                                                                                ],
                                                                                "type": "object",
                                                                            },
                                                                        ],
                                                                    },
                                                                },
                                                                "required": [
                                                                    "name",
                                                                    "include",
                                                                    "metric_type",
                                                                    "value",
                                                                ],
                                                                "type": "object",
                                                            },
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "generate_datadog_metrics",
                                                            "description": "The "
                                                            "processor "
                                                            "type. "
                                                            "Always "
                                                            "`generate_datadog_metrics`.",
                                                            "enum": ["generate_datadog_metrics"],
                                                            "example": "generate_datadog_metrics",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "GENERATE_DATADOG_METRICS"
                                                            ],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "inputs",
                                                        "include",
                                                        "metrics",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`sample` "
                                                    "processor "
                                                    "allows "
                                                    "probabilistic "
                                                    "sampling "
                                                    "of "
                                                    "logs "
                                                    "at "
                                                    "a "
                                                    "fixed "
                                                    "rate.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(for "
                                                            "example, "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "sample-processor",
                                                            "type": "string",
                                                        },
                                                        "include": {
                                                            "description": "A "
                                                            "Datadog "
                                                            "search "
                                                            "query "
                                                            "used "
                                                            "to "
                                                            "determine "
                                                            "which "
                                                            "logs "
                                                            "this "
                                                            "processor "
                                                            "targets.",
                                                            "example": "service:my-service",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["datadog-agent-source"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "percentage": {
                                                            "description": "The "
                                                            "percentage "
                                                            "of "
                                                            "logs "
                                                            "to "
                                                            "sample.",
                                                            "example": 10.0,
                                                            "format": "double",
                                                            "type": "number",
                                                        },
                                                        "rate": {
                                                            "description": "Number "
                                                            "of "
                                                            "events "
                                                            "to "
                                                            "sample "
                                                            "(1 "
                                                            "in "
                                                            "N).",
                                                            "example": 10,
                                                            "format": "int64",
                                                            "minimum": 1,
                                                            "type": "integer",
                                                        },
                                                        "type": {
                                                            "default": "sample",
                                                            "description": "The "
                                                            "processor "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`sample`.",
                                                            "enum": ["sample"],
                                                            "example": "sample",
                                                            "type": "string",
                                                            "x-enum-varnames": ["SAMPLE"],
                                                        },
                                                    },
                                                    "required": ["id", "type", "include", "inputs"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`parse_grok` "
                                                    "processor "
                                                    "extracts "
                                                    "structured "
                                                    "fields "
                                                    "from "
                                                    "unstructured "
                                                    "log "
                                                    "messages "
                                                    "using "
                                                    "Grok "
                                                    "patterns.",
                                                    "properties": {
                                                        "disable_library_rules": {
                                                            "default": False,
                                                            "description": "If "
                                                            "set "
                                                            "to "
                                                            "`true`, "
                                                            "disables "
                                                            "the "
                                                            "default "
                                                            "Grok "
                                                            "rules "
                                                            "provided "
                                                            "by "
                                                            "Datadog.",
                                                            "example": True,
                                                            "type": "boolean",
                                                        },
                                                        "id": {
                                                            "description": "A "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "processor.",
                                                            "example": "parse-grok-processor",
                                                            "type": "string",
                                                        },
                                                        "include": {
                                                            "description": "A "
                                                            "Datadog "
                                                            "search "
                                                            "query "
                                                            "used "
                                                            "to "
                                                            "determine "
                                                            "which "
                                                            "logs "
                                                            "this "
                                                            "processor "
                                                            "targets.",
                                                            "example": "service:my-service",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["datadog-agent-source"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "rules": {
                                                            "description": "The "
                                                            "list "
                                                            "of "
                                                            "Grok "
                                                            "parsing "
                                                            "rules. "
                                                            "If "
                                                            "multiple "
                                                            "matching "
                                                            "rules "
                                                            "are "
                                                            "provided, "
                                                            "they "
                                                            "are "
                                                            "evaluated "
                                                            "in "
                                                            "order. "
                                                            "The "
                                                            "first "
                                                            "successful "
                                                            "match "
                                                            "is "
                                                            "applied.",
                                                            "items": {
                                                                "description": "A "
                                                                "Grok "
                                                                "parsing "
                                                                "rule "
                                                                "used "
                                                                "in "
                                                                "the "
                                                                "`parse_grok` "
                                                                "processor. "
                                                                "Each "
                                                                "rule "
                                                                "defines "
                                                                "how "
                                                                "to "
                                                                "extract "
                                                                "structured "
                                                                "fields\n"
                                                                "from "
                                                                "a "
                                                                "specific "
                                                                "log "
                                                                "field "
                                                                "using "
                                                                "Grok "
                                                                "patterns.",
                                                                "properties": {
                                                                    "match_rules": {
                                                                        "description": "A "
                                                                        "list "
                                                                        "of "
                                                                        "Grok "
                                                                        "parsing "
                                                                        "rules "
                                                                        "that "
                                                                        "define "
                                                                        "how "
                                                                        "to "
                                                                        "extract "
                                                                        "fields "
                                                                        "from "
                                                                        "the "
                                                                        "source "
                                                                        "field.\n"
                                                                        "Each "
                                                                        "rule "
                                                                        "must "
                                                                        "contain "
                                                                        "a "
                                                                        "name "
                                                                        "and "
                                                                        "a "
                                                                        "valid "
                                                                        "Grok "
                                                                        "pattern.",
                                                                        "example": [
                                                                            {
                                                                                "name": "MyParsingRule",
                                                                                "rule": "%{word:user} "
                                                                                "connected "
                                                                                "on "
                                                                                '%{date("MM/dd/yyyy"):date}',
                                                                            }
                                                                        ],
                                                                        "items": {
                                                                            "description": "Defines "
                                                                            "a "
                                                                            "Grok "
                                                                            "parsing "
                                                                            "rule, "
                                                                            "which "
                                                                            "extracts "
                                                                            "structured "
                                                                            "fields "
                                                                            "from "
                                                                            "log "
                                                                            "content "
                                                                            "using "
                                                                            "named "
                                                                            "Grok "
                                                                            "patterns.\n"
                                                                            "Each "
                                                                            "rule "
                                                                            "must "
                                                                            "have "
                                                                            "a "
                                                                            "unique "
                                                                            "name "
                                                                            "and "
                                                                            "a "
                                                                            "valid "
                                                                            "Datadog "
                                                                            "Grok "
                                                                            "pattern "
                                                                            "that "
                                                                            "will "
                                                                            "be "
                                                                            "applied "
                                                                            "to "
                                                                            "the "
                                                                            "source "
                                                                            "field.",
                                                                            "properties": {
                                                                                "name": {
                                                                                    "description": "The "
                                                                                    "name "
                                                                                    "of "
                                                                                    "the "
                                                                                    "rule.",
                                                                                    "example": "MyParsingRule",
                                                                                    "type": "string",
                                                                                },
                                                                                "rule": {
                                                                                    "description": "The "
                                                                                    "definition "
                                                                                    "of "
                                                                                    "the "
                                                                                    "Grok "
                                                                                    "rule.",
                                                                                    "example": "%{word:user} "
                                                                                    "connected "
                                                                                    "on "
                                                                                    '%{date("MM/dd/yyyy"):date}',
                                                                                    "type": "string",
                                                                                },
                                                                            },
                                                                            "required": [
                                                                                "name",
                                                                                "rule",
                                                                            ],
                                                                            "type": "object",
                                                                        },
                                                                        "type": "array",
                                                                    },
                                                                    "source": {
                                                                        "description": "The "
                                                                        "name "
                                                                        "of "
                                                                        "the "
                                                                        "field "
                                                                        "in "
                                                                        "the "
                                                                        "log "
                                                                        "event "
                                                                        "to "
                                                                        "apply "
                                                                        "the "
                                                                        "Grok "
                                                                        "rules "
                                                                        "to.",
                                                                        "example": "message",
                                                                        "type": "string",
                                                                    },
                                                                    "support_rules": {
                                                                        "description": "A "
                                                                        "list "
                                                                        "of "
                                                                        "Grok "
                                                                        "helper "
                                                                        "rules "
                                                                        "that "
                                                                        "can "
                                                                        "be "
                                                                        "referenced "
                                                                        "by "
                                                                        "the "
                                                                        "parsing "
                                                                        "rules.",
                                                                        "example": [
                                                                            {
                                                                                "name": "user",
                                                                                "rule": "%{word:user.name}",
                                                                            }
                                                                        ],
                                                                        "items": {
                                                                            "description": "The "
                                                                            "Grok "
                                                                            "helper "
                                                                            "rule "
                                                                            "referenced "
                                                                            "in "
                                                                            "the "
                                                                            "parsing "
                                                                            "rules.",
                                                                            "properties": {
                                                                                "name": {
                                                                                    "description": "The "
                                                                                    "name "
                                                                                    "of "
                                                                                    "the "
                                                                                    "Grok "
                                                                                    "helper "
                                                                                    "rule.",
                                                                                    "example": "user",
                                                                                    "type": "string",
                                                                                },
                                                                                "rule": {
                                                                                    "description": "The "
                                                                                    "definition "
                                                                                    "of "
                                                                                    "the "
                                                                                    "Grok "
                                                                                    "helper "
                                                                                    "rule.",
                                                                                    "example": " "
                                                                                    "%{word:user.name}",
                                                                                    "type": "string",
                                                                                },
                                                                            },
                                                                            "required": [
                                                                                "name",
                                                                                "rule",
                                                                            ],
                                                                            "type": "object",
                                                                        },
                                                                        "type": "array",
                                                                    },
                                                                },
                                                                "required": [
                                                                    "source",
                                                                    "match_rules",
                                                                ],
                                                                "type": "object",
                                                            },
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "parse_grok",
                                                            "description": "The "
                                                            "processor "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`parse_grok`.",
                                                            "enum": ["parse_grok"],
                                                            "example": "parse_grok",
                                                            "type": "string",
                                                            "x-enum-varnames": ["PARSE_GROK"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "include",
                                                        "inputs",
                                                        "rules",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`sensitive_data_scanner` "
                                                    "processor "
                                                    "detects "
                                                    "and "
                                                    "optionally "
                                                    "redacts "
                                                    "sensitive "
                                                    "data "
                                                    "in "
                                                    "log "
                                                    "events.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(e.g., "
                                                            "as "
                                                            "input "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "sensitive-scanner",
                                                            "type": "string",
                                                        },
                                                        "include": {
                                                            "description": "A "
                                                            "Datadog "
                                                            "search "
                                                            "query "
                                                            "used "
                                                            "to "
                                                            "determine "
                                                            "which "
                                                            "logs "
                                                            "this "
                                                            "processor "
                                                            "targets.",
                                                            "example": "source:prod",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["parse-json-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "rules": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "rules "
                                                            "for "
                                                            "identifying "
                                                            "and "
                                                            "acting "
                                                            "on "
                                                            "sensitive "
                                                            "data "
                                                            "patterns.",
                                                            "items": {
                                                                "description": "Defines "
                                                                "a "
                                                                "rule "
                                                                "for "
                                                                "detecting "
                                                                "sensitive "
                                                                "data, "
                                                                "including "
                                                                "matching "
                                                                "pattern, "
                                                                "scope, "
                                                                "and "
                                                                "the "
                                                                "action "
                                                                "to "
                                                                "take.",
                                                                "properties": {
                                                                    "keyword_options": {
                                                                        "description": "Configuration "
                                                                        "for "
                                                                        "keywords "
                                                                        "used "
                                                                        "to "
                                                                        "reinforce "
                                                                        "sensitive "
                                                                        "data "
                                                                        "pattern "
                                                                        "detection.",
                                                                        "properties": {
                                                                            "keywords": {
                                                                                "description": "A "
                                                                                "list "
                                                                                "of "
                                                                                "keywords "
                                                                                "to "
                                                                                "match "
                                                                                "near "
                                                                                "the "
                                                                                "sensitive "
                                                                                "pattern.",
                                                                                "example": [
                                                                                    "ssn",
                                                                                    "card",
                                                                                    "account",
                                                                                ],
                                                                                "items": {
                                                                                    "type": "string"
                                                                                },
                                                                                "type": "array",
                                                                            },
                                                                            "proximity": {
                                                                                "description": "Maximum "
                                                                                "number "
                                                                                "of "
                                                                                "tokens "
                                                                                "between "
                                                                                "a "
                                                                                "keyword "
                                                                                "and "
                                                                                "a "
                                                                                "sensitive "
                                                                                "value "
                                                                                "match.",
                                                                                "example": 5,
                                                                                "format": "int64",
                                                                                "type": "integer",
                                                                            },
                                                                        },
                                                                        "required": [
                                                                            "keywords",
                                                                            "proximity",
                                                                        ],
                                                                        "type": "object",
                                                                    },
                                                                    "name": {
                                                                        "description": "A "
                                                                        "name "
                                                                        "identifying "
                                                                        "the "
                                                                        "rule.",
                                                                        "example": "Redact "
                                                                        "Credit "
                                                                        "Card "
                                                                        "Numbers",
                                                                        "type": "string",
                                                                    },
                                                                    "on_match": {
                                                                        "description": "Defines "
                                                                        "what "
                                                                        "action "
                                                                        "to "
                                                                        "take "
                                                                        "when "
                                                                        "sensitive "
                                                                        "data "
                                                                        "is "
                                                                        "matched.",
                                                                        "oneOf": [
                                                                            {
                                                                                "description": "Configuration "
                                                                                "for "
                                                                                "completely "
                                                                                "redacting "
                                                                                "matched "
                                                                                "sensitive "
                                                                                "data.",
                                                                                "properties": {
                                                                                    "action": {
                                                                                        "description": "Action "
                                                                                        "type "
                                                                                        "that "
                                                                                        "completely "
                                                                                        "replaces "
                                                                                        "the "
                                                                                        "matched "
                                                                                        "sensitive "
                                                                                        "data "
                                                                                        "with "
                                                                                        "a "
                                                                                        "fixed "
                                                                                        "replacement "
                                                                                        "string "
                                                                                        "to "
                                                                                        "remove "
                                                                                        "all "
                                                                                        "visibility.",
                                                                                        "enum": [
                                                                                            "redact"
                                                                                        ],
                                                                                        "example": "redact",
                                                                                        "type": "string",
                                                                                        "x-enum-varnames": [
                                                                                            "REDACT"
                                                                                        ],
                                                                                    },
                                                                                    "options": {
                                                                                        "description": "Configuration "
                                                                                        "for "
                                                                                        "fully "
                                                                                        "redacting "
                                                                                        "sensitive "
                                                                                        "data.",
                                                                                        "properties": {
                                                                                            "replace": {
                                                                                                "description": "The "
                                                                                                "`ObservabilityPipelineSensitiveDataScannerProcessorActionRedactOptions` "
                                                                                                "`replace`.",
                                                                                                "example": "***",
                                                                                                "type": "string",
                                                                                            }
                                                                                        },
                                                                                        "required": [
                                                                                            "replace"
                                                                                        ],
                                                                                        "type": "object",
                                                                                    },
                                                                                },
                                                                                "required": [
                                                                                    "action",
                                                                                    "options",
                                                                                ],
                                                                                "type": "object",
                                                                            },
                                                                            {
                                                                                "description": "Configuration "
                                                                                "for "
                                                                                "hashing "
                                                                                "matched "
                                                                                "sensitive "
                                                                                "values.",
                                                                                "properties": {
                                                                                    "action": {
                                                                                        "description": "Action "
                                                                                        "type "
                                                                                        "that "
                                                                                        "replaces "
                                                                                        "the "
                                                                                        "matched "
                                                                                        "sensitive "
                                                                                        "data "
                                                                                        "with "
                                                                                        "a "
                                                                                        "hashed "
                                                                                        "representation, "
                                                                                        "preserving "
                                                                                        "structure "
                                                                                        "while "
                                                                                        "securing "
                                                                                        "content.",
                                                                                        "enum": [
                                                                                            "hash"
                                                                                        ],
                                                                                        "example": "hash",
                                                                                        "type": "string",
                                                                                        "x-enum-varnames": [
                                                                                            "HASH"
                                                                                        ],
                                                                                    },
                                                                                    "options": {
                                                                                        "description": "The "
                                                                                        "`ObservabilityPipelineSensitiveDataScannerProcessorActionHash` "
                                                                                        "`options`.",
                                                                                        "type": "object",
                                                                                    },
                                                                                },
                                                                                "required": [
                                                                                    "action"
                                                                                ],
                                                                                "type": "object",
                                                                            },
                                                                            {
                                                                                "description": "Configuration "
                                                                                "for "
                                                                                "partially "
                                                                                "redacting "
                                                                                "matched "
                                                                                "sensitive "
                                                                                "data.",
                                                                                "properties": {
                                                                                    "action": {
                                                                                        "description": "Action "
                                                                                        "type "
                                                                                        "that "
                                                                                        "redacts "
                                                                                        "part "
                                                                                        "of "
                                                                                        "the "
                                                                                        "sensitive "
                                                                                        "data "
                                                                                        "while "
                                                                                        "preserving "
                                                                                        "a "
                                                                                        "configurable "
                                                                                        "number "
                                                                                        "of "
                                                                                        "characters, "
                                                                                        "typically "
                                                                                        "used "
                                                                                        "for "
                                                                                        "masking "
                                                                                        "purposes "
                                                                                        "(e.g., "
                                                                                        "show "
                                                                                        "last "
                                                                                        "4 "
                                                                                        "digits "
                                                                                        "of "
                                                                                        "a "
                                                                                        "credit "
                                                                                        "card).",
                                                                                        "enum": [
                                                                                            "partial_redact"
                                                                                        ],
                                                                                        "example": "partial_redact",
                                                                                        "type": "string",
                                                                                        "x-enum-varnames": [
                                                                                            "PARTIAL_REDACT"
                                                                                        ],
                                                                                    },
                                                                                    "options": {
                                                                                        "description": "Controls "
                                                                                        "how "
                                                                                        "partial "
                                                                                        "redaction "
                                                                                        "is "
                                                                                        "applied, "
                                                                                        "including "
                                                                                        "character "
                                                                                        "count "
                                                                                        "and "
                                                                                        "direction.",
                                                                                        "properties": {
                                                                                            "characters": {
                                                                                                "description": "The "
                                                                                                "`ObservabilityPipelineSensitiveDataScannerProcessorActionPartialRedactOptions` "
                                                                                                "`characters`.",
                                                                                                "example": 4,
                                                                                                "format": "int64",
                                                                                                "type": "integer",
                                                                                            },
                                                                                            "direction": {
                                                                                                "description": "Indicates "
                                                                                                "whether "
                                                                                                "to "
                                                                                                "redact "
                                                                                                "characters "
                                                                                                "from "
                                                                                                "the "
                                                                                                "first "
                                                                                                "or "
                                                                                                "last "
                                                                                                "part "
                                                                                                "of "
                                                                                                "the "
                                                                                                "matched "
                                                                                                "value.",
                                                                                                "enum": [
                                                                                                    "first",
                                                                                                    "last",
                                                                                                ],
                                                                                                "example": "last",
                                                                                                "type": "string",
                                                                                                "x-enum-varnames": [
                                                                                                    "FIRST",
                                                                                                    "LAST",
                                                                                                ],
                                                                                            },
                                                                                        },
                                                                                        "required": [
                                                                                            "characters",
                                                                                            "direction",
                                                                                        ],
                                                                                        "type": "object",
                                                                                    },
                                                                                },
                                                                                "required": [
                                                                                    "action",
                                                                                    "options",
                                                                                ],
                                                                                "type": "object",
                                                                            },
                                                                        ],
                                                                    },
                                                                    "pattern": {
                                                                        "description": "Pattern "
                                                                        "detection "
                                                                        "configuration "
                                                                        "for "
                                                                        "identifying "
                                                                        "sensitive "
                                                                        "data "
                                                                        "using "
                                                                        "either "
                                                                        "a "
                                                                        "custom "
                                                                        "regex "
                                                                        "or "
                                                                        "a "
                                                                        "library "
                                                                        "reference.",
                                                                        "oneOf": [
                                                                            {
                                                                                "description": "Defines "
                                                                                "a "
                                                                                "custom "
                                                                                "regex-based "
                                                                                "pattern "
                                                                                "for "
                                                                                "identifying "
                                                                                "sensitive "
                                                                                "data "
                                                                                "in "
                                                                                "logs.",
                                                                                "properties": {
                                                                                    "options": {
                                                                                        "description": "Options "
                                                                                        "for "
                                                                                        "defining "
                                                                                        "a "
                                                                                        "custom "
                                                                                        "regex "
                                                                                        "pattern.",
                                                                                        "properties": {
                                                                                            "rule": {
                                                                                                "description": "A "
                                                                                                "regular "
                                                                                                "expression "
                                                                                                "used "
                                                                                                "to "
                                                                                                "detect "
                                                                                                "sensitive "
                                                                                                "values. "
                                                                                                "Must "
                                                                                                "be "
                                                                                                "a "
                                                                                                "valid "
                                                                                                "regex.",
                                                                                                "example": "\\b\\d{16}\\b",
                                                                                                "type": "string",
                                                                                            }
                                                                                        },
                                                                                        "required": [
                                                                                            "rule"
                                                                                        ],
                                                                                        "type": "object",
                                                                                    },
                                                                                    "type": {
                                                                                        "description": "Indicates "
                                                                                        "a "
                                                                                        "custom "
                                                                                        "regular "
                                                                                        "expression "
                                                                                        "is "
                                                                                        "used "
                                                                                        "for "
                                                                                        "matching.",
                                                                                        "enum": [
                                                                                            "custom"
                                                                                        ],
                                                                                        "example": "custom",
                                                                                        "type": "string",
                                                                                        "x-enum-varnames": [
                                                                                            "CUSTOM"
                                                                                        ],
                                                                                    },
                                                                                },
                                                                                "required": [
                                                                                    "type",
                                                                                    "options",
                                                                                ],
                                                                                "type": "object",
                                                                            },
                                                                            {
                                                                                "description": "Specifies "
                                                                                "a "
                                                                                "pattern "
                                                                                "from "
                                                                                "Datadog’s "
                                                                                "sensitive "
                                                                                "data "
                                                                                "detection "
                                                                                "library "
                                                                                "to "
                                                                                "match "
                                                                                "known "
                                                                                "sensitive "
                                                                                "data "
                                                                                "types.",
                                                                                "properties": {
                                                                                    "options": {
                                                                                        "description": "Options "
                                                                                        "for "
                                                                                        "selecting "
                                                                                        "a "
                                                                                        "predefined "
                                                                                        "library "
                                                                                        "pattern "
                                                                                        "and "
                                                                                        "enabling "
                                                                                        "keyword "
                                                                                        "support.",
                                                                                        "properties": {
                                                                                            "id": {
                                                                                                "description": "Identifier "
                                                                                                "for "
                                                                                                "a "
                                                                                                "predefined "
                                                                                                "pattern "
                                                                                                "from "
                                                                                                "the "
                                                                                                "sensitive "
                                                                                                "data "
                                                                                                "scanner "
                                                                                                "pattern "
                                                                                                "library.",
                                                                                                "example": "credit_card",
                                                                                                "type": "string",
                                                                                            },
                                                                                            "use_recommended_keywords": {
                                                                                                "description": "Whether "
                                                                                                "to "
                                                                                                "augment "
                                                                                                "the "
                                                                                                "pattern "
                                                                                                "with "
                                                                                                "recommended "
                                                                                                "keywords "
                                                                                                "(optional).",
                                                                                                "type": "boolean",
                                                                                            },
                                                                                        },
                                                                                        "required": [
                                                                                            "id"
                                                                                        ],
                                                                                        "type": "object",
                                                                                    },
                                                                                    "type": {
                                                                                        "description": "Indicates "
                                                                                        "that "
                                                                                        "a "
                                                                                        "predefined "
                                                                                        "library "
                                                                                        "pattern "
                                                                                        "is "
                                                                                        "used.",
                                                                                        "enum": [
                                                                                            "library"
                                                                                        ],
                                                                                        "example": "library",
                                                                                        "type": "string",
                                                                                        "x-enum-varnames": [
                                                                                            "LIBRARY"
                                                                                        ],
                                                                                    },
                                                                                },
                                                                                "required": [
                                                                                    "type",
                                                                                    "options",
                                                                                ],
                                                                                "type": "object",
                                                                            },
                                                                        ],
                                                                    },
                                                                    "scope": {
                                                                        "description": "Determines "
                                                                        "which "
                                                                        "parts "
                                                                        "of "
                                                                        "the "
                                                                        "log "
                                                                        "the "
                                                                        "pattern-matching "
                                                                        "rule "
                                                                        "should "
                                                                        "be "
                                                                        "applied "
                                                                        "to.",
                                                                        "oneOf": [
                                                                            {
                                                                                "description": "Includes "
                                                                                "only "
                                                                                "specific "
                                                                                "fields "
                                                                                "for "
                                                                                "sensitive "
                                                                                "data "
                                                                                "scanning.",
                                                                                "properties": {
                                                                                    "options": {
                                                                                        "description": "Fields "
                                                                                        "to "
                                                                                        "which "
                                                                                        "the "
                                                                                        "scope "
                                                                                        "rule "
                                                                                        "applies.",
                                                                                        "properties": {
                                                                                            "fields": {
                                                                                                "description": "The "
                                                                                                "`ObservabilityPipelineSensitiveDataScannerProcessorScopeOptions` "
                                                                                                "`fields`.",
                                                                                                "example": [
                                                                                                    ""
                                                                                                ],
                                                                                                "items": {
                                                                                                    "type": "string"
                                                                                                },
                                                                                                "type": "array",
                                                                                            }
                                                                                        },
                                                                                        "required": [
                                                                                            "fields"
                                                                                        ],
                                                                                        "type": "object",
                                                                                    },
                                                                                    "target": {
                                                                                        "description": "Applies "
                                                                                        "the "
                                                                                        "rule "
                                                                                        "only "
                                                                                        "to "
                                                                                        "included "
                                                                                        "fields.",
                                                                                        "enum": [
                                                                                            "include"
                                                                                        ],
                                                                                        "example": "include",
                                                                                        "type": "string",
                                                                                        "x-enum-varnames": [
                                                                                            "INCLUDE"
                                                                                        ],
                                                                                    },
                                                                                },
                                                                                "required": [
                                                                                    "target",
                                                                                    "options",
                                                                                ],
                                                                                "type": "object",
                                                                            },
                                                                            {
                                                                                "description": "Excludes "
                                                                                "specific "
                                                                                "fields "
                                                                                "from "
                                                                                "sensitive "
                                                                                "data "
                                                                                "scanning.",
                                                                                "properties": {
                                                                                    "options": {
                                                                                        "description": "Fields "
                                                                                        "to "
                                                                                        "which "
                                                                                        "the "
                                                                                        "scope "
                                                                                        "rule "
                                                                                        "applies.",
                                                                                        "properties": {
                                                                                            "fields": {
                                                                                                "description": "The "
                                                                                                "`ObservabilityPipelineSensitiveDataScannerProcessorScopeOptions` "
                                                                                                "`fields`.",
                                                                                                "example": [
                                                                                                    ""
                                                                                                ],
                                                                                                "items": {
                                                                                                    "type": "string"
                                                                                                },
                                                                                                "type": "array",
                                                                                            }
                                                                                        },
                                                                                        "required": [
                                                                                            "fields"
                                                                                        ],
                                                                                        "type": "object",
                                                                                    },
                                                                                    "target": {
                                                                                        "description": "Excludes "
                                                                                        "specific "
                                                                                        "fields "
                                                                                        "from "
                                                                                        "processing.",
                                                                                        "enum": [
                                                                                            "exclude"
                                                                                        ],
                                                                                        "example": "exclude",
                                                                                        "type": "string",
                                                                                        "x-enum-varnames": [
                                                                                            "EXCLUDE"
                                                                                        ],
                                                                                    },
                                                                                },
                                                                                "required": [
                                                                                    "target",
                                                                                    "options",
                                                                                ],
                                                                                "type": "object",
                                                                            },
                                                                            {
                                                                                "description": "Applies "
                                                                                "scanning "
                                                                                "across "
                                                                                "all "
                                                                                "available "
                                                                                "fields.",
                                                                                "properties": {
                                                                                    "target": {
                                                                                        "description": "Applies "
                                                                                        "the "
                                                                                        "rule "
                                                                                        "to "
                                                                                        "all "
                                                                                        "fields.",
                                                                                        "enum": [
                                                                                            "all"
                                                                                        ],
                                                                                        "example": "all",
                                                                                        "type": "string",
                                                                                        "x-enum-varnames": [
                                                                                            "ALL"
                                                                                        ],
                                                                                    }
                                                                                },
                                                                                "required": [
                                                                                    "target"
                                                                                ],
                                                                                "type": "object",
                                                                            },
                                                                        ],
                                                                    },
                                                                    "tags": {
                                                                        "description": "Tags "
                                                                        "assigned "
                                                                        "to "
                                                                        "this "
                                                                        "rule "
                                                                        "for "
                                                                        "filtering "
                                                                        "and "
                                                                        "classification.",
                                                                        "example": ["pii", "ccn"],
                                                                        "items": {"type": "string"},
                                                                        "type": "array",
                                                                    },
                                                                },
                                                                "required": [
                                                                    "name",
                                                                    "tags",
                                                                    "pattern",
                                                                    "scope",
                                                                    "on_match",
                                                                ],
                                                                "type": "object",
                                                            },
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "sensitive_data_scanner",
                                                            "description": "The "
                                                            "processor "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`sensitive_data_scanner`.",
                                                            "enum": ["sensitive_data_scanner"],
                                                            "example": "sensitive_data_scanner",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "SENSITIVE_DATA_SCANNER"
                                                            ],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "include",
                                                        "inputs",
                                                        "rules",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`ocsf_mapper` "
                                                    "processor "
                                                    "transforms "
                                                    "logs "
                                                    "into "
                                                    "the "
                                                    "OCSF "
                                                    "schema "
                                                    "using "
                                                    "a "
                                                    "predefined "
                                                    "mapping "
                                                    "configuration.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline.",
                                                            "example": "ocsf-mapper-processor",
                                                            "type": "string",
                                                        },
                                                        "include": {
                                                            "description": "A "
                                                            "Datadog "
                                                            "search "
                                                            "query "
                                                            "used "
                                                            "to "
                                                            "determine "
                                                            "which "
                                                            "logs "
                                                            "this "
                                                            "processor "
                                                            "targets.",
                                                            "example": "service:my-service",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "processor.",
                                                            "example": ["filter-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "mappings": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "mapping "
                                                            "rules "
                                                            "to "
                                                            "convert "
                                                            "events "
                                                            "to "
                                                            "the "
                                                            "OCSF "
                                                            "format.",
                                                            "items": {
                                                                "description": "Defines "
                                                                "how "
                                                                "specific "
                                                                "events "
                                                                "are "
                                                                "transformed "
                                                                "to "
                                                                "OCSF "
                                                                "using "
                                                                "a "
                                                                "mapping "
                                                                "configuration.",
                                                                "properties": {
                                                                    "include": {
                                                                        "description": "A "
                                                                        "Datadog "
                                                                        "search "
                                                                        "query "
                                                                        "used "
                                                                        "to "
                                                                        "select "
                                                                        "the "
                                                                        "logs "
                                                                        "that "
                                                                        "this "
                                                                        "mapping "
                                                                        "should "
                                                                        "apply "
                                                                        "to.",
                                                                        "example": "service:my-service",
                                                                        "type": "string",
                                                                    },
                                                                    "mapping": {
                                                                        "description": "Defines "
                                                                        "a "
                                                                        "single "
                                                                        "mapping "
                                                                        "rule "
                                                                        "for "
                                                                        "transforming "
                                                                        "logs "
                                                                        "into "
                                                                        "the "
                                                                        "OCSF "
                                                                        "schema.",
                                                                        "oneOf": [
                                                                            {
                                                                                "description": "Predefined "
                                                                                "library "
                                                                                "mappings "
                                                                                "for "
                                                                                "common "
                                                                                "log "
                                                                                "formats.",
                                                                                "enum": [
                                                                                    "CloudTrail "
                                                                                    "Account "
                                                                                    "Change",
                                                                                    "GCP "
                                                                                    "Cloud "
                                                                                    "Audit "
                                                                                    "CreateBucket",
                                                                                    "GCP "
                                                                                    "Cloud "
                                                                                    "Audit "
                                                                                    "CreateSink",
                                                                                    "GCP "
                                                                                    "Cloud "
                                                                                    "Audit "
                                                                                    "SetIamPolicy",
                                                                                    "GCP "
                                                                                    "Cloud "
                                                                                    "Audit "
                                                                                    "UpdateSink",
                                                                                    "Github "
                                                                                    "Audit "
                                                                                    "Log "
                                                                                    "API "
                                                                                    "Activity",
                                                                                    "Google "
                                                                                    "Workspace "
                                                                                    "Admin "
                                                                                    "Audit "
                                                                                    "addPrivilege",
                                                                                    "Microsoft "
                                                                                    "365 "
                                                                                    "Defender "
                                                                                    "Incident",
                                                                                    "Microsoft "
                                                                                    "365 "
                                                                                    "Defender "
                                                                                    "UserLoggedIn",
                                                                                    "Okta "
                                                                                    "System "
                                                                                    "Log "
                                                                                    "Authentication",
                                                                                    "Palo "
                                                                                    "Alto "
                                                                                    "Networks "
                                                                                    "Firewall "
                                                                                    "Traffic",
                                                                                ],
                                                                                "example": "CloudTrail "
                                                                                "Account "
                                                                                "Change",
                                                                                "type": "string",
                                                                                "x-enum-varnames": [
                                                                                    "CLOUDTRAIL_ACCOUNT_CHANGE",
                                                                                    "GCP_CLOUD_AUDIT_CREATEBUCKET",
                                                                                    "GCP_CLOUD_AUDIT_CREATESINK",
                                                                                    "GCP_CLOUD_AUDIT_SETIAMPOLICY",
                                                                                    "GCP_CLOUD_AUDIT_UPDATESINK",
                                                                                    "GITHUB_AUDIT_LOG_API_ACTIVITY",
                                                                                    "GOOGLE_WORKSPACE_ADMIN_AUDIT_ADDPRIVILEGE",
                                                                                    "MICROSOFT_365_DEFENDER_INCIDENT",
                                                                                    "MICROSOFT_365_DEFENDER_USERLOGGEDIN",
                                                                                    "OKTA_SYSTEM_LOG_AUTHENTICATION",
                                                                                    "PALO_ALTO_NETWORKS_FIREWALL_TRAFFIC",
                                                                                ],
                                                                            }
                                                                        ],
                                                                    },
                                                                },
                                                                "required": ["include", "mapping"],
                                                                "type": "object",
                                                            },
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "ocsf_mapper",
                                                            "description": "The "
                                                            "processor "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`ocsf_mapper`.",
                                                            "enum": ["ocsf_mapper"],
                                                            "example": "ocsf_mapper",
                                                            "type": "string",
                                                            "x-enum-varnames": ["OCSF_MAPPER"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "include",
                                                        "inputs",
                                                        "mappings",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`add_env_vars` "
                                                    "processor "
                                                    "adds "
                                                    "environment "
                                                    "variable "
                                                    "values "
                                                    "to "
                                                    "log "
                                                    "events.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "processor "
                                                            "in "
                                                            "the "
                                                            "pipeline.",
                                                            "example": "add-env-vars-processor",
                                                            "type": "string",
                                                        },
                                                        "include": {
                                                            "description": "A "
                                                            "Datadog "
                                                            "search "
                                                            "query "
                                                            "used "
                                                            "to "
                                                            "determine "
                                                            "which "
                                                            "logs "
                                                            "this "
                                                            "processor "
                                                            "targets.",
                                                            "example": "service:my-service",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "input "
                                                            "for "
                                                            "this "
                                                            "processor.",
                                                            "example": ["datadog-agent-source"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "add_env_vars",
                                                            "description": "The "
                                                            "processor "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`add_env_vars`.",
                                                            "enum": ["add_env_vars"],
                                                            "example": "add_env_vars",
                                                            "type": "string",
                                                            "x-enum-varnames": ["ADD_ENV_VARS"],
                                                        },
                                                        "variables": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "environment "
                                                            "variable "
                                                            "mappings "
                                                            "to "
                                                            "apply "
                                                            "to "
                                                            "log "
                                                            "fields.",
                                                            "items": {
                                                                "description": "Defines "
                                                                "a "
                                                                "mapping "
                                                                "between "
                                                                "an "
                                                                "environment "
                                                                "variable "
                                                                "and "
                                                                "a "
                                                                "log "
                                                                "field.",
                                                                "properties": {
                                                                    "field": {
                                                                        "description": "The "
                                                                        "target "
                                                                        "field "
                                                                        "in "
                                                                        "the "
                                                                        "log "
                                                                        "event.",
                                                                        "example": "log.environment.region",
                                                                        "type": "string",
                                                                    },
                                                                    "name": {
                                                                        "description": "The "
                                                                        "name "
                                                                        "of "
                                                                        "the "
                                                                        "environment "
                                                                        "variable "
                                                                        "to "
                                                                        "read.",
                                                                        "example": "AWS_REGION",
                                                                        "type": "string",
                                                                    },
                                                                },
                                                                "required": ["field", "name"],
                                                                "type": "object",
                                                            },
                                                            "type": "array",
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "include",
                                                        "inputs",
                                                        "variables",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`dedupe` "
                                                    "processor "
                                                    "removes "
                                                    "duplicate "
                                                    "fields "
                                                    "in "
                                                    "log "
                                                    "events.",
                                                    "properties": {
                                                        "fields": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "log "
                                                            "field "
                                                            "paths "
                                                            "to "
                                                            "check "
                                                            "for "
                                                            "duplicates.",
                                                            "example": ["log.message", "log.error"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "processor.",
                                                            "example": "dedupe-processor",
                                                            "type": "string",
                                                        },
                                                        "include": {
                                                            "description": "A "
                                                            "Datadog "
                                                            "search "
                                                            "query "
                                                            "used "
                                                            "to "
                                                            "determine "
                                                            "which "
                                                            "logs "
                                                            "this "
                                                            "processor "
                                                            "targets.",
                                                            "example": "service:my-service",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "input "
                                                            "for "
                                                            "this "
                                                            "processor.",
                                                            "example": ["parse-json-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "mode": {
                                                            "description": "The "
                                                            "deduplication "
                                                            "mode "
                                                            "to "
                                                            "apply "
                                                            "to "
                                                            "the "
                                                            "fields.",
                                                            "enum": ["match", "ignore"],
                                                            "example": "match",
                                                            "type": "string",
                                                            "x-enum-varnames": ["MATCH", "IGNORE"],
                                                        },
                                                        "type": {
                                                            "default": "dedupe",
                                                            "description": "The "
                                                            "processor "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`dedupe`.",
                                                            "enum": ["dedupe"],
                                                            "example": "dedupe",
                                                            "type": "string",
                                                            "x-enum-varnames": ["DEDUPE"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "include",
                                                        "inputs",
                                                        "fields",
                                                        "mode",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`enrichment_table` "
                                                    "processor "
                                                    "enriches "
                                                    "logs "
                                                    "using "
                                                    "a "
                                                    "static "
                                                    "CSV "
                                                    "file "
                                                    "or "
                                                    "GeoIP "
                                                    "database.",
                                                    "properties": {
                                                        "file": {
                                                            "description": "Defines "
                                                            "a "
                                                            "static "
                                                            "enrichment "
                                                            "table "
                                                            "loaded "
                                                            "from "
                                                            "a "
                                                            "CSV "
                                                            "file.",
                                                            "properties": {
                                                                "encoding": {
                                                                    "description": "File "
                                                                    "encoding "
                                                                    "format.",
                                                                    "properties": {
                                                                        "delimiter": {
                                                                            "description": "The "
                                                                            "`encoding` "
                                                                            "`delimiter`.",
                                                                            "example": ",",
                                                                            "type": "string",
                                                                        },
                                                                        "includes_headers": {
                                                                            "description": "The "
                                                                            "`encoding` "
                                                                            "`includes_headers`.",
                                                                            "example": True,
                                                                            "type": "boolean",
                                                                        },
                                                                        "type": {
                                                                            "description": "Specifies "
                                                                            "the "
                                                                            "encoding "
                                                                            "format "
                                                                            "(e.g., "
                                                                            "CSV) "
                                                                            "used "
                                                                            "for "
                                                                            "enrichment "
                                                                            "tables.",
                                                                            "enum": ["csv"],
                                                                            "example": "csv",
                                                                            "type": "string",
                                                                            "x-enum-varnames": [
                                                                                "CSV"
                                                                            ],
                                                                        },
                                                                    },
                                                                    "required": [
                                                                        "type",
                                                                        "delimiter",
                                                                        "includes_headers",
                                                                    ],
                                                                    "type": "object",
                                                                },
                                                                "key": {
                                                                    "description": "Key "
                                                                    "fields "
                                                                    "used "
                                                                    "to "
                                                                    "look "
                                                                    "up "
                                                                    "enrichment "
                                                                    "values.",
                                                                    "items": {
                                                                        "description": "Defines "
                                                                        "how "
                                                                        "to "
                                                                        "map "
                                                                        "log "
                                                                        "fields "
                                                                        "to "
                                                                        "enrichment "
                                                                        "table "
                                                                        "columns "
                                                                        "during "
                                                                        "lookups.",
                                                                        "properties": {
                                                                            "column": {
                                                                                "description": "The "
                                                                                "`items` "
                                                                                "`column`.",
                                                                                "example": "user_id",
                                                                                "type": "string",
                                                                            },
                                                                            "comparison": {
                                                                                "description": "Defines "
                                                                                "how "
                                                                                "to "
                                                                                "compare "
                                                                                "key "
                                                                                "fields "
                                                                                "for "
                                                                                "enrichment "
                                                                                "table "
                                                                                "lookups.",
                                                                                "enum": ["equals"],
                                                                                "example": "equals",
                                                                                "type": "string",
                                                                                "x-enum-varnames": [
                                                                                    "EQUALS"
                                                                                ],
                                                                            },
                                                                            "field": {
                                                                                "description": "The "
                                                                                "`items` "
                                                                                "`field`.",
                                                                                "example": "log.user.id",
                                                                                "type": "string",
                                                                            },
                                                                        },
                                                                        "required": [
                                                                            "column",
                                                                            "comparison",
                                                                            "field",
                                                                        ],
                                                                        "type": "object",
                                                                    },
                                                                    "type": "array",
                                                                },
                                                                "path": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "CSV "
                                                                    "file.",
                                                                    "example": "/etc/enrichment/lookup.csv",
                                                                    "type": "string",
                                                                },
                                                                "schema": {
                                                                    "description": "Schema "
                                                                    "defining "
                                                                    "column "
                                                                    "names "
                                                                    "and "
                                                                    "their "
                                                                    "types.",
                                                                    "items": {
                                                                        "description": "Describes "
                                                                        "a "
                                                                        "single "
                                                                        "column "
                                                                        "and "
                                                                        "its "
                                                                        "type "
                                                                        "in "
                                                                        "an "
                                                                        "enrichment "
                                                                        "table "
                                                                        "schema.",
                                                                        "properties": {
                                                                            "column": {
                                                                                "description": "The "
                                                                                "`items` "
                                                                                "`column`.",
                                                                                "example": "region",
                                                                                "type": "string",
                                                                            },
                                                                            "type": {
                                                                                "description": "Declares "
                                                                                "allowed "
                                                                                "data "
                                                                                "types "
                                                                                "for "
                                                                                "enrichment "
                                                                                "table "
                                                                                "columns.",
                                                                                "enum": [
                                                                                    "string",
                                                                                    "boolean",
                                                                                    "integer",
                                                                                    "float",
                                                                                    "date",
                                                                                    "timestamp",
                                                                                ],
                                                                                "example": "string",
                                                                                "type": "string",
                                                                                "x-enum-varnames": [
                                                                                    "STRING",
                                                                                    "BOOLEAN",
                                                                                    "INTEGER",
                                                                                    "FLOAT",
                                                                                    "DATE",
                                                                                    "TIMESTAMP",
                                                                                ],
                                                                            },
                                                                        },
                                                                        "required": [
                                                                            "column",
                                                                            "type",
                                                                        ],
                                                                        "type": "object",
                                                                    },
                                                                    "type": "array",
                                                                },
                                                            },
                                                            "required": [
                                                                "encoding",
                                                                "key",
                                                                "path",
                                                                "schema",
                                                            ],
                                                            "type": "object",
                                                        },
                                                        "geoip": {
                                                            "description": "Uses "
                                                            "a "
                                                            "GeoIP "
                                                            "database "
                                                            "to "
                                                            "enrich "
                                                            "logs "
                                                            "based "
                                                            "on "
                                                            "an "
                                                            "IP "
                                                            "field.",
                                                            "properties": {
                                                                "key_field": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "IP "
                                                                    "field "
                                                                    "in "
                                                                    "the "
                                                                    "log.",
                                                                    "example": "log.source.ip",
                                                                    "type": "string",
                                                                },
                                                                "locale": {
                                                                    "description": "Locale "
                                                                    "used "
                                                                    "to "
                                                                    "resolve "
                                                                    "geographical "
                                                                    "names.",
                                                                    "example": "en",
                                                                    "type": "string",
                                                                },
                                                                "path": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "GeoIP "
                                                                    "database "
                                                                    "file.",
                                                                    "example": "/etc/geoip/GeoLite2-City.mmdb",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": [
                                                                "key_field",
                                                                "locale",
                                                                "path",
                                                            ],
                                                            "type": "object",
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "processor.",
                                                            "example": "enrichment-table-processor",
                                                            "type": "string",
                                                        },
                                                        "include": {
                                                            "description": "A "
                                                            "Datadog "
                                                            "search "
                                                            "query "
                                                            "used "
                                                            "to "
                                                            "determine "
                                                            "which "
                                                            "logs "
                                                            "this "
                                                            "processor "
                                                            "targets.",
                                                            "example": "source:my-source",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "input "
                                                            "for "
                                                            "this "
                                                            "processor.",
                                                            "example": ["add-fields-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "target": {
                                                            "description": "Path "
                                                            "where "
                                                            "enrichment "
                                                            "results "
                                                            "should "
                                                            "be "
                                                            "stored "
                                                            "in "
                                                            "the "
                                                            "log.",
                                                            "example": "enriched.geoip",
                                                            "type": "string",
                                                        },
                                                        "type": {
                                                            "default": "enrichment_table",
                                                            "description": "The "
                                                            "processor "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`enrichment_table`.",
                                                            "enum": ["enrichment_table"],
                                                            "example": "enrichment_table",
                                                            "type": "string",
                                                            "x-enum-varnames": ["ENRICHMENT_TABLE"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "include",
                                                        "inputs",
                                                        "target",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`reduce` "
                                                    "processor "
                                                    "aggregates "
                                                    "and "
                                                    "merges "
                                                    "logs "
                                                    "based "
                                                    "on "
                                                    "matching "
                                                    "keys "
                                                    "and "
                                                    "merge "
                                                    "strategies.",
                                                    "properties": {
                                                        "group_by": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "fields "
                                                            "used "
                                                            "to "
                                                            "group "
                                                            "log "
                                                            "events "
                                                            "for "
                                                            "merging.",
                                                            "example": [
                                                                "log.user.id",
                                                                "log.device.id",
                                                            ],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "processor.",
                                                            "example": "reduce-processor",
                                                            "type": "string",
                                                        },
                                                        "include": {
                                                            "description": "A "
                                                            "Datadog "
                                                            "search "
                                                            "query "
                                                            "used "
                                                            "to "
                                                            "determine "
                                                            "which "
                                                            "logs "
                                                            "this "
                                                            "processor "
                                                            "targets.",
                                                            "example": "env:prod",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "input "
                                                            "for "
                                                            "this "
                                                            "processor.",
                                                            "example": ["parse-json-processor"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "merge_strategies": {
                                                            "description": "List "
                                                            "of "
                                                            "merge "
                                                            "strategies "
                                                            "defining "
                                                            "how "
                                                            "values "
                                                            "from "
                                                            "grouped "
                                                            "events "
                                                            "should "
                                                            "be "
                                                            "combined.",
                                                            "items": {
                                                                "description": "Defines "
                                                                "how "
                                                                "a "
                                                                "specific "
                                                                "field "
                                                                "should "
                                                                "be "
                                                                "merged "
                                                                "across "
                                                                "grouped "
                                                                "events.",
                                                                "properties": {
                                                                    "path": {
                                                                        "description": "The "
                                                                        "field "
                                                                        "path "
                                                                        "in "
                                                                        "the "
                                                                        "log "
                                                                        "event.",
                                                                        "example": "log.user.roles",
                                                                        "type": "string",
                                                                    },
                                                                    "strategy": {
                                                                        "description": "The "
                                                                        "merge "
                                                                        "strategy "
                                                                        "to "
                                                                        "apply.",
                                                                        "enum": [
                                                                            "discard",
                                                                            "retain",
                                                                            "sum",
                                                                            "max",
                                                                            "min",
                                                                            "array",
                                                                            "concat",
                                                                            "concat_newline",
                                                                            "concat_raw",
                                                                            "shortest_array",
                                                                            "longest_array",
                                                                            "flat_unique",
                                                                        ],
                                                                        "example": "flat_unique",
                                                                        "type": "string",
                                                                        "x-enum-varnames": [
                                                                            "DISCARD",
                                                                            "RETAIN",
                                                                            "SUM",
                                                                            "MAX",
                                                                            "MIN",
                                                                            "ARRAY",
                                                                            "CONCAT",
                                                                            "CONCAT_NEWLINE",
                                                                            "CONCAT_RAW",
                                                                            "SHORTEST_ARRAY",
                                                                            "LONGEST_ARRAY",
                                                                            "FLAT_UNIQUE",
                                                                        ],
                                                                    },
                                                                },
                                                                "required": ["path", "strategy"],
                                                                "type": "object",
                                                            },
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "reduce",
                                                            "description": "The "
                                                            "processor "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`reduce`.",
                                                            "enum": ["reduce"],
                                                            "example": "reduce",
                                                            "type": "string",
                                                            "x-enum-varnames": ["REDUCE"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "include",
                                                        "inputs",
                                                        "group_by",
                                                        "merge_strategies",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`throttle` "
                                                    "processor "
                                                    "limits "
                                                    "the "
                                                    "number "
                                                    "of "
                                                    "events "
                                                    "that "
                                                    "pass "
                                                    "through "
                                                    "over "
                                                    "a "
                                                    "given "
                                                    "time "
                                                    "window.",
                                                    "properties": {
                                                        "group_by": {
                                                            "description": "Optional "
                                                            "list "
                                                            "of "
                                                            "fields "
                                                            "used "
                                                            "to "
                                                            "group "
                                                            "events "
                                                            "before "
                                                            "the "
                                                            "threshold "
                                                            "has "
                                                            "been "
                                                            "reached.",
                                                            "example": ["log.user.id"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "processor.",
                                                            "example": "throttle-processor",
                                                            "type": "string",
                                                        },
                                                        "include": {
                                                            "description": "A "
                                                            "Datadog "
                                                            "search "
                                                            "query "
                                                            "used "
                                                            "to "
                                                            "determine "
                                                            "which "
                                                            "logs "
                                                            "this "
                                                            "processor "
                                                            "targets.",
                                                            "example": "env:prod",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "input "
                                                            "for "
                                                            "this "
                                                            "processor.",
                                                            "example": ["datadog-agent-source"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "threshold": {
                                                            "description": "the "
                                                            "number "
                                                            "of "
                                                            "events "
                                                            "allowed "
                                                            "in "
                                                            "a "
                                                            "given "
                                                            "time "
                                                            "window. "
                                                            "Events "
                                                            "sent "
                                                            "after "
                                                            "the "
                                                            "threshold "
                                                            "has "
                                                            "been "
                                                            "reached, "
                                                            "are "
                                                            "dropped.",
                                                            "example": 1000,
                                                            "format": "int64",
                                                            "type": "integer",
                                                        },
                                                        "type": {
                                                            "default": "throttle",
                                                            "description": "The "
                                                            "processor "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`throttle`.",
                                                            "enum": ["throttle"],
                                                            "example": "throttle",
                                                            "type": "string",
                                                            "x-enum-varnames": ["THROTTLE"],
                                                        },
                                                        "window": {
                                                            "description": "The "
                                                            "time "
                                                            "window "
                                                            "in "
                                                            "seconds "
                                                            "over "
                                                            "which "
                                                            "the "
                                                            "threshold "
                                                            "applies.",
                                                            "example": 60.0,
                                                            "format": "double",
                                                            "type": "number",
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "include",
                                                        "inputs",
                                                        "threshold",
                                                        "window",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`custom_processor` "
                                                    "processor "
                                                    "transforms "
                                                    "events "
                                                    "using "
                                                    "[Vector "
                                                    "Remap "
                                                    "Language "
                                                    "(VRL)](https://vector.dev/docs/reference/vrl/) "
                                                    "scripts "
                                                    "with "
                                                    "advanced "
                                                    "filtering "
                                                    "capabilities.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "processor.",
                                                            "example": "remap-vrl-processor",
                                                            "type": "string",
                                                        },
                                                        "include": {
                                                            "default": "*",
                                                            "description": "A "
                                                            "Datadog "
                                                            "search "
                                                            "query "
                                                            "used "
                                                            "to "
                                                            "determine "
                                                            "which "
                                                            "logs "
                                                            "this "
                                                            "processor "
                                                            "targets. "
                                                            "This "
                                                            "field "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "set "
                                                            "to "
                                                            "`*` "
                                                            "for "
                                                            "the "
                                                            "custom_processor "
                                                            "processor.",
                                                            "example": "*",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "input "
                                                            "for "
                                                            "this "
                                                            "processor.",
                                                            "example": ["datadog-agent-source"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "remaps": {
                                                            "description": "Array "
                                                            "of "
                                                            "VRL "
                                                            "remap "
                                                            "rules.",
                                                            "items": {
                                                                "description": "Defines "
                                                                "a "
                                                                "single "
                                                                "VRL "
                                                                "remap "
                                                                "rule "
                                                                "with "
                                                                "its "
                                                                "own "
                                                                "filtering "
                                                                "and "
                                                                "transformation "
                                                                "logic.",
                                                                "properties": {
                                                                    "drop_on_error": {
                                                                        "description": "Whether "
                                                                        "to "
                                                                        "drop "
                                                                        "events "
                                                                        "that "
                                                                        "caused "
                                                                        "errors "
                                                                        "during "
                                                                        "processing.",
                                                                        "example": False,
                                                                        "type": "boolean",
                                                                    },
                                                                    "enabled": {
                                                                        "description": "Whether "
                                                                        "this "
                                                                        "remap "
                                                                        "rule "
                                                                        "is "
                                                                        "enabled.",
                                                                        "example": True,
                                                                        "type": "boolean",
                                                                    },
                                                                    "include": {
                                                                        "description": "A "
                                                                        "Datadog "
                                                                        "search "
                                                                        "query "
                                                                        "used "
                                                                        "to "
                                                                        "filter "
                                                                        "events "
                                                                        "for "
                                                                        "this "
                                                                        "specific "
                                                                        "remap "
                                                                        "rule.",
                                                                        "example": "service:web",
                                                                        "type": "string",
                                                                    },
                                                                    "name": {
                                                                        "description": "A "
                                                                        "descriptive "
                                                                        "name "
                                                                        "for "
                                                                        "this "
                                                                        "remap "
                                                                        "rule.",
                                                                        "example": "Parse "
                                                                        "JSON "
                                                                        "from "
                                                                        "message "
                                                                        "field",
                                                                        "type": "string",
                                                                    },
                                                                    "source": {
                                                                        "description": "The "
                                                                        "VRL "
                                                                        "script "
                                                                        "source "
                                                                        "code "
                                                                        "that "
                                                                        "defines "
                                                                        "the "
                                                                        "processing "
                                                                        "logic.",
                                                                        "example": ". "
                                                                        "= "
                                                                        "parse_json!(.message)",
                                                                        "type": "string",
                                                                    },
                                                                },
                                                                "required": [
                                                                    "include",
                                                                    "name",
                                                                    "source",
                                                                    "enabled",
                                                                    "drop_on_error",
                                                                ],
                                                                "type": "object",
                                                            },
                                                            "minItems": 1,
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "custom_processor",
                                                            "description": "The "
                                                            "processor "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`custom_processor`.",
                                                            "enum": ["custom_processor"],
                                                            "example": "custom_processor",
                                                            "type": "string",
                                                            "x-enum-varnames": ["CUSTOM_PROCESSOR"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "include",
                                                        "remaps",
                                                        "inputs",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`datadog_tags` "
                                                    "processor "
                                                    "includes "
                                                    "or "
                                                    "excludes "
                                                    "specific "
                                                    "Datadog "
                                                    "tags "
                                                    "in "
                                                    "your "
                                                    "logs.",
                                                    "properties": {
                                                        "action": {
                                                            "description": "The "
                                                            "action "
                                                            "to "
                                                            "take "
                                                            "on "
                                                            "tags "
                                                            "with "
                                                            "matching "
                                                            "keys.",
                                                            "enum": ["include", "exclude"],
                                                            "example": "include",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "INCLUDE",
                                                                "EXCLUDE",
                                                            ],
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(for "
                                                            "example, "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "datadog-tags-processor",
                                                            "type": "string",
                                                        },
                                                        "include": {
                                                            "description": "A "
                                                            "Datadog "
                                                            "search "
                                                            "query "
                                                            "used "
                                                            "to "
                                                            "determine "
                                                            "which "
                                                            "logs "
                                                            "this "
                                                            "processor "
                                                            "targets.",
                                                            "example": "service:my-service",
                                                            "type": "string",
                                                        },
                                                        "inputs": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "component "
                                                            "IDs "
                                                            "whose "
                                                            "output "
                                                            "is "
                                                            "used "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "for "
                                                            "this "
                                                            "component.",
                                                            "example": ["datadog-agent-source"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "keys": {
                                                            "description": "A list of tag keys.",
                                                            "example": [
                                                                "env",
                                                                "service",
                                                                "version",
                                                            ],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "mode": {
                                                            "description": "The processing mode.",
                                                            "enum": ["filter"],
                                                            "example": "filter",
                                                            "type": "string",
                                                            "x-enum-varnames": ["FILTER"],
                                                        },
                                                        "type": {
                                                            "default": "datadog_tags",
                                                            "description": "The "
                                                            "processor "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`datadog_tags`.",
                                                            "enum": ["datadog_tags"],
                                                            "example": "datadog_tags",
                                                            "type": "string",
                                                            "x-enum-varnames": ["DATADOG_TAGS"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "include",
                                                        "mode",
                                                        "action",
                                                        "keys",
                                                        "inputs",
                                                    ],
                                                    "type": "object",
                                                },
                                            ],
                                        },
                                        "type": "array",
                                    },
                                    "sources": {
                                        "description": "A "
                                        "list "
                                        "of "
                                        "configured "
                                        "data "
                                        "sources "
                                        "for "
                                        "the "
                                        "pipeline.",
                                        "example": [
                                            {"id": "datadog-agent-source", "type": "datadog_agent"}
                                        ],
                                        "items": {
                                            "description": "A data source for the pipeline.",
                                            "oneOf": [
                                                {
                                                    "description": "The "
                                                    "`kafka` "
                                                    "source "
                                                    "ingests "
                                                    "data "
                                                    "from "
                                                    "Apache "
                                                    "Kafka "
                                                    "topics.",
                                                    "properties": {
                                                        "group_id": {
                                                            "description": "Consumer "
                                                            "group "
                                                            "ID "
                                                            "used "
                                                            "by "
                                                            "the "
                                                            "Kafka "
                                                            "client.",
                                                            "example": "consumer-group-0",
                                                            "type": "string",
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(e.g., "
                                                            "as "
                                                            "input "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "kafka-source",
                                                            "type": "string",
                                                        },
                                                        "librdkafka_options": {
                                                            "description": "Optional "
                                                            "list "
                                                            "of "
                                                            "advanced "
                                                            "Kafka "
                                                            "client "
                                                            "configuration "
                                                            "options, "
                                                            "defined "
                                                            "as "
                                                            "key-value "
                                                            "pairs.",
                                                            "items": {
                                                                "description": "Represents "
                                                                "a "
                                                                "key-value "
                                                                "pair "
                                                                "used "
                                                                "to "
                                                                "configure "
                                                                "low-level "
                                                                "`librdkafka` "
                                                                "client "
                                                                "options "
                                                                "for "
                                                                "Kafka "
                                                                "sources, "
                                                                "such "
                                                                "as "
                                                                "timeouts, "
                                                                "buffer "
                                                                "sizes, "
                                                                "and "
                                                                "security "
                                                                "settings.",
                                                                "properties": {
                                                                    "name": {
                                                                        "description": "The "
                                                                        "name "
                                                                        "of "
                                                                        "the "
                                                                        "`librdkafka` "
                                                                        "configuration "
                                                                        "option "
                                                                        "to "
                                                                        "set.",
                                                                        "example": "fetch.message.max.bytes",
                                                                        "type": "string",
                                                                    },
                                                                    "value": {
                                                                        "description": "The "
                                                                        "value "
                                                                        "assigned "
                                                                        "to "
                                                                        "the "
                                                                        "specified "
                                                                        "`librdkafka` "
                                                                        "configuration "
                                                                        "option.",
                                                                        "example": "1048576",
                                                                        "type": "string",
                                                                    },
                                                                },
                                                                "required": ["name", "value"],
                                                                "type": "object",
                                                            },
                                                            "type": "array",
                                                        },
                                                        "sasl": {
                                                            "description": "Specifies "
                                                            "the "
                                                            "SASL "
                                                            "mechanism "
                                                            "for "
                                                            "authenticating "
                                                            "with "
                                                            "a "
                                                            "Kafka "
                                                            "cluster.",
                                                            "properties": {
                                                                "mechanism": {
                                                                    "description": "SASL "
                                                                    "mechanism "
                                                                    "used "
                                                                    "for "
                                                                    "Kafka "
                                                                    "authentication.",
                                                                    "enum": [
                                                                        "PLAIN",
                                                                        "SCRAM-SHA-256",
                                                                        "SCRAM-SHA-512",
                                                                    ],
                                                                    "type": "string",
                                                                    "x-enum-varnames": [
                                                                        "PLAIN",
                                                                        "SCRAMNOT_SHANOT_256",
                                                                        "SCRAMNOT_SHANOT_512",
                                                                    ],
                                                                }
                                                            },
                                                            "type": "object",
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "topics": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "Kafka "
                                                            "topic "
                                                            "names "
                                                            "to "
                                                            "subscribe "
                                                            "to. "
                                                            "The "
                                                            "source "
                                                            "ingests "
                                                            "messages "
                                                            "from "
                                                            "each "
                                                            "topic "
                                                            "specified.",
                                                            "example": ["topic1", "topic2"],
                                                            "items": {"type": "string"},
                                                            "type": "array",
                                                        },
                                                        "type": {
                                                            "default": "kafka",
                                                            "description": "The "
                                                            "source "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`kafka`.",
                                                            "enum": ["kafka"],
                                                            "example": "kafka",
                                                            "type": "string",
                                                            "x-enum-varnames": ["KAFKA"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "group_id",
                                                        "topics",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`datadog_agent` "
                                                    "source "
                                                    "collects "
                                                    "logs "
                                                    "from "
                                                    "the "
                                                    "Datadog "
                                                    "Agent.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(e.g., "
                                                            "as "
                                                            "input "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "datadog-agent-source",
                                                            "type": "string",
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "datadog_agent",
                                                            "description": "The "
                                                            "source "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`datadog_agent`.",
                                                            "enum": ["datadog_agent"],
                                                            "example": "datadog_agent",
                                                            "type": "string",
                                                            "x-enum-varnames": ["DATADOG_AGENT"],
                                                        },
                                                    },
                                                    "required": ["id", "type"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`splunk_tcp` "
                                                    "source "
                                                    "receives "
                                                    "logs "
                                                    "from "
                                                    "a "
                                                    "Splunk "
                                                    "Universal "
                                                    "Forwarder "
                                                    "over "
                                                    "TCP.\n"
                                                    "TLS "
                                                    "is "
                                                    "supported "
                                                    "for "
                                                    "secure "
                                                    "transmission.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(e.g., "
                                                            "as "
                                                            "input "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "splunk-tcp-source",
                                                            "type": "string",
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "splunk_tcp",
                                                            "description": "The "
                                                            "source "
                                                            "type. "
                                                            "Always "
                                                            "`splunk_tcp`.",
                                                            "enum": ["splunk_tcp"],
                                                            "example": "splunk_tcp",
                                                            "type": "string",
                                                            "x-enum-varnames": ["SPLUNK_TCP"],
                                                        },
                                                    },
                                                    "required": ["id", "type"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`splunk_hec` "
                                                    "source "
                                                    "implements "
                                                    "the "
                                                    "Splunk "
                                                    "HTTP "
                                                    "Event "
                                                    "Collector "
                                                    "(HEC) "
                                                    "API.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(e.g., "
                                                            "as "
                                                            "input "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "splunk-hec-source",
                                                            "type": "string",
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "splunk_hec",
                                                            "description": "The "
                                                            "source "
                                                            "type. "
                                                            "Always "
                                                            "`splunk_hec`.",
                                                            "enum": ["splunk_hec"],
                                                            "example": "splunk_hec",
                                                            "type": "string",
                                                            "x-enum-varnames": ["SPLUNK_HEC"],
                                                        },
                                                    },
                                                    "required": ["id", "type"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`amazon_s3` "
                                                    "source "
                                                    "ingests "
                                                    "logs "
                                                    "from "
                                                    "an "
                                                    "Amazon "
                                                    "S3 "
                                                    "bucket.\n"
                                                    "It "
                                                    "supports "
                                                    "AWS "
                                                    "authentication "
                                                    "and "
                                                    "TLS "
                                                    "encryption.",
                                                    "properties": {
                                                        "auth": {
                                                            "description": "AWS "
                                                            "authentication "
                                                            "credentials "
                                                            "used "
                                                            "for "
                                                            "accessing "
                                                            "AWS "
                                                            "services "
                                                            "such "
                                                            "as "
                                                            "S3.\n"
                                                            "If "
                                                            "omitted, "
                                                            "the "
                                                            "system’s "
                                                            "default "
                                                            "credentials "
                                                            "are "
                                                            "used "
                                                            "(for "
                                                            "example, "
                                                            "the "
                                                            "IAM "
                                                            "role "
                                                            "and "
                                                            "environment "
                                                            "variables).",
                                                            "properties": {
                                                                "assume_role": {
                                                                    "description": "The "
                                                                    "Amazon "
                                                                    "Resource "
                                                                    "Name "
                                                                    "(ARN) "
                                                                    "of "
                                                                    "the "
                                                                    "role "
                                                                    "to "
                                                                    "assume.",
                                                                    "type": "string",
                                                                },
                                                                "external_id": {
                                                                    "description": "A "
                                                                    "unique "
                                                                    "identifier "
                                                                    "for "
                                                                    "cross-account "
                                                                    "role "
                                                                    "assumption.",
                                                                    "type": "string",
                                                                },
                                                                "session_name": {
                                                                    "description": "A "
                                                                    "session "
                                                                    "identifier "
                                                                    "used "
                                                                    "for "
                                                                    "logging "
                                                                    "and "
                                                                    "tracing "
                                                                    "the "
                                                                    "assumed "
                                                                    "role "
                                                                    "session.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "type": "object",
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(e.g., "
                                                            "as "
                                                            "input "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "aws-s3-source",
                                                            "type": "string",
                                                        },
                                                        "region": {
                                                            "description": "AWS "
                                                            "region "
                                                            "where "
                                                            "the "
                                                            "S3 "
                                                            "bucket "
                                                            "resides.",
                                                            "example": "us-east-1",
                                                            "type": "string",
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "amazon_s3",
                                                            "description": "The "
                                                            "source "
                                                            "type. "
                                                            "Always "
                                                            "`amazon_s3`.",
                                                            "enum": ["amazon_s3"],
                                                            "example": "amazon_s3",
                                                            "type": "string",
                                                            "x-enum-varnames": ["AMAZON_S3"],
                                                        },
                                                    },
                                                    "required": ["id", "type", "region"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`fluentd` "
                                                    "source "
                                                    "ingests "
                                                    "logs "
                                                    "from "
                                                    "a "
                                                    "Fluentd-compatible "
                                                    "service.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(for "
                                                            "example, "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "fluent-source",
                                                            "type": "string",
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "fluentd",
                                                            "description": "The "
                                                            "source "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`fluentd.",
                                                            "enum": ["fluentd"],
                                                            "example": "fluentd",
                                                            "type": "string",
                                                            "x-enum-varnames": ["FLUENTD"],
                                                        },
                                                    },
                                                    "required": ["id", "type"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`fluent_bit` "
                                                    "source "
                                                    "ingests "
                                                    "logs "
                                                    "from "
                                                    "Fluent "
                                                    "Bit.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(for "
                                                            "example, "
                                                            "as "
                                                            "the "
                                                            "`input` "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "fluent-source",
                                                            "type": "string",
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "fluent_bit",
                                                            "description": "The "
                                                            "source "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`fluent_bit`.",
                                                            "enum": ["fluent_bit"],
                                                            "example": "fluent_bit",
                                                            "type": "string",
                                                            "x-enum-varnames": ["FLUENT_BIT"],
                                                        },
                                                    },
                                                    "required": ["id", "type"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`http_server` "
                                                    "source "
                                                    "collects "
                                                    "logs "
                                                    "over "
                                                    "HTTP "
                                                    "POST "
                                                    "from "
                                                    "external "
                                                    "services.",
                                                    "properties": {
                                                        "auth_strategy": {
                                                            "description": "HTTP "
                                                            "authentication "
                                                            "method.",
                                                            "enum": ["none", "plain"],
                                                            "example": "plain",
                                                            "type": "string",
                                                            "x-enum-varnames": ["NONE", "PLAIN"],
                                                        },
                                                        "decoding": {
                                                            "description": "The "
                                                            "decoding "
                                                            "format "
                                                            "used "
                                                            "to "
                                                            "interpret "
                                                            "incoming "
                                                            "logs.",
                                                            "enum": [
                                                                "bytes",
                                                                "gelf",
                                                                "json",
                                                                "syslog",
                                                            ],
                                                            "example": "json",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "DECODE_BYTES",
                                                                "DECODE_GELF",
                                                                "DECODE_JSON",
                                                                "DECODE_SYSLOG",
                                                            ],
                                                        },
                                                        "id": {
                                                            "description": "Unique "
                                                            "ID "
                                                            "for "
                                                            "the "
                                                            "HTTP "
                                                            "server "
                                                            "source.",
                                                            "example": "http-server-source",
                                                            "type": "string",
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "http_server",
                                                            "description": "The "
                                                            "source "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`http_server`.",
                                                            "enum": ["http_server"],
                                                            "example": "http_server",
                                                            "type": "string",
                                                            "x-enum-varnames": ["HTTP_SERVER"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "auth_strategy",
                                                        "decoding",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`sumo_logic` "
                                                    "source "
                                                    "receives "
                                                    "logs "
                                                    "from "
                                                    "Sumo "
                                                    "Logic "
                                                    "collectors.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(e.g., "
                                                            "as "
                                                            "input "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "sumo-logic-source",
                                                            "type": "string",
                                                        },
                                                        "type": {
                                                            "default": "sumo_logic",
                                                            "description": "The "
                                                            "source "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`sumo_logic`.",
                                                            "enum": ["sumo_logic"],
                                                            "example": "sumo_logic",
                                                            "type": "string",
                                                            "x-enum-varnames": ["SUMO_LOGIC"],
                                                        },
                                                    },
                                                    "required": ["id", "type"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`rsyslog` "
                                                    "source "
                                                    "listens "
                                                    "for "
                                                    "logs "
                                                    "over "
                                                    "TCP "
                                                    "or "
                                                    "UDP "
                                                    "from "
                                                    "an "
                                                    "`rsyslog` "
                                                    "server "
                                                    "using "
                                                    "the "
                                                    "syslog "
                                                    "protocol.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(e.g., "
                                                            "as "
                                                            "input "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "rsyslog-source",
                                                            "type": "string",
                                                        },
                                                        "mode": {
                                                            "description": "Protocol "
                                                            "used "
                                                            "by "
                                                            "the "
                                                            "syslog "
                                                            "source "
                                                            "to "
                                                            "receive "
                                                            "messages.",
                                                            "enum": ["tcp", "udp"],
                                                            "example": "tcp",
                                                            "type": "string",
                                                            "x-enum-varnames": ["TCP", "UDP"],
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "rsyslog",
                                                            "description": "The "
                                                            "source "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`rsyslog`.",
                                                            "enum": ["rsyslog"],
                                                            "example": "rsyslog",
                                                            "type": "string",
                                                            "x-enum-varnames": ["RSYSLOG"],
                                                        },
                                                    },
                                                    "required": ["id", "type", "mode"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`syslog_ng` "
                                                    "source "
                                                    "listens "
                                                    "for "
                                                    "logs "
                                                    "over "
                                                    "TCP "
                                                    "or "
                                                    "UDP "
                                                    "from "
                                                    "a "
                                                    "`syslog-ng` "
                                                    "server "
                                                    "using "
                                                    "the "
                                                    "syslog "
                                                    "protocol.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(e.g., "
                                                            "as "
                                                            "input "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "syslog-ng-source",
                                                            "type": "string",
                                                        },
                                                        "mode": {
                                                            "description": "Protocol "
                                                            "used "
                                                            "by "
                                                            "the "
                                                            "syslog "
                                                            "source "
                                                            "to "
                                                            "receive "
                                                            "messages.",
                                                            "enum": ["tcp", "udp"],
                                                            "example": "tcp",
                                                            "type": "string",
                                                            "x-enum-varnames": ["TCP", "UDP"],
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "syslog_ng",
                                                            "description": "The "
                                                            "source "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`syslog_ng`.",
                                                            "enum": ["syslog_ng"],
                                                            "example": "syslog_ng",
                                                            "type": "string",
                                                            "x-enum-varnames": ["SYSLOG_NG"],
                                                        },
                                                    },
                                                    "required": ["id", "type", "mode"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`amazon_data_firehose` "
                                                    "source "
                                                    "ingests "
                                                    "logs "
                                                    "from "
                                                    "AWS "
                                                    "Data "
                                                    "Firehose.",
                                                    "properties": {
                                                        "auth": {
                                                            "description": "AWS "
                                                            "authentication "
                                                            "credentials "
                                                            "used "
                                                            "for "
                                                            "accessing "
                                                            "AWS "
                                                            "services "
                                                            "such "
                                                            "as "
                                                            "S3.\n"
                                                            "If "
                                                            "omitted, "
                                                            "the "
                                                            "system’s "
                                                            "default "
                                                            "credentials "
                                                            "are "
                                                            "used "
                                                            "(for "
                                                            "example, "
                                                            "the "
                                                            "IAM "
                                                            "role "
                                                            "and "
                                                            "environment "
                                                            "variables).",
                                                            "properties": {
                                                                "assume_role": {
                                                                    "description": "The "
                                                                    "Amazon "
                                                                    "Resource "
                                                                    "Name "
                                                                    "(ARN) "
                                                                    "of "
                                                                    "the "
                                                                    "role "
                                                                    "to "
                                                                    "assume.",
                                                                    "type": "string",
                                                                },
                                                                "external_id": {
                                                                    "description": "A "
                                                                    "unique "
                                                                    "identifier "
                                                                    "for "
                                                                    "cross-account "
                                                                    "role "
                                                                    "assumption.",
                                                                    "type": "string",
                                                                },
                                                                "session_name": {
                                                                    "description": "A "
                                                                    "session "
                                                                    "identifier "
                                                                    "used "
                                                                    "for "
                                                                    "logging "
                                                                    "and "
                                                                    "tracing "
                                                                    "the "
                                                                    "assumed "
                                                                    "role "
                                                                    "session.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "type": "object",
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(e.g., "
                                                            "as "
                                                            "input "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "amazon-firehose-source",
                                                            "type": "string",
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "amazon_data_firehose",
                                                            "description": "The "
                                                            "source "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`amazon_data_firehose`.",
                                                            "enum": ["amazon_data_firehose"],
                                                            "example": "amazon_data_firehose",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "AMAZON_DATA_FIREHOSE"
                                                            ],
                                                        },
                                                    },
                                                    "required": ["id", "type"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`google_pubsub` "
                                                    "source "
                                                    "ingests "
                                                    "logs "
                                                    "from "
                                                    "a "
                                                    "Google "
                                                    "Cloud "
                                                    "Pub/Sub "
                                                    "subscription.",
                                                    "properties": {
                                                        "auth": {
                                                            "description": "GCP "
                                                            "credentials "
                                                            "used "
                                                            "to "
                                                            "authenticate "
                                                            "with "
                                                            "Google "
                                                            "Cloud "
                                                            "Storage.",
                                                            "properties": {
                                                                "credentials_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "GCP "
                                                                    "service "
                                                                    "account "
                                                                    "key "
                                                                    "file.",
                                                                    "example": "/var/secrets/gcp-credentials.json",
                                                                    "type": "string",
                                                                }
                                                            },
                                                            "required": ["credentials_file"],
                                                            "type": "object",
                                                        },
                                                        "decoding": {
                                                            "description": "The "
                                                            "decoding "
                                                            "format "
                                                            "used "
                                                            "to "
                                                            "interpret "
                                                            "incoming "
                                                            "logs.",
                                                            "enum": [
                                                                "bytes",
                                                                "gelf",
                                                                "json",
                                                                "syslog",
                                                            ],
                                                            "example": "json",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "DECODE_BYTES",
                                                                "DECODE_GELF",
                                                                "DECODE_JSON",
                                                                "DECODE_SYSLOG",
                                                            ],
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(e.g., "
                                                            "as "
                                                            "input "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "google-pubsub-source",
                                                            "type": "string",
                                                        },
                                                        "project": {
                                                            "description": "The "
                                                            "GCP "
                                                            "project "
                                                            "ID "
                                                            "that "
                                                            "owns "
                                                            "the "
                                                            "Pub/Sub "
                                                            "subscription.",
                                                            "example": "my-gcp-project",
                                                            "type": "string",
                                                        },
                                                        "subscription": {
                                                            "description": "The "
                                                            "Pub/Sub "
                                                            "subscription "
                                                            "name "
                                                            "from "
                                                            "which "
                                                            "messages "
                                                            "are "
                                                            "consumed.",
                                                            "example": "logs-subscription",
                                                            "type": "string",
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "google_pubsub",
                                                            "description": "The "
                                                            "source "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`google_pubsub`.",
                                                            "enum": ["google_pubsub"],
                                                            "example": "google_pubsub",
                                                            "type": "string",
                                                            "x-enum-varnames": ["GOOGLE_PUBSUB"],
                                                        },
                                                    },
                                                    "required": [
                                                        "id",
                                                        "type",
                                                        "auth",
                                                        "decoding",
                                                        "project",
                                                        "subscription",
                                                    ],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`http_client` "
                                                    "source "
                                                    "scrapes "
                                                    "logs "
                                                    "from "
                                                    "HTTP "
                                                    "endpoints "
                                                    "at "
                                                    "regular "
                                                    "intervals.",
                                                    "properties": {
                                                        "auth_strategy": {
                                                            "description": "Optional "
                                                            "authentication "
                                                            "strategy "
                                                            "for "
                                                            "HTTP "
                                                            "requests.",
                                                            "enum": ["basic", "bearer"],
                                                            "example": "basic",
                                                            "type": "string",
                                                            "x-enum-varnames": ["BASIC", "BEARER"],
                                                        },
                                                        "decoding": {
                                                            "description": "The "
                                                            "decoding "
                                                            "format "
                                                            "used "
                                                            "to "
                                                            "interpret "
                                                            "incoming "
                                                            "logs.",
                                                            "enum": [
                                                                "bytes",
                                                                "gelf",
                                                                "json",
                                                                "syslog",
                                                            ],
                                                            "example": "json",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "DECODE_BYTES",
                                                                "DECODE_GELF",
                                                                "DECODE_JSON",
                                                                "DECODE_SYSLOG",
                                                            ],
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(e.g., "
                                                            "as "
                                                            "input "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "http-client-source",
                                                            "type": "string",
                                                        },
                                                        "scrape_interval_secs": {
                                                            "description": "The "
                                                            "interval "
                                                            "(in "
                                                            "seconds) "
                                                            "between "
                                                            "HTTP "
                                                            "scrape "
                                                            "requests.",
                                                            "example": 60,
                                                            "format": "int64",
                                                            "type": "integer",
                                                        },
                                                        "scrape_timeout_secs": {
                                                            "description": "The "
                                                            "timeout "
                                                            "(in "
                                                            "seconds) "
                                                            "for "
                                                            "each "
                                                            "scrape "
                                                            "request.",
                                                            "example": 10,
                                                            "format": "int64",
                                                            "type": "integer",
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "http_client",
                                                            "description": "The "
                                                            "source "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`http_client`.",
                                                            "enum": ["http_client"],
                                                            "example": "http_client",
                                                            "type": "string",
                                                            "x-enum-varnames": ["HTTP_CLIENT"],
                                                        },
                                                    },
                                                    "required": ["id", "type", "decoding"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`logstash` "
                                                    "source "
                                                    "ingests "
                                                    "logs "
                                                    "from "
                                                    "a "
                                                    "Logstash "
                                                    "forwarder.",
                                                    "properties": {
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(e.g., "
                                                            "as "
                                                            "input "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "logstash-source",
                                                            "type": "string",
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "logstash",
                                                            "description": "The "
                                                            "source "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`logstash`.",
                                                            "enum": ["logstash"],
                                                            "example": "logstash",
                                                            "type": "string",
                                                            "x-enum-varnames": ["LOGSTASH"],
                                                        },
                                                    },
                                                    "required": ["id", "type"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "The "
                                                    "`socket` "
                                                    "source "
                                                    "ingests "
                                                    "logs "
                                                    "over "
                                                    "TCP "
                                                    "or "
                                                    "UDP.",
                                                    "properties": {
                                                        "framing": {
                                                            "description": "Framing "
                                                            "method "
                                                            "configuration "
                                                            "for "
                                                            "the "
                                                            "socket "
                                                            "source.",
                                                            "oneOf": [
                                                                {
                                                                    "description": "Byte "
                                                                    "frames "
                                                                    "which "
                                                                    "are "
                                                                    "delimited "
                                                                    "by "
                                                                    "a "
                                                                    "newline "
                                                                    "character.",
                                                                    "properties": {
                                                                        "method": {
                                                                            "description": "Byte "
                                                                            "frames "
                                                                            "which "
                                                                            "are "
                                                                            "delimited "
                                                                            "by "
                                                                            "a "
                                                                            "newline "
                                                                            "character.",
                                                                            "enum": [
                                                                                "newline_delimited"
                                                                            ],
                                                                            "example": "newline_delimited",
                                                                            "type": "string",
                                                                            "x-enum-varnames": [
                                                                                "NEWLINE_DELIMITED"
                                                                            ],
                                                                        }
                                                                    },
                                                                    "required": ["method"],
                                                                    "type": "object",
                                                                },
                                                                {
                                                                    "description": "Byte "
                                                                    "frames "
                                                                    "are "
                                                                    "passed "
                                                                    "through "
                                                                    "as-is "
                                                                    "according "
                                                                    "to "
                                                                    "the "
                                                                    "underlying "
                                                                    "I/O "
                                                                    "boundaries "
                                                                    "(for "
                                                                    "example, "
                                                                    "split "
                                                                    "between "
                                                                    "messages "
                                                                    "or "
                                                                    "stream "
                                                                    "segments).",
                                                                    "properties": {
                                                                        "method": {
                                                                            "description": "Byte "
                                                                            "frames "
                                                                            "are "
                                                                            "passed "
                                                                            "through "
                                                                            "as-is "
                                                                            "according "
                                                                            "to "
                                                                            "the "
                                                                            "underlying "
                                                                            "I/O "
                                                                            "boundaries "
                                                                            "(for "
                                                                            "example, "
                                                                            "split "
                                                                            "between "
                                                                            "messages "
                                                                            "or "
                                                                            "stream "
                                                                            "segments).",
                                                                            "enum": ["bytes"],
                                                                            "example": "bytes",
                                                                            "type": "string",
                                                                            "x-enum-varnames": [
                                                                                "BYTES"
                                                                            ],
                                                                        }
                                                                    },
                                                                    "required": ["method"],
                                                                    "type": "object",
                                                                },
                                                                {
                                                                    "description": "Byte "
                                                                    "frames "
                                                                    "which "
                                                                    "are "
                                                                    "delimited "
                                                                    "by "
                                                                    "a "
                                                                    "chosen "
                                                                    "character.",
                                                                    "properties": {
                                                                        "delimiter": {
                                                                            "description": "A "
                                                                            "single "
                                                                            "ASCII "
                                                                            "character "
                                                                            "used "
                                                                            "to "
                                                                            "delimit "
                                                                            "events.",
                                                                            "example": "|",
                                                                            "maxLength": 1,
                                                                            "minLength": 1,
                                                                            "type": "string",
                                                                        },
                                                                        "method": {
                                                                            "description": "Byte "
                                                                            "frames "
                                                                            "which "
                                                                            "are "
                                                                            "delimited "
                                                                            "by "
                                                                            "a "
                                                                            "chosen "
                                                                            "character.",
                                                                            "enum": [
                                                                                "character_delimited"
                                                                            ],
                                                                            "example": "character_delimited",
                                                                            "type": "string",
                                                                            "x-enum-varnames": [
                                                                                "CHARACTER_DELIMITED"
                                                                            ],
                                                                        },
                                                                    },
                                                                    "required": [
                                                                        "method",
                                                                        "delimiter",
                                                                    ],
                                                                    "type": "object",
                                                                },
                                                                {
                                                                    "description": "Byte "
                                                                    "frames "
                                                                    "according "
                                                                    "to "
                                                                    "the "
                                                                    "octet "
                                                                    "counting "
                                                                    "format "
                                                                    "as "
                                                                    "per "
                                                                    "RFC6587.",
                                                                    "properties": {
                                                                        "method": {
                                                                            "description": "Byte "
                                                                            "frames "
                                                                            "according "
                                                                            "to "
                                                                            "the "
                                                                            "octet "
                                                                            "counting "
                                                                            "format "
                                                                            "as "
                                                                            "per "
                                                                            "RFC6587.",
                                                                            "enum": [
                                                                                "octet_counting"
                                                                            ],
                                                                            "example": "octet_counting",
                                                                            "type": "string",
                                                                            "x-enum-varnames": [
                                                                                "OCTET_COUNTING"
                                                                            ],
                                                                        }
                                                                    },
                                                                    "required": ["method"],
                                                                    "type": "object",
                                                                },
                                                                {
                                                                    "description": "Byte "
                                                                    "frames "
                                                                    "which "
                                                                    "are "
                                                                    "chunked "
                                                                    "GELF "
                                                                    "messages.",
                                                                    "properties": {
                                                                        "method": {
                                                                            "description": "Byte "
                                                                            "frames "
                                                                            "which "
                                                                            "are "
                                                                            "chunked "
                                                                            "GELF "
                                                                            "messages.",
                                                                            "enum": [
                                                                                "chunked_gelf"
                                                                            ],
                                                                            "example": "chunked_gelf",
                                                                            "type": "string",
                                                                            "x-enum-varnames": [
                                                                                "CHUNKED_GELF"
                                                                            ],
                                                                        }
                                                                    },
                                                                    "required": ["method"],
                                                                    "type": "object",
                                                                },
                                                            ],
                                                        },
                                                        "id": {
                                                            "description": "The "
                                                            "unique "
                                                            "identifier "
                                                            "for "
                                                            "this "
                                                            "component. "
                                                            "Used "
                                                            "to "
                                                            "reference "
                                                            "this "
                                                            "component "
                                                            "in "
                                                            "other "
                                                            "parts "
                                                            "of "
                                                            "the "
                                                            "pipeline "
                                                            "(e.g., "
                                                            "as "
                                                            "input "
                                                            "to "
                                                            "downstream "
                                                            "components).",
                                                            "example": "socket-source",
                                                            "type": "string",
                                                        },
                                                        "mode": {
                                                            "description": "Protocol "
                                                            "used "
                                                            "to "
                                                            "receive "
                                                            "logs.",
                                                            "enum": ["tcp", "udp"],
                                                            "example": "tcp",
                                                            "type": "string",
                                                            "x-enum-varnames": ["TCP", "UDP"],
                                                        },
                                                        "tls": {
                                                            "description": "Configuration "
                                                            "for "
                                                            "enabling "
                                                            "TLS "
                                                            "encryption "
                                                            "between "
                                                            "the "
                                                            "pipeline "
                                                            "component "
                                                            "and "
                                                            "external "
                                                            "services.",
                                                            "properties": {
                                                                "ca_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "Certificate "
                                                                    "Authority "
                                                                    "(CA) "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "validate "
                                                                    "the "
                                                                    "server’s "
                                                                    "TLS "
                                                                    "certificate.",
                                                                    "type": "string",
                                                                },
                                                                "crt_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate "
                                                                    "file "
                                                                    "used "
                                                                    "to "
                                                                    "authenticate "
                                                                    "the "
                                                                    "pipeline "
                                                                    "component "
                                                                    "with "
                                                                    "upstream "
                                                                    "or "
                                                                    "downstream "
                                                                    "services.",
                                                                    "example": "/path/to/cert.crt",
                                                                    "type": "string",
                                                                },
                                                                "key_file": {
                                                                    "description": "Path "
                                                                    "to "
                                                                    "the "
                                                                    "private "
                                                                    "key "
                                                                    "file "
                                                                    "associated "
                                                                    "with "
                                                                    "the "
                                                                    "TLS "
                                                                    "client "
                                                                    "certificate. "
                                                                    "Used "
                                                                    "for "
                                                                    "mutual "
                                                                    "TLS "
                                                                    "authentication.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "required": ["crt_file"],
                                                            "type": "object",
                                                        },
                                                        "type": {
                                                            "default": "socket",
                                                            "description": "The "
                                                            "source "
                                                            "type. "
                                                            "The "
                                                            "value "
                                                            "should "
                                                            "always "
                                                            "be "
                                                            "`socket`.",
                                                            "enum": ["socket"],
                                                            "example": "socket",
                                                            "type": "string",
                                                            "x-enum-varnames": ["SOCKET"],
                                                        },
                                                    },
                                                    "required": ["id", "type", "mode", "framing"],
                                                    "type": "object",
                                                },
                                            ],
                                        },
                                        "type": "array",
                                    },
                                },
                                "required": ["sources", "destinations"],
                                "type": "object",
                            },
                            "name": {
                                "description": "Name of the pipeline.",
                                "example": "Main Observability Pipeline",
                                "type": "string",
                            },
                        },
                        "required": ["name", "config"],
                        "type": "object",
                    },
                    "id": {
                        "description": "Unique identifier for the pipeline.",
                        "example": "3fa85f64-5717-4562-b3fc-2c963f66afa6",
                        "type": "string",
                    },
                    "type": {
                        "default": "pipelines",
                        "description": "The resource type "
                        "identifier. For "
                        "pipeline resources, "
                        "this should always be "
                        "set to `pipelines`.",
                        "example": "pipelines",
                        "type": "string",
                    },
                },
                "required": ["id", "type", "attributes"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "UPDATERESTRICTIONPOLICY_REQUEST_BODY_SCHEMA": {
        "description": "Update request for a restriction policy.",
        "properties": {
            "data": {
                "description": "Restriction policy object.",
                "properties": {
                    "attributes": {
                        "description": "Restriction policy attributes.",
                        "example": {"bindings": []},
                        "properties": {
                            "bindings": {
                                "description": "An array of bindings.",
                                "items": {
                                    "description": "Specifies "
                                    "which "
                                    "principals "
                                    "are "
                                    "associated "
                                    "with "
                                    "a "
                                    "relation.",
                                    "properties": {
                                        "principals": {
                                            "description": "An "
                                            "array "
                                            "of "
                                            "principals. "
                                            "A "
                                            "principal "
                                            "is "
                                            "a "
                                            "subject "
                                            "or "
                                            "group "
                                            "of "
                                            "subjects.\n"
                                            "Each "
                                            "principal "
                                            "is "
                                            "formatted "
                                            "as "
                                            "`type:id`. "
                                            "Supported "
                                            "types: "
                                            "`role`, "
                                            "`team`, "
                                            "`user`, "
                                            "and "
                                            "`org`.\n"
                                            "The "
                                            "org "
                                            "ID "
                                            "can "
                                            "be "
                                            "obtained "
                                            "through "
                                            "the "
                                            "api/v2/current_user "
                                            "API.\n"
                                            "The "
                                            "user "
                                            "principal "
                                            "type "
                                            "accepts "
                                            "service "
                                            "account "
                                            "IDs.",
                                            "example": [
                                                "role:00000000-0000-1111-0000-000000000000"
                                            ],
                                            "items": {
                                                "description": "Subject "
                                                "or "
                                                "group "
                                                "of "
                                                "subjects. "
                                                "Each "
                                                "principal "
                                                "is "
                                                "formatted "
                                                "as "
                                                "`type:id`.\n"
                                                "Supported "
                                                "types: "
                                                "`role`, "
                                                "`team`, "
                                                "`user`, "
                                                "and "
                                                "`org`.\n"
                                                "The "
                                                "org "
                                                "ID "
                                                "can "
                                                "be "
                                                "obtained "
                                                "through "
                                                "the "
                                                "api/v2/current_user "
                                                "API.\n"
                                                "The "
                                                "user "
                                                "principal "
                                                "type "
                                                "accepts "
                                                "service "
                                                "account "
                                                "IDs.",
                                                "type": "string",
                                            },
                                            "type": "array",
                                        },
                                        "relation": {
                                            "description": "The role/level of access.",
                                            "example": "editor",
                                            "type": "string",
                                        },
                                    },
                                    "required": ["relation", "principals"],
                                    "type": "object",
                                },
                                "type": "array",
                            }
                        },
                        "required": ["bindings"],
                        "type": "object",
                    },
                    "id": {
                        "description": "The identifier, always "
                        "equivalent to the value "
                        "specified in the "
                        "`resource_id` path "
                        "parameter.",
                        "example": "dashboard:abc-def-ghi",
                        "type": "string",
                    },
                    "type": {
                        "default": "restriction_policy",
                        "description": "Restriction policy type.",
                        "enum": ["restriction_policy"],
                        "example": "restriction_policy",
                        "type": "string",
                        "x-enum-varnames": ["RESTRICTION_POLICY"],
                    },
                },
                "required": ["type", "id", "attributes"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "CREATEROLE_REQUEST_BODY_SCHEMA": {
        "description": "Create a role.",
        "properties": {
            "data": {
                "description": "Data related to the creation of a role.",
                "properties": {
                    "attributes": {
                        "description": "Attributes of the created role.",
                        "properties": {
                            "created_at": {
                                "description": "Creation time of the role.",
                                "format": "date-time",
                                "readOnly": True,
                                "type": "string",
                            },
                            "modified_at": {
                                "description": "Time of last role modification.",
                                "format": "date-time",
                                "readOnly": True,
                                "type": "string",
                            },
                            "name": {
                                "description": "Name of the role.",
                                "example": "developers",
                                "type": "string",
                            },
                        },
                        "required": ["name"],
                        "type": "object",
                    },
                    "relationships": {
                        "description": "Relationships of the role object.",
                        "properties": {
                            "permissions": {
                                "description": "Relationship to multiple permissions objects.",
                                "properties": {
                                    "data": {
                                        "description": "Relationships to permission objects.",
                                        "items": {
                                            "description": "Relationship to permission object.",
                                            "properties": {
                                                "id": {
                                                    "description": "ID of the permission.",
                                                    "type": "string",
                                                },
                                                "type": {
                                                    "default": "permissions",
                                                    "description": "Permissions resource type.",
                                                    "enum": ["permissions"],
                                                    "example": "permissions",
                                                    "type": "string",
                                                    "x-enum-varnames": ["PERMISSIONS"],
                                                },
                                            },
                                            "type": "object",
                                        },
                                        "type": "array",
                                    }
                                },
                                "type": "object",
                            }
                        },
                        "type": "object",
                    },
                    "type": {
                        "default": "roles",
                        "description": "Roles type.",
                        "enum": ["roles"],
                        "example": "roles",
                        "type": "string",
                        "x-enum-varnames": ["ROLES"],
                    },
                },
                "required": ["attributes"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "EDITROLE_REQUEST_BODY_SCHEMA": {
        "description": "Update a role.",
        "properties": {
            "data": {
                "description": "Data related to the update of a role.",
                "properties": {
                    "attributes": {
                        "description": "Attributes of the role.",
                        "properties": {
                            "created_at": {
                                "description": "Creation time of the role.",
                                "format": "date-time",
                                "readOnly": True,
                                "type": "string",
                            },
                            "modified_at": {
                                "description": "Time of last role modification.",
                                "format": "date-time",
                                "readOnly": True,
                                "type": "string",
                            },
                            "name": {"description": "Name of the role.", "type": "string"},
                            "user_count": {
                                "description": "The user count.",
                                "format": "int32",
                                "maximum": 2147483647,
                                "type": "integer",
                            },
                        },
                        "type": "object",
                    },
                    "id": {
                        "description": "The unique identifier of the role.",
                        "example": "00000000-0000-1111-0000-000000000000",
                        "type": "string",
                    },
                    "relationships": {
                        "description": "Relationships of the role object.",
                        "properties": {
                            "permissions": {
                                "description": "Relationship to multiple permissions objects.",
                                "properties": {
                                    "data": {
                                        "description": "Relationships to permission objects.",
                                        "items": {
                                            "description": "Relationship to permission object.",
                                            "properties": {
                                                "id": {
                                                    "description": "ID of the permission.",
                                                    "type": "string",
                                                },
                                                "type": {
                                                    "default": "permissions",
                                                    "description": "Permissions resource type.",
                                                    "enum": ["permissions"],
                                                    "example": "permissions",
                                                    "type": "string",
                                                    "x-enum-varnames": ["PERMISSIONS"],
                                                },
                                            },
                                            "type": "object",
                                        },
                                        "type": "array",
                                    }
                                },
                                "type": "object",
                            }
                        },
                        "type": "object",
                    },
                    "type": {
                        "default": "roles",
                        "description": "Roles type.",
                        "enum": ["roles"],
                        "example": "roles",
                        "type": "string",
                        "x-enum-varnames": ["ROLES"],
                    },
                },
                "required": ["attributes", "type", "id"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "AGGREGATERUMEVENTS_REQUEST_BODY_SCHEMA": {
        "description": "The object sent with the request to retrieve aggregation buckets of "
        "RUM events from your organization.",
        "properties": {
            "compute": {
                "description": "The list of metrics or timeseries to "
                "compute for the retrieved buckets.",
                "items": {
                    "description": "A compute rule to compute metrics or timeseries.",
                    "properties": {
                        "aggregation": {
                            "description": "An aggregation function.",
                            "enum": [
                                "count",
                                "cardinality",
                                "pc75",
                                "pc90",
                                "pc95",
                                "pc98",
                                "pc99",
                                "sum",
                                "min",
                                "max",
                                "avg",
                                "median",
                            ],
                            "example": "pc90",
                            "type": "string",
                            "x-enum-varnames": [
                                "COUNT",
                                "CARDINALITY",
                                "PERCENTILE_75",
                                "PERCENTILE_90",
                                "PERCENTILE_95",
                                "PERCENTILE_98",
                                "PERCENTILE_99",
                                "SUM",
                                "MIN",
                                "MAX",
                                "AVG",
                                "MEDIAN",
                            ],
                        },
                        "interval": {
                            "description": "The "
                            "time "
                            "buckets' "
                            "size "
                            "(only "
                            "used "
                            "for "
                            "type=timeseries)\n"
                            "Defaults "
                            "to a "
                            "resolution "
                            "of "
                            "150 "
                            "points.",
                            "example": "5m",
                            "type": "string",
                        },
                        "metric": {
                            "description": "The metric to use.",
                            "example": "@duration",
                            "type": "string",
                        },
                        "type": {
                            "default": "total",
                            "description": "The type of compute.",
                            "enum": ["timeseries", "total"],
                            "type": "string",
                            "x-enum-varnames": ["TIMESERIES", "TOTAL"],
                        },
                    },
                    "required": ["aggregation"],
                    "type": "object",
                },
                "type": "array",
            },
            "filter": {
                "description": "The search and filter query settings.",
                "properties": {
                    "from": {
                        "default": "now-15m",
                        "description": "The minimum time "
                        "for the requested "
                        "events; supports "
                        "date (in [ISO "
                        "8601](https://www.w3.org/TR/NOTE-datetime) "
                        "format with full "
                        "date, hours, "
                        "minutes, and the "
                        "`Z` UTC indicator - "
                        "seconds and "
                        "fractional seconds "
                        "are optional), "
                        "math, and regular "
                        "timestamps (in "
                        "milliseconds).",
                        "example": "now-15m",
                        "type": "string",
                    },
                    "query": {
                        "default": "*",
                        "description": "The search query following the RUM search syntax.",
                        "example": "@type:session AND @session.type:user",
                        "type": "string",
                    },
                    "to": {
                        "default": "now",
                        "description": "The maximum time for "
                        "the requested events; "
                        "supports date (in "
                        "[ISO "
                        "8601](https://www.w3.org/TR/NOTE-datetime) "
                        "format with full "
                        "date, hours, minutes, "
                        "and the `Z` UTC "
                        "indicator - seconds "
                        "and fractional "
                        "seconds are "
                        "optional), math, and "
                        "regular timestamps "
                        "(in milliseconds).",
                        "example": "now",
                        "type": "string",
                    },
                },
                "type": "object",
            },
            "group_by": {
                "description": "The rules for the group by.",
                "items": {
                    "description": "A group-by rule.",
                    "properties": {
                        "facet": {
                            "description": "The name of the facet to use (required).",
                            "example": "@view.time_spent",
                            "type": "string",
                        },
                        "histogram": {
                            "description": "Used "
                            "to "
                            "perform "
                            "a "
                            "histogram "
                            "computation "
                            "(only "
                            "for "
                            "measure "
                            "facets).\n"
                            "Note: "
                            "At "
                            "most "
                            "100 "
                            "buckets "
                            "are "
                            "allowed, "
                            "the "
                            "number "
                            "of "
                            "buckets "
                            "is "
                            "(max "
                            "- "
                            "min)/interval.",
                            "properties": {
                                "interval": {
                                    "description": "The bin size of the histogram buckets.",
                                    "example": 10,
                                    "format": "double",
                                    "type": "number",
                                },
                                "max": {
                                    "description": "The "
                                    "maximum "
                                    "value "
                                    "for "
                                    "the "
                                    "measure "
                                    "used "
                                    "in "
                                    "the "
                                    "histogram\n"
                                    "(values "
                                    "greater "
                                    "than "
                                    "this "
                                    "one "
                                    "are "
                                    "filtered "
                                    "out).",
                                    "example": 100,
                                    "format": "double",
                                    "type": "number",
                                },
                                "min": {
                                    "description": "The "
                                    "minimum "
                                    "value "
                                    "for "
                                    "the "
                                    "measure "
                                    "used "
                                    "in "
                                    "the "
                                    "histogram\n"
                                    "(values "
                                    "smaller "
                                    "than "
                                    "this "
                                    "one "
                                    "are "
                                    "filtered "
                                    "out).",
                                    "example": 50,
                                    "format": "double",
                                    "type": "number",
                                },
                            },
                            "required": ["interval", "min", "max"],
                            "type": "object",
                        },
                        "limit": {
                            "default": 10,
                            "description": "The maximum buckets to return for this group-by.",
                            "format": "int64",
                            "type": "integer",
                        },
                        "missing": {
                            "description": "The "
                            "value "
                            "to "
                            "use "
                            "for "
                            "logs "
                            "that "
                            "don't "
                            "have "
                            "the "
                            "facet "
                            "used "
                            "to "
                            "group "
                            "by.",
                            "oneOf": [
                                {
                                    "description": "The "
                                    "missing "
                                    "value "
                                    "to "
                                    "use "
                                    "if "
                                    "there "
                                    "is "
                                    "string "
                                    "valued "
                                    "facet.",
                                    "type": "string",
                                },
                                {
                                    "description": "The "
                                    "missing "
                                    "value "
                                    "to "
                                    "use "
                                    "if "
                                    "there "
                                    "is "
                                    "a "
                                    "number "
                                    "valued "
                                    "facet.",
                                    "format": "double",
                                    "type": "number",
                                },
                            ],
                        },
                        "sort": {
                            "description": "A sort rule.",
                            "example": {"aggregation": "count", "order": "asc"},
                            "properties": {
                                "aggregation": {
                                    "description": "An aggregation function.",
                                    "enum": [
                                        "count",
                                        "cardinality",
                                        "pc75",
                                        "pc90",
                                        "pc95",
                                        "pc98",
                                        "pc99",
                                        "sum",
                                        "min",
                                        "max",
                                        "avg",
                                        "median",
                                    ],
                                    "example": "pc90",
                                    "type": "string",
                                    "x-enum-varnames": [
                                        "COUNT",
                                        "CARDINALITY",
                                        "PERCENTILE_75",
                                        "PERCENTILE_90",
                                        "PERCENTILE_95",
                                        "PERCENTILE_98",
                                        "PERCENTILE_99",
                                        "SUM",
                                        "MIN",
                                        "MAX",
                                        "AVG",
                                        "MEDIAN",
                                    ],
                                },
                                "metric": {
                                    "description": "The "
                                    "metric "
                                    "to "
                                    "sort "
                                    "by "
                                    "(only "
                                    "used "
                                    "for "
                                    "`type=measure`).",
                                    "example": "@duration",
                                    "type": "string",
                                },
                                "order": {
                                    "description": "The order to use, ascending or descending.",
                                    "enum": ["asc", "desc"],
                                    "example": "asc",
                                    "type": "string",
                                    "x-enum-varnames": ["ASCENDING", "DESCENDING"],
                                },
                                "type": {
                                    "default": "alphabetical",
                                    "description": "The type of sorting algorithm.",
                                    "enum": ["alphabetical", "measure"],
                                    "type": "string",
                                    "x-enum-varnames": ["ALPHABETICAL", "MEASURE"],
                                },
                            },
                            "type": "object",
                        },
                        "total": {
                            "default": False,
                            "description": "A "
                            "resulting "
                            "object "
                            "to put "
                            "the "
                            "given "
                            "computes "
                            "in "
                            "over "
                            "all "
                            "the "
                            "matching "
                            "records.",
                            "oneOf": [
                                {
                                    "description": "If "
                                    "set "
                                    "to "
                                    "true, "
                                    "creates "
                                    "an "
                                    "additional "
                                    "bucket "
                                    "labeled "
                                    '"$facet_total".',
                                    "type": "boolean",
                                },
                                {
                                    "description": "A "
                                    "string "
                                    "to "
                                    "use "
                                    "as "
                                    "the "
                                    "key "
                                    "value "
                                    "for "
                                    "the "
                                    "total "
                                    "bucket.",
                                    "type": "string",
                                },
                                {
                                    "description": "A "
                                    "number "
                                    "to "
                                    "use "
                                    "as "
                                    "the "
                                    "key "
                                    "value "
                                    "for "
                                    "the "
                                    "total "
                                    "bucket.",
                                    "format": "double",
                                    "type": "number",
                                },
                            ],
                        },
                    },
                    "required": ["facet"],
                    "type": "object",
                },
                "type": "array",
            },
            "options": {
                "description": "Global query options that are used during "
                "the query.\n"
                "Note: Only supply timezone or time offset, "
                "not both. Otherwise, the query fails.",
                "properties": {
                    "time_offset": {
                        "description": "The time offset (in seconds) to apply to the query.",
                        "format": "int64",
                        "type": "integer",
                    },
                    "timezone": {
                        "default": "UTC",
                        "description": "The timezone "
                        "can be "
                        "specified as "
                        "GMT, UTC, an "
                        "offset from "
                        "UTC (like "
                        "UTC+1), or as "
                        "a Timezone "
                        "Database "
                        "identifier "
                        "(like "
                        "America/New_York).",
                        "example": "GMT",
                        "type": "string",
                    },
                },
                "type": "object",
            },
            "page": {
                "description": "Paging attributes for listing events.",
                "properties": {
                    "cursor": {
                        "description": "List following "
                        "results with a "
                        "cursor provided in "
                        "the previous query.",
                        "example": "eyJzdGFydEF0IjoiQVFBQUFYS2tMS3pPbm40NGV3QUFBQUJCV0V0clRFdDZVbG8zY3pCRmNsbHJiVmxDWlEifQ==",
                        "type": "string",
                    },
                    "limit": {
                        "default": 10,
                        "description": "Maximum number of events in the response.",
                        "example": 25,
                        "format": "int32",
                        "maximum": 1000,
                        "type": "integer",
                    },
                },
                "type": "object",
            },
        },
        "type": "object",
    },
    "ORDERRUMRETENTIONFILTERS_REQUEST_BODY_SCHEMA": {
        "description": "The list of RUM retention filter IDs along with their corresponding "
        "type to reorder.\n"
        "All retention filter IDs should be included in the list created for a "
        "RUM application.",
        "properties": {
            "data": {
                "description": "A list of RUM retention filter IDs along with type.",
                "items": {
                    "description": "The RUM retention filter data for ordering.",
                    "properties": {
                        "id": {
                            "description": "ID of retention filter in UUID.",
                            "example": "051601eb-54a0-abc0-03f9-cc02efa18892",
                            "type": "string",
                        },
                        "type": {
                            "default": "retention_filters",
                            "description": "The type of "
                            "the "
                            "resource. "
                            "The value "
                            "should "
                            "always be "
                            "retention_filters.",
                            "enum": ["retention_filters"],
                            "example": "retention_filters",
                            "type": "string",
                            "x-enum-varnames": ["RETENTION_FILTERS"],
                        },
                    },
                    "required": ["id", "type"],
                    "type": "object",
                },
                "type": "array",
            }
        },
        "type": "object",
    },
    "CREATERUMMETRIC_REQUEST_BODY_SCHEMA": {
        "description": "The new rum-based metric body.",
        "properties": {
            "data": {
                "description": "The new rum-based metric properties.",
                "properties": {
                    "attributes": {
                        "description": "The object "
                        "describing the "
                        "Datadog "
                        "rum-based "
                        "metric to "
                        "create.",
                        "properties": {
                            "compute": {
                                "description": "The compute rule to compute the rum-based metric.",
                                "properties": {
                                    "aggregation_type": {
                                        "description": "The type of aggregation to use.",
                                        "enum": ["count", "distribution"],
                                        "example": "distribution",
                                        "type": "string",
                                        "x-enum-varnames": ["COUNT", "DISTRIBUTION"],
                                    },
                                    "include_percentiles": {
                                        "description": "Toggle "
                                        "to "
                                        "include "
                                        "or "
                                        "exclude "
                                        "percentile "
                                        "aggregations "
                                        "for "
                                        "distribution "
                                        "metrics.\n"
                                        "Only "
                                        "present "
                                        "when "
                                        "`aggregation_type` "
                                        "is "
                                        "`distribution`.",
                                        "example": True,
                                        "type": "boolean",
                                    },
                                    "path": {
                                        "description": "The "
                                        "path "
                                        "to "
                                        "the "
                                        "value "
                                        "the "
                                        "rum-based "
                                        "metric "
                                        "will "
                                        "aggregate "
                                        "on.\n"
                                        "Only "
                                        "present "
                                        "when "
                                        "`aggregation_type` "
                                        "is "
                                        "`distribution`.",
                                        "example": "@duration",
                                        "type": "string",
                                    },
                                },
                                "required": ["aggregation_type"],
                                "type": "object",
                            },
                            "event_type": {
                                "description": "The type of RUM events to filter on.",
                                "enum": [
                                    "session",
                                    "view",
                                    "action",
                                    "error",
                                    "resource",
                                    "long_task",
                                    "vital",
                                ],
                                "example": "session",
                                "type": "string",
                                "x-enum-varnames": [
                                    "SESSION",
                                    "VIEW",
                                    "ACTION",
                                    "ERROR",
                                    "RESOURCE",
                                    "LONG_TASK",
                                    "VITAL",
                                ],
                            },
                            "filter": {
                                "description": "The "
                                "rum-based "
                                "metric "
                                "filter. "
                                "Events "
                                "matching "
                                "this "
                                "filter "
                                "will "
                                "be "
                                "aggregated "
                                "in "
                                "this "
                                "metric.",
                                "properties": {
                                    "query": {
                                        "default": "*",
                                        "description": "The "
                                        "search "
                                        "query "
                                        "- "
                                        "following "
                                        "the "
                                        "RUM "
                                        "search "
                                        "syntax.",
                                        "example": "@service:web-ui: ",
                                        "type": "string",
                                    }
                                },
                                "required": ["query"],
                                "type": "object",
                            },
                            "group_by": {
                                "description": "The rules for the group by.",
                                "items": {
                                    "description": "A group by rule.",
                                    "properties": {
                                        "path": {
                                            "description": "The "
                                            "path "
                                            "to "
                                            "the "
                                            "value "
                                            "the "
                                            "rum-based "
                                            "metric "
                                            "will "
                                            "be "
                                            "aggregated "
                                            "over.",
                                            "example": "@browser.name",
                                            "type": "string",
                                        },
                                        "tag_name": {
                                            "description": "Eventual "
                                            "name "
                                            "of "
                                            "the "
                                            "tag "
                                            "that "
                                            "gets "
                                            "created. "
                                            "By "
                                            "default, "
                                            "`path` "
                                            "is "
                                            "used "
                                            "as "
                                            "the "
                                            "tag "
                                            "name.",
                                            "example": "browser_name",
                                            "type": "string",
                                        },
                                    },
                                    "required": ["path"],
                                    "type": "object",
                                },
                                "type": "array",
                            },
                            "uniqueness": {
                                "description": "The "
                                "rule "
                                "to "
                                "count "
                                "updatable "
                                "events. "
                                "Is "
                                "only "
                                "set "
                                "if "
                                "`event_type` "
                                "is "
                                "`sessions` "
                                "or "
                                "`views`.",
                                "properties": {
                                    "when": {
                                        "description": "When "
                                        "to "
                                        "count "
                                        "updatable "
                                        "events. "
                                        "`match` "
                                        "when "
                                        "the "
                                        "event "
                                        "is "
                                        "first "
                                        "seen, "
                                        "or "
                                        "`end` "
                                        "when "
                                        "the "
                                        "event "
                                        "is "
                                        "complete.",
                                        "enum": ["match", "end"],
                                        "example": "match",
                                        "type": "string",
                                        "x-enum-varnames": ["WHEN_MATCH", "WHEN_END"],
                                    }
                                },
                                "required": ["when"],
                                "type": "object",
                            },
                        },
                        "required": ["event_type", "compute"],
                        "type": "object",
                    },
                    "id": {
                        "description": "The name of the rum-based metric.",
                        "example": "rum.sessions.webui.count",
                        "type": "string",
                    },
                    "type": {
                        "default": "rum_metrics",
                        "description": "The type of the "
                        "resource. The value "
                        "should always be "
                        "rum_metrics.",
                        "enum": ["rum_metrics"],
                        "example": "rum_metrics",
                        "type": "string",
                        "x-enum-varnames": ["RUM_METRICS"],
                    },
                },
                "required": ["id", "type", "attributes"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "UPDATERUMMETRIC_REQUEST_BODY_SCHEMA": {
        "description": "The new rum-based metric body.",
        "properties": {
            "data": {
                "description": "The new rum-based metric properties.",
                "properties": {
                    "attributes": {
                        "description": "The rum-based metric properties that will be updated.",
                        "properties": {
                            "compute": {
                                "description": "The compute rule to compute the rum-based metric.",
                                "properties": {
                                    "include_percentiles": {
                                        "description": "Toggle "
                                        "to "
                                        "include "
                                        "or "
                                        "exclude "
                                        "percentile "
                                        "aggregations "
                                        "for "
                                        "distribution "
                                        "metrics.\n"
                                        "Only "
                                        "present "
                                        "when "
                                        "`aggregation_type` "
                                        "is "
                                        "`distribution`.",
                                        "example": True,
                                        "type": "boolean",
                                    }
                                },
                                "type": "object",
                            },
                            "filter": {
                                "description": "The "
                                "rum-based "
                                "metric "
                                "filter. "
                                "Events "
                                "matching "
                                "this "
                                "filter "
                                "will "
                                "be "
                                "aggregated "
                                "in "
                                "this "
                                "metric.",
                                "properties": {
                                    "query": {
                                        "default": "*",
                                        "description": "The "
                                        "search "
                                        "query "
                                        "- "
                                        "following "
                                        "the "
                                        "RUM "
                                        "search "
                                        "syntax.",
                                        "example": "@service:web-ui: ",
                                        "type": "string",
                                    }
                                },
                                "required": ["query"],
                                "type": "object",
                            },
                            "group_by": {
                                "description": "The rules for the group by.",
                                "items": {
                                    "description": "A group by rule.",
                                    "properties": {
                                        "path": {
                                            "description": "The "
                                            "path "
                                            "to "
                                            "the "
                                            "value "
                                            "the "
                                            "rum-based "
                                            "metric "
                                            "will "
                                            "be "
                                            "aggregated "
                                            "over.",
                                            "example": "@browser.name",
                                            "type": "string",
                                        },
                                        "tag_name": {
                                            "description": "Eventual "
                                            "name "
                                            "of "
                                            "the "
                                            "tag "
                                            "that "
                                            "gets "
                                            "created. "
                                            "By "
                                            "default, "
                                            "`path` "
                                            "is "
                                            "used "
                                            "as "
                                            "the "
                                            "tag "
                                            "name.",
                                            "example": "browser_name",
                                            "type": "string",
                                        },
                                    },
                                    "required": ["path"],
                                    "type": "object",
                                },
                                "type": "array",
                            },
                        },
                        "type": "object",
                    },
                    "id": {
                        "description": "The name of the rum-based metric.",
                        "example": "rum.sessions.webui.count",
                        "type": "string",
                    },
                    "type": {
                        "default": "rum_metrics",
                        "description": "The type of the "
                        "resource. The value "
                        "should always be "
                        "rum_metrics.",
                        "enum": ["rum_metrics"],
                        "example": "rum_metrics",
                        "type": "string",
                        "x-enum-varnames": ["RUM_METRICS"],
                    },
                },
                "required": ["type", "attributes"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "UPDATESCORECARDOUTCOMES_REQUEST_BODY_SCHEMA": {
        "description": "Scorecard outcomes batch request.",
        "properties": {
            "data": {
                "description": "Scorecard outcomes batch request data.",
                "properties": {
                    "attributes": {
                        "description": "The JSON:API "
                        "attributes for "
                        "a batched set "
                        "of scorecard "
                        "outcomes.",
                        "properties": {
                            "results": {
                                "description": "Set "
                                "of "
                                "scorecard "
                                "outcomes "
                                "to "
                                "update "
                                "asynchronously.",
                                "items": {
                                    "description": "Scorecard "
                                    "outcome "
                                    "for "
                                    "a "
                                    "single "
                                    "entity "
                                    "and "
                                    "rule.",
                                    "properties": {
                                        "entity_reference": {
                                            "description": "The "
                                            "unique "
                                            "reference "
                                            "for "
                                            "an "
                                            "IDP "
                                            "entity.",
                                            "example": "service:my-service",
                                            "type": "string",
                                        },
                                        "remarks": {
                                            "description": "Any "
                                            "remarks "
                                            "regarding "
                                            "the "
                                            "scorecard "
                                            "rule's "
                                            "evaluation. "
                                            "Supports "
                                            "HTML "
                                            "hyperlinks.",
                                            "example": "See: "
                                            "<a "
                                            'href="https://app.datadoghq.com/services">Services</a>',
                                            "type": "string",
                                        },
                                        "rule_id": {
                                            "description": "The unique ID for a scorecard rule.",
                                            "example": "q8MQxk8TCqrHnWkx",
                                            "type": "string",
                                        },
                                        "state": {
                                            "description": "The state of the rule evaluation.",
                                            "enum": ["pass", "fail", "skip"],
                                            "example": "pass",
                                            "type": "string",
                                            "x-enum-varnames": ["PASS", "FAIL", "SKIP"],
                                        },
                                    },
                                    "required": ["rule_id", "entity_reference", "state"],
                                    "type": "object",
                                },
                                "type": "array",
                            }
                        },
                        "type": "object",
                    },
                    "type": {
                        "default": "batched-outcome",
                        "description": "The JSON:API type for scorecard outcomes.",
                        "enum": ["batched-outcome"],
                        "example": "batched-outcome",
                        "type": "string",
                        "x-enum-varnames": ["BATCHED_OUTCOME"],
                    },
                },
                "type": "object",
            }
        },
        "type": "object",
    },
    "SETSERVICERULEOUTCOMESBATCH_REQUEST_BODY_SCHEMA": {
        "description": "Scorecard outcomes batch request.",
        "properties": {
            "data": {
                "description": "Scorecard outcomes batch request data.",
                "properties": {
                    "attributes": {
                        "description": "The JSON:API "
                        "attributes for "
                        "a batched set "
                        "of scorecard "
                        "outcomes.",
                        "properties": {
                            "results": {
                                "description": "Set of scorecard outcomes to update.",
                                "items": {
                                    "description": "Scorecard "
                                    "outcome "
                                    "for "
                                    "a "
                                    "specific "
                                    "rule, "
                                    "for "
                                    "a "
                                    "given "
                                    "service "
                                    "within "
                                    "a "
                                    "batched "
                                    "update.",
                                    "properties": {
                                        "remarks": {
                                            "description": "Any "
                                            "remarks "
                                            "regarding "
                                            "the "
                                            "scorecard "
                                            "rule's "
                                            "evaluation, "
                                            "and "
                                            "supports "
                                            "HTML "
                                            "hyperlinks.",
                                            "example": "See: "
                                            "<a "
                                            'href="https://app.datadoghq.com/services">Services</a>',
                                            "type": "string",
                                        },
                                        "rule_id": {
                                            "description": "The unique ID for a scorecard rule.",
                                            "example": "q8MQxk8TCqrHnWkx",
                                            "type": "string",
                                        },
                                        "service_name": {
                                            "description": "The "
                                            "unique "
                                            "name "
                                            "for "
                                            "a "
                                            "service "
                                            "in "
                                            "the "
                                            "catalog.",
                                            "example": "my-service",
                                            "type": "string",
                                        },
                                        "state": {
                                            "description": "The state of the rule evaluation.",
                                            "enum": ["pass", "fail", "skip"],
                                            "example": "pass",
                                            "type": "string",
                                            "x-enum-varnames": ["PASS", "FAIL", "SKIP"],
                                        },
                                    },
                                    "required": ["rule_id", "service_name", "state"],
                                    "type": "object",
                                },
                                "type": "array",
                            }
                        },
                        "type": "object",
                    },
                    "type": {
                        "default": "batched-outcome",
                        "description": "The JSON:API type for scorecard outcomes.",
                        "enum": ["batched-outcome"],
                        "example": "batched-outcome",
                        "type": "string",
                        "x-enum-varnames": ["BATCHED_OUTCOME"],
                    },
                },
                "type": "object",
            }
        },
        "type": "object",
    },
    "CREATESCORECARDRULE_REQUEST_BODY_SCHEMA": {
        "description": "Scorecard create rule request.",
        "properties": {
            "data": {
                "description": "Scorecard create rule request data.",
                "properties": {
                    "attributes": {
                        "description": "Details of a rule.",
                        "properties": {
                            "category": {
                                "deprecated": True,
                                "description": "The scorecard name to which this rule must belong.",
                                "type": "string",
                            },
                            "created_at": {
                                "description": "Creation time of the rule outcome.",
                                "format": "date-time",
                                "type": "string",
                            },
                            "custom": {
                                "description": "Defines if the rule is a custom rule.",
                                "type": "boolean",
                            },
                            "description": {
                                "description": "Explanation of the rule.",
                                "type": "string",
                            },
                            "enabled": {
                                "description": "If "
                                "enabled, "
                                "the "
                                "rule "
                                "is "
                                "calculated "
                                "as "
                                "part "
                                "of "
                                "the "
                                "score.",
                                "example": True,
                                "type": "boolean",
                            },
                            "level": {
                                "description": "The maturity level of the rule (1, 2, or 3).",
                                "example": 2,
                                "format": "int32",
                                "maximum": 3,
                                "minimum": 1,
                                "type": "integer",
                            },
                            "modified_at": {
                                "description": "Time of the last rule outcome modification.",
                                "format": "date-time",
                                "type": "string",
                            },
                            "name": {
                                "description": "Name of the rule.",
                                "example": "Team Defined",
                                "type": "string",
                            },
                            "owner": {"description": "Owner of the rule.", "type": "string"},
                            "scorecard_name": {
                                "description": "The scorecard name to which this rule must belong.",
                                "example": "Deployments automated via Deployment Trains",
                                "type": "string",
                            },
                        },
                        "type": "object",
                    },
                    "type": {
                        "default": "rule",
                        "description": "The JSON:API type for scorecard rules.",
                        "enum": ["rule"],
                        "example": "rule",
                        "type": "string",
                        "x-enum-varnames": ["RULE"],
                    },
                },
                "type": "object",
            }
        },
        "type": "object",
    },
    "UPDATESCORECARDRULE_REQUEST_BODY_SCHEMA": {
        "description": "Request to update a scorecard rule.",
        "properties": {
            "data": {
                "description": "Data for the request to update a scorecard rule.",
                "properties": {
                    "attributes": {
                        "description": "Details of a rule.",
                        "properties": {
                            "category": {
                                "deprecated": True,
                                "description": "The scorecard name to which this rule must belong.",
                                "type": "string",
                            },
                            "created_at": {
                                "description": "Creation time of the rule outcome.",
                                "format": "date-time",
                                "type": "string",
                            },
                            "custom": {
                                "description": "Defines if the rule is a custom rule.",
                                "type": "boolean",
                            },
                            "description": {
                                "description": "Explanation of the rule.",
                                "type": "string",
                            },
                            "enabled": {
                                "description": "If "
                                "enabled, "
                                "the "
                                "rule "
                                "is "
                                "calculated "
                                "as "
                                "part "
                                "of "
                                "the "
                                "score.",
                                "example": True,
                                "type": "boolean",
                            },
                            "level": {
                                "description": "The maturity level of the rule (1, 2, or 3).",
                                "example": 2,
                                "format": "int32",
                                "maximum": 3,
                                "minimum": 1,
                                "type": "integer",
                            },
                            "modified_at": {
                                "description": "Time of the last rule outcome modification.",
                                "format": "date-time",
                                "type": "string",
                            },
                            "name": {
                                "description": "Name of the rule.",
                                "example": "Team Defined",
                                "type": "string",
                            },
                            "owner": {"description": "Owner of the rule.", "type": "string"},
                            "scorecard_name": {
                                "description": "The scorecard name to which this rule must belong.",
                                "example": "Deployments automated via Deployment Trains",
                                "type": "string",
                            },
                        },
                        "type": "object",
                    },
                    "type": {
                        "default": "rule",
                        "description": "The JSON:API type for scorecard rules.",
                        "enum": ["rule"],
                        "example": "rule",
                        "type": "string",
                        "x-enum-varnames": ["RULE"],
                    },
                },
                "type": "object",
            }
        },
        "type": "object",
    },
    "CREATECLOUDWORKLOADSECURITYAGENTRULE_REQUEST_BODY_SCHEMA": {
        "description": "Request object that includes the Agent rule to create",
        "properties": {
            "data": {
                "description": "Object for a single Agent rule",
                "properties": {
                    "attributes": {
                        "description": "Create a new Cloud Workload Security Agent rule.",
                        "properties": {
                            "actions": {
                                "description": "The "
                                "array "
                                "of "
                                "actions "
                                "the "
                                "rule "
                                "can "
                                "perform "
                                "if "
                                "triggered",
                                "items": {
                                    "description": "The action the rule can perform if triggered",
                                    "properties": {
                                        "filter": {
                                            "description": "SECL "
                                            "expression "
                                            "used "
                                            "to "
                                            "target "
                                            "the "
                                            "container "
                                            "to "
                                            "apply "
                                            "the "
                                            "action "
                                            "on",
                                            "type": "string",
                                        },
                                        "hash": {
                                            "additionalProperties": {},
                                            "description": "An "
                                            "empty "
                                            "object "
                                            "indicating "
                                            "the "
                                            "hash "
                                            "action",
                                            "type": "object",
                                        },
                                        "kill": {
                                            "description": "Kill "
                                            "system "
                                            "call "
                                            "applied "
                                            "on "
                                            "the "
                                            "container "
                                            "matching "
                                            "the "
                                            "rule",
                                            "properties": {
                                                "signal": {
                                                    "description": "Supported "
                                                    "signals "
                                                    "for "
                                                    "the "
                                                    "kill "
                                                    "system "
                                                    "call",
                                                    "type": "string",
                                                }
                                            },
                                            "type": "object",
                                        },
                                        "metadata": {
                                            "description": "The "
                                            "metadata "
                                            "action "
                                            "applied "
                                            "on "
                                            "the "
                                            "scope "
                                            "matching "
                                            "the "
                                            "rule",
                                            "properties": {
                                                "image_tag": {
                                                    "description": "The "
                                                    "image "
                                                    "tag "
                                                    "of "
                                                    "the "
                                                    "metadata "
                                                    "action",
                                                    "type": "string",
                                                },
                                                "service": {
                                                    "description": "The "
                                                    "service "
                                                    "of "
                                                    "the "
                                                    "metadata "
                                                    "action",
                                                    "type": "string",
                                                },
                                                "short_image": {
                                                    "description": "The "
                                                    "short "
                                                    "image "
                                                    "of "
                                                    "the "
                                                    "metadata "
                                                    "action",
                                                    "type": "string",
                                                },
                                            },
                                            "type": "object",
                                        },
                                        "set": {
                                            "description": "The "
                                            "set "
                                            "action "
                                            "applied "
                                            "on "
                                            "the "
                                            "scope "
                                            "matching "
                                            "the "
                                            "rule",
                                            "properties": {
                                                "append": {
                                                    "description": "Whether "
                                                    "the "
                                                    "value "
                                                    "should "
                                                    "be "
                                                    "appended "
                                                    "to "
                                                    "the "
                                                    "field.",
                                                    "type": "boolean",
                                                },
                                                "default_value": {
                                                    "description": "The "
                                                    "default "
                                                    "value "
                                                    "of "
                                                    "the "
                                                    "set "
                                                    "action",
                                                    "type": "string",
                                                },
                                                "expression": {
                                                    "description": "The "
                                                    "expression "
                                                    "of "
                                                    "the "
                                                    "set "
                                                    "action.",
                                                    "type": "string",
                                                },
                                                "field": {
                                                    "description": "The field of the set action",
                                                    "type": "string",
                                                },
                                                "inherited": {
                                                    "description": "Whether "
                                                    "the "
                                                    "value "
                                                    "should "
                                                    "be "
                                                    "inherited.",
                                                    "type": "boolean",
                                                },
                                                "name": {
                                                    "description": "The name of the set action",
                                                    "type": "string",
                                                },
                                                "scope": {
                                                    "description": "The scope of the set action.",
                                                    "type": "string",
                                                },
                                                "size": {
                                                    "description": "The size of the set action.",
                                                    "format": "int64",
                                                    "type": "integer",
                                                },
                                                "ttl": {
                                                    "description": "The "
                                                    "time "
                                                    "to "
                                                    "live "
                                                    "of "
                                                    "the "
                                                    "set "
                                                    "action.",
                                                    "format": "int64",
                                                    "type": "integer",
                                                },
                                                "value": {
                                                    "description": "The value of the set action",
                                                    "type": "string",
                                                },
                                            },
                                            "type": "object",
                                        },
                                    },
                                    "type": "object",
                                },
                                "nullable": True,
                                "type": "array",
                            },
                            "agent_version": {
                                "description": "Constrain "
                                "the "
                                "rule "
                                "to "
                                "specific "
                                "versions "
                                "of "
                                "the "
                                "Datadog "
                                "Agent.",
                                "type": "string",
                            },
                            "blocking": {
                                "description": "The blocking policies that the rule belongs to.",
                                "items": {"type": "string"},
                                "type": "array",
                            },
                            "description": {
                                "description": "The description of the Agent rule.",
                                "example": "My Agent rule",
                                "type": "string",
                            },
                            "disabled": {
                                "description": "The disabled policies that the rule belongs to.",
                                "items": {"type": "string"},
                                "type": "array",
                            },
                            "enabled": {
                                "description": "Whether the Agent rule is enabled.",
                                "example": True,
                                "type": "boolean",
                            },
                            "expression": {
                                "description": "The SECL expression of the Agent rule.",
                                "example": 'exec.file.name == "sh"',
                                "type": "string",
                            },
                            "filters": {
                                "description": "The platforms the Agent rule is supported on.",
                                "items": {"type": "string"},
                                "type": "array",
                            },
                            "monitoring": {
                                "description": "The monitoring policies that the rule belongs to.",
                                "items": {"type": "string"},
                                "type": "array",
                            },
                            "name": {
                                "description": "The name of the Agent rule.",
                                "example": "my_agent_rule",
                                "type": "string",
                            },
                            "policy_id": {
                                "description": "The "
                                "ID "
                                "of "
                                "the "
                                "policy "
                                "where "
                                "the "
                                "Agent "
                                "rule "
                                "is "
                                "saved.",
                                "example": "a8c8e364-6556-434d-b798-a4c23de29c0b",
                                "type": "string",
                            },
                            "product_tags": {
                                "description": "The list of product tags associated with the rule.",
                                "items": {"type": "string"},
                                "type": "array",
                            },
                            "silent": {
                                "description": "Whether the rule is silent.",
                                "example": False,
                                "type": "boolean",
                            },
                        },
                        "required": ["name", "expression"],
                        "type": "object",
                    },
                    "type": {
                        "default": "agent_rule",
                        "description": "The type of the resource, must always be `agent_rule`",
                        "enum": ["agent_rule"],
                        "example": "agent_rule",
                        "type": "string",
                        "x-enum-varnames": ["AGENT_RULE"],
                    },
                },
                "required": ["attributes", "type"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "UPDATECLOUDWORKLOADSECURITYAGENTRULE_REQUEST_BODY_SCHEMA": {
        "description": "Request object that includes the Agent rule with the attributes to update",
        "properties": {
            "data": {
                "description": "Object for a single Agent rule",
                "properties": {
                    "attributes": {
                        "description": "Update an existing Cloud Workload Security Agent rule",
                        "properties": {
                            "actions": {
                                "description": "The "
                                "array "
                                "of "
                                "actions "
                                "the "
                                "rule "
                                "can "
                                "perform "
                                "if "
                                "triggered",
                                "items": {
                                    "description": "The action the rule can perform if triggered",
                                    "properties": {
                                        "filter": {
                                            "description": "SECL "
                                            "expression "
                                            "used "
                                            "to "
                                            "target "
                                            "the "
                                            "container "
                                            "to "
                                            "apply "
                                            "the "
                                            "action "
                                            "on",
                                            "type": "string",
                                        },
                                        "hash": {
                                            "additionalProperties": {},
                                            "description": "An "
                                            "empty "
                                            "object "
                                            "indicating "
                                            "the "
                                            "hash "
                                            "action",
                                            "type": "object",
                                        },
                                        "kill": {
                                            "description": "Kill "
                                            "system "
                                            "call "
                                            "applied "
                                            "on "
                                            "the "
                                            "container "
                                            "matching "
                                            "the "
                                            "rule",
                                            "properties": {
                                                "signal": {
                                                    "description": "Supported "
                                                    "signals "
                                                    "for "
                                                    "the "
                                                    "kill "
                                                    "system "
                                                    "call",
                                                    "type": "string",
                                                }
                                            },
                                            "type": "object",
                                        },
                                        "metadata": {
                                            "description": "The "
                                            "metadata "
                                            "action "
                                            "applied "
                                            "on "
                                            "the "
                                            "scope "
                                            "matching "
                                            "the "
                                            "rule",
                                            "properties": {
                                                "image_tag": {
                                                    "description": "The "
                                                    "image "
                                                    "tag "
                                                    "of "
                                                    "the "
                                                    "metadata "
                                                    "action",
                                                    "type": "string",
                                                },
                                                "service": {
                                                    "description": "The "
                                                    "service "
                                                    "of "
                                                    "the "
                                                    "metadata "
                                                    "action",
                                                    "type": "string",
                                                },
                                                "short_image": {
                                                    "description": "The "
                                                    "short "
                                                    "image "
                                                    "of "
                                                    "the "
                                                    "metadata "
                                                    "action",
                                                    "type": "string",
                                                },
                                            },
                                            "type": "object",
                                        },
                                        "set": {
                                            "description": "The "
                                            "set "
                                            "action "
                                            "applied "
                                            "on "
                                            "the "
                                            "scope "
                                            "matching "
                                            "the "
                                            "rule",
                                            "properties": {
                                                "append": {
                                                    "description": "Whether "
                                                    "the "
                                                    "value "
                                                    "should "
                                                    "be "
                                                    "appended "
                                                    "to "
                                                    "the "
                                                    "field.",
                                                    "type": "boolean",
                                                },
                                                "default_value": {
                                                    "description": "The "
                                                    "default "
                                                    "value "
                                                    "of "
                                                    "the "
                                                    "set "
                                                    "action",
                                                    "type": "string",
                                                },
                                                "expression": {
                                                    "description": "The "
                                                    "expression "
                                                    "of "
                                                    "the "
                                                    "set "
                                                    "action.",
                                                    "type": "string",
                                                },
                                                "field": {
                                                    "description": "The field of the set action",
                                                    "type": "string",
                                                },
                                                "inherited": {
                                                    "description": "Whether "
                                                    "the "
                                                    "value "
                                                    "should "
                                                    "be "
                                                    "inherited.",
                                                    "type": "boolean",
                                                },
                                                "name": {
                                                    "description": "The name of the set action",
                                                    "type": "string",
                                                },
                                                "scope": {
                                                    "description": "The scope of the set action.",
                                                    "type": "string",
                                                },
                                                "size": {
                                                    "description": "The size of the set action.",
                                                    "format": "int64",
                                                    "type": "integer",
                                                },
                                                "ttl": {
                                                    "description": "The "
                                                    "time "
                                                    "to "
                                                    "live "
                                                    "of "
                                                    "the "
                                                    "set "
                                                    "action.",
                                                    "format": "int64",
                                                    "type": "integer",
                                                },
                                                "value": {
                                                    "description": "The value of the set action",
                                                    "type": "string",
                                                },
                                            },
                                            "type": "object",
                                        },
                                    },
                                    "type": "object",
                                },
                                "nullable": True,
                                "type": "array",
                            },
                            "agent_version": {
                                "description": "Constrain "
                                "the "
                                "rule "
                                "to "
                                "specific "
                                "versions "
                                "of "
                                "the "
                                "Datadog "
                                "Agent",
                                "type": "string",
                            },
                            "blocking": {
                                "description": "The blocking policies that the rule belongs to",
                                "items": {"type": "string"},
                                "type": "array",
                            },
                            "description": {
                                "description": "The description of the Agent rule",
                                "example": "My Agent rule",
                                "type": "string",
                            },
                            "disabled": {
                                "description": "The disabled policies that the rule belongs to",
                                "items": {"type": "string"},
                                "type": "array",
                            },
                            "enabled": {
                                "description": "Whether the Agent rule is enabled",
                                "example": True,
                                "type": "boolean",
                            },
                            "expression": {
                                "description": "The SECL expression of the Agent rule",
                                "example": 'exec.file.name == "sh"',
                                "type": "string",
                            },
                            "monitoring": {
                                "description": "The monitoring policies that the rule belongs to",
                                "items": {"type": "string"},
                                "type": "array",
                            },
                            "policy_id": {
                                "description": "The ID of the policy where the Agent rule is saved",
                                "example": "a8c8e364-6556-434d-b798-a4c23de29c0b",
                                "type": "string",
                            },
                            "product_tags": {
                                "description": "The list of product tags associated with the rule",
                                "items": {"type": "string"},
                                "type": "array",
                            },
                            "silent": {
                                "description": "Whether the rule is silent.",
                                "example": False,
                                "type": "boolean",
                            },
                        },
                        "type": "object",
                    },
                    "id": {
                        "description": "The ID of the Agent rule",
                        "example": "3dd-0uc-h1s",
                        "type": "string",
                    },
                    "type": {
                        "default": "agent_rule",
                        "description": "The type of the resource, must always be `agent_rule`",
                        "enum": ["agent_rule"],
                        "example": "agent_rule",
                        "type": "string",
                        "x-enum-varnames": ["AGENT_RULE"],
                    },
                },
                "required": ["attributes", "type"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "CREATESECURITYFILTER_REQUEST_BODY_SCHEMA": {
        "description": "Request object that includes the security filter that you would like "
        "to create.",
        "properties": {
            "data": {
                "description": "Object for a single security filter.",
                "properties": {
                    "attributes": {
                        "description": "Object "
                        "containing the "
                        "attributes of "
                        "the security "
                        "filter to be "
                        "created.",
                        "properties": {
                            "exclusion_filters": {
                                "description": "Exclusion "
                                "filters "
                                "to "
                                "exclude "
                                "some "
                                "logs "
                                "from "
                                "the "
                                "security "
                                "filter.",
                                "example": [{"name": "Exclude staging", "query": "source:staging"}],
                                "items": {
                                    "description": "Exclusion filter for the security filter.",
                                    "example": {
                                        "name": "Exclude staging",
                                        "query": "source:staging",
                                    },
                                    "properties": {
                                        "name": {
                                            "description": "Exclusion filter name.",
                                            "example": "Exclude staging",
                                            "type": "string",
                                        },
                                        "query": {
                                            "description": "Exclusion "
                                            "filter "
                                            "query. "
                                            "Logs "
                                            "that "
                                            "match "
                                            "this "
                                            "query "
                                            "are "
                                            "excluded "
                                            "from "
                                            "the "
                                            "security "
                                            "filter.",
                                            "example": "source:staging",
                                            "type": "string",
                                        },
                                    },
                                    "required": ["name", "query"],
                                    "type": "object",
                                },
                                "type": "array",
                            },
                            "filtered_data_type": {
                                "description": "The filtered data type.",
                                "enum": ["logs"],
                                "example": "logs",
                                "type": "string",
                                "x-enum-varnames": ["LOGS"],
                            },
                            "is_enabled": {
                                "description": "Whether the security filter is enabled.",
                                "example": True,
                                "type": "boolean",
                            },
                            "name": {
                                "description": "The name of the security filter.",
                                "example": "Custom security filter",
                                "type": "string",
                            },
                            "query": {
                                "description": "The query of the security filter.",
                                "example": "service:api",
                                "type": "string",
                            },
                        },
                        "required": [
                            "name",
                            "query",
                            "exclusion_filters",
                            "filtered_data_type",
                            "is_enabled",
                        ],
                        "type": "object",
                    },
                    "type": {
                        "default": "security_filters",
                        "description": "The type of the "
                        "resource. The value "
                        "should always be "
                        "`security_filters`.",
                        "enum": ["security_filters"],
                        "example": "security_filters",
                        "type": "string",
                        "x-enum-varnames": ["SECURITY_FILTERS"],
                    },
                },
                "required": ["type", "attributes"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "UPDATESECURITYFILTER_REQUEST_BODY_SCHEMA": {
        "description": "The new security filter body.",
        "properties": {
            "data": {
                "description": "The new security filter properties.",
                "properties": {
                    "attributes": {
                        "description": "The security filters properties to be updated.",
                        "properties": {
                            "exclusion_filters": {
                                "description": "Exclusion "
                                "filters "
                                "to "
                                "exclude "
                                "some "
                                "logs "
                                "from "
                                "the "
                                "security "
                                "filter.",
                                "example": [],
                                "items": {
                                    "description": "Exclusion filter for the security filter.",
                                    "example": {
                                        "name": "Exclude staging",
                                        "query": "source:staging",
                                    },
                                    "properties": {
                                        "name": {
                                            "description": "Exclusion filter name.",
                                            "example": "Exclude staging",
                                            "type": "string",
                                        },
                                        "query": {
                                            "description": "Exclusion "
                                            "filter "
                                            "query. "
                                            "Logs "
                                            "that "
                                            "match "
                                            "this "
                                            "query "
                                            "are "
                                            "excluded "
                                            "from "
                                            "the "
                                            "security "
                                            "filter.",
                                            "example": "source:staging",
                                            "type": "string",
                                        },
                                    },
                                    "required": ["name", "query"],
                                    "type": "object",
                                },
                                "type": "array",
                            },
                            "filtered_data_type": {
                                "description": "The filtered data type.",
                                "enum": ["logs"],
                                "example": "logs",
                                "type": "string",
                                "x-enum-varnames": ["LOGS"],
                            },
                            "is_enabled": {
                                "description": "Whether the security filter is enabled.",
                                "example": True,
                                "type": "boolean",
                            },
                            "name": {
                                "description": "The name of the security filter.",
                                "example": "Custom security filter",
                                "type": "string",
                            },
                            "query": {
                                "description": "The query of the security filter.",
                                "example": "service:api",
                                "type": "string",
                            },
                            "version": {
                                "description": "The version of the security filter to update.",
                                "example": 1,
                                "format": "int32",
                                "maximum": 2147483647,
                                "type": "integer",
                            },
                        },
                        "type": "object",
                    },
                    "type": {
                        "default": "security_filters",
                        "description": "The type of the "
                        "resource. The value "
                        "should always be "
                        "`security_filters`.",
                        "enum": ["security_filters"],
                        "example": "security_filters",
                        "type": "string",
                        "x-enum-varnames": ["SECURITY_FILTERS"],
                    },
                },
                "required": ["type", "attributes"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "GETFUTURERULESUPPRESSIONS_REQUEST_BODY_SCHEMA": {
        "description": "Create a new rule.",
        "oneOf": [
            {
                "description": "Create a new rule.",
                "properties": {
                    "calculatedFields": {
                        "description": "Calculated fields. "
                        "Only allowed for "
                        "scheduled rules - in "
                        "other words, when "
                        "schedulingOptions is "
                        "also defined.",
                        "items": {
                            "description": "Calculated field.",
                            "properties": {
                                "expression": {
                                    "description": "Expression.",
                                    "example": "@request_end_timestamp - @request_start_timestamp",
                                    "type": "string",
                                },
                                "name": {
                                    "description": "Field name.",
                                    "example": "response_time",
                                    "type": "string",
                                },
                            },
                            "required": ["name", "expression"],
                            "type": "object",
                        },
                        "type": "array",
                    },
                    "cases": {
                        "description": "Cases for generating signals.",
                        "example": [],
                        "items": {
                            "description": "Case when signal is generated.",
                            "properties": {
                                "actions": {
                                    "description": "Action to perform for each rule case.",
                                    "items": {
                                        "description": "Action "
                                        "to "
                                        "perform "
                                        "when "
                                        "a "
                                        "signal "
                                        "is "
                                        "triggered. "
                                        "Only "
                                        "available "
                                        "for "
                                        "Application "
                                        "Security "
                                        "rule "
                                        "type.",
                                        "properties": {
                                            "options": {
                                                "additionalProperties": {},
                                                "description": "Options for the rule action",
                                                "properties": {
                                                    "duration": {
                                                        "description": "Duration "
                                                        "of "
                                                        "the "
                                                        "action "
                                                        "in "
                                                        "seconds. "
                                                        "0 "
                                                        "indicates "
                                                        "no "
                                                        "expiration.",
                                                        "example": 0,
                                                        "format": "int64",
                                                        "minimum": 0,
                                                        "type": "integer",
                                                    },
                                                    "flaggedIPType": {
                                                        "description": "Used "
                                                        "with "
                                                        "the "
                                                        "case "
                                                        "action "
                                                        "of "
                                                        "type "
                                                        "'flag_ip'. "
                                                        "The "
                                                        "value "
                                                        "specified "
                                                        "in "
                                                        "this "
                                                        "field "
                                                        "is "
                                                        "applied "
                                                        "as "
                                                        "a "
                                                        "flag "
                                                        "to "
                                                        "the "
                                                        "IP "
                                                        "addresses.",
                                                        "enum": ["SUSPICIOUS", "FLAGGED"],
                                                        "example": "FLAGGED",
                                                        "type": "string",
                                                        "x-enum-varnames": [
                                                            "SUSPICIOUS",
                                                            "FLAGGED",
                                                        ],
                                                    },
                                                    "userBehaviorName": {
                                                        "description": "Used "
                                                        "with "
                                                        "the "
                                                        "case "
                                                        "action "
                                                        "of "
                                                        "type "
                                                        "'user_behavior'. "
                                                        "The "
                                                        "value "
                                                        "specified "
                                                        "in "
                                                        "this "
                                                        "field "
                                                        "is "
                                                        "applied "
                                                        "as "
                                                        "a "
                                                        "risk "
                                                        "tag "
                                                        "to "
                                                        "all "
                                                        "users "
                                                        "affected "
                                                        "by "
                                                        "the "
                                                        "rule.",
                                                        "type": "string",
                                                    },
                                                },
                                                "type": "object",
                                            },
                                            "type": {
                                                "description": "The action type.",
                                                "enum": [
                                                    "block_ip",
                                                    "block_user",
                                                    "user_behavior",
                                                    "flag_ip",
                                                ],
                                                "type": "string",
                                                "x-enum-varnames": [
                                                    "BLOCK_IP",
                                                    "BLOCK_USER",
                                                    "USER_BEHAVIOR",
                                                    "FLAG_IP",
                                                ],
                                            },
                                        },
                                        "type": "object",
                                    },
                                    "type": "array",
                                },
                                "condition": {
                                    "description": "A "
                                    "case "
                                    "contains "
                                    "logical "
                                    "operations "
                                    "(`>`,`>=`, "
                                    "`&&`, "
                                    "`||`) "
                                    "to "
                                    "determine "
                                    "if "
                                    "a "
                                    "signal "
                                    "should "
                                    "be "
                                    "generated\n"
                                    "based "
                                    "on "
                                    "the "
                                    "event "
                                    "counts "
                                    "in "
                                    "the "
                                    "previously "
                                    "defined "
                                    "queries.",
                                    "type": "string",
                                },
                                "name": {"description": "Name of the case.", "type": "string"},
                                "notifications": {
                                    "description": "Notification targets.",
                                    "items": {"description": "Notification.", "type": "string"},
                                    "type": "array",
                                },
                                "status": {
                                    "description": "Severity of the Security Signal.",
                                    "enum": ["info", "low", "medium", "high", "critical"],
                                    "example": "critical",
                                    "type": "string",
                                    "x-enum-varnames": [
                                        "INFO",
                                        "LOW",
                                        "MEDIUM",
                                        "HIGH",
                                        "CRITICAL",
                                    ],
                                },
                            },
                            "required": ["status"],
                            "type": "object",
                        },
                        "type": "array",
                    },
                    "filters": {
                        "description": "Additional queries to filter "
                        "matched events before they are "
                        "processed. This field is "
                        "deprecated for log detection, "
                        "signal correlation, and "
                        "workload security rules.",
                        "items": {
                            "description": "The rule's suppression filter.",
                            "properties": {
                                "action": {
                                    "description": "The type of filtering action.",
                                    "enum": ["require", "suppress"],
                                    "type": "string",
                                    "x-enum-varnames": ["REQUIRE", "SUPPRESS"],
                                },
                                "query": {
                                    "description": "Query "
                                    "for "
                                    "selecting "
                                    "logs "
                                    "to "
                                    "apply "
                                    "the "
                                    "filtering "
                                    "action.",
                                    "type": "string",
                                },
                            },
                            "type": "object",
                        },
                        "type": "array",
                    },
                    "groupSignalsBy": {
                        "description": "Additional grouping to "
                        "perform on top of the "
                        "existing groups in the "
                        "query section. Must be a "
                        "subset of the existing "
                        "groups.",
                        "example": ["service"],
                        "items": {"description": "Field to group by.", "type": "string"},
                        "type": "array",
                    },
                    "hasExtendedTitle": {
                        "description": "Whether the "
                        "notifications include "
                        "the triggering "
                        "group-by values in "
                        "their title.",
                        "example": True,
                        "type": "boolean",
                    },
                    "isEnabled": {
                        "description": "Whether the rule is enabled.",
                        "example": True,
                        "type": "boolean",
                    },
                    "message": {
                        "description": "Message for generated signals.",
                        "example": "",
                        "type": "string",
                    },
                    "name": {
                        "description": "The name of the rule.",
                        "example": "My security monitoring rule.",
                        "type": "string",
                    },
                    "options": {
                        "description": "Options.",
                        "properties": {
                            "complianceRuleOptions": {
                                "additionalProperties": {},
                                "description": "Options "
                                "for "
                                "cloud_configuration "
                                "rules.\n"
                                "Fields "
                                "`resourceType` "
                                "and "
                                "`regoRule` "
                                "are "
                                "mandatory "
                                "when "
                                "managing "
                                "custom "
                                "`cloud_configuration` "
                                "rules.",
                                "properties": {
                                    "complexRule": {
                                        "description": "Whether "
                                        "the "
                                        "rule "
                                        "is "
                                        "a "
                                        "complex "
                                        "one.\n"
                                        "Must "
                                        "be "
                                        "set "
                                        "to "
                                        "true "
                                        "if "
                                        "`regoRule.resourceTypes` "
                                        "contains "
                                        "more "
                                        "than "
                                        "one "
                                        "item. "
                                        "Defaults "
                                        "to "
                                        "false.",
                                        "type": "boolean",
                                    },
                                    "regoRule": {
                                        "description": "Rule details.",
                                        "properties": {
                                            "policy": {
                                                "description": "The "
                                                "policy "
                                                "written "
                                                "in "
                                                "`rego`, "
                                                "see: "
                                                "https://www.openpolicyagent.org/docs/latest/policy-language/",
                                                "example": "package "
                                                "datadog\n"
                                                "\n"
                                                "import "
                                                "data.datadog.output "
                                                "as "
                                                "dd_output\n"
                                                "import "
                                                "future.keywords.contains\n"
                                                "import "
                                                "future.keywords.if\n"
                                                "import "
                                                "future.keywords.in\n"
                                                "\n"
                                                "eval(resource) "
                                                "= "
                                                '"skip" '
                                                "if "
                                                "{\n"
                                                "  "
                                                "# "
                                                "Logic "
                                                "that "
                                                "evaluates "
                                                "to "
                                                "true "
                                                "if "
                                                "the "
                                                "resource "
                                                "should "
                                                "be "
                                                "skipped\n"
                                                "  "
                                                "true\n"
                                                "} "
                                                "else "
                                                "= "
                                                '"pass" '
                                                "{\n"
                                                "  "
                                                "# "
                                                "Logic "
                                                "that "
                                                "evaluates "
                                                "to "
                                                "true "
                                                "if "
                                                "the "
                                                "resource "
                                                "is "
                                                "compliant\n"
                                                "  "
                                                "true\n"
                                                "} "
                                                "else "
                                                "= "
                                                '"fail" '
                                                "{\n"
                                                "  "
                                                "# "
                                                "Logic "
                                                "that "
                                                "evaluates "
                                                "to "
                                                "true "
                                                "if "
                                                "the "
                                                "resource "
                                                "is "
                                                "not "
                                                "compliant\n"
                                                "  "
                                                "true\n"
                                                "}\n"
                                                "\n"
                                                "# "
                                                "This "
                                                "part "
                                                "remains "
                                                "unchanged "
                                                "for "
                                                "all "
                                                "rules\n"
                                                "results "
                                                "contains "
                                                "result "
                                                "if "
                                                "{\n"
                                                "  "
                                                "some "
                                                "resource "
                                                "in "
                                                "input.resources[input.main_resource_type]\n"
                                                "  "
                                                "result "
                                                ":= "
                                                "dd_output.format(resource, "
                                                "eval(resource))\n"
                                                "}",
                                                "type": "string",
                                            },
                                            "resourceTypes": {
                                                "description": "List "
                                                "of "
                                                "resource "
                                                "types "
                                                "that "
                                                "will "
                                                "be "
                                                "evaluated "
                                                "upon. "
                                                "Must "
                                                "have "
                                                "at "
                                                "least "
                                                "one "
                                                "element.",
                                                "example": [
                                                    "gcp_iam_service_account",
                                                    "gcp_iam_policy",
                                                ],
                                                "items": {"type": "string"},
                                                "type": "array",
                                            },
                                        },
                                        "required": ["policy", "resourceTypes"],
                                        "type": "object",
                                    },
                                    "resourceType": {
                                        "description": "Main "
                                        "resource "
                                        "type "
                                        "to "
                                        "be "
                                        "checked "
                                        "by "
                                        "the "
                                        "rule. "
                                        "It "
                                        "should "
                                        "be "
                                        "specified "
                                        "again "
                                        "in "
                                        "`regoRule.resourceTypes`.",
                                        "example": "aws_acm",
                                        "type": "string",
                                    },
                                },
                                "type": "object",
                            },
                            "decreaseCriticalityBasedOnEnv": {
                                "description": "If "
                                "true, "
                                "signals "
                                "in "
                                "non-production "
                                "environments "
                                "have "
                                "a "
                                "lower "
                                "severity "
                                "than "
                                "what "
                                "is "
                                "defined "
                                "by "
                                "the "
                                "rule "
                                "case, "
                                "which "
                                "can "
                                "reduce "
                                "signal "
                                "noise.\n"
                                "The "
                                "severity "
                                "is "
                                "decreased "
                                "by "
                                "one "
                                "level: "
                                "`CRITICAL` "
                                "in "
                                "production "
                                "becomes "
                                "`HIGH` "
                                "in "
                                "non-production, "
                                "`HIGH` "
                                "becomes "
                                "`MEDIUM` "
                                "and "
                                "so "
                                "on. "
                                "`INFO` "
                                "remains "
                                "`INFO`.\n"
                                "The "
                                "decrement "
                                "is "
                                "applied "
                                "when "
                                "the "
                                "environment "
                                "tag "
                                "of "
                                "the "
                                "signal "
                                "starts "
                                "with "
                                "`staging`, "
                                "`test` "
                                "or "
                                "`dev`.",
                                "example": False,
                                "type": "boolean",
                            },
                            "detectionMethod": {
                                "description": "The detection method.",
                                "enum": [
                                    "threshold",
                                    "new_value",
                                    "anomaly_detection",
                                    "impossible_travel",
                                    "hardcoded",
                                    "third_party",
                                    "anomaly_threshold",
                                    "sequence_detection",
                                ],
                                "type": "string",
                                "x-enum-varnames": [
                                    "THRESHOLD",
                                    "NEW_VALUE",
                                    "ANOMALY_DETECTION",
                                    "IMPOSSIBLE_TRAVEL",
                                    "HARDCODED",
                                    "THIRD_PARTY",
                                    "ANOMALY_THRESHOLD",
                                    "SEQUENCE_DETECTION",
                                ],
                            },
                            "evaluationWindow": {
                                "description": "A "
                                "time "
                                "window "
                                "is "
                                "specified "
                                "to "
                                "match "
                                "when "
                                "at "
                                "least "
                                "one "
                                "of "
                                "the "
                                "cases "
                                "matches "
                                "true. "
                                "This "
                                "is "
                                "a "
                                "sliding "
                                "window\n"
                                "and "
                                "evaluates "
                                "in "
                                "real "
                                "time. "
                                "For "
                                "third "
                                "party "
                                "detection "
                                "method, "
                                "this "
                                "field "
                                "is "
                                "not "
                                "used.",
                                "enum": [
                                    0,
                                    60,
                                    300,
                                    600,
                                    900,
                                    1800,
                                    3600,
                                    7200,
                                    10800,
                                    21600,
                                    43200,
                                    86400,
                                ],
                                "format": "int32",
                                "type": "integer",
                                "x-enum-varnames": [
                                    "ZERO_MINUTES",
                                    "ONE_MINUTE",
                                    "FIVE_MINUTES",
                                    "TEN_MINUTES",
                                    "FIFTEEN_MINUTES",
                                    "THIRTY_MINUTES",
                                    "ONE_HOUR",
                                    "TWO_HOURS",
                                    "THREE_HOURS",
                                    "SIX_HOURS",
                                    "TWELVE_HOURS",
                                    "ONE_DAY",
                                ],
                            },
                            "hardcodedEvaluatorType": {
                                "description": "Hardcoded evaluator type.",
                                "enum": ["log4shell"],
                                "type": "string",
                                "x-enum-varnames": ["LOG4SHELL"],
                            },
                            "impossibleTravelOptions": {
                                "description": "Options on impossible travel detection method.",
                                "properties": {
                                    "baselineUserLocations": {
                                        "description": "If "
                                        "true, "
                                        "signals "
                                        "are "
                                        "suppressed "
                                        "for "
                                        "the "
                                        "first "
                                        "24 "
                                        "hours. "
                                        "In "
                                        "that "
                                        "time, "
                                        "Datadog "
                                        "learns "
                                        "the "
                                        "user's "
                                        "regular\n"
                                        "access "
                                        "locations. "
                                        "This "
                                        "can "
                                        "be "
                                        "helpful "
                                        "to "
                                        "reduce "
                                        "noise "
                                        "and "
                                        "infer "
                                        "VPN "
                                        "usage "
                                        "or "
                                        "credentialed "
                                        "API "
                                        "access.",
                                        "example": True,
                                        "type": "boolean",
                                    }
                                },
                                "type": "object",
                            },
                            "keepAlive": {
                                "description": "Once "
                                "a "
                                "signal "
                                "is "
                                "generated, "
                                "the "
                                "signal "
                                "will "
                                "remain "
                                '"open" '
                                "if "
                                "a "
                                "case "
                                "is "
                                "matched "
                                "at "
                                "least "
                                "once "
                                "within\n"
                                "this "
                                "keep "
                                "alive "
                                "window. "
                                "For "
                                "third "
                                "party "
                                "detection "
                                "method, "
                                "this "
                                "field "
                                "is "
                                "not "
                                "used.",
                                "enum": [
                                    0,
                                    60,
                                    300,
                                    600,
                                    900,
                                    1800,
                                    3600,
                                    7200,
                                    10800,
                                    21600,
                                    43200,
                                    86400,
                                ],
                                "format": "int32",
                                "type": "integer",
                                "x-enum-varnames": [
                                    "ZERO_MINUTES",
                                    "ONE_MINUTE",
                                    "FIVE_MINUTES",
                                    "TEN_MINUTES",
                                    "FIFTEEN_MINUTES",
                                    "THIRTY_MINUTES",
                                    "ONE_HOUR",
                                    "TWO_HOURS",
                                    "THREE_HOURS",
                                    "SIX_HOURS",
                                    "TWELVE_HOURS",
                                    "ONE_DAY",
                                ],
                            },
                            "maxSignalDuration": {
                                "description": "A "
                                "signal "
                                "will "
                                '"close" '
                                "regardless "
                                "of "
                                "the "
                                "query "
                                "being "
                                "matched "
                                "once "
                                "the "
                                "time "
                                "exceeds "
                                "the "
                                "maximum "
                                "duration.\n"
                                "This "
                                "time "
                                "is "
                                "calculated "
                                "from "
                                "the "
                                "first "
                                "seen "
                                "timestamp.",
                                "enum": [
                                    0,
                                    60,
                                    300,
                                    600,
                                    900,
                                    1800,
                                    3600,
                                    7200,
                                    10800,
                                    21600,
                                    43200,
                                    86400,
                                ],
                                "format": "int32",
                                "type": "integer",
                                "x-enum-varnames": [
                                    "ZERO_MINUTES",
                                    "ONE_MINUTE",
                                    "FIVE_MINUTES",
                                    "TEN_MINUTES",
                                    "FIFTEEN_MINUTES",
                                    "THIRTY_MINUTES",
                                    "ONE_HOUR",
                                    "TWO_HOURS",
                                    "THREE_HOURS",
                                    "SIX_HOURS",
                                    "TWELVE_HOURS",
                                    "ONE_DAY",
                                ],
                            },
                            "newValueOptions": {
                                "description": "Options on new value detection method.",
                                "properties": {
                                    "forgetAfter": {
                                        "description": "The "
                                        "duration "
                                        "in "
                                        "days "
                                        "after "
                                        "which "
                                        "a "
                                        "learned "
                                        "value "
                                        "is "
                                        "forgotten.",
                                        "enum": [1, 2, 7, 14, 21, 28],
                                        "format": "int32",
                                        "type": "integer",
                                        "x-enum-varnames": [
                                            "ONE_DAY",
                                            "TWO_DAYS",
                                            "ONE_WEEK",
                                            "TWO_WEEKS",
                                            "THREE_WEEKS",
                                            "FOUR_WEEKS",
                                        ],
                                    },
                                    "learningDuration": {
                                        "default": 0,
                                        "description": "The "
                                        "duration "
                                        "in "
                                        "days "
                                        "during "
                                        "which "
                                        "values "
                                        "are "
                                        "learned, "
                                        "and "
                                        "after "
                                        "which "
                                        "signals "
                                        "will "
                                        "be "
                                        "generated "
                                        "for "
                                        "values "
                                        "that\n"
                                        "weren't "
                                        "learned. "
                                        "If "
                                        "set "
                                        "to "
                                        "0, "
                                        "a "
                                        "signal "
                                        "will "
                                        "be "
                                        "generated "
                                        "for "
                                        "all "
                                        "new "
                                        "values "
                                        "after "
                                        "the "
                                        "first "
                                        "value "
                                        "is "
                                        "learned.",
                                        "enum": [0, 1, 7],
                                        "format": "int32",
                                        "type": "integer",
                                        "x-enum-varnames": ["ZERO_DAYS", "ONE_DAY", "SEVEN_DAYS"],
                                    },
                                    "learningMethod": {
                                        "default": "duration",
                                        "description": "The "
                                        "learning "
                                        "method "
                                        "used "
                                        "to "
                                        "determine "
                                        "when "
                                        "signals "
                                        "should "
                                        "be "
                                        "generated "
                                        "for "
                                        "values "
                                        "that "
                                        "weren't "
                                        "learned.",
                                        "enum": ["duration", "threshold"],
                                        "type": "string",
                                        "x-enum-varnames": ["DURATION", "THRESHOLD"],
                                    },
                                    "learningThreshold": {
                                        "default": 0,
                                        "description": "A "
                                        "number "
                                        "of "
                                        "occurrences "
                                        "after "
                                        "which "
                                        "signals "
                                        "will "
                                        "be "
                                        "generated "
                                        "for "
                                        "values "
                                        "that "
                                        "weren't "
                                        "learned.",
                                        "enum": [0, 1],
                                        "format": "int32",
                                        "type": "integer",
                                        "x-enum-varnames": ["ZERO_OCCURRENCES", "ONE_OCCURRENCE"],
                                    },
                                },
                                "type": "object",
                            },
                            "sequenceDetectionOptions": {
                                "description": "Options on sequence detection method.",
                                "properties": {
                                    "stepTransitions": {
                                        "description": "Transitions "
                                        "defining "
                                        "the "
                                        "allowed "
                                        "order "
                                        "of "
                                        "steps "
                                        "and "
                                        "their "
                                        "evaluation "
                                        "windows.",
                                        "items": {
                                            "description": "Transition "
                                            "from "
                                            "a "
                                            "parent "
                                            "step "
                                            "to "
                                            "a "
                                            "child "
                                            "step "
                                            "within "
                                            "a "
                                            "sequence "
                                            "detection "
                                            "rule.",
                                            "properties": {
                                                "child": {
                                                    "description": "Name of the child step.",
                                                    "type": "string",
                                                },
                                                "evaluationWindow": {
                                                    "description": "A "
                                                    "time "
                                                    "window "
                                                    "is "
                                                    "specified "
                                                    "to "
                                                    "match "
                                                    "when "
                                                    "at "
                                                    "least "
                                                    "one "
                                                    "of "
                                                    "the "
                                                    "cases "
                                                    "matches "
                                                    "true. "
                                                    "This "
                                                    "is "
                                                    "a "
                                                    "sliding "
                                                    "window\n"
                                                    "and "
                                                    "evaluates "
                                                    "in "
                                                    "real "
                                                    "time. "
                                                    "For "
                                                    "third "
                                                    "party "
                                                    "detection "
                                                    "method, "
                                                    "this "
                                                    "field "
                                                    "is "
                                                    "not "
                                                    "used.",
                                                    "enum": [
                                                        0,
                                                        60,
                                                        300,
                                                        600,
                                                        900,
                                                        1800,
                                                        3600,
                                                        7200,
                                                        10800,
                                                        21600,
                                                        43200,
                                                        86400,
                                                    ],
                                                    "format": "int32",
                                                    "type": "integer",
                                                    "x-enum-varnames": [
                                                        "ZERO_MINUTES",
                                                        "ONE_MINUTE",
                                                        "FIVE_MINUTES",
                                                        "TEN_MINUTES",
                                                        "FIFTEEN_MINUTES",
                                                        "THIRTY_MINUTES",
                                                        "ONE_HOUR",
                                                        "TWO_HOURS",
                                                        "THREE_HOURS",
                                                        "SIX_HOURS",
                                                        "TWELVE_HOURS",
                                                        "ONE_DAY",
                                                    ],
                                                },
                                                "parent": {
                                                    "description": "Name of the parent step.",
                                                    "type": "string",
                                                },
                                            },
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "steps": {
                                        "description": "Steps "
                                        "that "
                                        "define "
                                        "the "
                                        "conditions "
                                        "to "
                                        "be "
                                        "matched "
                                        "in "
                                        "sequence.",
                                        "items": {
                                            "description": "Step "
                                            "definition "
                                            "for "
                                            "sequence "
                                            "detection "
                                            "containing "
                                            "the "
                                            "step "
                                            "name, "
                                            "condition, "
                                            "and "
                                            "evaluation "
                                            "window.",
                                            "properties": {
                                                "condition": {
                                                    "description": "Condition "
                                                    "referencing "
                                                    "rule "
                                                    "queries "
                                                    "(e.g., "
                                                    "`a "
                                                    "> "
                                                    "0`).",
                                                    "type": "string",
                                                },
                                                "evaluationWindow": {
                                                    "description": "A "
                                                    "time "
                                                    "window "
                                                    "is "
                                                    "specified "
                                                    "to "
                                                    "match "
                                                    "when "
                                                    "at "
                                                    "least "
                                                    "one "
                                                    "of "
                                                    "the "
                                                    "cases "
                                                    "matches "
                                                    "true. "
                                                    "This "
                                                    "is "
                                                    "a "
                                                    "sliding "
                                                    "window\n"
                                                    "and "
                                                    "evaluates "
                                                    "in "
                                                    "real "
                                                    "time. "
                                                    "For "
                                                    "third "
                                                    "party "
                                                    "detection "
                                                    "method, "
                                                    "this "
                                                    "field "
                                                    "is "
                                                    "not "
                                                    "used.",
                                                    "enum": [
                                                        0,
                                                        60,
                                                        300,
                                                        600,
                                                        900,
                                                        1800,
                                                        3600,
                                                        7200,
                                                        10800,
                                                        21600,
                                                        43200,
                                                        86400,
                                                    ],
                                                    "format": "int32",
                                                    "type": "integer",
                                                    "x-enum-varnames": [
                                                        "ZERO_MINUTES",
                                                        "ONE_MINUTE",
                                                        "FIVE_MINUTES",
                                                        "TEN_MINUTES",
                                                        "FIFTEEN_MINUTES",
                                                        "THIRTY_MINUTES",
                                                        "ONE_HOUR",
                                                        "TWO_HOURS",
                                                        "THREE_HOURS",
                                                        "SIX_HOURS",
                                                        "TWELVE_HOURS",
                                                        "ONE_DAY",
                                                    ],
                                                },
                                                "name": {
                                                    "description": "Unique "
                                                    "name "
                                                    "identifying "
                                                    "the "
                                                    "step.",
                                                    "type": "string",
                                                },
                                            },
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                },
                                "type": "object",
                            },
                            "thirdPartyRuleOptions": {
                                "description": "Options on third party detection method.",
                                "properties": {
                                    "defaultNotifications": {
                                        "description": "Notification "
                                        "targets "
                                        "for "
                                        "the "
                                        "logs "
                                        "that "
                                        "do "
                                        "not "
                                        "correspond "
                                        "to "
                                        "any "
                                        "of "
                                        "the "
                                        "cases.",
                                        "items": {"description": "Notification.", "type": "string"},
                                        "type": "array",
                                    },
                                    "defaultStatus": {
                                        "description": "Severity of the Security Signal.",
                                        "enum": ["info", "low", "medium", "high", "critical"],
                                        "example": "critical",
                                        "type": "string",
                                        "x-enum-varnames": [
                                            "INFO",
                                            "LOW",
                                            "MEDIUM",
                                            "HIGH",
                                            "CRITICAL",
                                        ],
                                    },
                                    "rootQueries": {
                                        "description": "Queries "
                                        "to "
                                        "be "
                                        "combined "
                                        "with "
                                        "third "
                                        "party "
                                        "case "
                                        "queries. "
                                        "Each "
                                        "of "
                                        "them "
                                        "can "
                                        "have "
                                        "different "
                                        "group "
                                        "by "
                                        "fields, "
                                        "to "
                                        "aggregate "
                                        "differently "
                                        "based "
                                        "on "
                                        "the "
                                        "type "
                                        "of "
                                        "alert.",
                                        "items": {
                                            "description": "A "
                                            "query "
                                            "to "
                                            "be "
                                            "combined "
                                            "with "
                                            "the "
                                            "third "
                                            "party "
                                            "case "
                                            "query.",
                                            "properties": {
                                                "groupByFields": {
                                                    "description": "Fields to group by.",
                                                    "items": {
                                                        "description": "Field.",
                                                        "type": "string",
                                                    },
                                                    "type": "array",
                                                },
                                                "query": {
                                                    "description": "Query to run on logs.",
                                                    "example": "source:cloudtrail",
                                                    "type": "string",
                                                },
                                            },
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "signalTitleTemplate": {
                                        "description": "A "
                                        "template "
                                        "for "
                                        "the "
                                        "signal "
                                        "title; "
                                        "if "
                                        "omitted, "
                                        "the "
                                        "title "
                                        "is "
                                        "generated "
                                        "based "
                                        "on "
                                        "the "
                                        "case "
                                        "name.",
                                        "type": "string",
                                    },
                                },
                                "type": "object",
                            },
                        },
                        "type": "object",
                    },
                    "queries": {
                        "description": "Queries for selecting logs which are part of the rule.",
                        "example": [],
                        "items": {
                            "description": "Query for matching rule.",
                            "properties": {
                                "aggregation": {
                                    "description": "The aggregation type.",
                                    "enum": [
                                        "count",
                                        "cardinality",
                                        "sum",
                                        "max",
                                        "new_value",
                                        "geo_data",
                                        "event_count",
                                        "none",
                                    ],
                                    "type": "string",
                                    "x-enum-varnames": [
                                        "COUNT",
                                        "CARDINALITY",
                                        "SUM",
                                        "MAX",
                                        "NEW_VALUE",
                                        "GEO_DATA",
                                        "EVENT_COUNT",
                                        "NONE",
                                    ],
                                },
                                "customQueryExtension": {
                                    "description": "Query extension to append to the logs query.",
                                    "example": "a > 3",
                                    "type": "string",
                                },
                                "dataSource": {
                                    "default": "logs",
                                    "description": "Source "
                                    "of "
                                    "events, "
                                    "either "
                                    "logs, "
                                    "audit "
                                    "trail, "
                                    "or "
                                    "Datadog "
                                    "events.",
                                    "enum": [
                                        "logs",
                                        "audit",
                                        "app_sec_spans",
                                        "spans",
                                        "security_runtime",
                                        "network",
                                        "events",
                                    ],
                                    "example": "logs",
                                    "type": "string",
                                    "x-enum-varnames": [
                                        "LOGS",
                                        "AUDIT",
                                        "APP_SEC_SPANS",
                                        "SPANS",
                                        "SECURITY_RUNTIME",
                                        "NETWORK",
                                        "EVENTS",
                                    ],
                                },
                                "distinctFields": {
                                    "description": "Field "
                                    "for "
                                    "which "
                                    "the "
                                    "cardinality "
                                    "is "
                                    "measured. "
                                    "Sent "
                                    "as "
                                    "an "
                                    "array.",
                                    "items": {"description": "Field.", "type": "string"},
                                    "type": "array",
                                },
                                "groupByFields": {
                                    "description": "Fields to group by.",
                                    "items": {"description": "Field.", "type": "string"},
                                    "type": "array",
                                },
                                "hasOptionalGroupByFields": {
                                    "default": False,
                                    "description": "When "
                                    "false, "
                                    "events "
                                    "without "
                                    "a "
                                    "group-by "
                                    "value "
                                    "are "
                                    "ignored "
                                    "by "
                                    "the "
                                    "rule. "
                                    "When "
                                    "true, "
                                    "events "
                                    "with "
                                    "missing "
                                    "group-by "
                                    "fields "
                                    "are "
                                    "processed "
                                    "with "
                                    "`N/A`, "
                                    "replacing "
                                    "the "
                                    "missing "
                                    "values.",
                                    "example": False,
                                    "type": "boolean",
                                },
                                "index": {
                                    "description": "**This "
                                    "field "
                                    "is "
                                    "currently "
                                    "unstable "
                                    "and "
                                    "might "
                                    "be "
                                    "removed "
                                    "in "
                                    "a "
                                    "minor "
                                    "version "
                                    "upgrade.**\n"
                                    "The "
                                    "index "
                                    "to "
                                    "run "
                                    "the "
                                    "query "
                                    "on, "
                                    "if "
                                    "the "
                                    "`dataSource` "
                                    "is "
                                    "`logs`. "
                                    "Only "
                                    "used "
                                    "for "
                                    "scheduled "
                                    "rules "
                                    "- "
                                    "in "
                                    "other "
                                    "words, "
                                    "when "
                                    "the "
                                    "`schedulingOptions` "
                                    "field "
                                    "is "
                                    "present "
                                    "in "
                                    "the "
                                    "rule "
                                    "payload.",
                                    "type": "string",
                                },
                                "indexes": {
                                    "description": "List "
                                    "of "
                                    "indexes "
                                    "to "
                                    "query "
                                    "when "
                                    "the "
                                    "`dataSource` "
                                    "is "
                                    "`logs`. "
                                    "Only "
                                    "used "
                                    "for "
                                    "scheduled "
                                    "rules, "
                                    "such "
                                    "as "
                                    "when "
                                    "the "
                                    "`schedulingOptions` "
                                    "field "
                                    "is "
                                    "present "
                                    "in "
                                    "the "
                                    "rule "
                                    "payload.",
                                    "items": {"description": "Index.", "type": "string"},
                                    "type": "array",
                                },
                                "metric": {
                                    "deprecated": True,
                                    "description": "(Deprecated) "
                                    "The "
                                    "target "
                                    "field "
                                    "to "
                                    "aggregate "
                                    "over "
                                    "when "
                                    "using "
                                    "the "
                                    "sum "
                                    "or "
                                    "max\n"
                                    "aggregations. "
                                    "`metrics` "
                                    "field "
                                    "should "
                                    "be "
                                    "used "
                                    "instead.",
                                    "type": "string",
                                },
                                "metrics": {
                                    "description": "Group "
                                    "of "
                                    "target "
                                    "fields "
                                    "to "
                                    "aggregate "
                                    "over "
                                    "when "
                                    "using "
                                    "the "
                                    "sum, "
                                    "max, "
                                    "geo "
                                    "data, "
                                    "or "
                                    "new "
                                    "value "
                                    "aggregations. "
                                    "The "
                                    "sum, "
                                    "max, "
                                    "and "
                                    "geo "
                                    "data "
                                    "aggregations "
                                    "only "
                                    "accept "
                                    "one "
                                    "value "
                                    "in "
                                    "this "
                                    "list, "
                                    "whereas "
                                    "the "
                                    "new "
                                    "value "
                                    "aggregation "
                                    "accepts "
                                    "up "
                                    "to "
                                    "five "
                                    "values.",
                                    "items": {"description": "Field.", "type": "string"},
                                    "type": "array",
                                },
                                "name": {"description": "Name of the query.", "type": "string"},
                                "query": {
                                    "description": "Query to run on logs.",
                                    "example": "a > 3",
                                    "type": "string",
                                },
                            },
                            "type": "object",
                        },
                        "type": "array",
                    },
                    "referenceTables": {
                        "description": "Reference tables for the rule.",
                        "items": {
                            "description": "Reference tables used in the queries.",
                            "properties": {
                                "checkPresence": {
                                    "description": "Whether "
                                    "to "
                                    "include "
                                    "or "
                                    "exclude "
                                    "the "
                                    "matched "
                                    "values.",
                                    "type": "boolean",
                                },
                                "columnName": {
                                    "description": "The name of the column in the reference table.",
                                    "type": "string",
                                },
                                "logFieldPath": {
                                    "description": "The "
                                    "field "
                                    "in "
                                    "the "
                                    "log "
                                    "to "
                                    "match "
                                    "against "
                                    "the "
                                    "reference "
                                    "table.",
                                    "type": "string",
                                },
                                "ruleQueryName": {
                                    "description": "The "
                                    "name "
                                    "of "
                                    "the "
                                    "query "
                                    "to "
                                    "apply "
                                    "the "
                                    "reference "
                                    "table "
                                    "to.",
                                    "type": "string",
                                },
                                "tableName": {
                                    "description": "The name of the reference table.",
                                    "type": "string",
                                },
                            },
                            "type": "object",
                        },
                        "type": "array",
                    },
                    "schedulingOptions": {
                        "description": "Options for scheduled "
                        "rules. When this "
                        "field is present, the "
                        "rule runs based on "
                        "the schedule. When "
                        "absent, it runs "
                        "real-time on ingested "
                        "logs.",
                        "nullable": True,
                        "properties": {
                            "rrule": {
                                "description": "Schedule "
                                "for "
                                "the "
                                "rule "
                                "queries, "
                                "written "
                                "in "
                                "RRULE "
                                "syntax. "
                                "See "
                                "[RFC](https://icalendar.org/iCalendar-RFC-5545/3-8-5-3-recurrence-rule.html) "
                                "for "
                                "syntax "
                                "reference.",
                                "example": "FREQ=HOURLY;INTERVAL=1;",
                                "type": "string",
                            },
                            "start": {
                                "description": "Start "
                                "date "
                                "for "
                                "the "
                                "schedule, "
                                "in "
                                "ISO "
                                "8601 "
                                "format "
                                "without "
                                "timezone.",
                                "example": "2025-07-14T12:00:00",
                                "type": "string",
                            },
                            "timezone": {
                                "description": "Time "
                                "zone "
                                "of "
                                "the "
                                "start "
                                "date, "
                                "in "
                                "the "
                                "[tz "
                                "database](https://en.wikipedia.org/wiki/List_of_tz_database_time_zones) "
                                "format.",
                                "example": "America/New_York",
                                "type": "string",
                            },
                        },
                        "type": "object",
                    },
                    "tags": {
                        "description": "Tags for generated signals.",
                        "example": ["env:prod", "team:security"],
                        "items": {"description": "Tag.", "type": "string"},
                        "type": "array",
                    },
                    "thirdPartyCases": {
                        "description": "Cases for generating "
                        "signals from "
                        "third-party rules. Only "
                        "available for "
                        "third-party rules.",
                        "example": [],
                        "items": {
                            "description": "Case when a signal is generated by a third party rule.",
                            "properties": {
                                "name": {"description": "Name of the case.", "type": "string"},
                                "notifications": {
                                    "description": "Notification targets for each case.",
                                    "items": {"description": "Notification.", "type": "string"},
                                    "type": "array",
                                },
                                "query": {
                                    "description": "A "
                                    "query "
                                    "to "
                                    "map "
                                    "a "
                                    "third "
                                    "party "
                                    "event "
                                    "to "
                                    "this "
                                    "case.",
                                    "type": "string",
                                },
                                "status": {
                                    "description": "Severity of the Security Signal.",
                                    "enum": ["info", "low", "medium", "high", "critical"],
                                    "example": "critical",
                                    "type": "string",
                                    "x-enum-varnames": [
                                        "INFO",
                                        "LOW",
                                        "MEDIUM",
                                        "HIGH",
                                        "CRITICAL",
                                    ],
                                },
                            },
                            "required": ["status"],
                            "type": "object",
                        },
                        "type": "array",
                    },
                    "type": {
                        "description": "The rule type.",
                        "enum": [
                            "api_security",
                            "application_security",
                            "log_detection",
                            "workload_security",
                        ],
                        "type": "string",
                        "x-enum-varnames": [
                            "API_SECURITY",
                            "APPLICATION_SECURITY",
                            "LOG_DETECTION",
                            "WORKLOAD_SECURITY",
                        ],
                    },
                },
                "required": ["name", "isEnabled", "queries", "options", "cases", "message"],
                "type": "object",
            },
            {
                "description": "Create a new signal correlation rule.",
                "properties": {
                    "cases": {
                        "description": "Cases for generating signals.",
                        "example": [],
                        "items": {
                            "description": "Case when signal is generated.",
                            "properties": {
                                "actions": {
                                    "description": "Action to perform for each rule case.",
                                    "items": {
                                        "description": "Action "
                                        "to "
                                        "perform "
                                        "when "
                                        "a "
                                        "signal "
                                        "is "
                                        "triggered. "
                                        "Only "
                                        "available "
                                        "for "
                                        "Application "
                                        "Security "
                                        "rule "
                                        "type.",
                                        "properties": {
                                            "options": {
                                                "additionalProperties": {},
                                                "description": "Options for the rule action",
                                                "properties": {
                                                    "duration": {
                                                        "description": "Duration "
                                                        "of "
                                                        "the "
                                                        "action "
                                                        "in "
                                                        "seconds. "
                                                        "0 "
                                                        "indicates "
                                                        "no "
                                                        "expiration.",
                                                        "example": 0,
                                                        "format": "int64",
                                                        "minimum": 0,
                                                        "type": "integer",
                                                    },
                                                    "flaggedIPType": {
                                                        "description": "Used "
                                                        "with "
                                                        "the "
                                                        "case "
                                                        "action "
                                                        "of "
                                                        "type "
                                                        "'flag_ip'. "
                                                        "The "
                                                        "value "
                                                        "specified "
                                                        "in "
                                                        "this "
                                                        "field "
                                                        "is "
                                                        "applied "
                                                        "as "
                                                        "a "
                                                        "flag "
                                                        "to "
                                                        "the "
                                                        "IP "
                                                        "addresses.",
                                                        "enum": ["SUSPICIOUS", "FLAGGED"],
                                                        "example": "FLAGGED",
                                                        "type": "string",
                                                        "x-enum-varnames": [
                                                            "SUSPICIOUS",
                                                            "FLAGGED",
                                                        ],
                                                    },
                                                    "userBehaviorName": {
                                                        "description": "Used "
                                                        "with "
                                                        "the "
                                                        "case "
                                                        "action "
                                                        "of "
                                                        "type "
                                                        "'user_behavior'. "
                                                        "The "
                                                        "value "
                                                        "specified "
                                                        "in "
                                                        "this "
                                                        "field "
                                                        "is "
                                                        "applied "
                                                        "as "
                                                        "a "
                                                        "risk "
                                                        "tag "
                                                        "to "
                                                        "all "
                                                        "users "
                                                        "affected "
                                                        "by "
                                                        "the "
                                                        "rule.",
                                                        "type": "string",
                                                    },
                                                },
                                                "type": "object",
                                            },
                                            "type": {
                                                "description": "The action type.",
                                                "enum": [
                                                    "block_ip",
                                                    "block_user",
                                                    "user_behavior",
                                                    "flag_ip",
                                                ],
                                                "type": "string",
                                                "x-enum-varnames": [
                                                    "BLOCK_IP",
                                                    "BLOCK_USER",
                                                    "USER_BEHAVIOR",
                                                    "FLAG_IP",
                                                ],
                                            },
                                        },
                                        "type": "object",
                                    },
                                    "type": "array",
                                },
                                "condition": {
                                    "description": "A "
                                    "case "
                                    "contains "
                                    "logical "
                                    "operations "
                                    "(`>`,`>=`, "
                                    "`&&`, "
                                    "`||`) "
                                    "to "
                                    "determine "
                                    "if "
                                    "a "
                                    "signal "
                                    "should "
                                    "be "
                                    "generated\n"
                                    "based "
                                    "on "
                                    "the "
                                    "event "
                                    "counts "
                                    "in "
                                    "the "
                                    "previously "
                                    "defined "
                                    "queries.",
                                    "type": "string",
                                },
                                "name": {"description": "Name of the case.", "type": "string"},
                                "notifications": {
                                    "description": "Notification targets.",
                                    "items": {"description": "Notification.", "type": "string"},
                                    "type": "array",
                                },
                                "status": {
                                    "description": "Severity of the Security Signal.",
                                    "enum": ["info", "low", "medium", "high", "critical"],
                                    "example": "critical",
                                    "type": "string",
                                    "x-enum-varnames": [
                                        "INFO",
                                        "LOW",
                                        "MEDIUM",
                                        "HIGH",
                                        "CRITICAL",
                                    ],
                                },
                            },
                            "required": ["status"],
                            "type": "object",
                        },
                        "type": "array",
                    },
                    "filters": {
                        "description": "Additional queries to filter "
                        "matched events before they are "
                        "processed. This field is "
                        "deprecated for log detection, "
                        "signal correlation, and "
                        "workload security rules.",
                        "items": {
                            "description": "The rule's suppression filter.",
                            "properties": {
                                "action": {
                                    "description": "The type of filtering action.",
                                    "enum": ["require", "suppress"],
                                    "type": "string",
                                    "x-enum-varnames": ["REQUIRE", "SUPPRESS"],
                                },
                                "query": {
                                    "description": "Query "
                                    "for "
                                    "selecting "
                                    "logs "
                                    "to "
                                    "apply "
                                    "the "
                                    "filtering "
                                    "action.",
                                    "type": "string",
                                },
                            },
                            "type": "object",
                        },
                        "type": "array",
                    },
                    "hasExtendedTitle": {
                        "description": "Whether the "
                        "notifications include "
                        "the triggering "
                        "group-by values in "
                        "their title.",
                        "example": True,
                        "type": "boolean",
                    },
                    "isEnabled": {
                        "description": "Whether the rule is enabled.",
                        "example": True,
                        "type": "boolean",
                    },
                    "message": {
                        "description": "Message for generated signals.",
                        "example": "",
                        "type": "string",
                    },
                    "name": {
                        "description": "The name of the rule.",
                        "example": "My security monitoring rule.",
                        "type": "string",
                    },
                    "options": {
                        "description": "Options.",
                        "properties": {
                            "complianceRuleOptions": {
                                "additionalProperties": {},
                                "description": "Options "
                                "for "
                                "cloud_configuration "
                                "rules.\n"
                                "Fields "
                                "`resourceType` "
                                "and "
                                "`regoRule` "
                                "are "
                                "mandatory "
                                "when "
                                "managing "
                                "custom "
                                "`cloud_configuration` "
                                "rules.",
                                "properties": {
                                    "complexRule": {
                                        "description": "Whether "
                                        "the "
                                        "rule "
                                        "is "
                                        "a "
                                        "complex "
                                        "one.\n"
                                        "Must "
                                        "be "
                                        "set "
                                        "to "
                                        "true "
                                        "if "
                                        "`regoRule.resourceTypes` "
                                        "contains "
                                        "more "
                                        "than "
                                        "one "
                                        "item. "
                                        "Defaults "
                                        "to "
                                        "false.",
                                        "type": "boolean",
                                    },
                                    "regoRule": {
                                        "description": "Rule details.",
                                        "properties": {
                                            "policy": {
                                                "description": "The "
                                                "policy "
                                                "written "
                                                "in "
                                                "`rego`, "
                                                "see: "
                                                "https://www.openpolicyagent.org/docs/latest/policy-language/",
                                                "example": "package "
                                                "datadog\n"
                                                "\n"
                                                "import "
                                                "data.datadog.output "
                                                "as "
                                                "dd_output\n"
                                                "import "
                                                "future.keywords.contains\n"
                                                "import "
                                                "future.keywords.if\n"
                                                "import "
                                                "future.keywords.in\n"
                                                "\n"
                                                "eval(resource) "
                                                "= "
                                                '"skip" '
                                                "if "
                                                "{\n"
                                                "  "
                                                "# "
                                                "Logic "
                                                "that "
                                                "evaluates "
                                                "to "
                                                "true "
                                                "if "
                                                "the "
                                                "resource "
                                                "should "
                                                "be "
                                                "skipped\n"
                                                "  "
                                                "true\n"
                                                "} "
                                                "else "
                                                "= "
                                                '"pass" '
                                                "{\n"
                                                "  "
                                                "# "
                                                "Logic "
                                                "that "
                                                "evaluates "
                                                "to "
                                                "true "
                                                "if "
                                                "the "
                                                "resource "
                                                "is "
                                                "compliant\n"
                                                "  "
                                                "true\n"
                                                "} "
                                                "else "
                                                "= "
                                                '"fail" '
                                                "{\n"
                                                "  "
                                                "# "
                                                "Logic "
                                                "that "
                                                "evaluates "
                                                "to "
                                                "true "
                                                "if "
                                                "the "
                                                "resource "
                                                "is "
                                                "not "
                                                "compliant\n"
                                                "  "
                                                "true\n"
                                                "}\n"
                                                "\n"
                                                "# "
                                                "This "
                                                "part "
                                                "remains "
                                                "unchanged "
                                                "for "
                                                "all "
                                                "rules\n"
                                                "results "
                                                "contains "
                                                "result "
                                                "if "
                                                "{\n"
                                                "  "
                                                "some "
                                                "resource "
                                                "in "
                                                "input.resources[input.main_resource_type]\n"
                                                "  "
                                                "result "
                                                ":= "
                                                "dd_output.format(resource, "
                                                "eval(resource))\n"
                                                "}",
                                                "type": "string",
                                            },
                                            "resourceTypes": {
                                                "description": "List "
                                                "of "
                                                "resource "
                                                "types "
                                                "that "
                                                "will "
                                                "be "
                                                "evaluated "
                                                "upon. "
                                                "Must "
                                                "have "
                                                "at "
                                                "least "
                                                "one "
                                                "element.",
                                                "example": [
                                                    "gcp_iam_service_account",
                                                    "gcp_iam_policy",
                                                ],
                                                "items": {"type": "string"},
                                                "type": "array",
                                            },
                                        },
                                        "required": ["policy", "resourceTypes"],
                                        "type": "object",
                                    },
                                    "resourceType": {
                                        "description": "Main "
                                        "resource "
                                        "type "
                                        "to "
                                        "be "
                                        "checked "
                                        "by "
                                        "the "
                                        "rule. "
                                        "It "
                                        "should "
                                        "be "
                                        "specified "
                                        "again "
                                        "in "
                                        "`regoRule.resourceTypes`.",
                                        "example": "aws_acm",
                                        "type": "string",
                                    },
                                },
                                "type": "object",
                            },
                            "decreaseCriticalityBasedOnEnv": {
                                "description": "If "
                                "true, "
                                "signals "
                                "in "
                                "non-production "
                                "environments "
                                "have "
                                "a "
                                "lower "
                                "severity "
                                "than "
                                "what "
                                "is "
                                "defined "
                                "by "
                                "the "
                                "rule "
                                "case, "
                                "which "
                                "can "
                                "reduce "
                                "signal "
                                "noise.\n"
                                "The "
                                "severity "
                                "is "
                                "decreased "
                                "by "
                                "one "
                                "level: "
                                "`CRITICAL` "
                                "in "
                                "production "
                                "becomes "
                                "`HIGH` "
                                "in "
                                "non-production, "
                                "`HIGH` "
                                "becomes "
                                "`MEDIUM` "
                                "and "
                                "so "
                                "on. "
                                "`INFO` "
                                "remains "
                                "`INFO`.\n"
                                "The "
                                "decrement "
                                "is "
                                "applied "
                                "when "
                                "the "
                                "environment "
                                "tag "
                                "of "
                                "the "
                                "signal "
                                "starts "
                                "with "
                                "`staging`, "
                                "`test` "
                                "or "
                                "`dev`.",
                                "example": False,
                                "type": "boolean",
                            },
                            "detectionMethod": {
                                "description": "The detection method.",
                                "enum": [
                                    "threshold",
                                    "new_value",
                                    "anomaly_detection",
                                    "impossible_travel",
                                    "hardcoded",
                                    "third_party",
                                    "anomaly_threshold",
                                    "sequence_detection",
                                ],
                                "type": "string",
                                "x-enum-varnames": [
                                    "THRESHOLD",
                                    "NEW_VALUE",
                                    "ANOMALY_DETECTION",
                                    "IMPOSSIBLE_TRAVEL",
                                    "HARDCODED",
                                    "THIRD_PARTY",
                                    "ANOMALY_THRESHOLD",
                                    "SEQUENCE_DETECTION",
                                ],
                            },
                            "evaluationWindow": {
                                "description": "A "
                                "time "
                                "window "
                                "is "
                                "specified "
                                "to "
                                "match "
                                "when "
                                "at "
                                "least "
                                "one "
                                "of "
                                "the "
                                "cases "
                                "matches "
                                "true. "
                                "This "
                                "is "
                                "a "
                                "sliding "
                                "window\n"
                                "and "
                                "evaluates "
                                "in "
                                "real "
                                "time. "
                                "For "
                                "third "
                                "party "
                                "detection "
                                "method, "
                                "this "
                                "field "
                                "is "
                                "not "
                                "used.",
                                "enum": [
                                    0,
                                    60,
                                    300,
                                    600,
                                    900,
                                    1800,
                                    3600,
                                    7200,
                                    10800,
                                    21600,
                                    43200,
                                    86400,
                                ],
                                "format": "int32",
                                "type": "integer",
                                "x-enum-varnames": [
                                    "ZERO_MINUTES",
                                    "ONE_MINUTE",
                                    "FIVE_MINUTES",
                                    "TEN_MINUTES",
                                    "FIFTEEN_MINUTES",
                                    "THIRTY_MINUTES",
                                    "ONE_HOUR",
                                    "TWO_HOURS",
                                    "THREE_HOURS",
                                    "SIX_HOURS",
                                    "TWELVE_HOURS",
                                    "ONE_DAY",
                                ],
                            },
                            "hardcodedEvaluatorType": {
                                "description": "Hardcoded evaluator type.",
                                "enum": ["log4shell"],
                                "type": "string",
                                "x-enum-varnames": ["LOG4SHELL"],
                            },
                            "impossibleTravelOptions": {
                                "description": "Options on impossible travel detection method.",
                                "properties": {
                                    "baselineUserLocations": {
                                        "description": "If "
                                        "true, "
                                        "signals "
                                        "are "
                                        "suppressed "
                                        "for "
                                        "the "
                                        "first "
                                        "24 "
                                        "hours. "
                                        "In "
                                        "that "
                                        "time, "
                                        "Datadog "
                                        "learns "
                                        "the "
                                        "user's "
                                        "regular\n"
                                        "access "
                                        "locations. "
                                        "This "
                                        "can "
                                        "be "
                                        "helpful "
                                        "to "
                                        "reduce "
                                        "noise "
                                        "and "
                                        "infer "
                                        "VPN "
                                        "usage "
                                        "or "
                                        "credentialed "
                                        "API "
                                        "access.",
                                        "example": True,
                                        "type": "boolean",
                                    }
                                },
                                "type": "object",
                            },
                            "keepAlive": {
                                "description": "Once "
                                "a "
                                "signal "
                                "is "
                                "generated, "
                                "the "
                                "signal "
                                "will "
                                "remain "
                                '"open" '
                                "if "
                                "a "
                                "case "
                                "is "
                                "matched "
                                "at "
                                "least "
                                "once "
                                "within\n"
                                "this "
                                "keep "
                                "alive "
                                "window. "
                                "For "
                                "third "
                                "party "
                                "detection "
                                "method, "
                                "this "
                                "field "
                                "is "
                                "not "
                                "used.",
                                "enum": [
                                    0,
                                    60,
                                    300,
                                    600,
                                    900,
                                    1800,
                                    3600,
                                    7200,
                                    10800,
                                    21600,
                                    43200,
                                    86400,
                                ],
                                "format": "int32",
                                "type": "integer",
                                "x-enum-varnames": [
                                    "ZERO_MINUTES",
                                    "ONE_MINUTE",
                                    "FIVE_MINUTES",
                                    "TEN_MINUTES",
                                    "FIFTEEN_MINUTES",
                                    "THIRTY_MINUTES",
                                    "ONE_HOUR",
                                    "TWO_HOURS",
                                    "THREE_HOURS",
                                    "SIX_HOURS",
                                    "TWELVE_HOURS",
                                    "ONE_DAY",
                                ],
                            },
                            "maxSignalDuration": {
                                "description": "A "
                                "signal "
                                "will "
                                '"close" '
                                "regardless "
                                "of "
                                "the "
                                "query "
                                "being "
                                "matched "
                                "once "
                                "the "
                                "time "
                                "exceeds "
                                "the "
                                "maximum "
                                "duration.\n"
                                "This "
                                "time "
                                "is "
                                "calculated "
                                "from "
                                "the "
                                "first "
                                "seen "
                                "timestamp.",
                                "enum": [
                                    0,
                                    60,
                                    300,
                                    600,
                                    900,
                                    1800,
                                    3600,
                                    7200,
                                    10800,
                                    21600,
                                    43200,
                                    86400,
                                ],
                                "format": "int32",
                                "type": "integer",
                                "x-enum-varnames": [
                                    "ZERO_MINUTES",
                                    "ONE_MINUTE",
                                    "FIVE_MINUTES",
                                    "TEN_MINUTES",
                                    "FIFTEEN_MINUTES",
                                    "THIRTY_MINUTES",
                                    "ONE_HOUR",
                                    "TWO_HOURS",
                                    "THREE_HOURS",
                                    "SIX_HOURS",
                                    "TWELVE_HOURS",
                                    "ONE_DAY",
                                ],
                            },
                            "newValueOptions": {
                                "description": "Options on new value detection method.",
                                "properties": {
                                    "forgetAfter": {
                                        "description": "The "
                                        "duration "
                                        "in "
                                        "days "
                                        "after "
                                        "which "
                                        "a "
                                        "learned "
                                        "value "
                                        "is "
                                        "forgotten.",
                                        "enum": [1, 2, 7, 14, 21, 28],
                                        "format": "int32",
                                        "type": "integer",
                                        "x-enum-varnames": [
                                            "ONE_DAY",
                                            "TWO_DAYS",
                                            "ONE_WEEK",
                                            "TWO_WEEKS",
                                            "THREE_WEEKS",
                                            "FOUR_WEEKS",
                                        ],
                                    },
                                    "learningDuration": {
                                        "default": 0,
                                        "description": "The "
                                        "duration "
                                        "in "
                                        "days "
                                        "during "
                                        "which "
                                        "values "
                                        "are "
                                        "learned, "
                                        "and "
                                        "after "
                                        "which "
                                        "signals "
                                        "will "
                                        "be "
                                        "generated "
                                        "for "
                                        "values "
                                        "that\n"
                                        "weren't "
                                        "learned. "
                                        "If "
                                        "set "
                                        "to "
                                        "0, "
                                        "a "
                                        "signal "
                                        "will "
                                        "be "
                                        "generated "
                                        "for "
                                        "all "
                                        "new "
                                        "values "
                                        "after "
                                        "the "
                                        "first "
                                        "value "
                                        "is "
                                        "learned.",
                                        "enum": [0, 1, 7],
                                        "format": "int32",
                                        "type": "integer",
                                        "x-enum-varnames": ["ZERO_DAYS", "ONE_DAY", "SEVEN_DAYS"],
                                    },
                                    "learningMethod": {
                                        "default": "duration",
                                        "description": "The "
                                        "learning "
                                        "method "
                                        "used "
                                        "to "
                                        "determine "
                                        "when "
                                        "signals "
                                        "should "
                                        "be "
                                        "generated "
                                        "for "
                                        "values "
                                        "that "
                                        "weren't "
                                        "learned.",
                                        "enum": ["duration", "threshold"],
                                        "type": "string",
                                        "x-enum-varnames": ["DURATION", "THRESHOLD"],
                                    },
                                    "learningThreshold": {
                                        "default": 0,
                                        "description": "A "
                                        "number "
                                        "of "
                                        "occurrences "
                                        "after "
                                        "which "
                                        "signals "
                                        "will "
                                        "be "
                                        "generated "
                                        "for "
                                        "values "
                                        "that "
                                        "weren't "
                                        "learned.",
                                        "enum": [0, 1],
                                        "format": "int32",
                                        "type": "integer",
                                        "x-enum-varnames": ["ZERO_OCCURRENCES", "ONE_OCCURRENCE"],
                                    },
                                },
                                "type": "object",
                            },
                            "sequenceDetectionOptions": {
                                "description": "Options on sequence detection method.",
                                "properties": {
                                    "stepTransitions": {
                                        "description": "Transitions "
                                        "defining "
                                        "the "
                                        "allowed "
                                        "order "
                                        "of "
                                        "steps "
                                        "and "
                                        "their "
                                        "evaluation "
                                        "windows.",
                                        "items": {
                                            "description": "Transition "
                                            "from "
                                            "a "
                                            "parent "
                                            "step "
                                            "to "
                                            "a "
                                            "child "
                                            "step "
                                            "within "
                                            "a "
                                            "sequence "
                                            "detection "
                                            "rule.",
                                            "properties": {
                                                "child": {
                                                    "description": "Name of the child step.",
                                                    "type": "string",
                                                },
                                                "evaluationWindow": {
                                                    "description": "A "
                                                    "time "
                                                    "window "
                                                    "is "
                                                    "specified "
                                                    "to "
                                                    "match "
                                                    "when "
                                                    "at "
                                                    "least "
                                                    "one "
                                                    "of "
                                                    "the "
                                                    "cases "
                                                    "matches "
                                                    "true. "
                                                    "This "
                                                    "is "
                                                    "a "
                                                    "sliding "
                                                    "window\n"
                                                    "and "
                                                    "evaluates "
                                                    "in "
                                                    "real "
                                                    "time. "
                                                    "For "
                                                    "third "
                                                    "party "
                                                    "detection "
                                                    "method, "
                                                    "this "
                                                    "field "
                                                    "is "
                                                    "not "
                                                    "used.",
                                                    "enum": [
                                                        0,
                                                        60,
                                                        300,
                                                        600,
                                                        900,
                                                        1800,
                                                        3600,
                                                        7200,
                                                        10800,
                                                        21600,
                                                        43200,
                                                        86400,
                                                    ],
                                                    "format": "int32",
                                                    "type": "integer",
                                                    "x-enum-varnames": [
                                                        "ZERO_MINUTES",
                                                        "ONE_MINUTE",
                                                        "FIVE_MINUTES",
                                                        "TEN_MINUTES",
                                                        "FIFTEEN_MINUTES",
                                                        "THIRTY_MINUTES",
                                                        "ONE_HOUR",
                                                        "TWO_HOURS",
                                                        "THREE_HOURS",
                                                        "SIX_HOURS",
                                                        "TWELVE_HOURS",
                                                        "ONE_DAY",
                                                    ],
                                                },
                                                "parent": {
                                                    "description": "Name of the parent step.",
                                                    "type": "string",
                                                },
                                            },
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "steps": {
                                        "description": "Steps "
                                        "that "
                                        "define "
                                        "the "
                                        "conditions "
                                        "to "
                                        "be "
                                        "matched "
                                        "in "
                                        "sequence.",
                                        "items": {
                                            "description": "Step "
                                            "definition "
                                            "for "
                                            "sequence "
                                            "detection "
                                            "containing "
                                            "the "
                                            "step "
                                            "name, "
                                            "condition, "
                                            "and "
                                            "evaluation "
                                            "window.",
                                            "properties": {
                                                "condition": {
                                                    "description": "Condition "
                                                    "referencing "
                                                    "rule "
                                                    "queries "
                                                    "(e.g., "
                                                    "`a "
                                                    "> "
                                                    "0`).",
                                                    "type": "string",
                                                },
                                                "evaluationWindow": {
                                                    "description": "A "
                                                    "time "
                                                    "window "
                                                    "is "
                                                    "specified "
                                                    "to "
                                                    "match "
                                                    "when "
                                                    "at "
                                                    "least "
                                                    "one "
                                                    "of "
                                                    "the "
                                                    "cases "
                                                    "matches "
                                                    "true. "
                                                    "This "
                                                    "is "
                                                    "a "
                                                    "sliding "
                                                    "window\n"
                                                    "and "
                                                    "evaluates "
                                                    "in "
                                                    "real "
                                                    "time. "
                                                    "For "
                                                    "third "
                                                    "party "
                                                    "detection "
                                                    "method, "
                                                    "this "
                                                    "field "
                                                    "is "
                                                    "not "
                                                    "used.",
                                                    "enum": [
                                                        0,
                                                        60,
                                                        300,
                                                        600,
                                                        900,
                                                        1800,
                                                        3600,
                                                        7200,
                                                        10800,
                                                        21600,
                                                        43200,
                                                        86400,
                                                    ],
                                                    "format": "int32",
                                                    "type": "integer",
                                                    "x-enum-varnames": [
                                                        "ZERO_MINUTES",
                                                        "ONE_MINUTE",
                                                        "FIVE_MINUTES",
                                                        "TEN_MINUTES",
                                                        "FIFTEEN_MINUTES",
                                                        "THIRTY_MINUTES",
                                                        "ONE_HOUR",
                                                        "TWO_HOURS",
                                                        "THREE_HOURS",
                                                        "SIX_HOURS",
                                                        "TWELVE_HOURS",
                                                        "ONE_DAY",
                                                    ],
                                                },
                                                "name": {
                                                    "description": "Unique "
                                                    "name "
                                                    "identifying "
                                                    "the "
                                                    "step.",
                                                    "type": "string",
                                                },
                                            },
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                },
                                "type": "object",
                            },
                            "thirdPartyRuleOptions": {
                                "description": "Options on third party detection method.",
                                "properties": {
                                    "defaultNotifications": {
                                        "description": "Notification "
                                        "targets "
                                        "for "
                                        "the "
                                        "logs "
                                        "that "
                                        "do "
                                        "not "
                                        "correspond "
                                        "to "
                                        "any "
                                        "of "
                                        "the "
                                        "cases.",
                                        "items": {"description": "Notification.", "type": "string"},
                                        "type": "array",
                                    },
                                    "defaultStatus": {
                                        "description": "Severity of the Security Signal.",
                                        "enum": ["info", "low", "medium", "high", "critical"],
                                        "example": "critical",
                                        "type": "string",
                                        "x-enum-varnames": [
                                            "INFO",
                                            "LOW",
                                            "MEDIUM",
                                            "HIGH",
                                            "CRITICAL",
                                        ],
                                    },
                                    "rootQueries": {
                                        "description": "Queries "
                                        "to "
                                        "be "
                                        "combined "
                                        "with "
                                        "third "
                                        "party "
                                        "case "
                                        "queries. "
                                        "Each "
                                        "of "
                                        "them "
                                        "can "
                                        "have "
                                        "different "
                                        "group "
                                        "by "
                                        "fields, "
                                        "to "
                                        "aggregate "
                                        "differently "
                                        "based "
                                        "on "
                                        "the "
                                        "type "
                                        "of "
                                        "alert.",
                                        "items": {
                                            "description": "A "
                                            "query "
                                            "to "
                                            "be "
                                            "combined "
                                            "with "
                                            "the "
                                            "third "
                                            "party "
                                            "case "
                                            "query.",
                                            "properties": {
                                                "groupByFields": {
                                                    "description": "Fields to group by.",
                                                    "items": {
                                                        "description": "Field.",
                                                        "type": "string",
                                                    },
                                                    "type": "array",
                                                },
                                                "query": {
                                                    "description": "Query to run on logs.",
                                                    "example": "source:cloudtrail",
                                                    "type": "string",
                                                },
                                            },
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "signalTitleTemplate": {
                                        "description": "A "
                                        "template "
                                        "for "
                                        "the "
                                        "signal "
                                        "title; "
                                        "if "
                                        "omitted, "
                                        "the "
                                        "title "
                                        "is "
                                        "generated "
                                        "based "
                                        "on "
                                        "the "
                                        "case "
                                        "name.",
                                        "type": "string",
                                    },
                                },
                                "type": "object",
                            },
                        },
                        "type": "object",
                    },
                    "queries": {
                        "description": "Queries for selecting signals which are part of the rule.",
                        "example": [],
                        "items": {
                            "description": "Query for matching rule on signals.",
                            "properties": {
                                "aggregation": {
                                    "description": "The aggregation type.",
                                    "enum": [
                                        "count",
                                        "cardinality",
                                        "sum",
                                        "max",
                                        "new_value",
                                        "geo_data",
                                        "event_count",
                                        "none",
                                    ],
                                    "type": "string",
                                    "x-enum-varnames": [
                                        "COUNT",
                                        "CARDINALITY",
                                        "SUM",
                                        "MAX",
                                        "NEW_VALUE",
                                        "GEO_DATA",
                                        "EVENT_COUNT",
                                        "NONE",
                                    ],
                                },
                                "correlatedByFields": {
                                    "description": "Fields to group by.",
                                    "items": {"description": "Field.", "type": "string"},
                                    "type": "array",
                                },
                                "correlatedQueryIndex": {
                                    "description": "Index "
                                    "of "
                                    "the "
                                    "rule "
                                    "query "
                                    "used "
                                    "to "
                                    "retrieve "
                                    "the "
                                    "correlated "
                                    "field.",
                                    "format": "int32",
                                    "maximum": 9,
                                    "type": "integer",
                                },
                                "metrics": {
                                    "description": "Group of target fields to aggregate over.",
                                    "items": {"description": "Field.", "type": "string"},
                                    "type": "array",
                                },
                                "name": {"description": "Name of the query.", "type": "string"},
                                "ruleId": {
                                    "description": "Rule ID to match on signals.",
                                    "example": "org-ru1-e1d",
                                    "type": "string",
                                },
                            },
                            "required": ["ruleId"],
                            "type": "object",
                        },
                        "type": "array",
                    },
                    "tags": {
                        "description": "Tags for generated signals.",
                        "example": ["env:prod", "team:security"],
                        "items": {"description": "Tag.", "type": "string"},
                        "type": "array",
                    },
                    "type": {
                        "description": "The rule type.",
                        "enum": ["signal_correlation"],
                        "type": "string",
                        "x-enum-varnames": ["SIGNAL_CORRELATION"],
                    },
                },
                "required": ["name", "isEnabled", "queries", "options", "cases", "message"],
                "type": "object",
            },
            {
                "description": "Create a new cloud configuration rule.",
                "properties": {
                    "cases": {
                        "description": "Description of generated findings "
                        "and signals (severity and "
                        "channels to be notified in case "
                        "of a signal). Must contain "
                        "exactly one item.",
                        "items": {
                            "description": "Description of signals.",
                            "properties": {
                                "notifications": {
                                    "description": "Notification targets for each rule case.",
                                    "items": {"description": "Notification.", "type": "string"},
                                    "type": "array",
                                },
                                "status": {
                                    "description": "Severity of the Security Signal.",
                                    "enum": ["info", "low", "medium", "high", "critical"],
                                    "example": "critical",
                                    "type": "string",
                                    "x-enum-varnames": [
                                        "INFO",
                                        "LOW",
                                        "MEDIUM",
                                        "HIGH",
                                        "CRITICAL",
                                    ],
                                },
                            },
                            "required": ["status"],
                            "type": "object",
                        },
                        "type": "array",
                    },
                    "complianceSignalOptions": {
                        "description": "How to generate "
                        "compliance "
                        "signals. Useful "
                        "for "
                        "cloud_configuration "
                        "rules only.",
                        "properties": {
                            "defaultActivationStatus": {
                                "description": "The default activation status.",
                                "nullable": True,
                                "type": "boolean",
                            },
                            "defaultGroupByFields": {
                                "description": "The default group by fields.",
                                "items": {"type": "string"},
                                "nullable": True,
                                "type": "array",
                            },
                            "userActivationStatus": {
                                "description": "Whether signals will be sent.",
                                "nullable": True,
                                "type": "boolean",
                            },
                            "userGroupByFields": {
                                "description": "Fields "
                                "to "
                                "use "
                                "to "
                                "group "
                                "findings "
                                "by "
                                "when "
                                "sending "
                                "signals.",
                                "items": {"type": "string"},
                                "nullable": True,
                                "type": "array",
                            },
                        },
                        "type": "object",
                    },
                    "filters": {
                        "description": "Additional queries to filter "
                        "matched events before they are "
                        "processed.",
                        "items": {
                            "description": "The rule's suppression filter.",
                            "properties": {
                                "action": {
                                    "description": "The type of filtering action.",
                                    "enum": ["require", "suppress"],
                                    "type": "string",
                                    "x-enum-varnames": ["REQUIRE", "SUPPRESS"],
                                },
                                "query": {
                                    "description": "Query "
                                    "for "
                                    "selecting "
                                    "logs "
                                    "to "
                                    "apply "
                                    "the "
                                    "filtering "
                                    "action.",
                                    "type": "string",
                                },
                            },
                            "type": "object",
                        },
                        "type": "array",
                    },
                    "isEnabled": {
                        "description": "Whether the rule is enabled.",
                        "example": True,
                        "type": "boolean",
                    },
                    "message": {
                        "description": "Message in markdown format for "
                        "generated findings and signals.",
                        "example": "#Description\n"
                        "Explanation of the rule.\n"
                        "\n"
                        "#Remediation\n"
                        "How to fix the security issue.",
                        "type": "string",
                    },
                    "name": {
                        "description": "The name of the rule.",
                        "example": "My security monitoring rule.",
                        "type": "string",
                    },
                    "options": {
                        "description": "Options on cloud configuration rules.",
                        "properties": {
                            "complianceRuleOptions": {
                                "additionalProperties": {},
                                "description": "Options "
                                "for "
                                "cloud_configuration "
                                "rules.\n"
                                "Fields "
                                "`resourceType` "
                                "and "
                                "`regoRule` "
                                "are "
                                "mandatory "
                                "when "
                                "managing "
                                "custom "
                                "`cloud_configuration` "
                                "rules.",
                                "properties": {
                                    "complexRule": {
                                        "description": "Whether "
                                        "the "
                                        "rule "
                                        "is "
                                        "a "
                                        "complex "
                                        "one.\n"
                                        "Must "
                                        "be "
                                        "set "
                                        "to "
                                        "true "
                                        "if "
                                        "`regoRule.resourceTypes` "
                                        "contains "
                                        "more "
                                        "than "
                                        "one "
                                        "item. "
                                        "Defaults "
                                        "to "
                                        "false.",
                                        "type": "boolean",
                                    },
                                    "regoRule": {
                                        "description": "Rule details.",
                                        "properties": {
                                            "policy": {
                                                "description": "The "
                                                "policy "
                                                "written "
                                                "in "
                                                "`rego`, "
                                                "see: "
                                                "https://www.openpolicyagent.org/docs/latest/policy-language/",
                                                "example": "package "
                                                "datadog\n"
                                                "\n"
                                                "import "
                                                "data.datadog.output "
                                                "as "
                                                "dd_output\n"
                                                "import "
                                                "future.keywords.contains\n"
                                                "import "
                                                "future.keywords.if\n"
                                                "import "
                                                "future.keywords.in\n"
                                                "\n"
                                                "eval(resource) "
                                                "= "
                                                '"skip" '
                                                "if "
                                                "{\n"
                                                "  "
                                                "# "
                                                "Logic "
                                                "that "
                                                "evaluates "
                                                "to "
                                                "true "
                                                "if "
                                                "the "
                                                "resource "
                                                "should "
                                                "be "
                                                "skipped\n"
                                                "  "
                                                "true\n"
                                                "} "
                                                "else "
                                                "= "
                                                '"pass" '
                                                "{\n"
                                                "  "
                                                "# "
                                                "Logic "
                                                "that "
                                                "evaluates "
                                                "to "
                                                "true "
                                                "if "
                                                "the "
                                                "resource "
                                                "is "
                                                "compliant\n"
                                                "  "
                                                "true\n"
                                                "} "
                                                "else "
                                                "= "
                                                '"fail" '
                                                "{\n"
                                                "  "
                                                "# "
                                                "Logic "
                                                "that "
                                                "evaluates "
                                                "to "
                                                "true "
                                                "if "
                                                "the "
                                                "resource "
                                                "is "
                                                "not "
                                                "compliant\n"
                                                "  "
                                                "true\n"
                                                "}\n"
                                                "\n"
                                                "# "
                                                "This "
                                                "part "
                                                "remains "
                                                "unchanged "
                                                "for "
                                                "all "
                                                "rules\n"
                                                "results "
                                                "contains "
                                                "result "
                                                "if "
                                                "{\n"
                                                "  "
                                                "some "
                                                "resource "
                                                "in "
                                                "input.resources[input.main_resource_type]\n"
                                                "  "
                                                "result "
                                                ":= "
                                                "dd_output.format(resource, "
                                                "eval(resource))\n"
                                                "}",
                                                "type": "string",
                                            },
                                            "resourceTypes": {
                                                "description": "List "
                                                "of "
                                                "resource "
                                                "types "
                                                "that "
                                                "will "
                                                "be "
                                                "evaluated "
                                                "upon. "
                                                "Must "
                                                "have "
                                                "at "
                                                "least "
                                                "one "
                                                "element.",
                                                "example": [
                                                    "gcp_iam_service_account",
                                                    "gcp_iam_policy",
                                                ],
                                                "items": {"type": "string"},
                                                "type": "array",
                                            },
                                        },
                                        "required": ["policy", "resourceTypes"],
                                        "type": "object",
                                    },
                                    "resourceType": {
                                        "description": "Main "
                                        "resource "
                                        "type "
                                        "to "
                                        "be "
                                        "checked "
                                        "by "
                                        "the "
                                        "rule. "
                                        "It "
                                        "should "
                                        "be "
                                        "specified "
                                        "again "
                                        "in "
                                        "`regoRule.resourceTypes`.",
                                        "example": "aws_acm",
                                        "type": "string",
                                    },
                                },
                                "type": "object",
                            }
                        },
                        "required": ["complianceRuleOptions"],
                        "type": "object",
                    },
                    "tags": {
                        "description": "Tags for generated findings and signals.",
                        "example": ["env:prod", "team:security"],
                        "items": {"description": "Tag.", "type": "string"},
                        "type": "array",
                    },
                    "type": {
                        "description": "The rule type.",
                        "enum": ["cloud_configuration"],
                        "type": "string",
                        "x-enum-varnames": ["CLOUD_CONFIGURATION"],
                    },
                },
                "required": [
                    "name",
                    "isEnabled",
                    "options",
                    "complianceSignalOptions",
                    "cases",
                    "message",
                ],
                "type": "object",
            },
        ],
    },
    "UPDATESUPPRESSIONRULE_REQUEST_BODY_SCHEMA": {
        "description": "Request object containing the fields to update on the suppression rule.",
        "properties": {
            "data": {
                "description": "The new suppression properties; partial updates are supported.",
                "properties": {
                    "attributes": {
                        "description": "The suppression rule properties to be updated.",
                        "properties": {
                            "data_exclusion_query": {
                                "description": "An "
                                "exclusion "
                                "query "
                                "on "
                                "the "
                                "input "
                                "data "
                                "of "
                                "the "
                                "security "
                                "rules, "
                                "which "
                                "could "
                                "be "
                                "logs, "
                                "Agent "
                                "events, "
                                "or "
                                "other "
                                "types "
                                "of "
                                "data "
                                "based "
                                "on "
                                "the "
                                "security "
                                "rule. "
                                "Events "
                                "matching "
                                "this "
                                "query "
                                "are "
                                "ignored "
                                "by "
                                "any "
                                "detection "
                                "rules "
                                "referenced "
                                "in "
                                "the "
                                "suppression "
                                "rule.",
                                "example": "source:cloudtrail account_id:12345",
                                "type": "string",
                            },
                            "description": {
                                "description": "A description for the suppression rule.",
                                "example": "This "
                                "rule "
                                "suppresses "
                                "low-severity "
                                "signals "
                                "in "
                                "staging "
                                "environments.",
                                "type": "string",
                            },
                            "enabled": {
                                "description": "Whether the suppression rule is enabled.",
                                "example": True,
                                "type": "boolean",
                            },
                            "expiration_date": {
                                "description": "A "
                                "Unix "
                                "millisecond "
                                "timestamp "
                                "giving "
                                "an "
                                "expiration "
                                "date "
                                "for "
                                "the "
                                "suppression "
                                "rule. "
                                "After "
                                "this "
                                "date, "
                                "it "
                                "won't "
                                "suppress "
                                "signals "
                                "anymore. "
                                "If "
                                "unset, "
                                "the "
                                "expiration "
                                "date "
                                "of "
                                "the "
                                "suppression "
                                "rule "
                                "is "
                                "left "
                                "untouched. "
                                "If "
                                "set "
                                "to "
                                "`null`, "
                                "the "
                                "expiration "
                                "date "
                                "is "
                                "removed.",
                                "example": 1703187336000,
                                "format": "int64",
                                "nullable": True,
                                "type": "integer",
                            },
                            "name": {
                                "description": "The name of the suppression rule.",
                                "example": "Custom suppression",
                                "type": "string",
                            },
                            "rule_query": {
                                "description": "The "
                                "rule "
                                "query "
                                "of "
                                "the "
                                "suppression "
                                "rule, "
                                "with "
                                "the "
                                "same "
                                "syntax "
                                "as "
                                "the "
                                "search "
                                "bar "
                                "for "
                                "detection "
                                "rules.",
                                "example": "type:log_detection source:cloudtrail",
                                "type": "string",
                            },
                            "start_date": {
                                "description": "A "
                                "Unix "
                                "millisecond "
                                "timestamp "
                                "giving "
                                "the "
                                "start "
                                "date "
                                "for "
                                "the "
                                "suppression "
                                "rule. "
                                "After "
                                "this "
                                "date, "
                                "it "
                                "starts "
                                "suppressing "
                                "signals. "
                                "If "
                                "unset, "
                                "the "
                                "start "
                                "date "
                                "of "
                                "the "
                                "suppression "
                                "rule "
                                "is "
                                "left "
                                "untouched. "
                                "If "
                                "set "
                                "to "
                                "`null`, "
                                "the "
                                "start "
                                "date "
                                "is "
                                "removed.",
                                "example": 1703187336000,
                                "format": "int64",
                                "nullable": True,
                                "type": "integer",
                            },
                            "suppression_query": {
                                "description": "The "
                                "suppression "
                                "query "
                                "of "
                                "the "
                                "suppression "
                                "rule. "
                                "If "
                                "a "
                                "signal "
                                "matches "
                                "this "
                                "query, "
                                "it "
                                "is "
                                "suppressed "
                                "and "
                                "not "
                                "triggered. "
                                "Same "
                                "syntax "
                                "as "
                                "the "
                                "queries "
                                "to "
                                "search "
                                "signals "
                                "in "
                                "the "
                                "signal "
                                "explorer.",
                                "example": "env:staging status:low",
                                "type": "string",
                            },
                            "version": {
                                "description": "The "
                                "current "
                                "version "
                                "of "
                                "the "
                                "suppression. "
                                "This "
                                "is "
                                "optional, "
                                "but "
                                "it "
                                "can "
                                "help "
                                "prevent "
                                "concurrent "
                                "modifications.",
                                "format": "int32",
                                "maximum": 2147483647,
                                "type": "integer",
                            },
                        },
                        "type": "object",
                    },
                    "type": {
                        "default": "suppressions",
                        "description": "The type of the "
                        "resource. The value "
                        "should always be "
                        "`suppressions`.",
                        "enum": ["suppressions"],
                        "example": "suppressions",
                        "type": "string",
                        "x-enum-varnames": ["SUPPRESSIONS"],
                    },
                },
                "required": ["type", "attributes"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "CREATESECURITYMONITORINGRULE_REQUEST_BODY_SCHEMA": {
        "description": "Create a new rule.",
        "oneOf": [
            {
                "description": "Create a new rule.",
                "properties": {
                    "calculatedFields": {
                        "description": "Calculated fields. "
                        "Only allowed for "
                        "scheduled rules - in "
                        "other words, when "
                        "schedulingOptions is "
                        "also defined.",
                        "items": {
                            "description": "Calculated field.",
                            "properties": {
                                "expression": {
                                    "description": "Expression.",
                                    "example": "@request_end_timestamp - @request_start_timestamp",
                                    "type": "string",
                                },
                                "name": {
                                    "description": "Field name.",
                                    "example": "response_time",
                                    "type": "string",
                                },
                            },
                            "required": ["name", "expression"],
                            "type": "object",
                        },
                        "type": "array",
                    },
                    "cases": {
                        "description": "Cases for generating signals.",
                        "example": [],
                        "items": {
                            "description": "Case when signal is generated.",
                            "properties": {
                                "actions": {
                                    "description": "Action to perform for each rule case.",
                                    "items": {
                                        "description": "Action "
                                        "to "
                                        "perform "
                                        "when "
                                        "a "
                                        "signal "
                                        "is "
                                        "triggered. "
                                        "Only "
                                        "available "
                                        "for "
                                        "Application "
                                        "Security "
                                        "rule "
                                        "type.",
                                        "properties": {
                                            "options": {
                                                "additionalProperties": {},
                                                "description": "Options for the rule action",
                                                "properties": {
                                                    "duration": {
                                                        "description": "Duration "
                                                        "of "
                                                        "the "
                                                        "action "
                                                        "in "
                                                        "seconds. "
                                                        "0 "
                                                        "indicates "
                                                        "no "
                                                        "expiration.",
                                                        "example": 0,
                                                        "format": "int64",
                                                        "minimum": 0,
                                                        "type": "integer",
                                                    },
                                                    "flaggedIPType": {
                                                        "description": "Used "
                                                        "with "
                                                        "the "
                                                        "case "
                                                        "action "
                                                        "of "
                                                        "type "
                                                        "'flag_ip'. "
                                                        "The "
                                                        "value "
                                                        "specified "
                                                        "in "
                                                        "this "
                                                        "field "
                                                        "is "
                                                        "applied "
                                                        "as "
                                                        "a "
                                                        "flag "
                                                        "to "
                                                        "the "
                                                        "IP "
                                                        "addresses.",
                                                        "enum": ["SUSPICIOUS", "FLAGGED"],
                                                        "example": "FLAGGED",
                                                        "type": "string",
                                                        "x-enum-varnames": [
                                                            "SUSPICIOUS",
                                                            "FLAGGED",
                                                        ],
                                                    },
                                                    "userBehaviorName": {
                                                        "description": "Used "
                                                        "with "
                                                        "the "
                                                        "case "
                                                        "action "
                                                        "of "
                                                        "type "
                                                        "'user_behavior'. "
                                                        "The "
                                                        "value "
                                                        "specified "
                                                        "in "
                                                        "this "
                                                        "field "
                                                        "is "
                                                        "applied "
                                                        "as "
                                                        "a "
                                                        "risk "
                                                        "tag "
                                                        "to "
                                                        "all "
                                                        "users "
                                                        "affected "
                                                        "by "
                                                        "the "
                                                        "rule.",
                                                        "type": "string",
                                                    },
                                                },
                                                "type": "object",
                                            },
                                            "type": {
                                                "description": "The action type.",
                                                "enum": [
                                                    "block_ip",
                                                    "block_user",
                                                    "user_behavior",
                                                    "flag_ip",
                                                ],
                                                "type": "string",
                                                "x-enum-varnames": [
                                                    "BLOCK_IP",
                                                    "BLOCK_USER",
                                                    "USER_BEHAVIOR",
                                                    "FLAG_IP",
                                                ],
                                            },
                                        },
                                        "type": "object",
                                    },
                                    "type": "array",
                                },
                                "condition": {
                                    "description": "A "
                                    "case "
                                    "contains "
                                    "logical "
                                    "operations "
                                    "(`>`,`>=`, "
                                    "`&&`, "
                                    "`||`) "
                                    "to "
                                    "determine "
                                    "if "
                                    "a "
                                    "signal "
                                    "should "
                                    "be "
                                    "generated\n"
                                    "based "
                                    "on "
                                    "the "
                                    "event "
                                    "counts "
                                    "in "
                                    "the "
                                    "previously "
                                    "defined "
                                    "queries.",
                                    "type": "string",
                                },
                                "name": {"description": "Name of the case.", "type": "string"},
                                "notifications": {
                                    "description": "Notification targets.",
                                    "items": {"description": "Notification.", "type": "string"},
                                    "type": "array",
                                },
                                "status": {
                                    "description": "Severity of the Security Signal.",
                                    "enum": ["info", "low", "medium", "high", "critical"],
                                    "example": "critical",
                                    "type": "string",
                                    "x-enum-varnames": [
                                        "INFO",
                                        "LOW",
                                        "MEDIUM",
                                        "HIGH",
                                        "CRITICAL",
                                    ],
                                },
                            },
                            "required": ["status"],
                            "type": "object",
                        },
                        "type": "array",
                    },
                    "filters": {
                        "description": "Additional queries to filter "
                        "matched events before they are "
                        "processed. This field is "
                        "deprecated for log detection, "
                        "signal correlation, and "
                        "workload security rules.",
                        "items": {
                            "description": "The rule's suppression filter.",
                            "properties": {
                                "action": {
                                    "description": "The type of filtering action.",
                                    "enum": ["require", "suppress"],
                                    "type": "string",
                                    "x-enum-varnames": ["REQUIRE", "SUPPRESS"],
                                },
                                "query": {
                                    "description": "Query "
                                    "for "
                                    "selecting "
                                    "logs "
                                    "to "
                                    "apply "
                                    "the "
                                    "filtering "
                                    "action.",
                                    "type": "string",
                                },
                            },
                            "type": "object",
                        },
                        "type": "array",
                    },
                    "groupSignalsBy": {
                        "description": "Additional grouping to "
                        "perform on top of the "
                        "existing groups in the "
                        "query section. Must be a "
                        "subset of the existing "
                        "groups.",
                        "example": ["service"],
                        "items": {"description": "Field to group by.", "type": "string"},
                        "type": "array",
                    },
                    "hasExtendedTitle": {
                        "description": "Whether the "
                        "notifications include "
                        "the triggering "
                        "group-by values in "
                        "their title.",
                        "example": True,
                        "type": "boolean",
                    },
                    "isEnabled": {
                        "description": "Whether the rule is enabled.",
                        "example": True,
                        "type": "boolean",
                    },
                    "message": {
                        "description": "Message for generated signals.",
                        "example": "",
                        "type": "string",
                    },
                    "name": {
                        "description": "The name of the rule.",
                        "example": "My security monitoring rule.",
                        "type": "string",
                    },
                    "options": {
                        "description": "Options.",
                        "properties": {
                            "complianceRuleOptions": {
                                "additionalProperties": {},
                                "description": "Options "
                                "for "
                                "cloud_configuration "
                                "rules.\n"
                                "Fields "
                                "`resourceType` "
                                "and "
                                "`regoRule` "
                                "are "
                                "mandatory "
                                "when "
                                "managing "
                                "custom "
                                "`cloud_configuration` "
                                "rules.",
                                "properties": {
                                    "complexRule": {
                                        "description": "Whether "
                                        "the "
                                        "rule "
                                        "is "
                                        "a "
                                        "complex "
                                        "one.\n"
                                        "Must "
                                        "be "
                                        "set "
                                        "to "
                                        "true "
                                        "if "
                                        "`regoRule.resourceTypes` "
                                        "contains "
                                        "more "
                                        "than "
                                        "one "
                                        "item. "
                                        "Defaults "
                                        "to "
                                        "false.",
                                        "type": "boolean",
                                    },
                                    "regoRule": {
                                        "description": "Rule details.",
                                        "properties": {
                                            "policy": {
                                                "description": "The "
                                                "policy "
                                                "written "
                                                "in "
                                                "`rego`, "
                                                "see: "
                                                "https://www.openpolicyagent.org/docs/latest/policy-language/",
                                                "example": "package "
                                                "datadog\n"
                                                "\n"
                                                "import "
                                                "data.datadog.output "
                                                "as "
                                                "dd_output\n"
                                                "import "
                                                "future.keywords.contains\n"
                                                "import "
                                                "future.keywords.if\n"
                                                "import "
                                                "future.keywords.in\n"
                                                "\n"
                                                "eval(resource) "
                                                "= "
                                                '"skip" '
                                                "if "
                                                "{\n"
                                                "  "
                                                "# "
                                                "Logic "
                                                "that "
                                                "evaluates "
                                                "to "
                                                "true "
                                                "if "
                                                "the "
                                                "resource "
                                                "should "
                                                "be "
                                                "skipped\n"
                                                "  "
                                                "true\n"
                                                "} "
                                                "else "
                                                "= "
                                                '"pass" '
                                                "{\n"
                                                "  "
                                                "# "
                                                "Logic "
                                                "that "
                                                "evaluates "
                                                "to "
                                                "true "
                                                "if "
                                                "the "
                                                "resource "
                                                "is "
                                                "compliant\n"
                                                "  "
                                                "true\n"
                                                "} "
                                                "else "
                                                "= "
                                                '"fail" '
                                                "{\n"
                                                "  "
                                                "# "
                                                "Logic "
                                                "that "
                                                "evaluates "
                                                "to "
                                                "true "
                                                "if "
                                                "the "
                                                "resource "
                                                "is "
                                                "not "
                                                "compliant\n"
                                                "  "
                                                "true\n"
                                                "}\n"
                                                "\n"
                                                "# "
                                                "This "
                                                "part "
                                                "remains "
                                                "unchanged "
                                                "for "
                                                "all "
                                                "rules\n"
                                                "results "
                                                "contains "
                                                "result "
                                                "if "
                                                "{\n"
                                                "  "
                                                "some "
                                                "resource "
                                                "in "
                                                "input.resources[input.main_resource_type]\n"
                                                "  "
                                                "result "
                                                ":= "
                                                "dd_output.format(resource, "
                                                "eval(resource))\n"
                                                "}",
                                                "type": "string",
                                            },
                                            "resourceTypes": {
                                                "description": "List "
                                                "of "
                                                "resource "
                                                "types "
                                                "that "
                                                "will "
                                                "be "
                                                "evaluated "
                                                "upon. "
                                                "Must "
                                                "have "
                                                "at "
                                                "least "
                                                "one "
                                                "element.",
                                                "example": [
                                                    "gcp_iam_service_account",
                                                    "gcp_iam_policy",
                                                ],
                                                "items": {"type": "string"},
                                                "type": "array",
                                            },
                                        },
                                        "required": ["policy", "resourceTypes"],
                                        "type": "object",
                                    },
                                    "resourceType": {
                                        "description": "Main "
                                        "resource "
                                        "type "
                                        "to "
                                        "be "
                                        "checked "
                                        "by "
                                        "the "
                                        "rule. "
                                        "It "
                                        "should "
                                        "be "
                                        "specified "
                                        "again "
                                        "in "
                                        "`regoRule.resourceTypes`.",
                                        "example": "aws_acm",
                                        "type": "string",
                                    },
                                },
                                "type": "object",
                            },
                            "decreaseCriticalityBasedOnEnv": {
                                "description": "If "
                                "true, "
                                "signals "
                                "in "
                                "non-production "
                                "environments "
                                "have "
                                "a "
                                "lower "
                                "severity "
                                "than "
                                "what "
                                "is "
                                "defined "
                                "by "
                                "the "
                                "rule "
                                "case, "
                                "which "
                                "can "
                                "reduce "
                                "signal "
                                "noise.\n"
                                "The "
                                "severity "
                                "is "
                                "decreased "
                                "by "
                                "one "
                                "level: "
                                "`CRITICAL` "
                                "in "
                                "production "
                                "becomes "
                                "`HIGH` "
                                "in "
                                "non-production, "
                                "`HIGH` "
                                "becomes "
                                "`MEDIUM` "
                                "and "
                                "so "
                                "on. "
                                "`INFO` "
                                "remains "
                                "`INFO`.\n"
                                "The "
                                "decrement "
                                "is "
                                "applied "
                                "when "
                                "the "
                                "environment "
                                "tag "
                                "of "
                                "the "
                                "signal "
                                "starts "
                                "with "
                                "`staging`, "
                                "`test` "
                                "or "
                                "`dev`.",
                                "example": False,
                                "type": "boolean",
                            },
                            "detectionMethod": {
                                "description": "The detection method.",
                                "enum": [
                                    "threshold",
                                    "new_value",
                                    "anomaly_detection",
                                    "impossible_travel",
                                    "hardcoded",
                                    "third_party",
                                    "anomaly_threshold",
                                    "sequence_detection",
                                ],
                                "type": "string",
                                "x-enum-varnames": [
                                    "THRESHOLD",
                                    "NEW_VALUE",
                                    "ANOMALY_DETECTION",
                                    "IMPOSSIBLE_TRAVEL",
                                    "HARDCODED",
                                    "THIRD_PARTY",
                                    "ANOMALY_THRESHOLD",
                                    "SEQUENCE_DETECTION",
                                ],
                            },
                            "evaluationWindow": {
                                "description": "A "
                                "time "
                                "window "
                                "is "
                                "specified "
                                "to "
                                "match "
                                "when "
                                "at "
                                "least "
                                "one "
                                "of "
                                "the "
                                "cases "
                                "matches "
                                "true. "
                                "This "
                                "is "
                                "a "
                                "sliding "
                                "window\n"
                                "and "
                                "evaluates "
                                "in "
                                "real "
                                "time. "
                                "For "
                                "third "
                                "party "
                                "detection "
                                "method, "
                                "this "
                                "field "
                                "is "
                                "not "
                                "used.",
                                "enum": [
                                    0,
                                    60,
                                    300,
                                    600,
                                    900,
                                    1800,
                                    3600,
                                    7200,
                                    10800,
                                    21600,
                                    43200,
                                    86400,
                                ],
                                "format": "int32",
                                "type": "integer",
                                "x-enum-varnames": [
                                    "ZERO_MINUTES",
                                    "ONE_MINUTE",
                                    "FIVE_MINUTES",
                                    "TEN_MINUTES",
                                    "FIFTEEN_MINUTES",
                                    "THIRTY_MINUTES",
                                    "ONE_HOUR",
                                    "TWO_HOURS",
                                    "THREE_HOURS",
                                    "SIX_HOURS",
                                    "TWELVE_HOURS",
                                    "ONE_DAY",
                                ],
                            },
                            "hardcodedEvaluatorType": {
                                "description": "Hardcoded evaluator type.",
                                "enum": ["log4shell"],
                                "type": "string",
                                "x-enum-varnames": ["LOG4SHELL"],
                            },
                            "impossibleTravelOptions": {
                                "description": "Options on impossible travel detection method.",
                                "properties": {
                                    "baselineUserLocations": {
                                        "description": "If "
                                        "true, "
                                        "signals "
                                        "are "
                                        "suppressed "
                                        "for "
                                        "the "
                                        "first "
                                        "24 "
                                        "hours. "
                                        "In "
                                        "that "
                                        "time, "
                                        "Datadog "
                                        "learns "
                                        "the "
                                        "user's "
                                        "regular\n"
                                        "access "
                                        "locations. "
                                        "This "
                                        "can "
                                        "be "
                                        "helpful "
                                        "to "
                                        "reduce "
                                        "noise "
                                        "and "
                                        "infer "
                                        "VPN "
                                        "usage "
                                        "or "
                                        "credentialed "
                                        "API "
                                        "access.",
                                        "example": True,
                                        "type": "boolean",
                                    }
                                },
                                "type": "object",
                            },
                            "keepAlive": {
                                "description": "Once "
                                "a "
                                "signal "
                                "is "
                                "generated, "
                                "the "
                                "signal "
                                "will "
                                "remain "
                                '"open" '
                                "if "
                                "a "
                                "case "
                                "is "
                                "matched "
                                "at "
                                "least "
                                "once "
                                "within\n"
                                "this "
                                "keep "
                                "alive "
                                "window. "
                                "For "
                                "third "
                                "party "
                                "detection "
                                "method, "
                                "this "
                                "field "
                                "is "
                                "not "
                                "used.",
                                "enum": [
                                    0,
                                    60,
                                    300,
                                    600,
                                    900,
                                    1800,
                                    3600,
                                    7200,
                                    10800,
                                    21600,
                                    43200,
                                    86400,
                                ],
                                "format": "int32",
                                "type": "integer",
                                "x-enum-varnames": [
                                    "ZERO_MINUTES",
                                    "ONE_MINUTE",
                                    "FIVE_MINUTES",
                                    "TEN_MINUTES",
                                    "FIFTEEN_MINUTES",
                                    "THIRTY_MINUTES",
                                    "ONE_HOUR",
                                    "TWO_HOURS",
                                    "THREE_HOURS",
                                    "SIX_HOURS",
                                    "TWELVE_HOURS",
                                    "ONE_DAY",
                                ],
                            },
                            "maxSignalDuration": {
                                "description": "A "
                                "signal "
                                "will "
                                '"close" '
                                "regardless "
                                "of "
                                "the "
                                "query "
                                "being "
                                "matched "
                                "once "
                                "the "
                                "time "
                                "exceeds "
                                "the "
                                "maximum "
                                "duration.\n"
                                "This "
                                "time "
                                "is "
                                "calculated "
                                "from "
                                "the "
                                "first "
                                "seen "
                                "timestamp.",
                                "enum": [
                                    0,
                                    60,
                                    300,
                                    600,
                                    900,
                                    1800,
                                    3600,
                                    7200,
                                    10800,
                                    21600,
                                    43200,
                                    86400,
                                ],
                                "format": "int32",
                                "type": "integer",
                                "x-enum-varnames": [
                                    "ZERO_MINUTES",
                                    "ONE_MINUTE",
                                    "FIVE_MINUTES",
                                    "TEN_MINUTES",
                                    "FIFTEEN_MINUTES",
                                    "THIRTY_MINUTES",
                                    "ONE_HOUR",
                                    "TWO_HOURS",
                                    "THREE_HOURS",
                                    "SIX_HOURS",
                                    "TWELVE_HOURS",
                                    "ONE_DAY",
                                ],
                            },
                            "newValueOptions": {
                                "description": "Options on new value detection method.",
                                "properties": {
                                    "forgetAfter": {
                                        "description": "The "
                                        "duration "
                                        "in "
                                        "days "
                                        "after "
                                        "which "
                                        "a "
                                        "learned "
                                        "value "
                                        "is "
                                        "forgotten.",
                                        "enum": [1, 2, 7, 14, 21, 28],
                                        "format": "int32",
                                        "type": "integer",
                                        "x-enum-varnames": [
                                            "ONE_DAY",
                                            "TWO_DAYS",
                                            "ONE_WEEK",
                                            "TWO_WEEKS",
                                            "THREE_WEEKS",
                                            "FOUR_WEEKS",
                                        ],
                                    },
                                    "learningDuration": {
                                        "default": 0,
                                        "description": "The "
                                        "duration "
                                        "in "
                                        "days "
                                        "during "
                                        "which "
                                        "values "
                                        "are "
                                        "learned, "
                                        "and "
                                        "after "
                                        "which "
                                        "signals "
                                        "will "
                                        "be "
                                        "generated "
                                        "for "
                                        "values "
                                        "that\n"
                                        "weren't "
                                        "learned. "
                                        "If "
                                        "set "
                                        "to "
                                        "0, "
                                        "a "
                                        "signal "
                                        "will "
                                        "be "
                                        "generated "
                                        "for "
                                        "all "
                                        "new "
                                        "values "
                                        "after "
                                        "the "
                                        "first "
                                        "value "
                                        "is "
                                        "learned.",
                                        "enum": [0, 1, 7],
                                        "format": "int32",
                                        "type": "integer",
                                        "x-enum-varnames": ["ZERO_DAYS", "ONE_DAY", "SEVEN_DAYS"],
                                    },
                                    "learningMethod": {
                                        "default": "duration",
                                        "description": "The "
                                        "learning "
                                        "method "
                                        "used "
                                        "to "
                                        "determine "
                                        "when "
                                        "signals "
                                        "should "
                                        "be "
                                        "generated "
                                        "for "
                                        "values "
                                        "that "
                                        "weren't "
                                        "learned.",
                                        "enum": ["duration", "threshold"],
                                        "type": "string",
                                        "x-enum-varnames": ["DURATION", "THRESHOLD"],
                                    },
                                    "learningThreshold": {
                                        "default": 0,
                                        "description": "A "
                                        "number "
                                        "of "
                                        "occurrences "
                                        "after "
                                        "which "
                                        "signals "
                                        "will "
                                        "be "
                                        "generated "
                                        "for "
                                        "values "
                                        "that "
                                        "weren't "
                                        "learned.",
                                        "enum": [0, 1],
                                        "format": "int32",
                                        "type": "integer",
                                        "x-enum-varnames": ["ZERO_OCCURRENCES", "ONE_OCCURRENCE"],
                                    },
                                },
                                "type": "object",
                            },
                            "sequenceDetectionOptions": {
                                "description": "Options on sequence detection method.",
                                "properties": {
                                    "stepTransitions": {
                                        "description": "Transitions "
                                        "defining "
                                        "the "
                                        "allowed "
                                        "order "
                                        "of "
                                        "steps "
                                        "and "
                                        "their "
                                        "evaluation "
                                        "windows.",
                                        "items": {
                                            "description": "Transition "
                                            "from "
                                            "a "
                                            "parent "
                                            "step "
                                            "to "
                                            "a "
                                            "child "
                                            "step "
                                            "within "
                                            "a "
                                            "sequence "
                                            "detection "
                                            "rule.",
                                            "properties": {
                                                "child": {
                                                    "description": "Name of the child step.",
                                                    "type": "string",
                                                },
                                                "evaluationWindow": {
                                                    "description": "A "
                                                    "time "
                                                    "window "
                                                    "is "
                                                    "specified "
                                                    "to "
                                                    "match "
                                                    "when "
                                                    "at "
                                                    "least "
                                                    "one "
                                                    "of "
                                                    "the "
                                                    "cases "
                                                    "matches "
                                                    "true. "
                                                    "This "
                                                    "is "
                                                    "a "
                                                    "sliding "
                                                    "window\n"
                                                    "and "
                                                    "evaluates "
                                                    "in "
                                                    "real "
                                                    "time. "
                                                    "For "
                                                    "third "
                                                    "party "
                                                    "detection "
                                                    "method, "
                                                    "this "
                                                    "field "
                                                    "is "
                                                    "not "
                                                    "used.",
                                                    "enum": [
                                                        0,
                                                        60,
                                                        300,
                                                        600,
                                                        900,
                                                        1800,
                                                        3600,
                                                        7200,
                                                        10800,
                                                        21600,
                                                        43200,
                                                        86400,
                                                    ],
                                                    "format": "int32",
                                                    "type": "integer",
                                                    "x-enum-varnames": [
                                                        "ZERO_MINUTES",
                                                        "ONE_MINUTE",
                                                        "FIVE_MINUTES",
                                                        "TEN_MINUTES",
                                                        "FIFTEEN_MINUTES",
                                                        "THIRTY_MINUTES",
                                                        "ONE_HOUR",
                                                        "TWO_HOURS",
                                                        "THREE_HOURS",
                                                        "SIX_HOURS",
                                                        "TWELVE_HOURS",
                                                        "ONE_DAY",
                                                    ],
                                                },
                                                "parent": {
                                                    "description": "Name of the parent step.",
                                                    "type": "string",
                                                },
                                            },
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "steps": {
                                        "description": "Steps "
                                        "that "
                                        "define "
                                        "the "
                                        "conditions "
                                        "to "
                                        "be "
                                        "matched "
                                        "in "
                                        "sequence.",
                                        "items": {
                                            "description": "Step "
                                            "definition "
                                            "for "
                                            "sequence "
                                            "detection "
                                            "containing "
                                            "the "
                                            "step "
                                            "name, "
                                            "condition, "
                                            "and "
                                            "evaluation "
                                            "window.",
                                            "properties": {
                                                "condition": {
                                                    "description": "Condition "
                                                    "referencing "
                                                    "rule "
                                                    "queries "
                                                    "(e.g., "
                                                    "`a "
                                                    "> "
                                                    "0`).",
                                                    "type": "string",
                                                },
                                                "evaluationWindow": {
                                                    "description": "A "
                                                    "time "
                                                    "window "
                                                    "is "
                                                    "specified "
                                                    "to "
                                                    "match "
                                                    "when "
                                                    "at "
                                                    "least "
                                                    "one "
                                                    "of "
                                                    "the "
                                                    "cases "
                                                    "matches "
                                                    "true. "
                                                    "This "
                                                    "is "
                                                    "a "
                                                    "sliding "
                                                    "window\n"
                                                    "and "
                                                    "evaluates "
                                                    "in "
                                                    "real "
                                                    "time. "
                                                    "For "
                                                    "third "
                                                    "party "
                                                    "detection "
                                                    "method, "
                                                    "this "
                                                    "field "
                                                    "is "
                                                    "not "
                                                    "used.",
                                                    "enum": [
                                                        0,
                                                        60,
                                                        300,
                                                        600,
                                                        900,
                                                        1800,
                                                        3600,
                                                        7200,
                                                        10800,
                                                        21600,
                                                        43200,
                                                        86400,
                                                    ],
                                                    "format": "int32",
                                                    "type": "integer",
                                                    "x-enum-varnames": [
                                                        "ZERO_MINUTES",
                                                        "ONE_MINUTE",
                                                        "FIVE_MINUTES",
                                                        "TEN_MINUTES",
                                                        "FIFTEEN_MINUTES",
                                                        "THIRTY_MINUTES",
                                                        "ONE_HOUR",
                                                        "TWO_HOURS",
                                                        "THREE_HOURS",
                                                        "SIX_HOURS",
                                                        "TWELVE_HOURS",
                                                        "ONE_DAY",
                                                    ],
                                                },
                                                "name": {
                                                    "description": "Unique "
                                                    "name "
                                                    "identifying "
                                                    "the "
                                                    "step.",
                                                    "type": "string",
                                                },
                                            },
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                },
                                "type": "object",
                            },
                            "thirdPartyRuleOptions": {
                                "description": "Options on third party detection method.",
                                "properties": {
                                    "defaultNotifications": {
                                        "description": "Notification "
                                        "targets "
                                        "for "
                                        "the "
                                        "logs "
                                        "that "
                                        "do "
                                        "not "
                                        "correspond "
                                        "to "
                                        "any "
                                        "of "
                                        "the "
                                        "cases.",
                                        "items": {"description": "Notification.", "type": "string"},
                                        "type": "array",
                                    },
                                    "defaultStatus": {
                                        "description": "Severity of the Security Signal.",
                                        "enum": ["info", "low", "medium", "high", "critical"],
                                        "example": "critical",
                                        "type": "string",
                                        "x-enum-varnames": [
                                            "INFO",
                                            "LOW",
                                            "MEDIUM",
                                            "HIGH",
                                            "CRITICAL",
                                        ],
                                    },
                                    "rootQueries": {
                                        "description": "Queries "
                                        "to "
                                        "be "
                                        "combined "
                                        "with "
                                        "third "
                                        "party "
                                        "case "
                                        "queries. "
                                        "Each "
                                        "of "
                                        "them "
                                        "can "
                                        "have "
                                        "different "
                                        "group "
                                        "by "
                                        "fields, "
                                        "to "
                                        "aggregate "
                                        "differently "
                                        "based "
                                        "on "
                                        "the "
                                        "type "
                                        "of "
                                        "alert.",
                                        "items": {
                                            "description": "A "
                                            "query "
                                            "to "
                                            "be "
                                            "combined "
                                            "with "
                                            "the "
                                            "third "
                                            "party "
                                            "case "
                                            "query.",
                                            "properties": {
                                                "groupByFields": {
                                                    "description": "Fields to group by.",
                                                    "items": {
                                                        "description": "Field.",
                                                        "type": "string",
                                                    },
                                                    "type": "array",
                                                },
                                                "query": {
                                                    "description": "Query to run on logs.",
                                                    "example": "source:cloudtrail",
                                                    "type": "string",
                                                },
                                            },
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "signalTitleTemplate": {
                                        "description": "A "
                                        "template "
                                        "for "
                                        "the "
                                        "signal "
                                        "title; "
                                        "if "
                                        "omitted, "
                                        "the "
                                        "title "
                                        "is "
                                        "generated "
                                        "based "
                                        "on "
                                        "the "
                                        "case "
                                        "name.",
                                        "type": "string",
                                    },
                                },
                                "type": "object",
                            },
                        },
                        "type": "object",
                    },
                    "queries": {
                        "description": "Queries for selecting logs which are part of the rule.",
                        "example": [],
                        "items": {
                            "description": "Query for matching rule.",
                            "properties": {
                                "aggregation": {
                                    "description": "The aggregation type.",
                                    "enum": [
                                        "count",
                                        "cardinality",
                                        "sum",
                                        "max",
                                        "new_value",
                                        "geo_data",
                                        "event_count",
                                        "none",
                                    ],
                                    "type": "string",
                                    "x-enum-varnames": [
                                        "COUNT",
                                        "CARDINALITY",
                                        "SUM",
                                        "MAX",
                                        "NEW_VALUE",
                                        "GEO_DATA",
                                        "EVENT_COUNT",
                                        "NONE",
                                    ],
                                },
                                "customQueryExtension": {
                                    "description": "Query extension to append to the logs query.",
                                    "example": "a > 3",
                                    "type": "string",
                                },
                                "dataSource": {
                                    "default": "logs",
                                    "description": "Source "
                                    "of "
                                    "events, "
                                    "either "
                                    "logs, "
                                    "audit "
                                    "trail, "
                                    "or "
                                    "Datadog "
                                    "events.",
                                    "enum": [
                                        "logs",
                                        "audit",
                                        "app_sec_spans",
                                        "spans",
                                        "security_runtime",
                                        "network",
                                        "events",
                                    ],
                                    "example": "logs",
                                    "type": "string",
                                    "x-enum-varnames": [
                                        "LOGS",
                                        "AUDIT",
                                        "APP_SEC_SPANS",
                                        "SPANS",
                                        "SECURITY_RUNTIME",
                                        "NETWORK",
                                        "EVENTS",
                                    ],
                                },
                                "distinctFields": {
                                    "description": "Field "
                                    "for "
                                    "which "
                                    "the "
                                    "cardinality "
                                    "is "
                                    "measured. "
                                    "Sent "
                                    "as "
                                    "an "
                                    "array.",
                                    "items": {"description": "Field.", "type": "string"},
                                    "type": "array",
                                },
                                "groupByFields": {
                                    "description": "Fields to group by.",
                                    "items": {"description": "Field.", "type": "string"},
                                    "type": "array",
                                },
                                "hasOptionalGroupByFields": {
                                    "default": False,
                                    "description": "When "
                                    "false, "
                                    "events "
                                    "without "
                                    "a "
                                    "group-by "
                                    "value "
                                    "are "
                                    "ignored "
                                    "by "
                                    "the "
                                    "rule. "
                                    "When "
                                    "true, "
                                    "events "
                                    "with "
                                    "missing "
                                    "group-by "
                                    "fields "
                                    "are "
                                    "processed "
                                    "with "
                                    "`N/A`, "
                                    "replacing "
                                    "the "
                                    "missing "
                                    "values.",
                                    "example": False,
                                    "type": "boolean",
                                },
                                "index": {
                                    "description": "**This "
                                    "field "
                                    "is "
                                    "currently "
                                    "unstable "
                                    "and "
                                    "might "
                                    "be "
                                    "removed "
                                    "in "
                                    "a "
                                    "minor "
                                    "version "
                                    "upgrade.**\n"
                                    "The "
                                    "index "
                                    "to "
                                    "run "
                                    "the "
                                    "query "
                                    "on, "
                                    "if "
                                    "the "
                                    "`dataSource` "
                                    "is "
                                    "`logs`. "
                                    "Only "
                                    "used "
                                    "for "
                                    "scheduled "
                                    "rules "
                                    "- "
                                    "in "
                                    "other "
                                    "words, "
                                    "when "
                                    "the "
                                    "`schedulingOptions` "
                                    "field "
                                    "is "
                                    "present "
                                    "in "
                                    "the "
                                    "rule "
                                    "payload.",
                                    "type": "string",
                                },
                                "indexes": {
                                    "description": "List "
                                    "of "
                                    "indexes "
                                    "to "
                                    "query "
                                    "when "
                                    "the "
                                    "`dataSource` "
                                    "is "
                                    "`logs`. "
                                    "Only "
                                    "used "
                                    "for "
                                    "scheduled "
                                    "rules, "
                                    "such "
                                    "as "
                                    "when "
                                    "the "
                                    "`schedulingOptions` "
                                    "field "
                                    "is "
                                    "present "
                                    "in "
                                    "the "
                                    "rule "
                                    "payload.",
                                    "items": {"description": "Index.", "type": "string"},
                                    "type": "array",
                                },
                                "metric": {
                                    "deprecated": True,
                                    "description": "(Deprecated) "
                                    "The "
                                    "target "
                                    "field "
                                    "to "
                                    "aggregate "
                                    "over "
                                    "when "
                                    "using "
                                    "the "
                                    "sum "
                                    "or "
                                    "max\n"
                                    "aggregations. "
                                    "`metrics` "
                                    "field "
                                    "should "
                                    "be "
                                    "used "
                                    "instead.",
                                    "type": "string",
                                },
                                "metrics": {
                                    "description": "Group "
                                    "of "
                                    "target "
                                    "fields "
                                    "to "
                                    "aggregate "
                                    "over "
                                    "when "
                                    "using "
                                    "the "
                                    "sum, "
                                    "max, "
                                    "geo "
                                    "data, "
                                    "or "
                                    "new "
                                    "value "
                                    "aggregations. "
                                    "The "
                                    "sum, "
                                    "max, "
                                    "and "
                                    "geo "
                                    "data "
                                    "aggregations "
                                    "only "
                                    "accept "
                                    "one "
                                    "value "
                                    "in "
                                    "this "
                                    "list, "
                                    "whereas "
                                    "the "
                                    "new "
                                    "value "
                                    "aggregation "
                                    "accepts "
                                    "up "
                                    "to "
                                    "five "
                                    "values.",
                                    "items": {"description": "Field.", "type": "string"},
                                    "type": "array",
                                },
                                "name": {"description": "Name of the query.", "type": "string"},
                                "query": {
                                    "description": "Query to run on logs.",
                                    "example": "a > 3",
                                    "type": "string",
                                },
                            },
                            "type": "object",
                        },
                        "type": "array",
                    },
                    "referenceTables": {
                        "description": "Reference tables for the rule.",
                        "items": {
                            "description": "Reference tables used in the queries.",
                            "properties": {
                                "checkPresence": {
                                    "description": "Whether "
                                    "to "
                                    "include "
                                    "or "
                                    "exclude "
                                    "the "
                                    "matched "
                                    "values.",
                                    "type": "boolean",
                                },
                                "columnName": {
                                    "description": "The name of the column in the reference table.",
                                    "type": "string",
                                },
                                "logFieldPath": {
                                    "description": "The "
                                    "field "
                                    "in "
                                    "the "
                                    "log "
                                    "to "
                                    "match "
                                    "against "
                                    "the "
                                    "reference "
                                    "table.",
                                    "type": "string",
                                },
                                "ruleQueryName": {
                                    "description": "The "
                                    "name "
                                    "of "
                                    "the "
                                    "query "
                                    "to "
                                    "apply "
                                    "the "
                                    "reference "
                                    "table "
                                    "to.",
                                    "type": "string",
                                },
                                "tableName": {
                                    "description": "The name of the reference table.",
                                    "type": "string",
                                },
                            },
                            "type": "object",
                        },
                        "type": "array",
                    },
                    "schedulingOptions": {
                        "description": "Options for scheduled "
                        "rules. When this "
                        "field is present, the "
                        "rule runs based on "
                        "the schedule. When "
                        "absent, it runs "
                        "real-time on ingested "
                        "logs.",
                        "nullable": True,
                        "properties": {
                            "rrule": {
                                "description": "Schedule "
                                "for "
                                "the "
                                "rule "
                                "queries, "
                                "written "
                                "in "
                                "RRULE "
                                "syntax. "
                                "See "
                                "[RFC](https://icalendar.org/iCalendar-RFC-5545/3-8-5-3-recurrence-rule.html) "
                                "for "
                                "syntax "
                                "reference.",
                                "example": "FREQ=HOURLY;INTERVAL=1;",
                                "type": "string",
                            },
                            "start": {
                                "description": "Start "
                                "date "
                                "for "
                                "the "
                                "schedule, "
                                "in "
                                "ISO "
                                "8601 "
                                "format "
                                "without "
                                "timezone.",
                                "example": "2025-07-14T12:00:00",
                                "type": "string",
                            },
                            "timezone": {
                                "description": "Time "
                                "zone "
                                "of "
                                "the "
                                "start "
                                "date, "
                                "in "
                                "the "
                                "[tz "
                                "database](https://en.wikipedia.org/wiki/List_of_tz_database_time_zones) "
                                "format.",
                                "example": "America/New_York",
                                "type": "string",
                            },
                        },
                        "type": "object",
                    },
                    "tags": {
                        "description": "Tags for generated signals.",
                        "example": ["env:prod", "team:security"],
                        "items": {"description": "Tag.", "type": "string"},
                        "type": "array",
                    },
                    "thirdPartyCases": {
                        "description": "Cases for generating "
                        "signals from "
                        "third-party rules. Only "
                        "available for "
                        "third-party rules.",
                        "example": [],
                        "items": {
                            "description": "Case when a signal is generated by a third party rule.",
                            "properties": {
                                "name": {"description": "Name of the case.", "type": "string"},
                                "notifications": {
                                    "description": "Notification targets for each case.",
                                    "items": {"description": "Notification.", "type": "string"},
                                    "type": "array",
                                },
                                "query": {
                                    "description": "A "
                                    "query "
                                    "to "
                                    "map "
                                    "a "
                                    "third "
                                    "party "
                                    "event "
                                    "to "
                                    "this "
                                    "case.",
                                    "type": "string",
                                },
                                "status": {
                                    "description": "Severity of the Security Signal.",
                                    "enum": ["info", "low", "medium", "high", "critical"],
                                    "example": "critical",
                                    "type": "string",
                                    "x-enum-varnames": [
                                        "INFO",
                                        "LOW",
                                        "MEDIUM",
                                        "HIGH",
                                        "CRITICAL",
                                    ],
                                },
                            },
                            "required": ["status"],
                            "type": "object",
                        },
                        "type": "array",
                    },
                    "type": {
                        "description": "The rule type.",
                        "enum": [
                            "api_security",
                            "application_security",
                            "log_detection",
                            "workload_security",
                        ],
                        "type": "string",
                        "x-enum-varnames": [
                            "API_SECURITY",
                            "APPLICATION_SECURITY",
                            "LOG_DETECTION",
                            "WORKLOAD_SECURITY",
                        ],
                    },
                },
                "required": ["name", "isEnabled", "queries", "options", "cases", "message"],
                "type": "object",
            },
            {
                "description": "Create a new signal correlation rule.",
                "properties": {
                    "cases": {
                        "description": "Cases for generating signals.",
                        "example": [],
                        "items": {
                            "description": "Case when signal is generated.",
                            "properties": {
                                "actions": {
                                    "description": "Action to perform for each rule case.",
                                    "items": {
                                        "description": "Action "
                                        "to "
                                        "perform "
                                        "when "
                                        "a "
                                        "signal "
                                        "is "
                                        "triggered. "
                                        "Only "
                                        "available "
                                        "for "
                                        "Application "
                                        "Security "
                                        "rule "
                                        "type.",
                                        "properties": {
                                            "options": {
                                                "additionalProperties": {},
                                                "description": "Options for the rule action",
                                                "properties": {
                                                    "duration": {
                                                        "description": "Duration "
                                                        "of "
                                                        "the "
                                                        "action "
                                                        "in "
                                                        "seconds. "
                                                        "0 "
                                                        "indicates "
                                                        "no "
                                                        "expiration.",
                                                        "example": 0,
                                                        "format": "int64",
                                                        "minimum": 0,
                                                        "type": "integer",
                                                    },
                                                    "flaggedIPType": {
                                                        "description": "Used "
                                                        "with "
                                                        "the "
                                                        "case "
                                                        "action "
                                                        "of "
                                                        "type "
                                                        "'flag_ip'. "
                                                        "The "
                                                        "value "
                                                        "specified "
                                                        "in "
                                                        "this "
                                                        "field "
                                                        "is "
                                                        "applied "
                                                        "as "
                                                        "a "
                                                        "flag "
                                                        "to "
                                                        "the "
                                                        "IP "
                                                        "addresses.",
                                                        "enum": ["SUSPICIOUS", "FLAGGED"],
                                                        "example": "FLAGGED",
                                                        "type": "string",
                                                        "x-enum-varnames": [
                                                            "SUSPICIOUS",
                                                            "FLAGGED",
                                                        ],
                                                    },
                                                    "userBehaviorName": {
                                                        "description": "Used "
                                                        "with "
                                                        "the "
                                                        "case "
                                                        "action "
                                                        "of "
                                                        "type "
                                                        "'user_behavior'. "
                                                        "The "
                                                        "value "
                                                        "specified "
                                                        "in "
                                                        "this "
                                                        "field "
                                                        "is "
                                                        "applied "
                                                        "as "
                                                        "a "
                                                        "risk "
                                                        "tag "
                                                        "to "
                                                        "all "
                                                        "users "
                                                        "affected "
                                                        "by "
                                                        "the "
                                                        "rule.",
                                                        "type": "string",
                                                    },
                                                },
                                                "type": "object",
                                            },
                                            "type": {
                                                "description": "The action type.",
                                                "enum": [
                                                    "block_ip",
                                                    "block_user",
                                                    "user_behavior",
                                                    "flag_ip",
                                                ],
                                                "type": "string",
                                                "x-enum-varnames": [
                                                    "BLOCK_IP",
                                                    "BLOCK_USER",
                                                    "USER_BEHAVIOR",
                                                    "FLAG_IP",
                                                ],
                                            },
                                        },
                                        "type": "object",
                                    },
                                    "type": "array",
                                },
                                "condition": {
                                    "description": "A "
                                    "case "
                                    "contains "
                                    "logical "
                                    "operations "
                                    "(`>`,`>=`, "
                                    "`&&`, "
                                    "`||`) "
                                    "to "
                                    "determine "
                                    "if "
                                    "a "
                                    "signal "
                                    "should "
                                    "be "
                                    "generated\n"
                                    "based "
                                    "on "
                                    "the "
                                    "event "
                                    "counts "
                                    "in "
                                    "the "
                                    "previously "
                                    "defined "
                                    "queries.",
                                    "type": "string",
                                },
                                "name": {"description": "Name of the case.", "type": "string"},
                                "notifications": {
                                    "description": "Notification targets.",
                                    "items": {"description": "Notification.", "type": "string"},
                                    "type": "array",
                                },
                                "status": {
                                    "description": "Severity of the Security Signal.",
                                    "enum": ["info", "low", "medium", "high", "critical"],
                                    "example": "critical",
                                    "type": "string",
                                    "x-enum-varnames": [
                                        "INFO",
                                        "LOW",
                                        "MEDIUM",
                                        "HIGH",
                                        "CRITICAL",
                                    ],
                                },
                            },
                            "required": ["status"],
                            "type": "object",
                        },
                        "type": "array",
                    },
                    "filters": {
                        "description": "Additional queries to filter "
                        "matched events before they are "
                        "processed. This field is "
                        "deprecated for log detection, "
                        "signal correlation, and "
                        "workload security rules.",
                        "items": {
                            "description": "The rule's suppression filter.",
                            "properties": {
                                "action": {
                                    "description": "The type of filtering action.",
                                    "enum": ["require", "suppress"],
                                    "type": "string",
                                    "x-enum-varnames": ["REQUIRE", "SUPPRESS"],
                                },
                                "query": {
                                    "description": "Query "
                                    "for "
                                    "selecting "
                                    "logs "
                                    "to "
                                    "apply "
                                    "the "
                                    "filtering "
                                    "action.",
                                    "type": "string",
                                },
                            },
                            "type": "object",
                        },
                        "type": "array",
                    },
                    "hasExtendedTitle": {
                        "description": "Whether the "
                        "notifications include "
                        "the triggering "
                        "group-by values in "
                        "their title.",
                        "example": True,
                        "type": "boolean",
                    },
                    "isEnabled": {
                        "description": "Whether the rule is enabled.",
                        "example": True,
                        "type": "boolean",
                    },
                    "message": {
                        "description": "Message for generated signals.",
                        "example": "",
                        "type": "string",
                    },
                    "name": {
                        "description": "The name of the rule.",
                        "example": "My security monitoring rule.",
                        "type": "string",
                    },
                    "options": {
                        "description": "Options.",
                        "properties": {
                            "complianceRuleOptions": {
                                "additionalProperties": {},
                                "description": "Options "
                                "for "
                                "cloud_configuration "
                                "rules.\n"
                                "Fields "
                                "`resourceType` "
                                "and "
                                "`regoRule` "
                                "are "
                                "mandatory "
                                "when "
                                "managing "
                                "custom "
                                "`cloud_configuration` "
                                "rules.",
                                "properties": {
                                    "complexRule": {
                                        "description": "Whether "
                                        "the "
                                        "rule "
                                        "is "
                                        "a "
                                        "complex "
                                        "one.\n"
                                        "Must "
                                        "be "
                                        "set "
                                        "to "
                                        "true "
                                        "if "
                                        "`regoRule.resourceTypes` "
                                        "contains "
                                        "more "
                                        "than "
                                        "one "
                                        "item. "
                                        "Defaults "
                                        "to "
                                        "false.",
                                        "type": "boolean",
                                    },
                                    "regoRule": {
                                        "description": "Rule details.",
                                        "properties": {
                                            "policy": {
                                                "description": "The "
                                                "policy "
                                                "written "
                                                "in "
                                                "`rego`, "
                                                "see: "
                                                "https://www.openpolicyagent.org/docs/latest/policy-language/",
                                                "example": "package "
                                                "datadog\n"
                                                "\n"
                                                "import "
                                                "data.datadog.output "
                                                "as "
                                                "dd_output\n"
                                                "import "
                                                "future.keywords.contains\n"
                                                "import "
                                                "future.keywords.if\n"
                                                "import "
                                                "future.keywords.in\n"
                                                "\n"
                                                "eval(resource) "
                                                "= "
                                                '"skip" '
                                                "if "
                                                "{\n"
                                                "  "
                                                "# "
                                                "Logic "
                                                "that "
                                                "evaluates "
                                                "to "
                                                "true "
                                                "if "
                                                "the "
                                                "resource "
                                                "should "
                                                "be "
                                                "skipped\n"
                                                "  "
                                                "true\n"
                                                "} "
                                                "else "
                                                "= "
                                                '"pass" '
                                                "{\n"
                                                "  "
                                                "# "
                                                "Logic "
                                                "that "
                                                "evaluates "
                                                "to "
                                                "true "
                                                "if "
                                                "the "
                                                "resource "
                                                "is "
                                                "compliant\n"
                                                "  "
                                                "true\n"
                                                "} "
                                                "else "
                                                "= "
                                                '"fail" '
                                                "{\n"
                                                "  "
                                                "# "
                                                "Logic "
                                                "that "
                                                "evaluates "
                                                "to "
                                                "true "
                                                "if "
                                                "the "
                                                "resource "
                                                "is "
                                                "not "
                                                "compliant\n"
                                                "  "
                                                "true\n"
                                                "}\n"
                                                "\n"
                                                "# "
                                                "This "
                                                "part "
                                                "remains "
                                                "unchanged "
                                                "for "
                                                "all "
                                                "rules\n"
                                                "results "
                                                "contains "
                                                "result "
                                                "if "
                                                "{\n"
                                                "  "
                                                "some "
                                                "resource "
                                                "in "
                                                "input.resources[input.main_resource_type]\n"
                                                "  "
                                                "result "
                                                ":= "
                                                "dd_output.format(resource, "
                                                "eval(resource))\n"
                                                "}",
                                                "type": "string",
                                            },
                                            "resourceTypes": {
                                                "description": "List "
                                                "of "
                                                "resource "
                                                "types "
                                                "that "
                                                "will "
                                                "be "
                                                "evaluated "
                                                "upon. "
                                                "Must "
                                                "have "
                                                "at "
                                                "least "
                                                "one "
                                                "element.",
                                                "example": [
                                                    "gcp_iam_service_account",
                                                    "gcp_iam_policy",
                                                ],
                                                "items": {"type": "string"},
                                                "type": "array",
                                            },
                                        },
                                        "required": ["policy", "resourceTypes"],
                                        "type": "object",
                                    },
                                    "resourceType": {
                                        "description": "Main "
                                        "resource "
                                        "type "
                                        "to "
                                        "be "
                                        "checked "
                                        "by "
                                        "the "
                                        "rule. "
                                        "It "
                                        "should "
                                        "be "
                                        "specified "
                                        "again "
                                        "in "
                                        "`regoRule.resourceTypes`.",
                                        "example": "aws_acm",
                                        "type": "string",
                                    },
                                },
                                "type": "object",
                            },
                            "decreaseCriticalityBasedOnEnv": {
                                "description": "If "
                                "true, "
                                "signals "
                                "in "
                                "non-production "
                                "environments "
                                "have "
                                "a "
                                "lower "
                                "severity "
                                "than "
                                "what "
                                "is "
                                "defined "
                                "by "
                                "the "
                                "rule "
                                "case, "
                                "which "
                                "can "
                                "reduce "
                                "signal "
                                "noise.\n"
                                "The "
                                "severity "
                                "is "
                                "decreased "
                                "by "
                                "one "
                                "level: "
                                "`CRITICAL` "
                                "in "
                                "production "
                                "becomes "
                                "`HIGH` "
                                "in "
                                "non-production, "
                                "`HIGH` "
                                "becomes "
                                "`MEDIUM` "
                                "and "
                                "so "
                                "on. "
                                "`INFO` "
                                "remains "
                                "`INFO`.\n"
                                "The "
                                "decrement "
                                "is "
                                "applied "
                                "when "
                                "the "
                                "environment "
                                "tag "
                                "of "
                                "the "
                                "signal "
                                "starts "
                                "with "
                                "`staging`, "
                                "`test` "
                                "or "
                                "`dev`.",
                                "example": False,
                                "type": "boolean",
                            },
                            "detectionMethod": {
                                "description": "The detection method.",
                                "enum": [
                                    "threshold",
                                    "new_value",
                                    "anomaly_detection",
                                    "impossible_travel",
                                    "hardcoded",
                                    "third_party",
                                    "anomaly_threshold",
                                    "sequence_detection",
                                ],
                                "type": "string",
                                "x-enum-varnames": [
                                    "THRESHOLD",
                                    "NEW_VALUE",
                                    "ANOMALY_DETECTION",
                                    "IMPOSSIBLE_TRAVEL",
                                    "HARDCODED",
                                    "THIRD_PARTY",
                                    "ANOMALY_THRESHOLD",
                                    "SEQUENCE_DETECTION",
                                ],
                            },
                            "evaluationWindow": {
                                "description": "A "
                                "time "
                                "window "
                                "is "
                                "specified "
                                "to "
                                "match "
                                "when "
                                "at "
                                "least "
                                "one "
                                "of "
                                "the "
                                "cases "
                                "matches "
                                "true. "
                                "This "
                                "is "
                                "a "
                                "sliding "
                                "window\n"
                                "and "
                                "evaluates "
                                "in "
                                "real "
                                "time. "
                                "For "
                                "third "
                                "party "
                                "detection "
                                "method, "
                                "this "
                                "field "
                                "is "
                                "not "
                                "used.",
                                "enum": [
                                    0,
                                    60,
                                    300,
                                    600,
                                    900,
                                    1800,
                                    3600,
                                    7200,
                                    10800,
                                    21600,
                                    43200,
                                    86400,
                                ],
                                "format": "int32",
                                "type": "integer",
                                "x-enum-varnames": [
                                    "ZERO_MINUTES",
                                    "ONE_MINUTE",
                                    "FIVE_MINUTES",
                                    "TEN_MINUTES",
                                    "FIFTEEN_MINUTES",
                                    "THIRTY_MINUTES",
                                    "ONE_HOUR",
                                    "TWO_HOURS",
                                    "THREE_HOURS",
                                    "SIX_HOURS",
                                    "TWELVE_HOURS",
                                    "ONE_DAY",
                                ],
                            },
                            "hardcodedEvaluatorType": {
                                "description": "Hardcoded evaluator type.",
                                "enum": ["log4shell"],
                                "type": "string",
                                "x-enum-varnames": ["LOG4SHELL"],
                            },
                            "impossibleTravelOptions": {
                                "description": "Options on impossible travel detection method.",
                                "properties": {
                                    "baselineUserLocations": {
                                        "description": "If "
                                        "true, "
                                        "signals "
                                        "are "
                                        "suppressed "
                                        "for "
                                        "the "
                                        "first "
                                        "24 "
                                        "hours. "
                                        "In "
                                        "that "
                                        "time, "
                                        "Datadog "
                                        "learns "
                                        "the "
                                        "user's "
                                        "regular\n"
                                        "access "
                                        "locations. "
                                        "This "
                                        "can "
                                        "be "
                                        "helpful "
                                        "to "
                                        "reduce "
                                        "noise "
                                        "and "
                                        "infer "
                                        "VPN "
                                        "usage "
                                        "or "
                                        "credentialed "
                                        "API "
                                        "access.",
                                        "example": True,
                                        "type": "boolean",
                                    }
                                },
                                "type": "object",
                            },
                            "keepAlive": {
                                "description": "Once "
                                "a "
                                "signal "
                                "is "
                                "generated, "
                                "the "
                                "signal "
                                "will "
                                "remain "
                                '"open" '
                                "if "
                                "a "
                                "case "
                                "is "
                                "matched "
                                "at "
                                "least "
                                "once "
                                "within\n"
                                "this "
                                "keep "
                                "alive "
                                "window. "
                                "For "
                                "third "
                                "party "
                                "detection "
                                "method, "
                                "this "
                                "field "
                                "is "
                                "not "
                                "used.",
                                "enum": [
                                    0,
                                    60,
                                    300,
                                    600,
                                    900,
                                    1800,
                                    3600,
                                    7200,
                                    10800,
                                    21600,
                                    43200,
                                    86400,
                                ],
                                "format": "int32",
                                "type": "integer",
                                "x-enum-varnames": [
                                    "ZERO_MINUTES",
                                    "ONE_MINUTE",
                                    "FIVE_MINUTES",
                                    "TEN_MINUTES",
                                    "FIFTEEN_MINUTES",
                                    "THIRTY_MINUTES",
                                    "ONE_HOUR",
                                    "TWO_HOURS",
                                    "THREE_HOURS",
                                    "SIX_HOURS",
                                    "TWELVE_HOURS",
                                    "ONE_DAY",
                                ],
                            },
                            "maxSignalDuration": {
                                "description": "A "
                                "signal "
                                "will "
                                '"close" '
                                "regardless "
                                "of "
                                "the "
                                "query "
                                "being "
                                "matched "
                                "once "
                                "the "
                                "time "
                                "exceeds "
                                "the "
                                "maximum "
                                "duration.\n"
                                "This "
                                "time "
                                "is "
                                "calculated "
                                "from "
                                "the "
                                "first "
                                "seen "
                                "timestamp.",
                                "enum": [
                                    0,
                                    60,
                                    300,
                                    600,
                                    900,
                                    1800,
                                    3600,
                                    7200,
                                    10800,
                                    21600,
                                    43200,
                                    86400,
                                ],
                                "format": "int32",
                                "type": "integer",
                                "x-enum-varnames": [
                                    "ZERO_MINUTES",
                                    "ONE_MINUTE",
                                    "FIVE_MINUTES",
                                    "TEN_MINUTES",
                                    "FIFTEEN_MINUTES",
                                    "THIRTY_MINUTES",
                                    "ONE_HOUR",
                                    "TWO_HOURS",
                                    "THREE_HOURS",
                                    "SIX_HOURS",
                                    "TWELVE_HOURS",
                                    "ONE_DAY",
                                ],
                            },
                            "newValueOptions": {
                                "description": "Options on new value detection method.",
                                "properties": {
                                    "forgetAfter": {
                                        "description": "The "
                                        "duration "
                                        "in "
                                        "days "
                                        "after "
                                        "which "
                                        "a "
                                        "learned "
                                        "value "
                                        "is "
                                        "forgotten.",
                                        "enum": [1, 2, 7, 14, 21, 28],
                                        "format": "int32",
                                        "type": "integer",
                                        "x-enum-varnames": [
                                            "ONE_DAY",
                                            "TWO_DAYS",
                                            "ONE_WEEK",
                                            "TWO_WEEKS",
                                            "THREE_WEEKS",
                                            "FOUR_WEEKS",
                                        ],
                                    },
                                    "learningDuration": {
                                        "default": 0,
                                        "description": "The "
                                        "duration "
                                        "in "
                                        "days "
                                        "during "
                                        "which "
                                        "values "
                                        "are "
                                        "learned, "
                                        "and "
                                        "after "
                                        "which "
                                        "signals "
                                        "will "
                                        "be "
                                        "generated "
                                        "for "
                                        "values "
                                        "that\n"
                                        "weren't "
                                        "learned. "
                                        "If "
                                        "set "
                                        "to "
                                        "0, "
                                        "a "
                                        "signal "
                                        "will "
                                        "be "
                                        "generated "
                                        "for "
                                        "all "
                                        "new "
                                        "values "
                                        "after "
                                        "the "
                                        "first "
                                        "value "
                                        "is "
                                        "learned.",
                                        "enum": [0, 1, 7],
                                        "format": "int32",
                                        "type": "integer",
                                        "x-enum-varnames": ["ZERO_DAYS", "ONE_DAY", "SEVEN_DAYS"],
                                    },
                                    "learningMethod": {
                                        "default": "duration",
                                        "description": "The "
                                        "learning "
                                        "method "
                                        "used "
                                        "to "
                                        "determine "
                                        "when "
                                        "signals "
                                        "should "
                                        "be "
                                        "generated "
                                        "for "
                                        "values "
                                        "that "
                                        "weren't "
                                        "learned.",
                                        "enum": ["duration", "threshold"],
                                        "type": "string",
                                        "x-enum-varnames": ["DURATION", "THRESHOLD"],
                                    },
                                    "learningThreshold": {
                                        "default": 0,
                                        "description": "A "
                                        "number "
                                        "of "
                                        "occurrences "
                                        "after "
                                        "which "
                                        "signals "
                                        "will "
                                        "be "
                                        "generated "
                                        "for "
                                        "values "
                                        "that "
                                        "weren't "
                                        "learned.",
                                        "enum": [0, 1],
                                        "format": "int32",
                                        "type": "integer",
                                        "x-enum-varnames": ["ZERO_OCCURRENCES", "ONE_OCCURRENCE"],
                                    },
                                },
                                "type": "object",
                            },
                            "sequenceDetectionOptions": {
                                "description": "Options on sequence detection method.",
                                "properties": {
                                    "stepTransitions": {
                                        "description": "Transitions "
                                        "defining "
                                        "the "
                                        "allowed "
                                        "order "
                                        "of "
                                        "steps "
                                        "and "
                                        "their "
                                        "evaluation "
                                        "windows.",
                                        "items": {
                                            "description": "Transition "
                                            "from "
                                            "a "
                                            "parent "
                                            "step "
                                            "to "
                                            "a "
                                            "child "
                                            "step "
                                            "within "
                                            "a "
                                            "sequence "
                                            "detection "
                                            "rule.",
                                            "properties": {
                                                "child": {
                                                    "description": "Name of the child step.",
                                                    "type": "string",
                                                },
                                                "evaluationWindow": {
                                                    "description": "A "
                                                    "time "
                                                    "window "
                                                    "is "
                                                    "specified "
                                                    "to "
                                                    "match "
                                                    "when "
                                                    "at "
                                                    "least "
                                                    "one "
                                                    "of "
                                                    "the "
                                                    "cases "
                                                    "matches "
                                                    "true. "
                                                    "This "
                                                    "is "
                                                    "a "
                                                    "sliding "
                                                    "window\n"
                                                    "and "
                                                    "evaluates "
                                                    "in "
                                                    "real "
                                                    "time. "
                                                    "For "
                                                    "third "
                                                    "party "
                                                    "detection "
                                                    "method, "
                                                    "this "
                                                    "field "
                                                    "is "
                                                    "not "
                                                    "used.",
                                                    "enum": [
                                                        0,
                                                        60,
                                                        300,
                                                        600,
                                                        900,
                                                        1800,
                                                        3600,
                                                        7200,
                                                        10800,
                                                        21600,
                                                        43200,
                                                        86400,
                                                    ],
                                                    "format": "int32",
                                                    "type": "integer",
                                                    "x-enum-varnames": [
                                                        "ZERO_MINUTES",
                                                        "ONE_MINUTE",
                                                        "FIVE_MINUTES",
                                                        "TEN_MINUTES",
                                                        "FIFTEEN_MINUTES",
                                                        "THIRTY_MINUTES",
                                                        "ONE_HOUR",
                                                        "TWO_HOURS",
                                                        "THREE_HOURS",
                                                        "SIX_HOURS",
                                                        "TWELVE_HOURS",
                                                        "ONE_DAY",
                                                    ],
                                                },
                                                "parent": {
                                                    "description": "Name of the parent step.",
                                                    "type": "string",
                                                },
                                            },
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "steps": {
                                        "description": "Steps "
                                        "that "
                                        "define "
                                        "the "
                                        "conditions "
                                        "to "
                                        "be "
                                        "matched "
                                        "in "
                                        "sequence.",
                                        "items": {
                                            "description": "Step "
                                            "definition "
                                            "for "
                                            "sequence "
                                            "detection "
                                            "containing "
                                            "the "
                                            "step "
                                            "name, "
                                            "condition, "
                                            "and "
                                            "evaluation "
                                            "window.",
                                            "properties": {
                                                "condition": {
                                                    "description": "Condition "
                                                    "referencing "
                                                    "rule "
                                                    "queries "
                                                    "(e.g., "
                                                    "`a "
                                                    "> "
                                                    "0`).",
                                                    "type": "string",
                                                },
                                                "evaluationWindow": {
                                                    "description": "A "
                                                    "time "
                                                    "window "
                                                    "is "
                                                    "specified "
                                                    "to "
                                                    "match "
                                                    "when "
                                                    "at "
                                                    "least "
                                                    "one "
                                                    "of "
                                                    "the "
                                                    "cases "
                                                    "matches "
                                                    "true. "
                                                    "This "
                                                    "is "
                                                    "a "
                                                    "sliding "
                                                    "window\n"
                                                    "and "
                                                    "evaluates "
                                                    "in "
                                                    "real "
                                                    "time. "
                                                    "For "
                                                    "third "
                                                    "party "
                                                    "detection "
                                                    "method, "
                                                    "this "
                                                    "field "
                                                    "is "
                                                    "not "
                                                    "used.",
                                                    "enum": [
                                                        0,
                                                        60,
                                                        300,
                                                        600,
                                                        900,
                                                        1800,
                                                        3600,
                                                        7200,
                                                        10800,
                                                        21600,
                                                        43200,
                                                        86400,
                                                    ],
                                                    "format": "int32",
                                                    "type": "integer",
                                                    "x-enum-varnames": [
                                                        "ZERO_MINUTES",
                                                        "ONE_MINUTE",
                                                        "FIVE_MINUTES",
                                                        "TEN_MINUTES",
                                                        "FIFTEEN_MINUTES",
                                                        "THIRTY_MINUTES",
                                                        "ONE_HOUR",
                                                        "TWO_HOURS",
                                                        "THREE_HOURS",
                                                        "SIX_HOURS",
                                                        "TWELVE_HOURS",
                                                        "ONE_DAY",
                                                    ],
                                                },
                                                "name": {
                                                    "description": "Unique "
                                                    "name "
                                                    "identifying "
                                                    "the "
                                                    "step.",
                                                    "type": "string",
                                                },
                                            },
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                },
                                "type": "object",
                            },
                            "thirdPartyRuleOptions": {
                                "description": "Options on third party detection method.",
                                "properties": {
                                    "defaultNotifications": {
                                        "description": "Notification "
                                        "targets "
                                        "for "
                                        "the "
                                        "logs "
                                        "that "
                                        "do "
                                        "not "
                                        "correspond "
                                        "to "
                                        "any "
                                        "of "
                                        "the "
                                        "cases.",
                                        "items": {"description": "Notification.", "type": "string"},
                                        "type": "array",
                                    },
                                    "defaultStatus": {
                                        "description": "Severity of the Security Signal.",
                                        "enum": ["info", "low", "medium", "high", "critical"],
                                        "example": "critical",
                                        "type": "string",
                                        "x-enum-varnames": [
                                            "INFO",
                                            "LOW",
                                            "MEDIUM",
                                            "HIGH",
                                            "CRITICAL",
                                        ],
                                    },
                                    "rootQueries": {
                                        "description": "Queries "
                                        "to "
                                        "be "
                                        "combined "
                                        "with "
                                        "third "
                                        "party "
                                        "case "
                                        "queries. "
                                        "Each "
                                        "of "
                                        "them "
                                        "can "
                                        "have "
                                        "different "
                                        "group "
                                        "by "
                                        "fields, "
                                        "to "
                                        "aggregate "
                                        "differently "
                                        "based "
                                        "on "
                                        "the "
                                        "type "
                                        "of "
                                        "alert.",
                                        "items": {
                                            "description": "A "
                                            "query "
                                            "to "
                                            "be "
                                            "combined "
                                            "with "
                                            "the "
                                            "third "
                                            "party "
                                            "case "
                                            "query.",
                                            "properties": {
                                                "groupByFields": {
                                                    "description": "Fields to group by.",
                                                    "items": {
                                                        "description": "Field.",
                                                        "type": "string",
                                                    },
                                                    "type": "array",
                                                },
                                                "query": {
                                                    "description": "Query to run on logs.",
                                                    "example": "source:cloudtrail",
                                                    "type": "string",
                                                },
                                            },
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "signalTitleTemplate": {
                                        "description": "A "
                                        "template "
                                        "for "
                                        "the "
                                        "signal "
                                        "title; "
                                        "if "
                                        "omitted, "
                                        "the "
                                        "title "
                                        "is "
                                        "generated "
                                        "based "
                                        "on "
                                        "the "
                                        "case "
                                        "name.",
                                        "type": "string",
                                    },
                                },
                                "type": "object",
                            },
                        },
                        "type": "object",
                    },
                    "queries": {
                        "description": "Queries for selecting signals which are part of the rule.",
                        "example": [],
                        "items": {
                            "description": "Query for matching rule on signals.",
                            "properties": {
                                "aggregation": {
                                    "description": "The aggregation type.",
                                    "enum": [
                                        "count",
                                        "cardinality",
                                        "sum",
                                        "max",
                                        "new_value",
                                        "geo_data",
                                        "event_count",
                                        "none",
                                    ],
                                    "type": "string",
                                    "x-enum-varnames": [
                                        "COUNT",
                                        "CARDINALITY",
                                        "SUM",
                                        "MAX",
                                        "NEW_VALUE",
                                        "GEO_DATA",
                                        "EVENT_COUNT",
                                        "NONE",
                                    ],
                                },
                                "correlatedByFields": {
                                    "description": "Fields to group by.",
                                    "items": {"description": "Field.", "type": "string"},
                                    "type": "array",
                                },
                                "correlatedQueryIndex": {
                                    "description": "Index "
                                    "of "
                                    "the "
                                    "rule "
                                    "query "
                                    "used "
                                    "to "
                                    "retrieve "
                                    "the "
                                    "correlated "
                                    "field.",
                                    "format": "int32",
                                    "maximum": 9,
                                    "type": "integer",
                                },
                                "metrics": {
                                    "description": "Group of target fields to aggregate over.",
                                    "items": {"description": "Field.", "type": "string"},
                                    "type": "array",
                                },
                                "name": {"description": "Name of the query.", "type": "string"},
                                "ruleId": {
                                    "description": "Rule ID to match on signals.",
                                    "example": "org-ru1-e1d",
                                    "type": "string",
                                },
                            },
                            "required": ["ruleId"],
                            "type": "object",
                        },
                        "type": "array",
                    },
                    "tags": {
                        "description": "Tags for generated signals.",
                        "example": ["env:prod", "team:security"],
                        "items": {"description": "Tag.", "type": "string"},
                        "type": "array",
                    },
                    "type": {
                        "description": "The rule type.",
                        "enum": ["signal_correlation"],
                        "type": "string",
                        "x-enum-varnames": ["SIGNAL_CORRELATION"],
                    },
                },
                "required": ["name", "isEnabled", "queries", "options", "cases", "message"],
                "type": "object",
            },
            {
                "description": "Create a new cloud configuration rule.",
                "properties": {
                    "cases": {
                        "description": "Description of generated findings "
                        "and signals (severity and "
                        "channels to be notified in case "
                        "of a signal). Must contain "
                        "exactly one item.",
                        "items": {
                            "description": "Description of signals.",
                            "properties": {
                                "notifications": {
                                    "description": "Notification targets for each rule case.",
                                    "items": {"description": "Notification.", "type": "string"},
                                    "type": "array",
                                },
                                "status": {
                                    "description": "Severity of the Security Signal.",
                                    "enum": ["info", "low", "medium", "high", "critical"],
                                    "example": "critical",
                                    "type": "string",
                                    "x-enum-varnames": [
                                        "INFO",
                                        "LOW",
                                        "MEDIUM",
                                        "HIGH",
                                        "CRITICAL",
                                    ],
                                },
                            },
                            "required": ["status"],
                            "type": "object",
                        },
                        "type": "array",
                    },
                    "complianceSignalOptions": {
                        "description": "How to generate "
                        "compliance "
                        "signals. Useful "
                        "for "
                        "cloud_configuration "
                        "rules only.",
                        "properties": {
                            "defaultActivationStatus": {
                                "description": "The default activation status.",
                                "nullable": True,
                                "type": "boolean",
                            },
                            "defaultGroupByFields": {
                                "description": "The default group by fields.",
                                "items": {"type": "string"},
                                "nullable": True,
                                "type": "array",
                            },
                            "userActivationStatus": {
                                "description": "Whether signals will be sent.",
                                "nullable": True,
                                "type": "boolean",
                            },
                            "userGroupByFields": {
                                "description": "Fields "
                                "to "
                                "use "
                                "to "
                                "group "
                                "findings "
                                "by "
                                "when "
                                "sending "
                                "signals.",
                                "items": {"type": "string"},
                                "nullable": True,
                                "type": "array",
                            },
                        },
                        "type": "object",
                    },
                    "filters": {
                        "description": "Additional queries to filter "
                        "matched events before they are "
                        "processed.",
                        "items": {
                            "description": "The rule's suppression filter.",
                            "properties": {
                                "action": {
                                    "description": "The type of filtering action.",
                                    "enum": ["require", "suppress"],
                                    "type": "string",
                                    "x-enum-varnames": ["REQUIRE", "SUPPRESS"],
                                },
                                "query": {
                                    "description": "Query "
                                    "for "
                                    "selecting "
                                    "logs "
                                    "to "
                                    "apply "
                                    "the "
                                    "filtering "
                                    "action.",
                                    "type": "string",
                                },
                            },
                            "type": "object",
                        },
                        "type": "array",
                    },
                    "isEnabled": {
                        "description": "Whether the rule is enabled.",
                        "example": True,
                        "type": "boolean",
                    },
                    "message": {
                        "description": "Message in markdown format for "
                        "generated findings and signals.",
                        "example": "#Description\n"
                        "Explanation of the rule.\n"
                        "\n"
                        "#Remediation\n"
                        "How to fix the security issue.",
                        "type": "string",
                    },
                    "name": {
                        "description": "The name of the rule.",
                        "example": "My security monitoring rule.",
                        "type": "string",
                    },
                    "options": {
                        "description": "Options on cloud configuration rules.",
                        "properties": {
                            "complianceRuleOptions": {
                                "additionalProperties": {},
                                "description": "Options "
                                "for "
                                "cloud_configuration "
                                "rules.\n"
                                "Fields "
                                "`resourceType` "
                                "and "
                                "`regoRule` "
                                "are "
                                "mandatory "
                                "when "
                                "managing "
                                "custom "
                                "`cloud_configuration` "
                                "rules.",
                                "properties": {
                                    "complexRule": {
                                        "description": "Whether "
                                        "the "
                                        "rule "
                                        "is "
                                        "a "
                                        "complex "
                                        "one.\n"
                                        "Must "
                                        "be "
                                        "set "
                                        "to "
                                        "true "
                                        "if "
                                        "`regoRule.resourceTypes` "
                                        "contains "
                                        "more "
                                        "than "
                                        "one "
                                        "item. "
                                        "Defaults "
                                        "to "
                                        "false.",
                                        "type": "boolean",
                                    },
                                    "regoRule": {
                                        "description": "Rule details.",
                                        "properties": {
                                            "policy": {
                                                "description": "The "
                                                "policy "
                                                "written "
                                                "in "
                                                "`rego`, "
                                                "see: "
                                                "https://www.openpolicyagent.org/docs/latest/policy-language/",
                                                "example": "package "
                                                "datadog\n"
                                                "\n"
                                                "import "
                                                "data.datadog.output "
                                                "as "
                                                "dd_output\n"
                                                "import "
                                                "future.keywords.contains\n"
                                                "import "
                                                "future.keywords.if\n"
                                                "import "
                                                "future.keywords.in\n"
                                                "\n"
                                                "eval(resource) "
                                                "= "
                                                '"skip" '
                                                "if "
                                                "{\n"
                                                "  "
                                                "# "
                                                "Logic "
                                                "that "
                                                "evaluates "
                                                "to "
                                                "true "
                                                "if "
                                                "the "
                                                "resource "
                                                "should "
                                                "be "
                                                "skipped\n"
                                                "  "
                                                "true\n"
                                                "} "
                                                "else "
                                                "= "
                                                '"pass" '
                                                "{\n"
                                                "  "
                                                "# "
                                                "Logic "
                                                "that "
                                                "evaluates "
                                                "to "
                                                "true "
                                                "if "
                                                "the "
                                                "resource "
                                                "is "
                                                "compliant\n"
                                                "  "
                                                "true\n"
                                                "} "
                                                "else "
                                                "= "
                                                '"fail" '
                                                "{\n"
                                                "  "
                                                "# "
                                                "Logic "
                                                "that "
                                                "evaluates "
                                                "to "
                                                "true "
                                                "if "
                                                "the "
                                                "resource "
                                                "is "
                                                "not "
                                                "compliant\n"
                                                "  "
                                                "true\n"
                                                "}\n"
                                                "\n"
                                                "# "
                                                "This "
                                                "part "
                                                "remains "
                                                "unchanged "
                                                "for "
                                                "all "
                                                "rules\n"
                                                "results "
                                                "contains "
                                                "result "
                                                "if "
                                                "{\n"
                                                "  "
                                                "some "
                                                "resource "
                                                "in "
                                                "input.resources[input.main_resource_type]\n"
                                                "  "
                                                "result "
                                                ":= "
                                                "dd_output.format(resource, "
                                                "eval(resource))\n"
                                                "}",
                                                "type": "string",
                                            },
                                            "resourceTypes": {
                                                "description": "List "
                                                "of "
                                                "resource "
                                                "types "
                                                "that "
                                                "will "
                                                "be "
                                                "evaluated "
                                                "upon. "
                                                "Must "
                                                "have "
                                                "at "
                                                "least "
                                                "one "
                                                "element.",
                                                "example": [
                                                    "gcp_iam_service_account",
                                                    "gcp_iam_policy",
                                                ],
                                                "items": {"type": "string"},
                                                "type": "array",
                                            },
                                        },
                                        "required": ["policy", "resourceTypes"],
                                        "type": "object",
                                    },
                                    "resourceType": {
                                        "description": "Main "
                                        "resource "
                                        "type "
                                        "to "
                                        "be "
                                        "checked "
                                        "by "
                                        "the "
                                        "rule. "
                                        "It "
                                        "should "
                                        "be "
                                        "specified "
                                        "again "
                                        "in "
                                        "`regoRule.resourceTypes`.",
                                        "example": "aws_acm",
                                        "type": "string",
                                    },
                                },
                                "type": "object",
                            }
                        },
                        "required": ["complianceRuleOptions"],
                        "type": "object",
                    },
                    "tags": {
                        "description": "Tags for generated findings and signals.",
                        "example": ["env:prod", "team:security"],
                        "items": {"description": "Tag.", "type": "string"},
                        "type": "array",
                    },
                    "type": {
                        "description": "The rule type.",
                        "enum": ["cloud_configuration"],
                        "type": "string",
                        "x-enum-varnames": ["CLOUD_CONFIGURATION"],
                    },
                },
                "required": [
                    "name",
                    "isEnabled",
                    "options",
                    "complianceSignalOptions",
                    "cases",
                    "message",
                ],
                "type": "object",
            },
        ],
    },
    "CONVERTRULEJSONTOTERRAFORM_REQUEST_BODY_SCHEMA": {
        "description": "Convert a rule from JSON to Terraform.",
        "oneOf": [
            {
                "description": "The payload of a rule.",
                "properties": {
                    "calculatedFields": {
                        "description": "Calculated fields. "
                        "Only allowed for "
                        "scheduled rules - in "
                        "other words, when "
                        "schedulingOptions is "
                        "also defined.",
                        "items": {
                            "description": "Calculated field.",
                            "properties": {
                                "expression": {
                                    "description": "Expression.",
                                    "example": "@request_end_timestamp - @request_start_timestamp",
                                    "type": "string",
                                },
                                "name": {
                                    "description": "Field name.",
                                    "example": "response_time",
                                    "type": "string",
                                },
                            },
                            "required": ["name", "expression"],
                            "type": "object",
                        },
                        "type": "array",
                    },
                    "cases": {
                        "description": "Cases for generating signals.",
                        "example": [],
                        "items": {
                            "description": "Case when signal is generated.",
                            "properties": {
                                "actions": {
                                    "description": "Action to perform for each rule case.",
                                    "items": {
                                        "description": "Action "
                                        "to "
                                        "perform "
                                        "when "
                                        "a "
                                        "signal "
                                        "is "
                                        "triggered. "
                                        "Only "
                                        "available "
                                        "for "
                                        "Application "
                                        "Security "
                                        "rule "
                                        "type.",
                                        "properties": {
                                            "options": {
                                                "additionalProperties": {},
                                                "description": "Options for the rule action",
                                                "properties": {
                                                    "duration": {
                                                        "description": "Duration "
                                                        "of "
                                                        "the "
                                                        "action "
                                                        "in "
                                                        "seconds. "
                                                        "0 "
                                                        "indicates "
                                                        "no "
                                                        "expiration.",
                                                        "example": 0,
                                                        "format": "int64",
                                                        "minimum": 0,
                                                        "type": "integer",
                                                    },
                                                    "flaggedIPType": {
                                                        "description": "Used "
                                                        "with "
                                                        "the "
                                                        "case "
                                                        "action "
                                                        "of "
                                                        "type "
                                                        "'flag_ip'. "
                                                        "The "
                                                        "value "
                                                        "specified "
                                                        "in "
                                                        "this "
                                                        "field "
                                                        "is "
                                                        "applied "
                                                        "as "
                                                        "a "
                                                        "flag "
                                                        "to "
                                                        "the "
                                                        "IP "
                                                        "addresses.",
                                                        "enum": ["SUSPICIOUS", "FLAGGED"],
                                                        "example": "FLAGGED",
                                                        "type": "string",
                                                        "x-enum-varnames": [
                                                            "SUSPICIOUS",
                                                            "FLAGGED",
                                                        ],
                                                    },
                                                    "userBehaviorName": {
                                                        "description": "Used "
                                                        "with "
                                                        "the "
                                                        "case "
                                                        "action "
                                                        "of "
                                                        "type "
                                                        "'user_behavior'. "
                                                        "The "
                                                        "value "
                                                        "specified "
                                                        "in "
                                                        "this "
                                                        "field "
                                                        "is "
                                                        "applied "
                                                        "as "
                                                        "a "
                                                        "risk "
                                                        "tag "
                                                        "to "
                                                        "all "
                                                        "users "
                                                        "affected "
                                                        "by "
                                                        "the "
                                                        "rule.",
                                                        "type": "string",
                                                    },
                                                },
                                                "type": "object",
                                            },
                                            "type": {
                                                "description": "The action type.",
                                                "enum": [
                                                    "block_ip",
                                                    "block_user",
                                                    "user_behavior",
                                                    "flag_ip",
                                                ],
                                                "type": "string",
                                                "x-enum-varnames": [
                                                    "BLOCK_IP",
                                                    "BLOCK_USER",
                                                    "USER_BEHAVIOR",
                                                    "FLAG_IP",
                                                ],
                                            },
                                        },
                                        "type": "object",
                                    },
                                    "type": "array",
                                },
                                "condition": {
                                    "description": "A "
                                    "case "
                                    "contains "
                                    "logical "
                                    "operations "
                                    "(`>`,`>=`, "
                                    "`&&`, "
                                    "`||`) "
                                    "to "
                                    "determine "
                                    "if "
                                    "a "
                                    "signal "
                                    "should "
                                    "be "
                                    "generated\n"
                                    "based "
                                    "on "
                                    "the "
                                    "event "
                                    "counts "
                                    "in "
                                    "the "
                                    "previously "
                                    "defined "
                                    "queries.",
                                    "type": "string",
                                },
                                "name": {"description": "Name of the case.", "type": "string"},
                                "notifications": {
                                    "description": "Notification targets.",
                                    "items": {"description": "Notification.", "type": "string"},
                                    "type": "array",
                                },
                                "status": {
                                    "description": "Severity of the Security Signal.",
                                    "enum": ["info", "low", "medium", "high", "critical"],
                                    "example": "critical",
                                    "type": "string",
                                    "x-enum-varnames": [
                                        "INFO",
                                        "LOW",
                                        "MEDIUM",
                                        "HIGH",
                                        "CRITICAL",
                                    ],
                                },
                            },
                            "required": ["status"],
                            "type": "object",
                        },
                        "type": "array",
                    },
                    "customMessage": {
                        "description": "Custom/Overridden message "
                        "for generated signals "
                        "(used in case of Default "
                        "rule update).",
                        "type": "string",
                    },
                    "customName": {
                        "description": "Custom/Overridden name of "
                        "the rule (used in case of "
                        "Default rule update).",
                        "type": "string",
                    },
                    "filters": {
                        "description": "Additional queries to filter "
                        "matched events before they are "
                        "processed. This field is "
                        "deprecated for log detection, "
                        "signal correlation, and "
                        "workload security rules.",
                        "items": {
                            "description": "The rule's suppression filter.",
                            "properties": {
                                "action": {
                                    "description": "The type of filtering action.",
                                    "enum": ["require", "suppress"],
                                    "type": "string",
                                    "x-enum-varnames": ["REQUIRE", "SUPPRESS"],
                                },
                                "query": {
                                    "description": "Query "
                                    "for "
                                    "selecting "
                                    "logs "
                                    "to "
                                    "apply "
                                    "the "
                                    "filtering "
                                    "action.",
                                    "type": "string",
                                },
                            },
                            "type": "object",
                        },
                        "type": "array",
                    },
                    "groupSignalsBy": {
                        "description": "Additional grouping to "
                        "perform on top of the "
                        "existing groups in the "
                        "query section. Must be a "
                        "subset of the existing "
                        "groups.",
                        "example": ["service"],
                        "items": {"description": "Field to group by.", "type": "string"},
                        "type": "array",
                    },
                    "hasExtendedTitle": {
                        "description": "Whether the "
                        "notifications include "
                        "the triggering "
                        "group-by values in "
                        "their title.",
                        "example": True,
                        "type": "boolean",
                    },
                    "isEnabled": {
                        "description": "Whether the rule is enabled.",
                        "example": True,
                        "type": "boolean",
                    },
                    "message": {
                        "description": "Message for generated signals.",
                        "example": "",
                        "type": "string",
                    },
                    "name": {
                        "description": "The name of the rule.",
                        "example": "My security monitoring rule.",
                        "type": "string",
                    },
                    "options": {
                        "description": "Options.",
                        "properties": {
                            "complianceRuleOptions": {
                                "additionalProperties": {},
                                "description": "Options "
                                "for "
                                "cloud_configuration "
                                "rules.\n"
                                "Fields "
                                "`resourceType` "
                                "and "
                                "`regoRule` "
                                "are "
                                "mandatory "
                                "when "
                                "managing "
                                "custom "
                                "`cloud_configuration` "
                                "rules.",
                                "properties": {
                                    "complexRule": {
                                        "description": "Whether "
                                        "the "
                                        "rule "
                                        "is "
                                        "a "
                                        "complex "
                                        "one.\n"
                                        "Must "
                                        "be "
                                        "set "
                                        "to "
                                        "true "
                                        "if "
                                        "`regoRule.resourceTypes` "
                                        "contains "
                                        "more "
                                        "than "
                                        "one "
                                        "item. "
                                        "Defaults "
                                        "to "
                                        "false.",
                                        "type": "boolean",
                                    },
                                    "regoRule": {
                                        "description": "Rule details.",
                                        "properties": {
                                            "policy": {
                                                "description": "The "
                                                "policy "
                                                "written "
                                                "in "
                                                "`rego`, "
                                                "see: "
                                                "https://www.openpolicyagent.org/docs/latest/policy-language/",
                                                "example": "package "
                                                "datadog\n"
                                                "\n"
                                                "import "
                                                "data.datadog.output "
                                                "as "
                                                "dd_output\n"
                                                "import "
                                                "future.keywords.contains\n"
                                                "import "
                                                "future.keywords.if\n"
                                                "import "
                                                "future.keywords.in\n"
                                                "\n"
                                                "eval(resource) "
                                                "= "
                                                '"skip" '
                                                "if "
                                                "{\n"
                                                "  "
                                                "# "
                                                "Logic "
                                                "that "
                                                "evaluates "
                                                "to "
                                                "true "
                                                "if "
                                                "the "
                                                "resource "
                                                "should "
                                                "be "
                                                "skipped\n"
                                                "  "
                                                "true\n"
                                                "} "
                                                "else "
                                                "= "
                                                '"pass" '
                                                "{\n"
                                                "  "
                                                "# "
                                                "Logic "
                                                "that "
                                                "evaluates "
                                                "to "
                                                "true "
                                                "if "
                                                "the "
                                                "resource "
                                                "is "
                                                "compliant\n"
                                                "  "
                                                "true\n"
                                                "} "
                                                "else "
                                                "= "
                                                '"fail" '
                                                "{\n"
                                                "  "
                                                "# "
                                                "Logic "
                                                "that "
                                                "evaluates "
                                                "to "
                                                "true "
                                                "if "
                                                "the "
                                                "resource "
                                                "is "
                                                "not "
                                                "compliant\n"
                                                "  "
                                                "true\n"
                                                "}\n"
                                                "\n"
                                                "# "
                                                "This "
                                                "part "
                                                "remains "
                                                "unchanged "
                                                "for "
                                                "all "
                                                "rules\n"
                                                "results "
                                                "contains "
                                                "result "
                                                "if "
                                                "{\n"
                                                "  "
                                                "some "
                                                "resource "
                                                "in "
                                                "input.resources[input.main_resource_type]\n"
                                                "  "
                                                "result "
                                                ":= "
                                                "dd_output.format(resource, "
                                                "eval(resource))\n"
                                                "}",
                                                "type": "string",
                                            },
                                            "resourceTypes": {
                                                "description": "List "
                                                "of "
                                                "resource "
                                                "types "
                                                "that "
                                                "will "
                                                "be "
                                                "evaluated "
                                                "upon. "
                                                "Must "
                                                "have "
                                                "at "
                                                "least "
                                                "one "
                                                "element.",
                                                "example": [
                                                    "gcp_iam_service_account",
                                                    "gcp_iam_policy",
                                                ],
                                                "items": {"type": "string"},
                                                "type": "array",
                                            },
                                        },
                                        "required": ["policy", "resourceTypes"],
                                        "type": "object",
                                    },
                                    "resourceType": {
                                        "description": "Main "
                                        "resource "
                                        "type "
                                        "to "
                                        "be "
                                        "checked "
                                        "by "
                                        "the "
                                        "rule. "
                                        "It "
                                        "should "
                                        "be "
                                        "specified "
                                        "again "
                                        "in "
                                        "`regoRule.resourceTypes`.",
                                        "example": "aws_acm",
                                        "type": "string",
                                    },
                                },
                                "type": "object",
                            },
                            "decreaseCriticalityBasedOnEnv": {
                                "description": "If "
                                "true, "
                                "signals "
                                "in "
                                "non-production "
                                "environments "
                                "have "
                                "a "
                                "lower "
                                "severity "
                                "than "
                                "what "
                                "is "
                                "defined "
                                "by "
                                "the "
                                "rule "
                                "case, "
                                "which "
                                "can "
                                "reduce "
                                "signal "
                                "noise.\n"
                                "The "
                                "severity "
                                "is "
                                "decreased "
                                "by "
                                "one "
                                "level: "
                                "`CRITICAL` "
                                "in "
                                "production "
                                "becomes "
                                "`HIGH` "
                                "in "
                                "non-production, "
                                "`HIGH` "
                                "becomes "
                                "`MEDIUM` "
                                "and "
                                "so "
                                "on. "
                                "`INFO` "
                                "remains "
                                "`INFO`.\n"
                                "The "
                                "decrement "
                                "is "
                                "applied "
                                "when "
                                "the "
                                "environment "
                                "tag "
                                "of "
                                "the "
                                "signal "
                                "starts "
                                "with "
                                "`staging`, "
                                "`test` "
                                "or "
                                "`dev`.",
                                "example": False,
                                "type": "boolean",
                            },
                            "detectionMethod": {
                                "description": "The detection method.",
                                "enum": [
                                    "threshold",
                                    "new_value",
                                    "anomaly_detection",
                                    "impossible_travel",
                                    "hardcoded",
                                    "third_party",
                                    "anomaly_threshold",
                                    "sequence_detection",
                                ],
                                "type": "string",
                                "x-enum-varnames": [
                                    "THRESHOLD",
                                    "NEW_VALUE",
                                    "ANOMALY_DETECTION",
                                    "IMPOSSIBLE_TRAVEL",
                                    "HARDCODED",
                                    "THIRD_PARTY",
                                    "ANOMALY_THRESHOLD",
                                    "SEQUENCE_DETECTION",
                                ],
                            },
                            "evaluationWindow": {
                                "description": "A "
                                "time "
                                "window "
                                "is "
                                "specified "
                                "to "
                                "match "
                                "when "
                                "at "
                                "least "
                                "one "
                                "of "
                                "the "
                                "cases "
                                "matches "
                                "true. "
                                "This "
                                "is "
                                "a "
                                "sliding "
                                "window\n"
                                "and "
                                "evaluates "
                                "in "
                                "real "
                                "time. "
                                "For "
                                "third "
                                "party "
                                "detection "
                                "method, "
                                "this "
                                "field "
                                "is "
                                "not "
                                "used.",
                                "enum": [
                                    0,
                                    60,
                                    300,
                                    600,
                                    900,
                                    1800,
                                    3600,
                                    7200,
                                    10800,
                                    21600,
                                    43200,
                                    86400,
                                ],
                                "format": "int32",
                                "type": "integer",
                                "x-enum-varnames": [
                                    "ZERO_MINUTES",
                                    "ONE_MINUTE",
                                    "FIVE_MINUTES",
                                    "TEN_MINUTES",
                                    "FIFTEEN_MINUTES",
                                    "THIRTY_MINUTES",
                                    "ONE_HOUR",
                                    "TWO_HOURS",
                                    "THREE_HOURS",
                                    "SIX_HOURS",
                                    "TWELVE_HOURS",
                                    "ONE_DAY",
                                ],
                            },
                            "hardcodedEvaluatorType": {
                                "description": "Hardcoded evaluator type.",
                                "enum": ["log4shell"],
                                "type": "string",
                                "x-enum-varnames": ["LOG4SHELL"],
                            },
                            "impossibleTravelOptions": {
                                "description": "Options on impossible travel detection method.",
                                "properties": {
                                    "baselineUserLocations": {
                                        "description": "If "
                                        "true, "
                                        "signals "
                                        "are "
                                        "suppressed "
                                        "for "
                                        "the "
                                        "first "
                                        "24 "
                                        "hours. "
                                        "In "
                                        "that "
                                        "time, "
                                        "Datadog "
                                        "learns "
                                        "the "
                                        "user's "
                                        "regular\n"
                                        "access "
                                        "locations. "
                                        "This "
                                        "can "
                                        "be "
                                        "helpful "
                                        "to "
                                        "reduce "
                                        "noise "
                                        "and "
                                        "infer "
                                        "VPN "
                                        "usage "
                                        "or "
                                        "credentialed "
                                        "API "
                                        "access.",
                                        "example": True,
                                        "type": "boolean",
                                    }
                                },
                                "type": "object",
                            },
                            "keepAlive": {
                                "description": "Once "
                                "a "
                                "signal "
                                "is "
                                "generated, "
                                "the "
                                "signal "
                                "will "
                                "remain "
                                '"open" '
                                "if "
                                "a "
                                "case "
                                "is "
                                "matched "
                                "at "
                                "least "
                                "once "
                                "within\n"
                                "this "
                                "keep "
                                "alive "
                                "window. "
                                "For "
                                "third "
                                "party "
                                "detection "
                                "method, "
                                "this "
                                "field "
                                "is "
                                "not "
                                "used.",
                                "enum": [
                                    0,
                                    60,
                                    300,
                                    600,
                                    900,
                                    1800,
                                    3600,
                                    7200,
                                    10800,
                                    21600,
                                    43200,
                                    86400,
                                ],
                                "format": "int32",
                                "type": "integer",
                                "x-enum-varnames": [
                                    "ZERO_MINUTES",
                                    "ONE_MINUTE",
                                    "FIVE_MINUTES",
                                    "TEN_MINUTES",
                                    "FIFTEEN_MINUTES",
                                    "THIRTY_MINUTES",
                                    "ONE_HOUR",
                                    "TWO_HOURS",
                                    "THREE_HOURS",
                                    "SIX_HOURS",
                                    "TWELVE_HOURS",
                                    "ONE_DAY",
                                ],
                            },
                            "maxSignalDuration": {
                                "description": "A "
                                "signal "
                                "will "
                                '"close" '
                                "regardless "
                                "of "
                                "the "
                                "query "
                                "being "
                                "matched "
                                "once "
                                "the "
                                "time "
                                "exceeds "
                                "the "
                                "maximum "
                                "duration.\n"
                                "This "
                                "time "
                                "is "
                                "calculated "
                                "from "
                                "the "
                                "first "
                                "seen "
                                "timestamp.",
                                "enum": [
                                    0,
                                    60,
                                    300,
                                    600,
                                    900,
                                    1800,
                                    3600,
                                    7200,
                                    10800,
                                    21600,
                                    43200,
                                    86400,
                                ],
                                "format": "int32",
                                "type": "integer",
                                "x-enum-varnames": [
                                    "ZERO_MINUTES",
                                    "ONE_MINUTE",
                                    "FIVE_MINUTES",
                                    "TEN_MINUTES",
                                    "FIFTEEN_MINUTES",
                                    "THIRTY_MINUTES",
                                    "ONE_HOUR",
                                    "TWO_HOURS",
                                    "THREE_HOURS",
                                    "SIX_HOURS",
                                    "TWELVE_HOURS",
                                    "ONE_DAY",
                                ],
                            },
                            "newValueOptions": {
                                "description": "Options on new value detection method.",
                                "properties": {
                                    "forgetAfter": {
                                        "description": "The "
                                        "duration "
                                        "in "
                                        "days "
                                        "after "
                                        "which "
                                        "a "
                                        "learned "
                                        "value "
                                        "is "
                                        "forgotten.",
                                        "enum": [1, 2, 7, 14, 21, 28],
                                        "format": "int32",
                                        "type": "integer",
                                        "x-enum-varnames": [
                                            "ONE_DAY",
                                            "TWO_DAYS",
                                            "ONE_WEEK",
                                            "TWO_WEEKS",
                                            "THREE_WEEKS",
                                            "FOUR_WEEKS",
                                        ],
                                    },
                                    "learningDuration": {
                                        "default": 0,
                                        "description": "The "
                                        "duration "
                                        "in "
                                        "days "
                                        "during "
                                        "which "
                                        "values "
                                        "are "
                                        "learned, "
                                        "and "
                                        "after "
                                        "which "
                                        "signals "
                                        "will "
                                        "be "
                                        "generated "
                                        "for "
                                        "values "
                                        "that\n"
                                        "weren't "
                                        "learned. "
                                        "If "
                                        "set "
                                        "to "
                                        "0, "
                                        "a "
                                        "signal "
                                        "will "
                                        "be "
                                        "generated "
                                        "for "
                                        "all "
                                        "new "
                                        "values "
                                        "after "
                                        "the "
                                        "first "
                                        "value "
                                        "is "
                                        "learned.",
                                        "enum": [0, 1, 7],
                                        "format": "int32",
                                        "type": "integer",
                                        "x-enum-varnames": ["ZERO_DAYS", "ONE_DAY", "SEVEN_DAYS"],
                                    },
                                    "learningMethod": {
                                        "default": "duration",
                                        "description": "The "
                                        "learning "
                                        "method "
                                        "used "
                                        "to "
                                        "determine "
                                        "when "
                                        "signals "
                                        "should "
                                        "be "
                                        "generated "
                                        "for "
                                        "values "
                                        "that "
                                        "weren't "
                                        "learned.",
                                        "enum": ["duration", "threshold"],
                                        "type": "string",
                                        "x-enum-varnames": ["DURATION", "THRESHOLD"],
                                    },
                                    "learningThreshold": {
                                        "default": 0,
                                        "description": "A "
                                        "number "
                                        "of "
                                        "occurrences "
                                        "after "
                                        "which "
                                        "signals "
                                        "will "
                                        "be "
                                        "generated "
                                        "for "
                                        "values "
                                        "that "
                                        "weren't "
                                        "learned.",
                                        "enum": [0, 1],
                                        "format": "int32",
                                        "type": "integer",
                                        "x-enum-varnames": ["ZERO_OCCURRENCES", "ONE_OCCURRENCE"],
                                    },
                                },
                                "type": "object",
                            },
                            "sequenceDetectionOptions": {
                                "description": "Options on sequence detection method.",
                                "properties": {
                                    "stepTransitions": {
                                        "description": "Transitions "
                                        "defining "
                                        "the "
                                        "allowed "
                                        "order "
                                        "of "
                                        "steps "
                                        "and "
                                        "their "
                                        "evaluation "
                                        "windows.",
                                        "items": {
                                            "description": "Transition "
                                            "from "
                                            "a "
                                            "parent "
                                            "step "
                                            "to "
                                            "a "
                                            "child "
                                            "step "
                                            "within "
                                            "a "
                                            "sequence "
                                            "detection "
                                            "rule.",
                                            "properties": {
                                                "child": {
                                                    "description": "Name of the child step.",
                                                    "type": "string",
                                                },
                                                "evaluationWindow": {
                                                    "description": "A "
                                                    "time "
                                                    "window "
                                                    "is "
                                                    "specified "
                                                    "to "
                                                    "match "
                                                    "when "
                                                    "at "
                                                    "least "
                                                    "one "
                                                    "of "
                                                    "the "
                                                    "cases "
                                                    "matches "
                                                    "true. "
                                                    "This "
                                                    "is "
                                                    "a "
                                                    "sliding "
                                                    "window\n"
                                                    "and "
                                                    "evaluates "
                                                    "in "
                                                    "real "
                                                    "time. "
                                                    "For "
                                                    "third "
                                                    "party "
                                                    "detection "
                                                    "method, "
                                                    "this "
                                                    "field "
                                                    "is "
                                                    "not "
                                                    "used.",
                                                    "enum": [
                                                        0,
                                                        60,
                                                        300,
                                                        600,
                                                        900,
                                                        1800,
                                                        3600,
                                                        7200,
                                                        10800,
                                                        21600,
                                                        43200,
                                                        86400,
                                                    ],
                                                    "format": "int32",
                                                    "type": "integer",
                                                    "x-enum-varnames": [
                                                        "ZERO_MINUTES",
                                                        "ONE_MINUTE",
                                                        "FIVE_MINUTES",
                                                        "TEN_MINUTES",
                                                        "FIFTEEN_MINUTES",
                                                        "THIRTY_MINUTES",
                                                        "ONE_HOUR",
                                                        "TWO_HOURS",
                                                        "THREE_HOURS",
                                                        "SIX_HOURS",
                                                        "TWELVE_HOURS",
                                                        "ONE_DAY",
                                                    ],
                                                },
                                                "parent": {
                                                    "description": "Name of the parent step.",
                                                    "type": "string",
                                                },
                                            },
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "steps": {
                                        "description": "Steps "
                                        "that "
                                        "define "
                                        "the "
                                        "conditions "
                                        "to "
                                        "be "
                                        "matched "
                                        "in "
                                        "sequence.",
                                        "items": {
                                            "description": "Step "
                                            "definition "
                                            "for "
                                            "sequence "
                                            "detection "
                                            "containing "
                                            "the "
                                            "step "
                                            "name, "
                                            "condition, "
                                            "and "
                                            "evaluation "
                                            "window.",
                                            "properties": {
                                                "condition": {
                                                    "description": "Condition "
                                                    "referencing "
                                                    "rule "
                                                    "queries "
                                                    "(e.g., "
                                                    "`a "
                                                    "> "
                                                    "0`).",
                                                    "type": "string",
                                                },
                                                "evaluationWindow": {
                                                    "description": "A "
                                                    "time "
                                                    "window "
                                                    "is "
                                                    "specified "
                                                    "to "
                                                    "match "
                                                    "when "
                                                    "at "
                                                    "least "
                                                    "one "
                                                    "of "
                                                    "the "
                                                    "cases "
                                                    "matches "
                                                    "true. "
                                                    "This "
                                                    "is "
                                                    "a "
                                                    "sliding "
                                                    "window\n"
                                                    "and "
                                                    "evaluates "
                                                    "in "
                                                    "real "
                                                    "time. "
                                                    "For "
                                                    "third "
                                                    "party "
                                                    "detection "
                                                    "method, "
                                                    "this "
                                                    "field "
                                                    "is "
                                                    "not "
                                                    "used.",
                                                    "enum": [
                                                        0,
                                                        60,
                                                        300,
                                                        600,
                                                        900,
                                                        1800,
                                                        3600,
                                                        7200,
                                                        10800,
                                                        21600,
                                                        43200,
                                                        86400,
                                                    ],
                                                    "format": "int32",
                                                    "type": "integer",
                                                    "x-enum-varnames": [
                                                        "ZERO_MINUTES",
                                                        "ONE_MINUTE",
                                                        "FIVE_MINUTES",
                                                        "TEN_MINUTES",
                                                        "FIFTEEN_MINUTES",
                                                        "THIRTY_MINUTES",
                                                        "ONE_HOUR",
                                                        "TWO_HOURS",
                                                        "THREE_HOURS",
                                                        "SIX_HOURS",
                                                        "TWELVE_HOURS",
                                                        "ONE_DAY",
                                                    ],
                                                },
                                                "name": {
                                                    "description": "Unique "
                                                    "name "
                                                    "identifying "
                                                    "the "
                                                    "step.",
                                                    "type": "string",
                                                },
                                            },
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                },
                                "type": "object",
                            },
                            "thirdPartyRuleOptions": {
                                "description": "Options on third party detection method.",
                                "properties": {
                                    "defaultNotifications": {
                                        "description": "Notification "
                                        "targets "
                                        "for "
                                        "the "
                                        "logs "
                                        "that "
                                        "do "
                                        "not "
                                        "correspond "
                                        "to "
                                        "any "
                                        "of "
                                        "the "
                                        "cases.",
                                        "items": {"description": "Notification.", "type": "string"},
                                        "type": "array",
                                    },
                                    "defaultStatus": {
                                        "description": "Severity of the Security Signal.",
                                        "enum": ["info", "low", "medium", "high", "critical"],
                                        "example": "critical",
                                        "type": "string",
                                        "x-enum-varnames": [
                                            "INFO",
                                            "LOW",
                                            "MEDIUM",
                                            "HIGH",
                                            "CRITICAL",
                                        ],
                                    },
                                    "rootQueries": {
                                        "description": "Queries "
                                        "to "
                                        "be "
                                        "combined "
                                        "with "
                                        "third "
                                        "party "
                                        "case "
                                        "queries. "
                                        "Each "
                                        "of "
                                        "them "
                                        "can "
                                        "have "
                                        "different "
                                        "group "
                                        "by "
                                        "fields, "
                                        "to "
                                        "aggregate "
                                        "differently "
                                        "based "
                                        "on "
                                        "the "
                                        "type "
                                        "of "
                                        "alert.",
                                        "items": {
                                            "description": "A "
                                            "query "
                                            "to "
                                            "be "
                                            "combined "
                                            "with "
                                            "the "
                                            "third "
                                            "party "
                                            "case "
                                            "query.",
                                            "properties": {
                                                "groupByFields": {
                                                    "description": "Fields to group by.",
                                                    "items": {
                                                        "description": "Field.",
                                                        "type": "string",
                                                    },
                                                    "type": "array",
                                                },
                                                "query": {
                                                    "description": "Query to run on logs.",
                                                    "example": "source:cloudtrail",
                                                    "type": "string",
                                                },
                                            },
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "signalTitleTemplate": {
                                        "description": "A "
                                        "template "
                                        "for "
                                        "the "
                                        "signal "
                                        "title; "
                                        "if "
                                        "omitted, "
                                        "the "
                                        "title "
                                        "is "
                                        "generated "
                                        "based "
                                        "on "
                                        "the "
                                        "case "
                                        "name.",
                                        "type": "string",
                                    },
                                },
                                "type": "object",
                            },
                        },
                        "type": "object",
                    },
                    "queries": {
                        "description": "Queries for selecting logs which are part of the rule.",
                        "example": [],
                        "items": {
                            "description": "Query for matching rule.",
                            "properties": {
                                "aggregation": {
                                    "description": "The aggregation type.",
                                    "enum": [
                                        "count",
                                        "cardinality",
                                        "sum",
                                        "max",
                                        "new_value",
                                        "geo_data",
                                        "event_count",
                                        "none",
                                    ],
                                    "type": "string",
                                    "x-enum-varnames": [
                                        "COUNT",
                                        "CARDINALITY",
                                        "SUM",
                                        "MAX",
                                        "NEW_VALUE",
                                        "GEO_DATA",
                                        "EVENT_COUNT",
                                        "NONE",
                                    ],
                                },
                                "customQueryExtension": {
                                    "description": "Query extension to append to the logs query.",
                                    "example": "a > 3",
                                    "type": "string",
                                },
                                "dataSource": {
                                    "default": "logs",
                                    "description": "Source "
                                    "of "
                                    "events, "
                                    "either "
                                    "logs, "
                                    "audit "
                                    "trail, "
                                    "or "
                                    "Datadog "
                                    "events.",
                                    "enum": [
                                        "logs",
                                        "audit",
                                        "app_sec_spans",
                                        "spans",
                                        "security_runtime",
                                        "network",
                                        "events",
                                    ],
                                    "example": "logs",
                                    "type": "string",
                                    "x-enum-varnames": [
                                        "LOGS",
                                        "AUDIT",
                                        "APP_SEC_SPANS",
                                        "SPANS",
                                        "SECURITY_RUNTIME",
                                        "NETWORK",
                                        "EVENTS",
                                    ],
                                },
                                "distinctFields": {
                                    "description": "Field "
                                    "for "
                                    "which "
                                    "the "
                                    "cardinality "
                                    "is "
                                    "measured. "
                                    "Sent "
                                    "as "
                                    "an "
                                    "array.",
                                    "items": {"description": "Field.", "type": "string"},
                                    "type": "array",
                                },
                                "groupByFields": {
                                    "description": "Fields to group by.",
                                    "items": {"description": "Field.", "type": "string"},
                                    "type": "array",
                                },
                                "hasOptionalGroupByFields": {
                                    "default": False,
                                    "description": "When "
                                    "false, "
                                    "events "
                                    "without "
                                    "a "
                                    "group-by "
                                    "value "
                                    "are "
                                    "ignored "
                                    "by "
                                    "the "
                                    "rule. "
                                    "When "
                                    "true, "
                                    "events "
                                    "with "
                                    "missing "
                                    "group-by "
                                    "fields "
                                    "are "
                                    "processed "
                                    "with "
                                    "`N/A`, "
                                    "replacing "
                                    "the "
                                    "missing "
                                    "values.",
                                    "example": False,
                                    "type": "boolean",
                                },
                                "index": {
                                    "description": "**This "
                                    "field "
                                    "is "
                                    "currently "
                                    "unstable "
                                    "and "
                                    "might "
                                    "be "
                                    "removed "
                                    "in "
                                    "a "
                                    "minor "
                                    "version "
                                    "upgrade.**\n"
                                    "The "
                                    "index "
                                    "to "
                                    "run "
                                    "the "
                                    "query "
                                    "on, "
                                    "if "
                                    "the "
                                    "`dataSource` "
                                    "is "
                                    "`logs`. "
                                    "Only "
                                    "used "
                                    "for "
                                    "scheduled "
                                    "rules "
                                    "- "
                                    "in "
                                    "other "
                                    "words, "
                                    "when "
                                    "the "
                                    "`schedulingOptions` "
                                    "field "
                                    "is "
                                    "present "
                                    "in "
                                    "the "
                                    "rule "
                                    "payload.",
                                    "type": "string",
                                },
                                "indexes": {
                                    "description": "List "
                                    "of "
                                    "indexes "
                                    "to "
                                    "query "
                                    "when "
                                    "the "
                                    "`dataSource` "
                                    "is "
                                    "`logs`. "
                                    "Only "
                                    "used "
                                    "for "
                                    "scheduled "
                                    "rules, "
                                    "such "
                                    "as "
                                    "when "
                                    "the "
                                    "`schedulingOptions` "
                                    "field "
                                    "is "
                                    "present "
                                    "in "
                                    "the "
                                    "rule "
                                    "payload.",
                                    "items": {"description": "Index.", "type": "string"},
                                    "type": "array",
                                },
                                "metric": {
                                    "deprecated": True,
                                    "description": "(Deprecated) "
                                    "The "
                                    "target "
                                    "field "
                                    "to "
                                    "aggregate "
                                    "over "
                                    "when "
                                    "using "
                                    "the "
                                    "sum "
                                    "or "
                                    "max\n"
                                    "aggregations. "
                                    "`metrics` "
                                    "field "
                                    "should "
                                    "be "
                                    "used "
                                    "instead.",
                                    "type": "string",
                                },
                                "metrics": {
                                    "description": "Group "
                                    "of "
                                    "target "
                                    "fields "
                                    "to "
                                    "aggregate "
                                    "over "
                                    "when "
                                    "using "
                                    "the "
                                    "sum, "
                                    "max, "
                                    "geo "
                                    "data, "
                                    "or "
                                    "new "
                                    "value "
                                    "aggregations. "
                                    "The "
                                    "sum, "
                                    "max, "
                                    "and "
                                    "geo "
                                    "data "
                                    "aggregations "
                                    "only "
                                    "accept "
                                    "one "
                                    "value "
                                    "in "
                                    "this "
                                    "list, "
                                    "whereas "
                                    "the "
                                    "new "
                                    "value "
                                    "aggregation "
                                    "accepts "
                                    "up "
                                    "to "
                                    "five "
                                    "values.",
                                    "items": {"description": "Field.", "type": "string"},
                                    "type": "array",
                                },
                                "name": {"description": "Name of the query.", "type": "string"},
                                "query": {
                                    "description": "Query to run on logs.",
                                    "example": "a > 3",
                                    "type": "string",
                                },
                            },
                            "type": "object",
                        },
                        "type": "array",
                    },
                    "referenceTables": {
                        "description": "Reference tables for the rule.",
                        "items": {
                            "description": "Reference tables used in the queries.",
                            "properties": {
                                "checkPresence": {
                                    "description": "Whether "
                                    "to "
                                    "include "
                                    "or "
                                    "exclude "
                                    "the "
                                    "matched "
                                    "values.",
                                    "type": "boolean",
                                },
                                "columnName": {
                                    "description": "The name of the column in the reference table.",
                                    "type": "string",
                                },
                                "logFieldPath": {
                                    "description": "The "
                                    "field "
                                    "in "
                                    "the "
                                    "log "
                                    "to "
                                    "match "
                                    "against "
                                    "the "
                                    "reference "
                                    "table.",
                                    "type": "string",
                                },
                                "ruleQueryName": {
                                    "description": "The "
                                    "name "
                                    "of "
                                    "the "
                                    "query "
                                    "to "
                                    "apply "
                                    "the "
                                    "reference "
                                    "table "
                                    "to.",
                                    "type": "string",
                                },
                                "tableName": {
                                    "description": "The name of the reference table.",
                                    "type": "string",
                                },
                            },
                            "type": "object",
                        },
                        "type": "array",
                    },
                    "schedulingOptions": {
                        "description": "Options for scheduled "
                        "rules. When this "
                        "field is present, the "
                        "rule runs based on "
                        "the schedule. When "
                        "absent, it runs "
                        "real-time on ingested "
                        "logs.",
                        "nullable": True,
                        "properties": {
                            "rrule": {
                                "description": "Schedule "
                                "for "
                                "the "
                                "rule "
                                "queries, "
                                "written "
                                "in "
                                "RRULE "
                                "syntax. "
                                "See "
                                "[RFC](https://icalendar.org/iCalendar-RFC-5545/3-8-5-3-recurrence-rule.html) "
                                "for "
                                "syntax "
                                "reference.",
                                "example": "FREQ=HOURLY;INTERVAL=1;",
                                "type": "string",
                            },
                            "start": {
                                "description": "Start "
                                "date "
                                "for "
                                "the "
                                "schedule, "
                                "in "
                                "ISO "
                                "8601 "
                                "format "
                                "without "
                                "timezone.",
                                "example": "2025-07-14T12:00:00",
                                "type": "string",
                            },
                            "timezone": {
                                "description": "Time "
                                "zone "
                                "of "
                                "the "
                                "start "
                                "date, "
                                "in "
                                "the "
                                "[tz "
                                "database](https://en.wikipedia.org/wiki/List_of_tz_database_time_zones) "
                                "format.",
                                "example": "America/New_York",
                                "type": "string",
                            },
                        },
                        "type": "object",
                    },
                    "tags": {
                        "description": "Tags for generated signals.",
                        "example": ["env:prod", "team:security"],
                        "items": {"description": "Tag.", "type": "string"},
                        "type": "array",
                    },
                    "thirdPartyCases": {
                        "description": "Cases for generating "
                        "signals from "
                        "third-party rules. Only "
                        "available for "
                        "third-party rules.",
                        "example": [],
                        "items": {
                            "description": "Case when a signal is generated by a third party rule.",
                            "properties": {
                                "name": {"description": "Name of the case.", "type": "string"},
                                "notifications": {
                                    "description": "Notification targets for each case.",
                                    "items": {"description": "Notification.", "type": "string"},
                                    "type": "array",
                                },
                                "query": {
                                    "description": "A "
                                    "query "
                                    "to "
                                    "map "
                                    "a "
                                    "third "
                                    "party "
                                    "event "
                                    "to "
                                    "this "
                                    "case.",
                                    "type": "string",
                                },
                                "status": {
                                    "description": "Severity of the Security Signal.",
                                    "enum": ["info", "low", "medium", "high", "critical"],
                                    "example": "critical",
                                    "type": "string",
                                    "x-enum-varnames": [
                                        "INFO",
                                        "LOW",
                                        "MEDIUM",
                                        "HIGH",
                                        "CRITICAL",
                                    ],
                                },
                            },
                            "required": ["status"],
                            "type": "object",
                        },
                        "type": "array",
                    },
                    "type": {
                        "description": "The rule type.",
                        "enum": [
                            "api_security",
                            "application_security",
                            "log_detection",
                            "workload_security",
                        ],
                        "type": "string",
                        "x-enum-varnames": [
                            "API_SECURITY",
                            "APPLICATION_SECURITY",
                            "LOG_DETECTION",
                            "WORKLOAD_SECURITY",
                        ],
                    },
                },
                "required": ["name", "isEnabled", "queries", "options", "cases", "message"],
                "type": "object",
            },
            {
                "description": "The payload of a signal correlation rule.",
                "properties": {
                    "cases": {
                        "description": "Cases for generating signals.",
                        "example": [],
                        "items": {
                            "description": "Case when signal is generated.",
                            "properties": {
                                "actions": {
                                    "description": "Action to perform for each rule case.",
                                    "items": {
                                        "description": "Action "
                                        "to "
                                        "perform "
                                        "when "
                                        "a "
                                        "signal "
                                        "is "
                                        "triggered. "
                                        "Only "
                                        "available "
                                        "for "
                                        "Application "
                                        "Security "
                                        "rule "
                                        "type.",
                                        "properties": {
                                            "options": {
                                                "additionalProperties": {},
                                                "description": "Options for the rule action",
                                                "properties": {
                                                    "duration": {
                                                        "description": "Duration "
                                                        "of "
                                                        "the "
                                                        "action "
                                                        "in "
                                                        "seconds. "
                                                        "0 "
                                                        "indicates "
                                                        "no "
                                                        "expiration.",
                                                        "example": 0,
                                                        "format": "int64",
                                                        "minimum": 0,
                                                        "type": "integer",
                                                    },
                                                    "flaggedIPType": {
                                                        "description": "Used "
                                                        "with "
                                                        "the "
                                                        "case "
                                                        "action "
                                                        "of "
                                                        "type "
                                                        "'flag_ip'. "
                                                        "The "
                                                        "value "
                                                        "specified "
                                                        "in "
                                                        "this "
                                                        "field "
                                                        "is "
                                                        "applied "
                                                        "as "
                                                        "a "
                                                        "flag "
                                                        "to "
                                                        "the "
                                                        "IP "
                                                        "addresses.",
                                                        "enum": ["SUSPICIOUS", "FLAGGED"],
                                                        "example": "FLAGGED",
                                                        "type": "string",
                                                        "x-enum-varnames": [
                                                            "SUSPICIOUS",
                                                            "FLAGGED",
                                                        ],
                                                    },
                                                    "userBehaviorName": {
                                                        "description": "Used "
                                                        "with "
                                                        "the "
                                                        "case "
                                                        "action "
                                                        "of "
                                                        "type "
                                                        "'user_behavior'. "
                                                        "The "
                                                        "value "
                                                        "specified "
                                                        "in "
                                                        "this "
                                                        "field "
                                                        "is "
                                                        "applied "
                                                        "as "
                                                        "a "
                                                        "risk "
                                                        "tag "
                                                        "to "
                                                        "all "
                                                        "users "
                                                        "affected "
                                                        "by "
                                                        "the "
                                                        "rule.",
                                                        "type": "string",
                                                    },
                                                },
                                                "type": "object",
                                            },
                                            "type": {
                                                "description": "The action type.",
                                                "enum": [
                                                    "block_ip",
                                                    "block_user",
                                                    "user_behavior",
                                                    "flag_ip",
                                                ],
                                                "type": "string",
                                                "x-enum-varnames": [
                                                    "BLOCK_IP",
                                                    "BLOCK_USER",
                                                    "USER_BEHAVIOR",
                                                    "FLAG_IP",
                                                ],
                                            },
                                        },
                                        "type": "object",
                                    },
                                    "type": "array",
                                },
                                "condition": {
                                    "description": "A "
                                    "case "
                                    "contains "
                                    "logical "
                                    "operations "
                                    "(`>`,`>=`, "
                                    "`&&`, "
                                    "`||`) "
                                    "to "
                                    "determine "
                                    "if "
                                    "a "
                                    "signal "
                                    "should "
                                    "be "
                                    "generated\n"
                                    "based "
                                    "on "
                                    "the "
                                    "event "
                                    "counts "
                                    "in "
                                    "the "
                                    "previously "
                                    "defined "
                                    "queries.",
                                    "type": "string",
                                },
                                "name": {"description": "Name of the case.", "type": "string"},
                                "notifications": {
                                    "description": "Notification targets.",
                                    "items": {"description": "Notification.", "type": "string"},
                                    "type": "array",
                                },
                                "status": {
                                    "description": "Severity of the Security Signal.",
                                    "enum": ["info", "low", "medium", "high", "critical"],
                                    "example": "critical",
                                    "type": "string",
                                    "x-enum-varnames": [
                                        "INFO",
                                        "LOW",
                                        "MEDIUM",
                                        "HIGH",
                                        "CRITICAL",
                                    ],
                                },
                            },
                            "required": ["status"],
                            "type": "object",
                        },
                        "type": "array",
                    },
                    "customMessage": {
                        "description": "Custom/Overridden message "
                        "for generated signals "
                        "(used in case of Default "
                        "rule update).",
                        "type": "string",
                    },
                    "customName": {
                        "description": "Custom/Overridden name of "
                        "the rule (used in case of "
                        "Default rule update).",
                        "type": "string",
                    },
                    "filters": {
                        "description": "Additional queries to filter "
                        "matched events before they are "
                        "processed. This field is "
                        "deprecated for log detection, "
                        "signal correlation, and "
                        "workload security rules.",
                        "items": {
                            "description": "The rule's suppression filter.",
                            "properties": {
                                "action": {
                                    "description": "The type of filtering action.",
                                    "enum": ["require", "suppress"],
                                    "type": "string",
                                    "x-enum-varnames": ["REQUIRE", "SUPPRESS"],
                                },
                                "query": {
                                    "description": "Query "
                                    "for "
                                    "selecting "
                                    "logs "
                                    "to "
                                    "apply "
                                    "the "
                                    "filtering "
                                    "action.",
                                    "type": "string",
                                },
                            },
                            "type": "object",
                        },
                        "type": "array",
                    },
                    "hasExtendedTitle": {
                        "description": "Whether the "
                        "notifications include "
                        "the triggering "
                        "group-by values in "
                        "their title.",
                        "example": True,
                        "type": "boolean",
                    },
                    "isEnabled": {
                        "description": "Whether the rule is enabled.",
                        "example": True,
                        "type": "boolean",
                    },
                    "message": {
                        "description": "Message for generated signals.",
                        "example": "",
                        "type": "string",
                    },
                    "name": {
                        "description": "The name of the rule.",
                        "example": "My security monitoring rule.",
                        "type": "string",
                    },
                    "options": {
                        "description": "Options.",
                        "properties": {
                            "complianceRuleOptions": {
                                "additionalProperties": {},
                                "description": "Options "
                                "for "
                                "cloud_configuration "
                                "rules.\n"
                                "Fields "
                                "`resourceType` "
                                "and "
                                "`regoRule` "
                                "are "
                                "mandatory "
                                "when "
                                "managing "
                                "custom "
                                "`cloud_configuration` "
                                "rules.",
                                "properties": {
                                    "complexRule": {
                                        "description": "Whether "
                                        "the "
                                        "rule "
                                        "is "
                                        "a "
                                        "complex "
                                        "one.\n"
                                        "Must "
                                        "be "
                                        "set "
                                        "to "
                                        "true "
                                        "if "
                                        "`regoRule.resourceTypes` "
                                        "contains "
                                        "more "
                                        "than "
                                        "one "
                                        "item. "
                                        "Defaults "
                                        "to "
                                        "false.",
                                        "type": "boolean",
                                    },
                                    "regoRule": {
                                        "description": "Rule details.",
                                        "properties": {
                                            "policy": {
                                                "description": "The "
                                                "policy "
                                                "written "
                                                "in "
                                                "`rego`, "
                                                "see: "
                                                "https://www.openpolicyagent.org/docs/latest/policy-language/",
                                                "example": "package "
                                                "datadog\n"
                                                "\n"
                                                "import "
                                                "data.datadog.output "
                                                "as "
                                                "dd_output\n"
                                                "import "
                                                "future.keywords.contains\n"
                                                "import "
                                                "future.keywords.if\n"
                                                "import "
                                                "future.keywords.in\n"
                                                "\n"
                                                "eval(resource) "
                                                "= "
                                                '"skip" '
                                                "if "
                                                "{\n"
                                                "  "
                                                "# "
                                                "Logic "
                                                "that "
                                                "evaluates "
                                                "to "
                                                "true "
                                                "if "
                                                "the "
                                                "resource "
                                                "should "
                                                "be "
                                                "skipped\n"
                                                "  "
                                                "true\n"
                                                "} "
                                                "else "
                                                "= "
                                                '"pass" '
                                                "{\n"
                                                "  "
                                                "# "
                                                "Logic "
                                                "that "
                                                "evaluates "
                                                "to "
                                                "true "
                                                "if "
                                                "the "
                                                "resource "
                                                "is "
                                                "compliant\n"
                                                "  "
                                                "true\n"
                                                "} "
                                                "else "
                                                "= "
                                                '"fail" '
                                                "{\n"
                                                "  "
                                                "# "
                                                "Logic "
                                                "that "
                                                "evaluates "
                                                "to "
                                                "true "
                                                "if "
                                                "the "
                                                "resource "
                                                "is "
                                                "not "
                                                "compliant\n"
                                                "  "
                                                "true\n"
                                                "}\n"
                                                "\n"
                                                "# "
                                                "This "
                                                "part "
                                                "remains "
                                                "unchanged "
                                                "for "
                                                "all "
                                                "rules\n"
                                                "results "
                                                "contains "
                                                "result "
                                                "if "
                                                "{\n"
                                                "  "
                                                "some "
                                                "resource "
                                                "in "
                                                "input.resources[input.main_resource_type]\n"
                                                "  "
                                                "result "
                                                ":= "
                                                "dd_output.format(resource, "
                                                "eval(resource))\n"
                                                "}",
                                                "type": "string",
                                            },
                                            "resourceTypes": {
                                                "description": "List "
                                                "of "
                                                "resource "
                                                "types "
                                                "that "
                                                "will "
                                                "be "
                                                "evaluated "
                                                "upon. "
                                                "Must "
                                                "have "
                                                "at "
                                                "least "
                                                "one "
                                                "element.",
                                                "example": [
                                                    "gcp_iam_service_account",
                                                    "gcp_iam_policy",
                                                ],
                                                "items": {"type": "string"},
                                                "type": "array",
                                            },
                                        },
                                        "required": ["policy", "resourceTypes"],
                                        "type": "object",
                                    },
                                    "resourceType": {
                                        "description": "Main "
                                        "resource "
                                        "type "
                                        "to "
                                        "be "
                                        "checked "
                                        "by "
                                        "the "
                                        "rule. "
                                        "It "
                                        "should "
                                        "be "
                                        "specified "
                                        "again "
                                        "in "
                                        "`regoRule.resourceTypes`.",
                                        "example": "aws_acm",
                                        "type": "string",
                                    },
                                },
                                "type": "object",
                            },
                            "decreaseCriticalityBasedOnEnv": {
                                "description": "If "
                                "true, "
                                "signals "
                                "in "
                                "non-production "
                                "environments "
                                "have "
                                "a "
                                "lower "
                                "severity "
                                "than "
                                "what "
                                "is "
                                "defined "
                                "by "
                                "the "
                                "rule "
                                "case, "
                                "which "
                                "can "
                                "reduce "
                                "signal "
                                "noise.\n"
                                "The "
                                "severity "
                                "is "
                                "decreased "
                                "by "
                                "one "
                                "level: "
                                "`CRITICAL` "
                                "in "
                                "production "
                                "becomes "
                                "`HIGH` "
                                "in "
                                "non-production, "
                                "`HIGH` "
                                "becomes "
                                "`MEDIUM` "
                                "and "
                                "so "
                                "on. "
                                "`INFO` "
                                "remains "
                                "`INFO`.\n"
                                "The "
                                "decrement "
                                "is "
                                "applied "
                                "when "
                                "the "
                                "environment "
                                "tag "
                                "of "
                                "the "
                                "signal "
                                "starts "
                                "with "
                                "`staging`, "
                                "`test` "
                                "or "
                                "`dev`.",
                                "example": False,
                                "type": "boolean",
                            },
                            "detectionMethod": {
                                "description": "The detection method.",
                                "enum": [
                                    "threshold",
                                    "new_value",
                                    "anomaly_detection",
                                    "impossible_travel",
                                    "hardcoded",
                                    "third_party",
                                    "anomaly_threshold",
                                    "sequence_detection",
                                ],
                                "type": "string",
                                "x-enum-varnames": [
                                    "THRESHOLD",
                                    "NEW_VALUE",
                                    "ANOMALY_DETECTION",
                                    "IMPOSSIBLE_TRAVEL",
                                    "HARDCODED",
                                    "THIRD_PARTY",
                                    "ANOMALY_THRESHOLD",
                                    "SEQUENCE_DETECTION",
                                ],
                            },
                            "evaluationWindow": {
                                "description": "A "
                                "time "
                                "window "
                                "is "
                                "specified "
                                "to "
                                "match "
                                "when "
                                "at "
                                "least "
                                "one "
                                "of "
                                "the "
                                "cases "
                                "matches "
                                "true. "
                                "This "
                                "is "
                                "a "
                                "sliding "
                                "window\n"
                                "and "
                                "evaluates "
                                "in "
                                "real "
                                "time. "
                                "For "
                                "third "
                                "party "
                                "detection "
                                "method, "
                                "this "
                                "field "
                                "is "
                                "not "
                                "used.",
                                "enum": [
                                    0,
                                    60,
                                    300,
                                    600,
                                    900,
                                    1800,
                                    3600,
                                    7200,
                                    10800,
                                    21600,
                                    43200,
                                    86400,
                                ],
                                "format": "int32",
                                "type": "integer",
                                "x-enum-varnames": [
                                    "ZERO_MINUTES",
                                    "ONE_MINUTE",
                                    "FIVE_MINUTES",
                                    "TEN_MINUTES",
                                    "FIFTEEN_MINUTES",
                                    "THIRTY_MINUTES",
                                    "ONE_HOUR",
                                    "TWO_HOURS",
                                    "THREE_HOURS",
                                    "SIX_HOURS",
                                    "TWELVE_HOURS",
                                    "ONE_DAY",
                                ],
                            },
                            "hardcodedEvaluatorType": {
                                "description": "Hardcoded evaluator type.",
                                "enum": ["log4shell"],
                                "type": "string",
                                "x-enum-varnames": ["LOG4SHELL"],
                            },
                            "impossibleTravelOptions": {
                                "description": "Options on impossible travel detection method.",
                                "properties": {
                                    "baselineUserLocations": {
                                        "description": "If "
                                        "true, "
                                        "signals "
                                        "are "
                                        "suppressed "
                                        "for "
                                        "the "
                                        "first "
                                        "24 "
                                        "hours. "
                                        "In "
                                        "that "
                                        "time, "
                                        "Datadog "
                                        "learns "
                                        "the "
                                        "user's "
                                        "regular\n"
                                        "access "
                                        "locations. "
                                        "This "
                                        "can "
                                        "be "
                                        "helpful "
                                        "to "
                                        "reduce "
                                        "noise "
                                        "and "
                                        "infer "
                                        "VPN "
                                        "usage "
                                        "or "
                                        "credentialed "
                                        "API "
                                        "access.",
                                        "example": True,
                                        "type": "boolean",
                                    }
                                },
                                "type": "object",
                            },
                            "keepAlive": {
                                "description": "Once "
                                "a "
                                "signal "
                                "is "
                                "generated, "
                                "the "
                                "signal "
                                "will "
                                "remain "
                                '"open" '
                                "if "
                                "a "
                                "case "
                                "is "
                                "matched "
                                "at "
                                "least "
                                "once "
                                "within\n"
                                "this "
                                "keep "
                                "alive "
                                "window. "
                                "For "
                                "third "
                                "party "
                                "detection "
                                "method, "
                                "this "
                                "field "
                                "is "
                                "not "
                                "used.",
                                "enum": [
                                    0,
                                    60,
                                    300,
                                    600,
                                    900,
                                    1800,
                                    3600,
                                    7200,
                                    10800,
                                    21600,
                                    43200,
                                    86400,
                                ],
                                "format": "int32",
                                "type": "integer",
                                "x-enum-varnames": [
                                    "ZERO_MINUTES",
                                    "ONE_MINUTE",
                                    "FIVE_MINUTES",
                                    "TEN_MINUTES",
                                    "FIFTEEN_MINUTES",
                                    "THIRTY_MINUTES",
                                    "ONE_HOUR",
                                    "TWO_HOURS",
                                    "THREE_HOURS",
                                    "SIX_HOURS",
                                    "TWELVE_HOURS",
                                    "ONE_DAY",
                                ],
                            },
                            "maxSignalDuration": {
                                "description": "A "
                                "signal "
                                "will "
                                '"close" '
                                "regardless "
                                "of "
                                "the "
                                "query "
                                "being "
                                "matched "
                                "once "
                                "the "
                                "time "
                                "exceeds "
                                "the "
                                "maximum "
                                "duration.\n"
                                "This "
                                "time "
                                "is "
                                "calculated "
                                "from "
                                "the "
                                "first "
                                "seen "
                                "timestamp.",
                                "enum": [
                                    0,
                                    60,
                                    300,
                                    600,
                                    900,
                                    1800,
                                    3600,
                                    7200,
                                    10800,
                                    21600,
                                    43200,
                                    86400,
                                ],
                                "format": "int32",
                                "type": "integer",
                                "x-enum-varnames": [
                                    "ZERO_MINUTES",
                                    "ONE_MINUTE",
                                    "FIVE_MINUTES",
                                    "TEN_MINUTES",
                                    "FIFTEEN_MINUTES",
                                    "THIRTY_MINUTES",
                                    "ONE_HOUR",
                                    "TWO_HOURS",
                                    "THREE_HOURS",
                                    "SIX_HOURS",
                                    "TWELVE_HOURS",
                                    "ONE_DAY",
                                ],
                            },
                            "newValueOptions": {
                                "description": "Options on new value detection method.",
                                "properties": {
                                    "forgetAfter": {
                                        "description": "The "
                                        "duration "
                                        "in "
                                        "days "
                                        "after "
                                        "which "
                                        "a "
                                        "learned "
                                        "value "
                                        "is "
                                        "forgotten.",
                                        "enum": [1, 2, 7, 14, 21, 28],
                                        "format": "int32",
                                        "type": "integer",
                                        "x-enum-varnames": [
                                            "ONE_DAY",
                                            "TWO_DAYS",
                                            "ONE_WEEK",
                                            "TWO_WEEKS",
                                            "THREE_WEEKS",
                                            "FOUR_WEEKS",
                                        ],
                                    },
                                    "learningDuration": {
                                        "default": 0,
                                        "description": "The "
                                        "duration "
                                        "in "
                                        "days "
                                        "during "
                                        "which "
                                        "values "
                                        "are "
                                        "learned, "
                                        "and "
                                        "after "
                                        "which "
                                        "signals "
                                        "will "
                                        "be "
                                        "generated "
                                        "for "
                                        "values "
                                        "that\n"
                                        "weren't "
                                        "learned. "
                                        "If "
                                        "set "
                                        "to "
                                        "0, "
                                        "a "
                                        "signal "
                                        "will "
                                        "be "
                                        "generated "
                                        "for "
                                        "all "
                                        "new "
                                        "values "
                                        "after "
                                        "the "
                                        "first "
                                        "value "
                                        "is "
                                        "learned.",
                                        "enum": [0, 1, 7],
                                        "format": "int32",
                                        "type": "integer",
                                        "x-enum-varnames": ["ZERO_DAYS", "ONE_DAY", "SEVEN_DAYS"],
                                    },
                                    "learningMethod": {
                                        "default": "duration",
                                        "description": "The "
                                        "learning "
                                        "method "
                                        "used "
                                        "to "
                                        "determine "
                                        "when "
                                        "signals "
                                        "should "
                                        "be "
                                        "generated "
                                        "for "
                                        "values "
                                        "that "
                                        "weren't "
                                        "learned.",
                                        "enum": ["duration", "threshold"],
                                        "type": "string",
                                        "x-enum-varnames": ["DURATION", "THRESHOLD"],
                                    },
                                    "learningThreshold": {
                                        "default": 0,
                                        "description": "A "
                                        "number "
                                        "of "
                                        "occurrences "
                                        "after "
                                        "which "
                                        "signals "
                                        "will "
                                        "be "
                                        "generated "
                                        "for "
                                        "values "
                                        "that "
                                        "weren't "
                                        "learned.",
                                        "enum": [0, 1],
                                        "format": "int32",
                                        "type": "integer",
                                        "x-enum-varnames": ["ZERO_OCCURRENCES", "ONE_OCCURRENCE"],
                                    },
                                },
                                "type": "object",
                            },
                            "sequenceDetectionOptions": {
                                "description": "Options on sequence detection method.",
                                "properties": {
                                    "stepTransitions": {
                                        "description": "Transitions "
                                        "defining "
                                        "the "
                                        "allowed "
                                        "order "
                                        "of "
                                        "steps "
                                        "and "
                                        "their "
                                        "evaluation "
                                        "windows.",
                                        "items": {
                                            "description": "Transition "
                                            "from "
                                            "a "
                                            "parent "
                                            "step "
                                            "to "
                                            "a "
                                            "child "
                                            "step "
                                            "within "
                                            "a "
                                            "sequence "
                                            "detection "
                                            "rule.",
                                            "properties": {
                                                "child": {
                                                    "description": "Name of the child step.",
                                                    "type": "string",
                                                },
                                                "evaluationWindow": {
                                                    "description": "A "
                                                    "time "
                                                    "window "
                                                    "is "
                                                    "specified "
                                                    "to "
                                                    "match "
                                                    "when "
                                                    "at "
                                                    "least "
                                                    "one "
                                                    "of "
                                                    "the "
                                                    "cases "
                                                    "matches "
                                                    "true. "
                                                    "This "
                                                    "is "
                                                    "a "
                                                    "sliding "
                                                    "window\n"
                                                    "and "
                                                    "evaluates "
                                                    "in "
                                                    "real "
                                                    "time. "
                                                    "For "
                                                    "third "
                                                    "party "
                                                    "detection "
                                                    "method, "
                                                    "this "
                                                    "field "
                                                    "is "
                                                    "not "
                                                    "used.",
                                                    "enum": [
                                                        0,
                                                        60,
                                                        300,
                                                        600,
                                                        900,
                                                        1800,
                                                        3600,
                                                        7200,
                                                        10800,
                                                        21600,
                                                        43200,
                                                        86400,
                                                    ],
                                                    "format": "int32",
                                                    "type": "integer",
                                                    "x-enum-varnames": [
                                                        "ZERO_MINUTES",
                                                        "ONE_MINUTE",
                                                        "FIVE_MINUTES",
                                                        "TEN_MINUTES",
                                                        "FIFTEEN_MINUTES",
                                                        "THIRTY_MINUTES",
                                                        "ONE_HOUR",
                                                        "TWO_HOURS",
                                                        "THREE_HOURS",
                                                        "SIX_HOURS",
                                                        "TWELVE_HOURS",
                                                        "ONE_DAY",
                                                    ],
                                                },
                                                "parent": {
                                                    "description": "Name of the parent step.",
                                                    "type": "string",
                                                },
                                            },
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "steps": {
                                        "description": "Steps "
                                        "that "
                                        "define "
                                        "the "
                                        "conditions "
                                        "to "
                                        "be "
                                        "matched "
                                        "in "
                                        "sequence.",
                                        "items": {
                                            "description": "Step "
                                            "definition "
                                            "for "
                                            "sequence "
                                            "detection "
                                            "containing "
                                            "the "
                                            "step "
                                            "name, "
                                            "condition, "
                                            "and "
                                            "evaluation "
                                            "window.",
                                            "properties": {
                                                "condition": {
                                                    "description": "Condition "
                                                    "referencing "
                                                    "rule "
                                                    "queries "
                                                    "(e.g., "
                                                    "`a "
                                                    "> "
                                                    "0`).",
                                                    "type": "string",
                                                },
                                                "evaluationWindow": {
                                                    "description": "A "
                                                    "time "
                                                    "window "
                                                    "is "
                                                    "specified "
                                                    "to "
                                                    "match "
                                                    "when "
                                                    "at "
                                                    "least "
                                                    "one "
                                                    "of "
                                                    "the "
                                                    "cases "
                                                    "matches "
                                                    "true. "
                                                    "This "
                                                    "is "
                                                    "a "
                                                    "sliding "
                                                    "window\n"
                                                    "and "
                                                    "evaluates "
                                                    "in "
                                                    "real "
                                                    "time. "
                                                    "For "
                                                    "third "
                                                    "party "
                                                    "detection "
                                                    "method, "
                                                    "this "
                                                    "field "
                                                    "is "
                                                    "not "
                                                    "used.",
                                                    "enum": [
                                                        0,
                                                        60,
                                                        300,
                                                        600,
                                                        900,
                                                        1800,
                                                        3600,
                                                        7200,
                                                        10800,
                                                        21600,
                                                        43200,
                                                        86400,
                                                    ],
                                                    "format": "int32",
                                                    "type": "integer",
                                                    "x-enum-varnames": [
                                                        "ZERO_MINUTES",
                                                        "ONE_MINUTE",
                                                        "FIVE_MINUTES",
                                                        "TEN_MINUTES",
                                                        "FIFTEEN_MINUTES",
                                                        "THIRTY_MINUTES",
                                                        "ONE_HOUR",
                                                        "TWO_HOURS",
                                                        "THREE_HOURS",
                                                        "SIX_HOURS",
                                                        "TWELVE_HOURS",
                                                        "ONE_DAY",
                                                    ],
                                                },
                                                "name": {
                                                    "description": "Unique "
                                                    "name "
                                                    "identifying "
                                                    "the "
                                                    "step.",
                                                    "type": "string",
                                                },
                                            },
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                },
                                "type": "object",
                            },
                            "thirdPartyRuleOptions": {
                                "description": "Options on third party detection method.",
                                "properties": {
                                    "defaultNotifications": {
                                        "description": "Notification "
                                        "targets "
                                        "for "
                                        "the "
                                        "logs "
                                        "that "
                                        "do "
                                        "not "
                                        "correspond "
                                        "to "
                                        "any "
                                        "of "
                                        "the "
                                        "cases.",
                                        "items": {"description": "Notification.", "type": "string"},
                                        "type": "array",
                                    },
                                    "defaultStatus": {
                                        "description": "Severity of the Security Signal.",
                                        "enum": ["info", "low", "medium", "high", "critical"],
                                        "example": "critical",
                                        "type": "string",
                                        "x-enum-varnames": [
                                            "INFO",
                                            "LOW",
                                            "MEDIUM",
                                            "HIGH",
                                            "CRITICAL",
                                        ],
                                    },
                                    "rootQueries": {
                                        "description": "Queries "
                                        "to "
                                        "be "
                                        "combined "
                                        "with "
                                        "third "
                                        "party "
                                        "case "
                                        "queries. "
                                        "Each "
                                        "of "
                                        "them "
                                        "can "
                                        "have "
                                        "different "
                                        "group "
                                        "by "
                                        "fields, "
                                        "to "
                                        "aggregate "
                                        "differently "
                                        "based "
                                        "on "
                                        "the "
                                        "type "
                                        "of "
                                        "alert.",
                                        "items": {
                                            "description": "A "
                                            "query "
                                            "to "
                                            "be "
                                            "combined "
                                            "with "
                                            "the "
                                            "third "
                                            "party "
                                            "case "
                                            "query.",
                                            "properties": {
                                                "groupByFields": {
                                                    "description": "Fields to group by.",
                                                    "items": {
                                                        "description": "Field.",
                                                        "type": "string",
                                                    },
                                                    "type": "array",
                                                },
                                                "query": {
                                                    "description": "Query to run on logs.",
                                                    "example": "source:cloudtrail",
                                                    "type": "string",
                                                },
                                            },
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "signalTitleTemplate": {
                                        "description": "A "
                                        "template "
                                        "for "
                                        "the "
                                        "signal "
                                        "title; "
                                        "if "
                                        "omitted, "
                                        "the "
                                        "title "
                                        "is "
                                        "generated "
                                        "based "
                                        "on "
                                        "the "
                                        "case "
                                        "name.",
                                        "type": "string",
                                    },
                                },
                                "type": "object",
                            },
                        },
                        "type": "object",
                    },
                    "queries": {
                        "description": "Queries for selecting signals which are part of the rule.",
                        "example": [],
                        "items": {
                            "description": "Query for matching rule on signals.",
                            "properties": {
                                "aggregation": {
                                    "description": "The aggregation type.",
                                    "enum": [
                                        "count",
                                        "cardinality",
                                        "sum",
                                        "max",
                                        "new_value",
                                        "geo_data",
                                        "event_count",
                                        "none",
                                    ],
                                    "type": "string",
                                    "x-enum-varnames": [
                                        "COUNT",
                                        "CARDINALITY",
                                        "SUM",
                                        "MAX",
                                        "NEW_VALUE",
                                        "GEO_DATA",
                                        "EVENT_COUNT",
                                        "NONE",
                                    ],
                                },
                                "correlatedByFields": {
                                    "description": "Fields to group by.",
                                    "items": {"description": "Field.", "type": "string"},
                                    "type": "array",
                                },
                                "correlatedQueryIndex": {
                                    "description": "Index "
                                    "of "
                                    "the "
                                    "rule "
                                    "query "
                                    "used "
                                    "to "
                                    "retrieve "
                                    "the "
                                    "correlated "
                                    "field.",
                                    "format": "int32",
                                    "maximum": 9,
                                    "type": "integer",
                                },
                                "metrics": {
                                    "description": "Group of target fields to aggregate over.",
                                    "items": {"description": "Field.", "type": "string"},
                                    "type": "array",
                                },
                                "name": {"description": "Name of the query.", "type": "string"},
                                "ruleId": {
                                    "description": "Rule ID to match on signals.",
                                    "example": "org-ru1-e1d",
                                    "type": "string",
                                },
                            },
                            "required": ["ruleId"],
                            "type": "object",
                        },
                        "type": "array",
                    },
                    "tags": {
                        "description": "Tags for generated signals.",
                        "example": ["env:prod", "team:security"],
                        "items": {"description": "Tag.", "type": "string"},
                        "type": "array",
                    },
                    "type": {
                        "description": "The rule type.",
                        "enum": ["signal_correlation"],
                        "type": "string",
                        "x-enum-varnames": ["SIGNAL_CORRELATION"],
                    },
                },
                "required": ["name", "isEnabled", "queries", "options", "cases", "message"],
                "type": "object",
            },
        ],
    },
    "TESTSECURITYRULE_REQUEST_BODY_SCHEMA": {
        "description": "Test the rule queries of a rule (rule property is ignored when "
        "applied to an existing rule)",
        "properties": {
            "rule": {
                "description": "Test a rule.",
                "oneOf": [
                    {
                        "description": "The payload of a rule to test",
                        "properties": {
                            "calculatedFields": {
                                "description": "Calculated "
                                "fields. "
                                "Only "
                                "allowed "
                                "for "
                                "scheduled "
                                "rules "
                                "- "
                                "in "
                                "other "
                                "words, "
                                "when "
                                "schedulingOptions "
                                "is "
                                "also "
                                "defined.",
                                "items": {
                                    "description": "Calculated field.",
                                    "properties": {
                                        "expression": {
                                            "description": "Expression.",
                                            "example": "@request_end_timestamp "
                                            "- "
                                            "@request_start_timestamp",
                                            "type": "string",
                                        },
                                        "name": {
                                            "description": "Field name.",
                                            "example": "response_time",
                                            "type": "string",
                                        },
                                    },
                                    "required": ["name", "expression"],
                                    "type": "object",
                                },
                                "type": "array",
                            },
                            "cases": {
                                "description": "Cases for generating signals.",
                                "example": [],
                                "items": {
                                    "description": "Case when signal is generated.",
                                    "properties": {
                                        "actions": {
                                            "description": "Action to perform for each rule case.",
                                            "items": {
                                                "description": "Action "
                                                "to "
                                                "perform "
                                                "when "
                                                "a "
                                                "signal "
                                                "is "
                                                "triggered. "
                                                "Only "
                                                "available "
                                                "for "
                                                "Application "
                                                "Security "
                                                "rule "
                                                "type.",
                                                "properties": {
                                                    "options": {
                                                        "additionalProperties": {},
                                                        "description": "Options "
                                                        "for "
                                                        "the "
                                                        "rule "
                                                        "action",
                                                        "properties": {
                                                            "duration": {
                                                                "description": "Duration "
                                                                "of "
                                                                "the "
                                                                "action "
                                                                "in "
                                                                "seconds. "
                                                                "0 "
                                                                "indicates "
                                                                "no "
                                                                "expiration.",
                                                                "example": 0,
                                                                "format": "int64",
                                                                "minimum": 0,
                                                                "type": "integer",
                                                            },
                                                            "flaggedIPType": {
                                                                "description": "Used "
                                                                "with "
                                                                "the "
                                                                "case "
                                                                "action "
                                                                "of "
                                                                "type "
                                                                "'flag_ip'. "
                                                                "The "
                                                                "value "
                                                                "specified "
                                                                "in "
                                                                "this "
                                                                "field "
                                                                "is "
                                                                "applied "
                                                                "as "
                                                                "a "
                                                                "flag "
                                                                "to "
                                                                "the "
                                                                "IP "
                                                                "addresses.",
                                                                "enum": ["SUSPICIOUS", "FLAGGED"],
                                                                "example": "FLAGGED",
                                                                "type": "string",
                                                                "x-enum-varnames": [
                                                                    "SUSPICIOUS",
                                                                    "FLAGGED",
                                                                ],
                                                            },
                                                            "userBehaviorName": {
                                                                "description": "Used "
                                                                "with "
                                                                "the "
                                                                "case "
                                                                "action "
                                                                "of "
                                                                "type "
                                                                "'user_behavior'. "
                                                                "The "
                                                                "value "
                                                                "specified "
                                                                "in "
                                                                "this "
                                                                "field "
                                                                "is "
                                                                "applied "
                                                                "as "
                                                                "a "
                                                                "risk "
                                                                "tag "
                                                                "to "
                                                                "all "
                                                                "users "
                                                                "affected "
                                                                "by "
                                                                "the "
                                                                "rule.",
                                                                "type": "string",
                                                            },
                                                        },
                                                        "type": "object",
                                                    },
                                                    "type": {
                                                        "description": "The action type.",
                                                        "enum": [
                                                            "block_ip",
                                                            "block_user",
                                                            "user_behavior",
                                                            "flag_ip",
                                                        ],
                                                        "type": "string",
                                                        "x-enum-varnames": [
                                                            "BLOCK_IP",
                                                            "BLOCK_USER",
                                                            "USER_BEHAVIOR",
                                                            "FLAG_IP",
                                                        ],
                                                    },
                                                },
                                                "type": "object",
                                            },
                                            "type": "array",
                                        },
                                        "condition": {
                                            "description": "A "
                                            "case "
                                            "contains "
                                            "logical "
                                            "operations "
                                            "(`>`,`>=`, "
                                            "`&&`, "
                                            "`||`) "
                                            "to "
                                            "determine "
                                            "if "
                                            "a "
                                            "signal "
                                            "should "
                                            "be "
                                            "generated\n"
                                            "based "
                                            "on "
                                            "the "
                                            "event "
                                            "counts "
                                            "in "
                                            "the "
                                            "previously "
                                            "defined "
                                            "queries.",
                                            "type": "string",
                                        },
                                        "name": {
                                            "description": "Name of the case.",
                                            "type": "string",
                                        },
                                        "notifications": {
                                            "description": "Notification targets.",
                                            "items": {
                                                "description": "Notification.",
                                                "type": "string",
                                            },
                                            "type": "array",
                                        },
                                        "status": {
                                            "description": "Severity of the Security Signal.",
                                            "enum": ["info", "low", "medium", "high", "critical"],
                                            "example": "critical",
                                            "type": "string",
                                            "x-enum-varnames": [
                                                "INFO",
                                                "LOW",
                                                "MEDIUM",
                                                "HIGH",
                                                "CRITICAL",
                                            ],
                                        },
                                    },
                                    "required": ["status"],
                                    "type": "object",
                                },
                                "type": "array",
                            },
                            "filters": {
                                "description": "Additional "
                                "queries "
                                "to "
                                "filter "
                                "matched "
                                "events "
                                "before "
                                "they "
                                "are "
                                "processed. "
                                "This "
                                "field "
                                "is "
                                "deprecated "
                                "for log "
                                "detection, "
                                "signal "
                                "correlation, "
                                "and "
                                "workload "
                                "security "
                                "rules.",
                                "items": {
                                    "description": "The rule's suppression filter.",
                                    "properties": {
                                        "action": {
                                            "description": "The type of filtering action.",
                                            "enum": ["require", "suppress"],
                                            "type": "string",
                                            "x-enum-varnames": ["REQUIRE", "SUPPRESS"],
                                        },
                                        "query": {
                                            "description": "Query "
                                            "for "
                                            "selecting "
                                            "logs "
                                            "to "
                                            "apply "
                                            "the "
                                            "filtering "
                                            "action.",
                                            "type": "string",
                                        },
                                    },
                                    "type": "object",
                                },
                                "type": "array",
                            },
                            "groupSignalsBy": {
                                "description": "Additional "
                                "grouping "
                                "to "
                                "perform "
                                "on "
                                "top "
                                "of "
                                "the "
                                "existing "
                                "groups "
                                "in "
                                "the "
                                "query "
                                "section. "
                                "Must "
                                "be "
                                "a "
                                "subset "
                                "of "
                                "the "
                                "existing "
                                "groups.",
                                "example": ["service"],
                                "items": {"description": "Field to group by.", "type": "string"},
                                "type": "array",
                            },
                            "hasExtendedTitle": {
                                "description": "Whether "
                                "the "
                                "notifications "
                                "include "
                                "the "
                                "triggering "
                                "group-by "
                                "values "
                                "in "
                                "their "
                                "title.",
                                "example": True,
                                "type": "boolean",
                            },
                            "isEnabled": {
                                "description": "Whether the rule is enabled.",
                                "example": True,
                                "type": "boolean",
                            },
                            "message": {
                                "description": "Message for generated signals.",
                                "example": "",
                                "type": "string",
                            },
                            "name": {
                                "description": "The name of the rule.",
                                "example": "My security monitoring rule.",
                                "type": "string",
                            },
                            "options": {
                                "description": "Options.",
                                "properties": {
                                    "complianceRuleOptions": {
                                        "additionalProperties": {},
                                        "description": "Options "
                                        "for "
                                        "cloud_configuration "
                                        "rules.\n"
                                        "Fields "
                                        "`resourceType` "
                                        "and "
                                        "`regoRule` "
                                        "are "
                                        "mandatory "
                                        "when "
                                        "managing "
                                        "custom "
                                        "`cloud_configuration` "
                                        "rules.",
                                        "properties": {
                                            "complexRule": {
                                                "description": "Whether "
                                                "the "
                                                "rule "
                                                "is "
                                                "a "
                                                "complex "
                                                "one.\n"
                                                "Must "
                                                "be "
                                                "set "
                                                "to "
                                                "true "
                                                "if "
                                                "`regoRule.resourceTypes` "
                                                "contains "
                                                "more "
                                                "than "
                                                "one "
                                                "item. "
                                                "Defaults "
                                                "to "
                                                "false.",
                                                "type": "boolean",
                                            },
                                            "regoRule": {
                                                "description": "Rule details.",
                                                "properties": {
                                                    "policy": {
                                                        "description": "The "
                                                        "policy "
                                                        "written "
                                                        "in "
                                                        "`rego`, "
                                                        "see: "
                                                        "https://www.openpolicyagent.org/docs/latest/policy-language/",
                                                        "example": "package "
                                                        "datadog\n"
                                                        "\n"
                                                        "import "
                                                        "data.datadog.output "
                                                        "as "
                                                        "dd_output\n"
                                                        "import "
                                                        "future.keywords.contains\n"
                                                        "import "
                                                        "future.keywords.if\n"
                                                        "import "
                                                        "future.keywords.in\n"
                                                        "\n"
                                                        "eval(resource) "
                                                        "= "
                                                        '"skip" '
                                                        "if "
                                                        "{\n"
                                                        "  "
                                                        "# "
                                                        "Logic "
                                                        "that "
                                                        "evaluates "
                                                        "to "
                                                        "true "
                                                        "if "
                                                        "the "
                                                        "resource "
                                                        "should "
                                                        "be "
                                                        "skipped\n"
                                                        "  "
                                                        "true\n"
                                                        "} "
                                                        "else "
                                                        "= "
                                                        '"pass" '
                                                        "{\n"
                                                        "  "
                                                        "# "
                                                        "Logic "
                                                        "that "
                                                        "evaluates "
                                                        "to "
                                                        "true "
                                                        "if "
                                                        "the "
                                                        "resource "
                                                        "is "
                                                        "compliant\n"
                                                        "  "
                                                        "true\n"
                                                        "} "
                                                        "else "
                                                        "= "
                                                        '"fail" '
                                                        "{\n"
                                                        "  "
                                                        "# "
                                                        "Logic "
                                                        "that "
                                                        "evaluates "
                                                        "to "
                                                        "true "
                                                        "if "
                                                        "the "
                                                        "resource "
                                                        "is "
                                                        "not "
                                                        "compliant\n"
                                                        "  "
                                                        "true\n"
                                                        "}\n"
                                                        "\n"
                                                        "# "
                                                        "This "
                                                        "part "
                                                        "remains "
                                                        "unchanged "
                                                        "for "
                                                        "all "
                                                        "rules\n"
                                                        "results "
                                                        "contains "
                                                        "result "
                                                        "if "
                                                        "{\n"
                                                        "  "
                                                        "some "
                                                        "resource "
                                                        "in "
                                                        "input.resources[input.main_resource_type]\n"
                                                        "  "
                                                        "result "
                                                        ":= "
                                                        "dd_output.format(resource, "
                                                        "eval(resource))\n"
                                                        "}",
                                                        "type": "string",
                                                    },
                                                    "resourceTypes": {
                                                        "description": "List "
                                                        "of "
                                                        "resource "
                                                        "types "
                                                        "that "
                                                        "will "
                                                        "be "
                                                        "evaluated "
                                                        "upon. "
                                                        "Must "
                                                        "have "
                                                        "at "
                                                        "least "
                                                        "one "
                                                        "element.",
                                                        "example": [
                                                            "gcp_iam_service_account",
                                                            "gcp_iam_policy",
                                                        ],
                                                        "items": {"type": "string"},
                                                        "type": "array",
                                                    },
                                                },
                                                "required": ["policy", "resourceTypes"],
                                                "type": "object",
                                            },
                                            "resourceType": {
                                                "description": "Main "
                                                "resource "
                                                "type "
                                                "to "
                                                "be "
                                                "checked "
                                                "by "
                                                "the "
                                                "rule. "
                                                "It "
                                                "should "
                                                "be "
                                                "specified "
                                                "again "
                                                "in "
                                                "`regoRule.resourceTypes`.",
                                                "example": "aws_acm",
                                                "type": "string",
                                            },
                                        },
                                        "type": "object",
                                    },
                                    "decreaseCriticalityBasedOnEnv": {
                                        "description": "If "
                                        "true, "
                                        "signals "
                                        "in "
                                        "non-production "
                                        "environments "
                                        "have "
                                        "a "
                                        "lower "
                                        "severity "
                                        "than "
                                        "what "
                                        "is "
                                        "defined "
                                        "by "
                                        "the "
                                        "rule "
                                        "case, "
                                        "which "
                                        "can "
                                        "reduce "
                                        "signal "
                                        "noise.\n"
                                        "The "
                                        "severity "
                                        "is "
                                        "decreased "
                                        "by "
                                        "one "
                                        "level: "
                                        "`CRITICAL` "
                                        "in "
                                        "production "
                                        "becomes "
                                        "`HIGH` "
                                        "in "
                                        "non-production, "
                                        "`HIGH` "
                                        "becomes "
                                        "`MEDIUM` "
                                        "and "
                                        "so "
                                        "on. "
                                        "`INFO` "
                                        "remains "
                                        "`INFO`.\n"
                                        "The "
                                        "decrement "
                                        "is "
                                        "applied "
                                        "when "
                                        "the "
                                        "environment "
                                        "tag "
                                        "of "
                                        "the "
                                        "signal "
                                        "starts "
                                        "with "
                                        "`staging`, "
                                        "`test` "
                                        "or "
                                        "`dev`.",
                                        "example": False,
                                        "type": "boolean",
                                    },
                                    "detectionMethod": {
                                        "description": "The detection method.",
                                        "enum": [
                                            "threshold",
                                            "new_value",
                                            "anomaly_detection",
                                            "impossible_travel",
                                            "hardcoded",
                                            "third_party",
                                            "anomaly_threshold",
                                            "sequence_detection",
                                        ],
                                        "type": "string",
                                        "x-enum-varnames": [
                                            "THRESHOLD",
                                            "NEW_VALUE",
                                            "ANOMALY_DETECTION",
                                            "IMPOSSIBLE_TRAVEL",
                                            "HARDCODED",
                                            "THIRD_PARTY",
                                            "ANOMALY_THRESHOLD",
                                            "SEQUENCE_DETECTION",
                                        ],
                                    },
                                    "evaluationWindow": {
                                        "description": "A "
                                        "time "
                                        "window "
                                        "is "
                                        "specified "
                                        "to "
                                        "match "
                                        "when "
                                        "at "
                                        "least "
                                        "one "
                                        "of "
                                        "the "
                                        "cases "
                                        "matches "
                                        "true. "
                                        "This "
                                        "is "
                                        "a "
                                        "sliding "
                                        "window\n"
                                        "and "
                                        "evaluates "
                                        "in "
                                        "real "
                                        "time. "
                                        "For "
                                        "third "
                                        "party "
                                        "detection "
                                        "method, "
                                        "this "
                                        "field "
                                        "is "
                                        "not "
                                        "used.",
                                        "enum": [
                                            0,
                                            60,
                                            300,
                                            600,
                                            900,
                                            1800,
                                            3600,
                                            7200,
                                            10800,
                                            21600,
                                            43200,
                                            86400,
                                        ],
                                        "format": "int32",
                                        "type": "integer",
                                        "x-enum-varnames": [
                                            "ZERO_MINUTES",
                                            "ONE_MINUTE",
                                            "FIVE_MINUTES",
                                            "TEN_MINUTES",
                                            "FIFTEEN_MINUTES",
                                            "THIRTY_MINUTES",
                                            "ONE_HOUR",
                                            "TWO_HOURS",
                                            "THREE_HOURS",
                                            "SIX_HOURS",
                                            "TWELVE_HOURS",
                                            "ONE_DAY",
                                        ],
                                    },
                                    "hardcodedEvaluatorType": {
                                        "description": "Hardcoded evaluator type.",
                                        "enum": ["log4shell"],
                                        "type": "string",
                                        "x-enum-varnames": ["LOG4SHELL"],
                                    },
                                    "impossibleTravelOptions": {
                                        "description": "Options "
                                        "on "
                                        "impossible "
                                        "travel "
                                        "detection "
                                        "method.",
                                        "properties": {
                                            "baselineUserLocations": {
                                                "description": "If "
                                                "true, "
                                                "signals "
                                                "are "
                                                "suppressed "
                                                "for "
                                                "the "
                                                "first "
                                                "24 "
                                                "hours. "
                                                "In "
                                                "that "
                                                "time, "
                                                "Datadog "
                                                "learns "
                                                "the "
                                                "user's "
                                                "regular\n"
                                                "access "
                                                "locations. "
                                                "This "
                                                "can "
                                                "be "
                                                "helpful "
                                                "to "
                                                "reduce "
                                                "noise "
                                                "and "
                                                "infer "
                                                "VPN "
                                                "usage "
                                                "or "
                                                "credentialed "
                                                "API "
                                                "access.",
                                                "example": True,
                                                "type": "boolean",
                                            }
                                        },
                                        "type": "object",
                                    },
                                    "keepAlive": {
                                        "description": "Once "
                                        "a "
                                        "signal "
                                        "is "
                                        "generated, "
                                        "the "
                                        "signal "
                                        "will "
                                        "remain "
                                        '"open" '
                                        "if "
                                        "a "
                                        "case "
                                        "is "
                                        "matched "
                                        "at "
                                        "least "
                                        "once "
                                        "within\n"
                                        "this "
                                        "keep "
                                        "alive "
                                        "window. "
                                        "For "
                                        "third "
                                        "party "
                                        "detection "
                                        "method, "
                                        "this "
                                        "field "
                                        "is "
                                        "not "
                                        "used.",
                                        "enum": [
                                            0,
                                            60,
                                            300,
                                            600,
                                            900,
                                            1800,
                                            3600,
                                            7200,
                                            10800,
                                            21600,
                                            43200,
                                            86400,
                                        ],
                                        "format": "int32",
                                        "type": "integer",
                                        "x-enum-varnames": [
                                            "ZERO_MINUTES",
                                            "ONE_MINUTE",
                                            "FIVE_MINUTES",
                                            "TEN_MINUTES",
                                            "FIFTEEN_MINUTES",
                                            "THIRTY_MINUTES",
                                            "ONE_HOUR",
                                            "TWO_HOURS",
                                            "THREE_HOURS",
                                            "SIX_HOURS",
                                            "TWELVE_HOURS",
                                            "ONE_DAY",
                                        ],
                                    },
                                    "maxSignalDuration": {
                                        "description": "A "
                                        "signal "
                                        "will "
                                        '"close" '
                                        "regardless "
                                        "of "
                                        "the "
                                        "query "
                                        "being "
                                        "matched "
                                        "once "
                                        "the "
                                        "time "
                                        "exceeds "
                                        "the "
                                        "maximum "
                                        "duration.\n"
                                        "This "
                                        "time "
                                        "is "
                                        "calculated "
                                        "from "
                                        "the "
                                        "first "
                                        "seen "
                                        "timestamp.",
                                        "enum": [
                                            0,
                                            60,
                                            300,
                                            600,
                                            900,
                                            1800,
                                            3600,
                                            7200,
                                            10800,
                                            21600,
                                            43200,
                                            86400,
                                        ],
                                        "format": "int32",
                                        "type": "integer",
                                        "x-enum-varnames": [
                                            "ZERO_MINUTES",
                                            "ONE_MINUTE",
                                            "FIVE_MINUTES",
                                            "TEN_MINUTES",
                                            "FIFTEEN_MINUTES",
                                            "THIRTY_MINUTES",
                                            "ONE_HOUR",
                                            "TWO_HOURS",
                                            "THREE_HOURS",
                                            "SIX_HOURS",
                                            "TWELVE_HOURS",
                                            "ONE_DAY",
                                        ],
                                    },
                                    "newValueOptions": {
                                        "description": "Options on new value detection method.",
                                        "properties": {
                                            "forgetAfter": {
                                                "description": "The "
                                                "duration "
                                                "in "
                                                "days "
                                                "after "
                                                "which "
                                                "a "
                                                "learned "
                                                "value "
                                                "is "
                                                "forgotten.",
                                                "enum": [1, 2, 7, 14, 21, 28],
                                                "format": "int32",
                                                "type": "integer",
                                                "x-enum-varnames": [
                                                    "ONE_DAY",
                                                    "TWO_DAYS",
                                                    "ONE_WEEK",
                                                    "TWO_WEEKS",
                                                    "THREE_WEEKS",
                                                    "FOUR_WEEKS",
                                                ],
                                            },
                                            "learningDuration": {
                                                "default": 0,
                                                "description": "The "
                                                "duration "
                                                "in "
                                                "days "
                                                "during "
                                                "which "
                                                "values "
                                                "are "
                                                "learned, "
                                                "and "
                                                "after "
                                                "which "
                                                "signals "
                                                "will "
                                                "be "
                                                "generated "
                                                "for "
                                                "values "
                                                "that\n"
                                                "weren't "
                                                "learned. "
                                                "If "
                                                "set "
                                                "to "
                                                "0, "
                                                "a "
                                                "signal "
                                                "will "
                                                "be "
                                                "generated "
                                                "for "
                                                "all "
                                                "new "
                                                "values "
                                                "after "
                                                "the "
                                                "first "
                                                "value "
                                                "is "
                                                "learned.",
                                                "enum": [0, 1, 7],
                                                "format": "int32",
                                                "type": "integer",
                                                "x-enum-varnames": [
                                                    "ZERO_DAYS",
                                                    "ONE_DAY",
                                                    "SEVEN_DAYS",
                                                ],
                                            },
                                            "learningMethod": {
                                                "default": "duration",
                                                "description": "The "
                                                "learning "
                                                "method "
                                                "used "
                                                "to "
                                                "determine "
                                                "when "
                                                "signals "
                                                "should "
                                                "be "
                                                "generated "
                                                "for "
                                                "values "
                                                "that "
                                                "weren't "
                                                "learned.",
                                                "enum": ["duration", "threshold"],
                                                "type": "string",
                                                "x-enum-varnames": ["DURATION", "THRESHOLD"],
                                            },
                                            "learningThreshold": {
                                                "default": 0,
                                                "description": "A "
                                                "number "
                                                "of "
                                                "occurrences "
                                                "after "
                                                "which "
                                                "signals "
                                                "will "
                                                "be "
                                                "generated "
                                                "for "
                                                "values "
                                                "that "
                                                "weren't "
                                                "learned.",
                                                "enum": [0, 1],
                                                "format": "int32",
                                                "type": "integer",
                                                "x-enum-varnames": [
                                                    "ZERO_OCCURRENCES",
                                                    "ONE_OCCURRENCE",
                                                ],
                                            },
                                        },
                                        "type": "object",
                                    },
                                    "sequenceDetectionOptions": {
                                        "description": "Options on sequence detection method.",
                                        "properties": {
                                            "stepTransitions": {
                                                "description": "Transitions "
                                                "defining "
                                                "the "
                                                "allowed "
                                                "order "
                                                "of "
                                                "steps "
                                                "and "
                                                "their "
                                                "evaluation "
                                                "windows.",
                                                "items": {
                                                    "description": "Transition "
                                                    "from "
                                                    "a "
                                                    "parent "
                                                    "step "
                                                    "to "
                                                    "a "
                                                    "child "
                                                    "step "
                                                    "within "
                                                    "a "
                                                    "sequence "
                                                    "detection "
                                                    "rule.",
                                                    "properties": {
                                                        "child": {
                                                            "description": "Name "
                                                            "of "
                                                            "the "
                                                            "child "
                                                            "step.",
                                                            "type": "string",
                                                        },
                                                        "evaluationWindow": {
                                                            "description": "A "
                                                            "time "
                                                            "window "
                                                            "is "
                                                            "specified "
                                                            "to "
                                                            "match "
                                                            "when "
                                                            "at "
                                                            "least "
                                                            "one "
                                                            "of "
                                                            "the "
                                                            "cases "
                                                            "matches "
                                                            "true. "
                                                            "This "
                                                            "is "
                                                            "a "
                                                            "sliding "
                                                            "window\n"
                                                            "and "
                                                            "evaluates "
                                                            "in "
                                                            "real "
                                                            "time. "
                                                            "For "
                                                            "third "
                                                            "party "
                                                            "detection "
                                                            "method, "
                                                            "this "
                                                            "field "
                                                            "is "
                                                            "not "
                                                            "used.",
                                                            "enum": [
                                                                0,
                                                                60,
                                                                300,
                                                                600,
                                                                900,
                                                                1800,
                                                                3600,
                                                                7200,
                                                                10800,
                                                                21600,
                                                                43200,
                                                                86400,
                                                            ],
                                                            "format": "int32",
                                                            "type": "integer",
                                                            "x-enum-varnames": [
                                                                "ZERO_MINUTES",
                                                                "ONE_MINUTE",
                                                                "FIVE_MINUTES",
                                                                "TEN_MINUTES",
                                                                "FIFTEEN_MINUTES",
                                                                "THIRTY_MINUTES",
                                                                "ONE_HOUR",
                                                                "TWO_HOURS",
                                                                "THREE_HOURS",
                                                                "SIX_HOURS",
                                                                "TWELVE_HOURS",
                                                                "ONE_DAY",
                                                            ],
                                                        },
                                                        "parent": {
                                                            "description": "Name "
                                                            "of "
                                                            "the "
                                                            "parent "
                                                            "step.",
                                                            "type": "string",
                                                        },
                                                    },
                                                    "type": "object",
                                                },
                                                "type": "array",
                                            },
                                            "steps": {
                                                "description": "Steps "
                                                "that "
                                                "define "
                                                "the "
                                                "conditions "
                                                "to "
                                                "be "
                                                "matched "
                                                "in "
                                                "sequence.",
                                                "items": {
                                                    "description": "Step "
                                                    "definition "
                                                    "for "
                                                    "sequence "
                                                    "detection "
                                                    "containing "
                                                    "the "
                                                    "step "
                                                    "name, "
                                                    "condition, "
                                                    "and "
                                                    "evaluation "
                                                    "window.",
                                                    "properties": {
                                                        "condition": {
                                                            "description": "Condition "
                                                            "referencing "
                                                            "rule "
                                                            "queries "
                                                            "(e.g., "
                                                            "`a "
                                                            "> "
                                                            "0`).",
                                                            "type": "string",
                                                        },
                                                        "evaluationWindow": {
                                                            "description": "A "
                                                            "time "
                                                            "window "
                                                            "is "
                                                            "specified "
                                                            "to "
                                                            "match "
                                                            "when "
                                                            "at "
                                                            "least "
                                                            "one "
                                                            "of "
                                                            "the "
                                                            "cases "
                                                            "matches "
                                                            "true. "
                                                            "This "
                                                            "is "
                                                            "a "
                                                            "sliding "
                                                            "window\n"
                                                            "and "
                                                            "evaluates "
                                                            "in "
                                                            "real "
                                                            "time. "
                                                            "For "
                                                            "third "
                                                            "party "
                                                            "detection "
                                                            "method, "
                                                            "this "
                                                            "field "
                                                            "is "
                                                            "not "
                                                            "used.",
                                                            "enum": [
                                                                0,
                                                                60,
                                                                300,
                                                                600,
                                                                900,
                                                                1800,
                                                                3600,
                                                                7200,
                                                                10800,
                                                                21600,
                                                                43200,
                                                                86400,
                                                            ],
                                                            "format": "int32",
                                                            "type": "integer",
                                                            "x-enum-varnames": [
                                                                "ZERO_MINUTES",
                                                                "ONE_MINUTE",
                                                                "FIVE_MINUTES",
                                                                "TEN_MINUTES",
                                                                "FIFTEEN_MINUTES",
                                                                "THIRTY_MINUTES",
                                                                "ONE_HOUR",
                                                                "TWO_HOURS",
                                                                "THREE_HOURS",
                                                                "SIX_HOURS",
                                                                "TWELVE_HOURS",
                                                                "ONE_DAY",
                                                            ],
                                                        },
                                                        "name": {
                                                            "description": "Unique "
                                                            "name "
                                                            "identifying "
                                                            "the "
                                                            "step.",
                                                            "type": "string",
                                                        },
                                                    },
                                                    "type": "object",
                                                },
                                                "type": "array",
                                            },
                                        },
                                        "type": "object",
                                    },
                                    "thirdPartyRuleOptions": {
                                        "description": "Options on third party detection method.",
                                        "properties": {
                                            "defaultNotifications": {
                                                "description": "Notification "
                                                "targets "
                                                "for "
                                                "the "
                                                "logs "
                                                "that "
                                                "do "
                                                "not "
                                                "correspond "
                                                "to "
                                                "any "
                                                "of "
                                                "the "
                                                "cases.",
                                                "items": {
                                                    "description": "Notification.",
                                                    "type": "string",
                                                },
                                                "type": "array",
                                            },
                                            "defaultStatus": {
                                                "description": "Severity of the Security Signal.",
                                                "enum": [
                                                    "info",
                                                    "low",
                                                    "medium",
                                                    "high",
                                                    "critical",
                                                ],
                                                "example": "critical",
                                                "type": "string",
                                                "x-enum-varnames": [
                                                    "INFO",
                                                    "LOW",
                                                    "MEDIUM",
                                                    "HIGH",
                                                    "CRITICAL",
                                                ],
                                            },
                                            "rootQueries": {
                                                "description": "Queries "
                                                "to "
                                                "be "
                                                "combined "
                                                "with "
                                                "third "
                                                "party "
                                                "case "
                                                "queries. "
                                                "Each "
                                                "of "
                                                "them "
                                                "can "
                                                "have "
                                                "different "
                                                "group "
                                                "by "
                                                "fields, "
                                                "to "
                                                "aggregate "
                                                "differently "
                                                "based "
                                                "on "
                                                "the "
                                                "type "
                                                "of "
                                                "alert.",
                                                "items": {
                                                    "description": "A "
                                                    "query "
                                                    "to "
                                                    "be "
                                                    "combined "
                                                    "with "
                                                    "the "
                                                    "third "
                                                    "party "
                                                    "case "
                                                    "query.",
                                                    "properties": {
                                                        "groupByFields": {
                                                            "description": "Fields to group by.",
                                                            "items": {
                                                                "description": "Field.",
                                                                "type": "string",
                                                            },
                                                            "type": "array",
                                                        },
                                                        "query": {
                                                            "description": "Query to run on logs.",
                                                            "example": "source:cloudtrail",
                                                            "type": "string",
                                                        },
                                                    },
                                                    "type": "object",
                                                },
                                                "type": "array",
                                            },
                                            "signalTitleTemplate": {
                                                "description": "A "
                                                "template "
                                                "for "
                                                "the "
                                                "signal "
                                                "title; "
                                                "if "
                                                "omitted, "
                                                "the "
                                                "title "
                                                "is "
                                                "generated "
                                                "based "
                                                "on "
                                                "the "
                                                "case "
                                                "name.",
                                                "type": "string",
                                            },
                                        },
                                        "type": "object",
                                    },
                                },
                                "type": "object",
                            },
                            "queries": {
                                "description": "Queries "
                                "for "
                                "selecting "
                                "logs "
                                "which "
                                "are "
                                "part of "
                                "the "
                                "rule.",
                                "example": [],
                                "items": {
                                    "description": "Query for matching rule.",
                                    "properties": {
                                        "aggregation": {
                                            "description": "The aggregation type.",
                                            "enum": [
                                                "count",
                                                "cardinality",
                                                "sum",
                                                "max",
                                                "new_value",
                                                "geo_data",
                                                "event_count",
                                                "none",
                                            ],
                                            "type": "string",
                                            "x-enum-varnames": [
                                                "COUNT",
                                                "CARDINALITY",
                                                "SUM",
                                                "MAX",
                                                "NEW_VALUE",
                                                "GEO_DATA",
                                                "EVENT_COUNT",
                                                "NONE",
                                            ],
                                        },
                                        "customQueryExtension": {
                                            "description": "Query "
                                            "extension "
                                            "to "
                                            "append "
                                            "to "
                                            "the "
                                            "logs "
                                            "query.",
                                            "example": "a > 3",
                                            "type": "string",
                                        },
                                        "dataSource": {
                                            "default": "logs",
                                            "description": "Source "
                                            "of "
                                            "events, "
                                            "either "
                                            "logs, "
                                            "audit "
                                            "trail, "
                                            "or "
                                            "Datadog "
                                            "events.",
                                            "enum": [
                                                "logs",
                                                "audit",
                                                "app_sec_spans",
                                                "spans",
                                                "security_runtime",
                                                "network",
                                                "events",
                                            ],
                                            "example": "logs",
                                            "type": "string",
                                            "x-enum-varnames": [
                                                "LOGS",
                                                "AUDIT",
                                                "APP_SEC_SPANS",
                                                "SPANS",
                                                "SECURITY_RUNTIME",
                                                "NETWORK",
                                                "EVENTS",
                                            ],
                                        },
                                        "distinctFields": {
                                            "description": "Field "
                                            "for "
                                            "which "
                                            "the "
                                            "cardinality "
                                            "is "
                                            "measured. "
                                            "Sent "
                                            "as "
                                            "an "
                                            "array.",
                                            "items": {"description": "Field.", "type": "string"},
                                            "type": "array",
                                        },
                                        "groupByFields": {
                                            "description": "Fields to group by.",
                                            "items": {"description": "Field.", "type": "string"},
                                            "type": "array",
                                        },
                                        "hasOptionalGroupByFields": {
                                            "default": False,
                                            "description": "When "
                                            "false, "
                                            "events "
                                            "without "
                                            "a "
                                            "group-by "
                                            "value "
                                            "are "
                                            "ignored "
                                            "by "
                                            "the "
                                            "rule. "
                                            "When "
                                            "true, "
                                            "events "
                                            "with "
                                            "missing "
                                            "group-by "
                                            "fields "
                                            "are "
                                            "processed "
                                            "with "
                                            "`N/A`, "
                                            "replacing "
                                            "the "
                                            "missing "
                                            "values.",
                                            "example": False,
                                            "type": "boolean",
                                        },
                                        "index": {
                                            "description": "**This "
                                            "field "
                                            "is "
                                            "currently "
                                            "unstable "
                                            "and "
                                            "might "
                                            "be "
                                            "removed "
                                            "in "
                                            "a "
                                            "minor "
                                            "version "
                                            "upgrade.**\n"
                                            "The "
                                            "index "
                                            "to "
                                            "run "
                                            "the "
                                            "query "
                                            "on, "
                                            "if "
                                            "the "
                                            "`dataSource` "
                                            "is "
                                            "`logs`. "
                                            "Only "
                                            "used "
                                            "for "
                                            "scheduled "
                                            "rules "
                                            "- "
                                            "in "
                                            "other "
                                            "words, "
                                            "when "
                                            "the "
                                            "`schedulingOptions` "
                                            "field "
                                            "is "
                                            "present "
                                            "in "
                                            "the "
                                            "rule "
                                            "payload.",
                                            "type": "string",
                                        },
                                        "indexes": {
                                            "description": "List "
                                            "of "
                                            "indexes "
                                            "to "
                                            "query "
                                            "when "
                                            "the "
                                            "`dataSource` "
                                            "is "
                                            "`logs`. "
                                            "Only "
                                            "used "
                                            "for "
                                            "scheduled "
                                            "rules, "
                                            "such "
                                            "as "
                                            "when "
                                            "the "
                                            "`schedulingOptions` "
                                            "field "
                                            "is "
                                            "present "
                                            "in "
                                            "the "
                                            "rule "
                                            "payload.",
                                            "items": {"description": "Index.", "type": "string"},
                                            "type": "array",
                                        },
                                        "metric": {
                                            "deprecated": True,
                                            "description": "(Deprecated) "
                                            "The "
                                            "target "
                                            "field "
                                            "to "
                                            "aggregate "
                                            "over "
                                            "when "
                                            "using "
                                            "the "
                                            "sum "
                                            "or "
                                            "max\n"
                                            "aggregations. "
                                            "`metrics` "
                                            "field "
                                            "should "
                                            "be "
                                            "used "
                                            "instead.",
                                            "type": "string",
                                        },
                                        "metrics": {
                                            "description": "Group "
                                            "of "
                                            "target "
                                            "fields "
                                            "to "
                                            "aggregate "
                                            "over "
                                            "when "
                                            "using "
                                            "the "
                                            "sum, "
                                            "max, "
                                            "geo "
                                            "data, "
                                            "or "
                                            "new "
                                            "value "
                                            "aggregations. "
                                            "The "
                                            "sum, "
                                            "max, "
                                            "and "
                                            "geo "
                                            "data "
                                            "aggregations "
                                            "only "
                                            "accept "
                                            "one "
                                            "value "
                                            "in "
                                            "this "
                                            "list, "
                                            "whereas "
                                            "the "
                                            "new "
                                            "value "
                                            "aggregation "
                                            "accepts "
                                            "up "
                                            "to "
                                            "five "
                                            "values.",
                                            "items": {"description": "Field.", "type": "string"},
                                            "type": "array",
                                        },
                                        "name": {
                                            "description": "Name of the query.",
                                            "type": "string",
                                        },
                                        "query": {
                                            "description": "Query to run on logs.",
                                            "example": "a > 3",
                                            "type": "string",
                                        },
                                    },
                                    "type": "object",
                                },
                                "type": "array",
                            },
                            "referenceTables": {
                                "description": "Reference tables for the rule.",
                                "items": {
                                    "description": "Reference tables used in the queries.",
                                    "properties": {
                                        "checkPresence": {
                                            "description": "Whether "
                                            "to "
                                            "include "
                                            "or "
                                            "exclude "
                                            "the "
                                            "matched "
                                            "values.",
                                            "type": "boolean",
                                        },
                                        "columnName": {
                                            "description": "The "
                                            "name "
                                            "of "
                                            "the "
                                            "column "
                                            "in "
                                            "the "
                                            "reference "
                                            "table.",
                                            "type": "string",
                                        },
                                        "logFieldPath": {
                                            "description": "The "
                                            "field "
                                            "in "
                                            "the "
                                            "log "
                                            "to "
                                            "match "
                                            "against "
                                            "the "
                                            "reference "
                                            "table.",
                                            "type": "string",
                                        },
                                        "ruleQueryName": {
                                            "description": "The "
                                            "name "
                                            "of "
                                            "the "
                                            "query "
                                            "to "
                                            "apply "
                                            "the "
                                            "reference "
                                            "table "
                                            "to.",
                                            "type": "string",
                                        },
                                        "tableName": {
                                            "description": "The name of the reference table.",
                                            "type": "string",
                                        },
                                    },
                                    "type": "object",
                                },
                                "type": "array",
                            },
                            "schedulingOptions": {
                                "description": "Options "
                                "for "
                                "scheduled "
                                "rules. "
                                "When "
                                "this "
                                "field "
                                "is "
                                "present, "
                                "the "
                                "rule "
                                "runs "
                                "based "
                                "on "
                                "the "
                                "schedule. "
                                "When "
                                "absent, "
                                "it "
                                "runs "
                                "real-time "
                                "on "
                                "ingested "
                                "logs.",
                                "nullable": True,
                                "properties": {
                                    "rrule": {
                                        "description": "Schedule "
                                        "for "
                                        "the "
                                        "rule "
                                        "queries, "
                                        "written "
                                        "in "
                                        "RRULE "
                                        "syntax. "
                                        "See "
                                        "[RFC](https://icalendar.org/iCalendar-RFC-5545/3-8-5-3-recurrence-rule.html) "
                                        "for "
                                        "syntax "
                                        "reference.",
                                        "example": "FREQ=HOURLY;INTERVAL=1;",
                                        "type": "string",
                                    },
                                    "start": {
                                        "description": "Start "
                                        "date "
                                        "for "
                                        "the "
                                        "schedule, "
                                        "in "
                                        "ISO "
                                        "8601 "
                                        "format "
                                        "without "
                                        "timezone.",
                                        "example": "2025-07-14T12:00:00",
                                        "type": "string",
                                    },
                                    "timezone": {
                                        "description": "Time "
                                        "zone "
                                        "of "
                                        "the "
                                        "start "
                                        "date, "
                                        "in "
                                        "the "
                                        "[tz "
                                        "database](https://en.wikipedia.org/wiki/List_of_tz_database_time_zones) "
                                        "format.",
                                        "example": "America/New_York",
                                        "type": "string",
                                    },
                                },
                                "type": "object",
                            },
                            "tags": {
                                "description": "Tags for generated signals.",
                                "example": ["env:prod", "team:security"],
                                "items": {"description": "Tag.", "type": "string"},
                                "type": "array",
                            },
                            "thirdPartyCases": {
                                "description": "Cases "
                                "for "
                                "generating "
                                "signals "
                                "from "
                                "third-party "
                                "rules. "
                                "Only "
                                "available "
                                "for "
                                "third-party "
                                "rules.",
                                "example": [],
                                "items": {
                                    "description": "Case "
                                    "when "
                                    "a "
                                    "signal "
                                    "is "
                                    "generated "
                                    "by "
                                    "a "
                                    "third "
                                    "party "
                                    "rule.",
                                    "properties": {
                                        "name": {
                                            "description": "Name of the case.",
                                            "type": "string",
                                        },
                                        "notifications": {
                                            "description": "Notification targets for each case.",
                                            "items": {
                                                "description": "Notification.",
                                                "type": "string",
                                            },
                                            "type": "array",
                                        },
                                        "query": {
                                            "description": "A "
                                            "query "
                                            "to "
                                            "map "
                                            "a "
                                            "third "
                                            "party "
                                            "event "
                                            "to "
                                            "this "
                                            "case.",
                                            "type": "string",
                                        },
                                        "status": {
                                            "description": "Severity of the Security Signal.",
                                            "enum": ["info", "low", "medium", "high", "critical"],
                                            "example": "critical",
                                            "type": "string",
                                            "x-enum-varnames": [
                                                "INFO",
                                                "LOW",
                                                "MEDIUM",
                                                "HIGH",
                                                "CRITICAL",
                                            ],
                                        },
                                    },
                                    "required": ["status"],
                                    "type": "object",
                                },
                                "type": "array",
                            },
                            "type": {
                                "description": "The rule type.",
                                "enum": ["log_detection"],
                                "type": "string",
                                "x-enum-varnames": ["LOG_DETECTION"],
                            },
                        },
                        "required": ["name", "isEnabled", "queries", "options", "cases", "message"],
                        "type": "object",
                    }
                ],
            },
            "ruleQueryPayloads": {
                "description": "Data payloads used to test rules query with the expected result.",
                "items": {
                    "description": "Payload to test a rule query with the expected result.",
                    "properties": {
                        "expectedResult": {
                            "description": "Expected result of the test.",
                            "example": True,
                            "type": "boolean",
                        },
                        "index": {
                            "description": "Index of the query under test.",
                            "example": 0,
                            "format": "int64",
                            "minimum": 0,
                            "type": "integer",
                        },
                        "payload": {
                            "additionalProperties": {},
                            "description": "Payload used to test the rule query.",
                            "properties": {
                                "ddsource": {
                                    "description": "Source of the payload.",
                                    "example": "nginx",
                                    "type": "string",
                                },
                                "ddtags": {
                                    "description": "Tags associated with your data.",
                                    "example": "env:staging,version:5.1",
                                    "type": "string",
                                },
                                "hostname": {
                                    "description": "The name of the originating host of the log.",
                                    "example": "i-012345678",
                                    "type": "string",
                                },
                                "message": {
                                    "description": "The message of the payload.",
                                    "example": "2019-11-19T14:37:58,995 "
                                    "INFO "
                                    "[process.name][20081] "
                                    "Hello "
                                    "World",
                                    "type": "string",
                                },
                                "service": {
                                    "description": "The "
                                    "name "
                                    "of "
                                    "the "
                                    "application "
                                    "or "
                                    "service "
                                    "generating "
                                    "the "
                                    "data.",
                                    "example": "payment",
                                    "type": "string",
                                },
                            },
                            "type": "object",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
        },
        "type": "object",
    },
    "VALIDATESECURITYMONITORINGRULE_REQUEST_BODY_SCHEMA": {
        "description": "Validate a rule.",
        "oneOf": [
            {
                "description": "The payload of a rule.",
                "properties": {
                    "calculatedFields": {
                        "description": "Calculated fields. "
                        "Only allowed for "
                        "scheduled rules - in "
                        "other words, when "
                        "schedulingOptions is "
                        "also defined.",
                        "items": {
                            "description": "Calculated field.",
                            "properties": {
                                "expression": {
                                    "description": "Expression.",
                                    "example": "@request_end_timestamp - @request_start_timestamp",
                                    "type": "string",
                                },
                                "name": {
                                    "description": "Field name.",
                                    "example": "response_time",
                                    "type": "string",
                                },
                            },
                            "required": ["name", "expression"],
                            "type": "object",
                        },
                        "type": "array",
                    },
                    "cases": {
                        "description": "Cases for generating signals.",
                        "example": [],
                        "items": {
                            "description": "Case when signal is generated.",
                            "properties": {
                                "actions": {
                                    "description": "Action to perform for each rule case.",
                                    "items": {
                                        "description": "Action "
                                        "to "
                                        "perform "
                                        "when "
                                        "a "
                                        "signal "
                                        "is "
                                        "triggered. "
                                        "Only "
                                        "available "
                                        "for "
                                        "Application "
                                        "Security "
                                        "rule "
                                        "type.",
                                        "properties": {
                                            "options": {
                                                "additionalProperties": {},
                                                "description": "Options for the rule action",
                                                "properties": {
                                                    "duration": {
                                                        "description": "Duration "
                                                        "of "
                                                        "the "
                                                        "action "
                                                        "in "
                                                        "seconds. "
                                                        "0 "
                                                        "indicates "
                                                        "no "
                                                        "expiration.",
                                                        "example": 0,
                                                        "format": "int64",
                                                        "minimum": 0,
                                                        "type": "integer",
                                                    },
                                                    "flaggedIPType": {
                                                        "description": "Used "
                                                        "with "
                                                        "the "
                                                        "case "
                                                        "action "
                                                        "of "
                                                        "type "
                                                        "'flag_ip'. "
                                                        "The "
                                                        "value "
                                                        "specified "
                                                        "in "
                                                        "this "
                                                        "field "
                                                        "is "
                                                        "applied "
                                                        "as "
                                                        "a "
                                                        "flag "
                                                        "to "
                                                        "the "
                                                        "IP "
                                                        "addresses.",
                                                        "enum": ["SUSPICIOUS", "FLAGGED"],
                                                        "example": "FLAGGED",
                                                        "type": "string",
                                                        "x-enum-varnames": [
                                                            "SUSPICIOUS",
                                                            "FLAGGED",
                                                        ],
                                                    },
                                                    "userBehaviorName": {
                                                        "description": "Used "
                                                        "with "
                                                        "the "
                                                        "case "
                                                        "action "
                                                        "of "
                                                        "type "
                                                        "'user_behavior'. "
                                                        "The "
                                                        "value "
                                                        "specified "
                                                        "in "
                                                        "this "
                                                        "field "
                                                        "is "
                                                        "applied "
                                                        "as "
                                                        "a "
                                                        "risk "
                                                        "tag "
                                                        "to "
                                                        "all "
                                                        "users "
                                                        "affected "
                                                        "by "
                                                        "the "
                                                        "rule.",
                                                        "type": "string",
                                                    },
                                                },
                                                "type": "object",
                                            },
                                            "type": {
                                                "description": "The action type.",
                                                "enum": [
                                                    "block_ip",
                                                    "block_user",
                                                    "user_behavior",
                                                    "flag_ip",
                                                ],
                                                "type": "string",
                                                "x-enum-varnames": [
                                                    "BLOCK_IP",
                                                    "BLOCK_USER",
                                                    "USER_BEHAVIOR",
                                                    "FLAG_IP",
                                                ],
                                            },
                                        },
                                        "type": "object",
                                    },
                                    "type": "array",
                                },
                                "condition": {
                                    "description": "A "
                                    "case "
                                    "contains "
                                    "logical "
                                    "operations "
                                    "(`>`,`>=`, "
                                    "`&&`, "
                                    "`||`) "
                                    "to "
                                    "determine "
                                    "if "
                                    "a "
                                    "signal "
                                    "should "
                                    "be "
                                    "generated\n"
                                    "based "
                                    "on "
                                    "the "
                                    "event "
                                    "counts "
                                    "in "
                                    "the "
                                    "previously "
                                    "defined "
                                    "queries.",
                                    "type": "string",
                                },
                                "name": {"description": "Name of the case.", "type": "string"},
                                "notifications": {
                                    "description": "Notification targets.",
                                    "items": {"description": "Notification.", "type": "string"},
                                    "type": "array",
                                },
                                "status": {
                                    "description": "Severity of the Security Signal.",
                                    "enum": ["info", "low", "medium", "high", "critical"],
                                    "example": "critical",
                                    "type": "string",
                                    "x-enum-varnames": [
                                        "INFO",
                                        "LOW",
                                        "MEDIUM",
                                        "HIGH",
                                        "CRITICAL",
                                    ],
                                },
                            },
                            "required": ["status"],
                            "type": "object",
                        },
                        "type": "array",
                    },
                    "customMessage": {
                        "description": "Custom/Overridden message "
                        "for generated signals "
                        "(used in case of Default "
                        "rule update).",
                        "type": "string",
                    },
                    "customName": {
                        "description": "Custom/Overridden name of "
                        "the rule (used in case of "
                        "Default rule update).",
                        "type": "string",
                    },
                    "filters": {
                        "description": "Additional queries to filter "
                        "matched events before they are "
                        "processed. This field is "
                        "deprecated for log detection, "
                        "signal correlation, and "
                        "workload security rules.",
                        "items": {
                            "description": "The rule's suppression filter.",
                            "properties": {
                                "action": {
                                    "description": "The type of filtering action.",
                                    "enum": ["require", "suppress"],
                                    "type": "string",
                                    "x-enum-varnames": ["REQUIRE", "SUPPRESS"],
                                },
                                "query": {
                                    "description": "Query "
                                    "for "
                                    "selecting "
                                    "logs "
                                    "to "
                                    "apply "
                                    "the "
                                    "filtering "
                                    "action.",
                                    "type": "string",
                                },
                            },
                            "type": "object",
                        },
                        "type": "array",
                    },
                    "groupSignalsBy": {
                        "description": "Additional grouping to "
                        "perform on top of the "
                        "existing groups in the "
                        "query section. Must be a "
                        "subset of the existing "
                        "groups.",
                        "example": ["service"],
                        "items": {"description": "Field to group by.", "type": "string"},
                        "type": "array",
                    },
                    "hasExtendedTitle": {
                        "description": "Whether the "
                        "notifications include "
                        "the triggering "
                        "group-by values in "
                        "their title.",
                        "example": True,
                        "type": "boolean",
                    },
                    "isEnabled": {
                        "description": "Whether the rule is enabled.",
                        "example": True,
                        "type": "boolean",
                    },
                    "message": {
                        "description": "Message for generated signals.",
                        "example": "",
                        "type": "string",
                    },
                    "name": {
                        "description": "The name of the rule.",
                        "example": "My security monitoring rule.",
                        "type": "string",
                    },
                    "options": {
                        "description": "Options.",
                        "properties": {
                            "complianceRuleOptions": {
                                "additionalProperties": {},
                                "description": "Options "
                                "for "
                                "cloud_configuration "
                                "rules.\n"
                                "Fields "
                                "`resourceType` "
                                "and "
                                "`regoRule` "
                                "are "
                                "mandatory "
                                "when "
                                "managing "
                                "custom "
                                "`cloud_configuration` "
                                "rules.",
                                "properties": {
                                    "complexRule": {
                                        "description": "Whether "
                                        "the "
                                        "rule "
                                        "is "
                                        "a "
                                        "complex "
                                        "one.\n"
                                        "Must "
                                        "be "
                                        "set "
                                        "to "
                                        "true "
                                        "if "
                                        "`regoRule.resourceTypes` "
                                        "contains "
                                        "more "
                                        "than "
                                        "one "
                                        "item. "
                                        "Defaults "
                                        "to "
                                        "false.",
                                        "type": "boolean",
                                    },
                                    "regoRule": {
                                        "description": "Rule details.",
                                        "properties": {
                                            "policy": {
                                                "description": "The "
                                                "policy "
                                                "written "
                                                "in "
                                                "`rego`, "
                                                "see: "
                                                "https://www.openpolicyagent.org/docs/latest/policy-language/",
                                                "example": "package "
                                                "datadog\n"
                                                "\n"
                                                "import "
                                                "data.datadog.output "
                                                "as "
                                                "dd_output\n"
                                                "import "
                                                "future.keywords.contains\n"
                                                "import "
                                                "future.keywords.if\n"
                                                "import "
                                                "future.keywords.in\n"
                                                "\n"
                                                "eval(resource) "
                                                "= "
                                                '"skip" '
                                                "if "
                                                "{\n"
                                                "  "
                                                "# "
                                                "Logic "
                                                "that "
                                                "evaluates "
                                                "to "
                                                "true "
                                                "if "
                                                "the "
                                                "resource "
                                                "should "
                                                "be "
                                                "skipped\n"
                                                "  "
                                                "true\n"
                                                "} "
                                                "else "
                                                "= "
                                                '"pass" '
                                                "{\n"
                                                "  "
                                                "# "
                                                "Logic "
                                                "that "
                                                "evaluates "
                                                "to "
                                                "true "
                                                "if "
                                                "the "
                                                "resource "
                                                "is "
                                                "compliant\n"
                                                "  "
                                                "true\n"
                                                "} "
                                                "else "
                                                "= "
                                                '"fail" '
                                                "{\n"
                                                "  "
                                                "# "
                                                "Logic "
                                                "that "
                                                "evaluates "
                                                "to "
                                                "true "
                                                "if "
                                                "the "
                                                "resource "
                                                "is "
                                                "not "
                                                "compliant\n"
                                                "  "
                                                "true\n"
                                                "}\n"
                                                "\n"
                                                "# "
                                                "This "
                                                "part "
                                                "remains "
                                                "unchanged "
                                                "for "
                                                "all "
                                                "rules\n"
                                                "results "
                                                "contains "
                                                "result "
                                                "if "
                                                "{\n"
                                                "  "
                                                "some "
                                                "resource "
                                                "in "
                                                "input.resources[input.main_resource_type]\n"
                                                "  "
                                                "result "
                                                ":= "
                                                "dd_output.format(resource, "
                                                "eval(resource))\n"
                                                "}",
                                                "type": "string",
                                            },
                                            "resourceTypes": {
                                                "description": "List "
                                                "of "
                                                "resource "
                                                "types "
                                                "that "
                                                "will "
                                                "be "
                                                "evaluated "
                                                "upon. "
                                                "Must "
                                                "have "
                                                "at "
                                                "least "
                                                "one "
                                                "element.",
                                                "example": [
                                                    "gcp_iam_service_account",
                                                    "gcp_iam_policy",
                                                ],
                                                "items": {"type": "string"},
                                                "type": "array",
                                            },
                                        },
                                        "required": ["policy", "resourceTypes"],
                                        "type": "object",
                                    },
                                    "resourceType": {
                                        "description": "Main "
                                        "resource "
                                        "type "
                                        "to "
                                        "be "
                                        "checked "
                                        "by "
                                        "the "
                                        "rule. "
                                        "It "
                                        "should "
                                        "be "
                                        "specified "
                                        "again "
                                        "in "
                                        "`regoRule.resourceTypes`.",
                                        "example": "aws_acm",
                                        "type": "string",
                                    },
                                },
                                "type": "object",
                            },
                            "decreaseCriticalityBasedOnEnv": {
                                "description": "If "
                                "true, "
                                "signals "
                                "in "
                                "non-production "
                                "environments "
                                "have "
                                "a "
                                "lower "
                                "severity "
                                "than "
                                "what "
                                "is "
                                "defined "
                                "by "
                                "the "
                                "rule "
                                "case, "
                                "which "
                                "can "
                                "reduce "
                                "signal "
                                "noise.\n"
                                "The "
                                "severity "
                                "is "
                                "decreased "
                                "by "
                                "one "
                                "level: "
                                "`CRITICAL` "
                                "in "
                                "production "
                                "becomes "
                                "`HIGH` "
                                "in "
                                "non-production, "
                                "`HIGH` "
                                "becomes "
                                "`MEDIUM` "
                                "and "
                                "so "
                                "on. "
                                "`INFO` "
                                "remains "
                                "`INFO`.\n"
                                "The "
                                "decrement "
                                "is "
                                "applied "
                                "when "
                                "the "
                                "environment "
                                "tag "
                                "of "
                                "the "
                                "signal "
                                "starts "
                                "with "
                                "`staging`, "
                                "`test` "
                                "or "
                                "`dev`.",
                                "example": False,
                                "type": "boolean",
                            },
                            "detectionMethod": {
                                "description": "The detection method.",
                                "enum": [
                                    "threshold",
                                    "new_value",
                                    "anomaly_detection",
                                    "impossible_travel",
                                    "hardcoded",
                                    "third_party",
                                    "anomaly_threshold",
                                    "sequence_detection",
                                ],
                                "type": "string",
                                "x-enum-varnames": [
                                    "THRESHOLD",
                                    "NEW_VALUE",
                                    "ANOMALY_DETECTION",
                                    "IMPOSSIBLE_TRAVEL",
                                    "HARDCODED",
                                    "THIRD_PARTY",
                                    "ANOMALY_THRESHOLD",
                                    "SEQUENCE_DETECTION",
                                ],
                            },
                            "evaluationWindow": {
                                "description": "A "
                                "time "
                                "window "
                                "is "
                                "specified "
                                "to "
                                "match "
                                "when "
                                "at "
                                "least "
                                "one "
                                "of "
                                "the "
                                "cases "
                                "matches "
                                "true. "
                                "This "
                                "is "
                                "a "
                                "sliding "
                                "window\n"
                                "and "
                                "evaluates "
                                "in "
                                "real "
                                "time. "
                                "For "
                                "third "
                                "party "
                                "detection "
                                "method, "
                                "this "
                                "field "
                                "is "
                                "not "
                                "used.",
                                "enum": [
                                    0,
                                    60,
                                    300,
                                    600,
                                    900,
                                    1800,
                                    3600,
                                    7200,
                                    10800,
                                    21600,
                                    43200,
                                    86400,
                                ],
                                "format": "int32",
                                "type": "integer",
                                "x-enum-varnames": [
                                    "ZERO_MINUTES",
                                    "ONE_MINUTE",
                                    "FIVE_MINUTES",
                                    "TEN_MINUTES",
                                    "FIFTEEN_MINUTES",
                                    "THIRTY_MINUTES",
                                    "ONE_HOUR",
                                    "TWO_HOURS",
                                    "THREE_HOURS",
                                    "SIX_HOURS",
                                    "TWELVE_HOURS",
                                    "ONE_DAY",
                                ],
                            },
                            "hardcodedEvaluatorType": {
                                "description": "Hardcoded evaluator type.",
                                "enum": ["log4shell"],
                                "type": "string",
                                "x-enum-varnames": ["LOG4SHELL"],
                            },
                            "impossibleTravelOptions": {
                                "description": "Options on impossible travel detection method.",
                                "properties": {
                                    "baselineUserLocations": {
                                        "description": "If "
                                        "true, "
                                        "signals "
                                        "are "
                                        "suppressed "
                                        "for "
                                        "the "
                                        "first "
                                        "24 "
                                        "hours. "
                                        "In "
                                        "that "
                                        "time, "
                                        "Datadog "
                                        "learns "
                                        "the "
                                        "user's "
                                        "regular\n"
                                        "access "
                                        "locations. "
                                        "This "
                                        "can "
                                        "be "
                                        "helpful "
                                        "to "
                                        "reduce "
                                        "noise "
                                        "and "
                                        "infer "
                                        "VPN "
                                        "usage "
                                        "or "
                                        "credentialed "
                                        "API "
                                        "access.",
                                        "example": True,
                                        "type": "boolean",
                                    }
                                },
                                "type": "object",
                            },
                            "keepAlive": {
                                "description": "Once "
                                "a "
                                "signal "
                                "is "
                                "generated, "
                                "the "
                                "signal "
                                "will "
                                "remain "
                                '"open" '
                                "if "
                                "a "
                                "case "
                                "is "
                                "matched "
                                "at "
                                "least "
                                "once "
                                "within\n"
                                "this "
                                "keep "
                                "alive "
                                "window. "
                                "For "
                                "third "
                                "party "
                                "detection "
                                "method, "
                                "this "
                                "field "
                                "is "
                                "not "
                                "used.",
                                "enum": [
                                    0,
                                    60,
                                    300,
                                    600,
                                    900,
                                    1800,
                                    3600,
                                    7200,
                                    10800,
                                    21600,
                                    43200,
                                    86400,
                                ],
                                "format": "int32",
                                "type": "integer",
                                "x-enum-varnames": [
                                    "ZERO_MINUTES",
                                    "ONE_MINUTE",
                                    "FIVE_MINUTES",
                                    "TEN_MINUTES",
                                    "FIFTEEN_MINUTES",
                                    "THIRTY_MINUTES",
                                    "ONE_HOUR",
                                    "TWO_HOURS",
                                    "THREE_HOURS",
                                    "SIX_HOURS",
                                    "TWELVE_HOURS",
                                    "ONE_DAY",
                                ],
                            },
                            "maxSignalDuration": {
                                "description": "A "
                                "signal "
                                "will "
                                '"close" '
                                "regardless "
                                "of "
                                "the "
                                "query "
                                "being "
                                "matched "
                                "once "
                                "the "
                                "time "
                                "exceeds "
                                "the "
                                "maximum "
                                "duration.\n"
                                "This "
                                "time "
                                "is "
                                "calculated "
                                "from "
                                "the "
                                "first "
                                "seen "
                                "timestamp.",
                                "enum": [
                                    0,
                                    60,
                                    300,
                                    600,
                                    900,
                                    1800,
                                    3600,
                                    7200,
                                    10800,
                                    21600,
                                    43200,
                                    86400,
                                ],
                                "format": "int32",
                                "type": "integer",
                                "x-enum-varnames": [
                                    "ZERO_MINUTES",
                                    "ONE_MINUTE",
                                    "FIVE_MINUTES",
                                    "TEN_MINUTES",
                                    "FIFTEEN_MINUTES",
                                    "THIRTY_MINUTES",
                                    "ONE_HOUR",
                                    "TWO_HOURS",
                                    "THREE_HOURS",
                                    "SIX_HOURS",
                                    "TWELVE_HOURS",
                                    "ONE_DAY",
                                ],
                            },
                            "newValueOptions": {
                                "description": "Options on new value detection method.",
                                "properties": {
                                    "forgetAfter": {
                                        "description": "The "
                                        "duration "
                                        "in "
                                        "days "
                                        "after "
                                        "which "
                                        "a "
                                        "learned "
                                        "value "
                                        "is "
                                        "forgotten.",
                                        "enum": [1, 2, 7, 14, 21, 28],
                                        "format": "int32",
                                        "type": "integer",
                                        "x-enum-varnames": [
                                            "ONE_DAY",
                                            "TWO_DAYS",
                                            "ONE_WEEK",
                                            "TWO_WEEKS",
                                            "THREE_WEEKS",
                                            "FOUR_WEEKS",
                                        ],
                                    },
                                    "learningDuration": {
                                        "default": 0,
                                        "description": "The "
                                        "duration "
                                        "in "
                                        "days "
                                        "during "
                                        "which "
                                        "values "
                                        "are "
                                        "learned, "
                                        "and "
                                        "after "
                                        "which "
                                        "signals "
                                        "will "
                                        "be "
                                        "generated "
                                        "for "
                                        "values "
                                        "that\n"
                                        "weren't "
                                        "learned. "
                                        "If "
                                        "set "
                                        "to "
                                        "0, "
                                        "a "
                                        "signal "
                                        "will "
                                        "be "
                                        "generated "
                                        "for "
                                        "all "
                                        "new "
                                        "values "
                                        "after "
                                        "the "
                                        "first "
                                        "value "
                                        "is "
                                        "learned.",
                                        "enum": [0, 1, 7],
                                        "format": "int32",
                                        "type": "integer",
                                        "x-enum-varnames": ["ZERO_DAYS", "ONE_DAY", "SEVEN_DAYS"],
                                    },
                                    "learningMethod": {
                                        "default": "duration",
                                        "description": "The "
                                        "learning "
                                        "method "
                                        "used "
                                        "to "
                                        "determine "
                                        "when "
                                        "signals "
                                        "should "
                                        "be "
                                        "generated "
                                        "for "
                                        "values "
                                        "that "
                                        "weren't "
                                        "learned.",
                                        "enum": ["duration", "threshold"],
                                        "type": "string",
                                        "x-enum-varnames": ["DURATION", "THRESHOLD"],
                                    },
                                    "learningThreshold": {
                                        "default": 0,
                                        "description": "A "
                                        "number "
                                        "of "
                                        "occurrences "
                                        "after "
                                        "which "
                                        "signals "
                                        "will "
                                        "be "
                                        "generated "
                                        "for "
                                        "values "
                                        "that "
                                        "weren't "
                                        "learned.",
                                        "enum": [0, 1],
                                        "format": "int32",
                                        "type": "integer",
                                        "x-enum-varnames": ["ZERO_OCCURRENCES", "ONE_OCCURRENCE"],
                                    },
                                },
                                "type": "object",
                            },
                            "sequenceDetectionOptions": {
                                "description": "Options on sequence detection method.",
                                "properties": {
                                    "stepTransitions": {
                                        "description": "Transitions "
                                        "defining "
                                        "the "
                                        "allowed "
                                        "order "
                                        "of "
                                        "steps "
                                        "and "
                                        "their "
                                        "evaluation "
                                        "windows.",
                                        "items": {
                                            "description": "Transition "
                                            "from "
                                            "a "
                                            "parent "
                                            "step "
                                            "to "
                                            "a "
                                            "child "
                                            "step "
                                            "within "
                                            "a "
                                            "sequence "
                                            "detection "
                                            "rule.",
                                            "properties": {
                                                "child": {
                                                    "description": "Name of the child step.",
                                                    "type": "string",
                                                },
                                                "evaluationWindow": {
                                                    "description": "A "
                                                    "time "
                                                    "window "
                                                    "is "
                                                    "specified "
                                                    "to "
                                                    "match "
                                                    "when "
                                                    "at "
                                                    "least "
                                                    "one "
                                                    "of "
                                                    "the "
                                                    "cases "
                                                    "matches "
                                                    "true. "
                                                    "This "
                                                    "is "
                                                    "a "
                                                    "sliding "
                                                    "window\n"
                                                    "and "
                                                    "evaluates "
                                                    "in "
                                                    "real "
                                                    "time. "
                                                    "For "
                                                    "third "
                                                    "party "
                                                    "detection "
                                                    "method, "
                                                    "this "
                                                    "field "
                                                    "is "
                                                    "not "
                                                    "used.",
                                                    "enum": [
                                                        0,
                                                        60,
                                                        300,
                                                        600,
                                                        900,
                                                        1800,
                                                        3600,
                                                        7200,
                                                        10800,
                                                        21600,
                                                        43200,
                                                        86400,
                                                    ],
                                                    "format": "int32",
                                                    "type": "integer",
                                                    "x-enum-varnames": [
                                                        "ZERO_MINUTES",
                                                        "ONE_MINUTE",
                                                        "FIVE_MINUTES",
                                                        "TEN_MINUTES",
                                                        "FIFTEEN_MINUTES",
                                                        "THIRTY_MINUTES",
                                                        "ONE_HOUR",
                                                        "TWO_HOURS",
                                                        "THREE_HOURS",
                                                        "SIX_HOURS",
                                                        "TWELVE_HOURS",
                                                        "ONE_DAY",
                                                    ],
                                                },
                                                "parent": {
                                                    "description": "Name of the parent step.",
                                                    "type": "string",
                                                },
                                            },
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "steps": {
                                        "description": "Steps "
                                        "that "
                                        "define "
                                        "the "
                                        "conditions "
                                        "to "
                                        "be "
                                        "matched "
                                        "in "
                                        "sequence.",
                                        "items": {
                                            "description": "Step "
                                            "definition "
                                            "for "
                                            "sequence "
                                            "detection "
                                            "containing "
                                            "the "
                                            "step "
                                            "name, "
                                            "condition, "
                                            "and "
                                            "evaluation "
                                            "window.",
                                            "properties": {
                                                "condition": {
                                                    "description": "Condition "
                                                    "referencing "
                                                    "rule "
                                                    "queries "
                                                    "(e.g., "
                                                    "`a "
                                                    "> "
                                                    "0`).",
                                                    "type": "string",
                                                },
                                                "evaluationWindow": {
                                                    "description": "A "
                                                    "time "
                                                    "window "
                                                    "is "
                                                    "specified "
                                                    "to "
                                                    "match "
                                                    "when "
                                                    "at "
                                                    "least "
                                                    "one "
                                                    "of "
                                                    "the "
                                                    "cases "
                                                    "matches "
                                                    "true. "
                                                    "This "
                                                    "is "
                                                    "a "
                                                    "sliding "
                                                    "window\n"
                                                    "and "
                                                    "evaluates "
                                                    "in "
                                                    "real "
                                                    "time. "
                                                    "For "
                                                    "third "
                                                    "party "
                                                    "detection "
                                                    "method, "
                                                    "this "
                                                    "field "
                                                    "is "
                                                    "not "
                                                    "used.",
                                                    "enum": [
                                                        0,
                                                        60,
                                                        300,
                                                        600,
                                                        900,
                                                        1800,
                                                        3600,
                                                        7200,
                                                        10800,
                                                        21600,
                                                        43200,
                                                        86400,
                                                    ],
                                                    "format": "int32",
                                                    "type": "integer",
                                                    "x-enum-varnames": [
                                                        "ZERO_MINUTES",
                                                        "ONE_MINUTE",
                                                        "FIVE_MINUTES",
                                                        "TEN_MINUTES",
                                                        "FIFTEEN_MINUTES",
                                                        "THIRTY_MINUTES",
                                                        "ONE_HOUR",
                                                        "TWO_HOURS",
                                                        "THREE_HOURS",
                                                        "SIX_HOURS",
                                                        "TWELVE_HOURS",
                                                        "ONE_DAY",
                                                    ],
                                                },
                                                "name": {
                                                    "description": "Unique "
                                                    "name "
                                                    "identifying "
                                                    "the "
                                                    "step.",
                                                    "type": "string",
                                                },
                                            },
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                },
                                "type": "object",
                            },
                            "thirdPartyRuleOptions": {
                                "description": "Options on third party detection method.",
                                "properties": {
                                    "defaultNotifications": {
                                        "description": "Notification "
                                        "targets "
                                        "for "
                                        "the "
                                        "logs "
                                        "that "
                                        "do "
                                        "not "
                                        "correspond "
                                        "to "
                                        "any "
                                        "of "
                                        "the "
                                        "cases.",
                                        "items": {"description": "Notification.", "type": "string"},
                                        "type": "array",
                                    },
                                    "defaultStatus": {
                                        "description": "Severity of the Security Signal.",
                                        "enum": ["info", "low", "medium", "high", "critical"],
                                        "example": "critical",
                                        "type": "string",
                                        "x-enum-varnames": [
                                            "INFO",
                                            "LOW",
                                            "MEDIUM",
                                            "HIGH",
                                            "CRITICAL",
                                        ],
                                    },
                                    "rootQueries": {
                                        "description": "Queries "
                                        "to "
                                        "be "
                                        "combined "
                                        "with "
                                        "third "
                                        "party "
                                        "case "
                                        "queries. "
                                        "Each "
                                        "of "
                                        "them "
                                        "can "
                                        "have "
                                        "different "
                                        "group "
                                        "by "
                                        "fields, "
                                        "to "
                                        "aggregate "
                                        "differently "
                                        "based "
                                        "on "
                                        "the "
                                        "type "
                                        "of "
                                        "alert.",
                                        "items": {
                                            "description": "A "
                                            "query "
                                            "to "
                                            "be "
                                            "combined "
                                            "with "
                                            "the "
                                            "third "
                                            "party "
                                            "case "
                                            "query.",
                                            "properties": {
                                                "groupByFields": {
                                                    "description": "Fields to group by.",
                                                    "items": {
                                                        "description": "Field.",
                                                        "type": "string",
                                                    },
                                                    "type": "array",
                                                },
                                                "query": {
                                                    "description": "Query to run on logs.",
                                                    "example": "source:cloudtrail",
                                                    "type": "string",
                                                },
                                            },
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "signalTitleTemplate": {
                                        "description": "A "
                                        "template "
                                        "for "
                                        "the "
                                        "signal "
                                        "title; "
                                        "if "
                                        "omitted, "
                                        "the "
                                        "title "
                                        "is "
                                        "generated "
                                        "based "
                                        "on "
                                        "the "
                                        "case "
                                        "name.",
                                        "type": "string",
                                    },
                                },
                                "type": "object",
                            },
                        },
                        "type": "object",
                    },
                    "queries": {
                        "description": "Queries for selecting logs which are part of the rule.",
                        "example": [],
                        "items": {
                            "description": "Query for matching rule.",
                            "properties": {
                                "aggregation": {
                                    "description": "The aggregation type.",
                                    "enum": [
                                        "count",
                                        "cardinality",
                                        "sum",
                                        "max",
                                        "new_value",
                                        "geo_data",
                                        "event_count",
                                        "none",
                                    ],
                                    "type": "string",
                                    "x-enum-varnames": [
                                        "COUNT",
                                        "CARDINALITY",
                                        "SUM",
                                        "MAX",
                                        "NEW_VALUE",
                                        "GEO_DATA",
                                        "EVENT_COUNT",
                                        "NONE",
                                    ],
                                },
                                "customQueryExtension": {
                                    "description": "Query extension to append to the logs query.",
                                    "example": "a > 3",
                                    "type": "string",
                                },
                                "dataSource": {
                                    "default": "logs",
                                    "description": "Source "
                                    "of "
                                    "events, "
                                    "either "
                                    "logs, "
                                    "audit "
                                    "trail, "
                                    "or "
                                    "Datadog "
                                    "events.",
                                    "enum": [
                                        "logs",
                                        "audit",
                                        "app_sec_spans",
                                        "spans",
                                        "security_runtime",
                                        "network",
                                        "events",
                                    ],
                                    "example": "logs",
                                    "type": "string",
                                    "x-enum-varnames": [
                                        "LOGS",
                                        "AUDIT",
                                        "APP_SEC_SPANS",
                                        "SPANS",
                                        "SECURITY_RUNTIME",
                                        "NETWORK",
                                        "EVENTS",
                                    ],
                                },
                                "distinctFields": {
                                    "description": "Field "
                                    "for "
                                    "which "
                                    "the "
                                    "cardinality "
                                    "is "
                                    "measured. "
                                    "Sent "
                                    "as "
                                    "an "
                                    "array.",
                                    "items": {"description": "Field.", "type": "string"},
                                    "type": "array",
                                },
                                "groupByFields": {
                                    "description": "Fields to group by.",
                                    "items": {"description": "Field.", "type": "string"},
                                    "type": "array",
                                },
                                "hasOptionalGroupByFields": {
                                    "default": False,
                                    "description": "When "
                                    "false, "
                                    "events "
                                    "without "
                                    "a "
                                    "group-by "
                                    "value "
                                    "are "
                                    "ignored "
                                    "by "
                                    "the "
                                    "rule. "
                                    "When "
                                    "true, "
                                    "events "
                                    "with "
                                    "missing "
                                    "group-by "
                                    "fields "
                                    "are "
                                    "processed "
                                    "with "
                                    "`N/A`, "
                                    "replacing "
                                    "the "
                                    "missing "
                                    "values.",
                                    "example": False,
                                    "type": "boolean",
                                },
                                "index": {
                                    "description": "**This "
                                    "field "
                                    "is "
                                    "currently "
                                    "unstable "
                                    "and "
                                    "might "
                                    "be "
                                    "removed "
                                    "in "
                                    "a "
                                    "minor "
                                    "version "
                                    "upgrade.**\n"
                                    "The "
                                    "index "
                                    "to "
                                    "run "
                                    "the "
                                    "query "
                                    "on, "
                                    "if "
                                    "the "
                                    "`dataSource` "
                                    "is "
                                    "`logs`. "
                                    "Only "
                                    "used "
                                    "for "
                                    "scheduled "
                                    "rules "
                                    "- "
                                    "in "
                                    "other "
                                    "words, "
                                    "when "
                                    "the "
                                    "`schedulingOptions` "
                                    "field "
                                    "is "
                                    "present "
                                    "in "
                                    "the "
                                    "rule "
                                    "payload.",
                                    "type": "string",
                                },
                                "indexes": {
                                    "description": "List "
                                    "of "
                                    "indexes "
                                    "to "
                                    "query "
                                    "when "
                                    "the "
                                    "`dataSource` "
                                    "is "
                                    "`logs`. "
                                    "Only "
                                    "used "
                                    "for "
                                    "scheduled "
                                    "rules, "
                                    "such "
                                    "as "
                                    "when "
                                    "the "
                                    "`schedulingOptions` "
                                    "field "
                                    "is "
                                    "present "
                                    "in "
                                    "the "
                                    "rule "
                                    "payload.",
                                    "items": {"description": "Index.", "type": "string"},
                                    "type": "array",
                                },
                                "metric": {
                                    "deprecated": True,
                                    "description": "(Deprecated) "
                                    "The "
                                    "target "
                                    "field "
                                    "to "
                                    "aggregate "
                                    "over "
                                    "when "
                                    "using "
                                    "the "
                                    "sum "
                                    "or "
                                    "max\n"
                                    "aggregations. "
                                    "`metrics` "
                                    "field "
                                    "should "
                                    "be "
                                    "used "
                                    "instead.",
                                    "type": "string",
                                },
                                "metrics": {
                                    "description": "Group "
                                    "of "
                                    "target "
                                    "fields "
                                    "to "
                                    "aggregate "
                                    "over "
                                    "when "
                                    "using "
                                    "the "
                                    "sum, "
                                    "max, "
                                    "geo "
                                    "data, "
                                    "or "
                                    "new "
                                    "value "
                                    "aggregations. "
                                    "The "
                                    "sum, "
                                    "max, "
                                    "and "
                                    "geo "
                                    "data "
                                    "aggregations "
                                    "only "
                                    "accept "
                                    "one "
                                    "value "
                                    "in "
                                    "this "
                                    "list, "
                                    "whereas "
                                    "the "
                                    "new "
                                    "value "
                                    "aggregation "
                                    "accepts "
                                    "up "
                                    "to "
                                    "five "
                                    "values.",
                                    "items": {"description": "Field.", "type": "string"},
                                    "type": "array",
                                },
                                "name": {"description": "Name of the query.", "type": "string"},
                                "query": {
                                    "description": "Query to run on logs.",
                                    "example": "a > 3",
                                    "type": "string",
                                },
                            },
                            "type": "object",
                        },
                        "type": "array",
                    },
                    "referenceTables": {
                        "description": "Reference tables for the rule.",
                        "items": {
                            "description": "Reference tables used in the queries.",
                            "properties": {
                                "checkPresence": {
                                    "description": "Whether "
                                    "to "
                                    "include "
                                    "or "
                                    "exclude "
                                    "the "
                                    "matched "
                                    "values.",
                                    "type": "boolean",
                                },
                                "columnName": {
                                    "description": "The name of the column in the reference table.",
                                    "type": "string",
                                },
                                "logFieldPath": {
                                    "description": "The "
                                    "field "
                                    "in "
                                    "the "
                                    "log "
                                    "to "
                                    "match "
                                    "against "
                                    "the "
                                    "reference "
                                    "table.",
                                    "type": "string",
                                },
                                "ruleQueryName": {
                                    "description": "The "
                                    "name "
                                    "of "
                                    "the "
                                    "query "
                                    "to "
                                    "apply "
                                    "the "
                                    "reference "
                                    "table "
                                    "to.",
                                    "type": "string",
                                },
                                "tableName": {
                                    "description": "The name of the reference table.",
                                    "type": "string",
                                },
                            },
                            "type": "object",
                        },
                        "type": "array",
                    },
                    "schedulingOptions": {
                        "description": "Options for scheduled "
                        "rules. When this "
                        "field is present, the "
                        "rule runs based on "
                        "the schedule. When "
                        "absent, it runs "
                        "real-time on ingested "
                        "logs.",
                        "nullable": True,
                        "properties": {
                            "rrule": {
                                "description": "Schedule "
                                "for "
                                "the "
                                "rule "
                                "queries, "
                                "written "
                                "in "
                                "RRULE "
                                "syntax. "
                                "See "
                                "[RFC](https://icalendar.org/iCalendar-RFC-5545/3-8-5-3-recurrence-rule.html) "
                                "for "
                                "syntax "
                                "reference.",
                                "example": "FREQ=HOURLY;INTERVAL=1;",
                                "type": "string",
                            },
                            "start": {
                                "description": "Start "
                                "date "
                                "for "
                                "the "
                                "schedule, "
                                "in "
                                "ISO "
                                "8601 "
                                "format "
                                "without "
                                "timezone.",
                                "example": "2025-07-14T12:00:00",
                                "type": "string",
                            },
                            "timezone": {
                                "description": "Time "
                                "zone "
                                "of "
                                "the "
                                "start "
                                "date, "
                                "in "
                                "the "
                                "[tz "
                                "database](https://en.wikipedia.org/wiki/List_of_tz_database_time_zones) "
                                "format.",
                                "example": "America/New_York",
                                "type": "string",
                            },
                        },
                        "type": "object",
                    },
                    "tags": {
                        "description": "Tags for generated signals.",
                        "example": ["env:prod", "team:security"],
                        "items": {"description": "Tag.", "type": "string"},
                        "type": "array",
                    },
                    "thirdPartyCases": {
                        "description": "Cases for generating "
                        "signals from "
                        "third-party rules. Only "
                        "available for "
                        "third-party rules.",
                        "example": [],
                        "items": {
                            "description": "Case when a signal is generated by a third party rule.",
                            "properties": {
                                "name": {"description": "Name of the case.", "type": "string"},
                                "notifications": {
                                    "description": "Notification targets for each case.",
                                    "items": {"description": "Notification.", "type": "string"},
                                    "type": "array",
                                },
                                "query": {
                                    "description": "A "
                                    "query "
                                    "to "
                                    "map "
                                    "a "
                                    "third "
                                    "party "
                                    "event "
                                    "to "
                                    "this "
                                    "case.",
                                    "type": "string",
                                },
                                "status": {
                                    "description": "Severity of the Security Signal.",
                                    "enum": ["info", "low", "medium", "high", "critical"],
                                    "example": "critical",
                                    "type": "string",
                                    "x-enum-varnames": [
                                        "INFO",
                                        "LOW",
                                        "MEDIUM",
                                        "HIGH",
                                        "CRITICAL",
                                    ],
                                },
                            },
                            "required": ["status"],
                            "type": "object",
                        },
                        "type": "array",
                    },
                    "type": {
                        "description": "The rule type.",
                        "enum": [
                            "api_security",
                            "application_security",
                            "log_detection",
                            "workload_security",
                        ],
                        "type": "string",
                        "x-enum-varnames": [
                            "API_SECURITY",
                            "APPLICATION_SECURITY",
                            "LOG_DETECTION",
                            "WORKLOAD_SECURITY",
                        ],
                    },
                },
                "required": ["name", "isEnabled", "queries", "options", "cases", "message"],
                "type": "object",
            },
            {
                "description": "The payload of a signal correlation rule.",
                "properties": {
                    "cases": {
                        "description": "Cases for generating signals.",
                        "example": [],
                        "items": {
                            "description": "Case when signal is generated.",
                            "properties": {
                                "actions": {
                                    "description": "Action to perform for each rule case.",
                                    "items": {
                                        "description": "Action "
                                        "to "
                                        "perform "
                                        "when "
                                        "a "
                                        "signal "
                                        "is "
                                        "triggered. "
                                        "Only "
                                        "available "
                                        "for "
                                        "Application "
                                        "Security "
                                        "rule "
                                        "type.",
                                        "properties": {
                                            "options": {
                                                "additionalProperties": {},
                                                "description": "Options for the rule action",
                                                "properties": {
                                                    "duration": {
                                                        "description": "Duration "
                                                        "of "
                                                        "the "
                                                        "action "
                                                        "in "
                                                        "seconds. "
                                                        "0 "
                                                        "indicates "
                                                        "no "
                                                        "expiration.",
                                                        "example": 0,
                                                        "format": "int64",
                                                        "minimum": 0,
                                                        "type": "integer",
                                                    },
                                                    "flaggedIPType": {
                                                        "description": "Used "
                                                        "with "
                                                        "the "
                                                        "case "
                                                        "action "
                                                        "of "
                                                        "type "
                                                        "'flag_ip'. "
                                                        "The "
                                                        "value "
                                                        "specified "
                                                        "in "
                                                        "this "
                                                        "field "
                                                        "is "
                                                        "applied "
                                                        "as "
                                                        "a "
                                                        "flag "
                                                        "to "
                                                        "the "
                                                        "IP "
                                                        "addresses.",
                                                        "enum": ["SUSPICIOUS", "FLAGGED"],
                                                        "example": "FLAGGED",
                                                        "type": "string",
                                                        "x-enum-varnames": [
                                                            "SUSPICIOUS",
                                                            "FLAGGED",
                                                        ],
                                                    },
                                                    "userBehaviorName": {
                                                        "description": "Used "
                                                        "with "
                                                        "the "
                                                        "case "
                                                        "action "
                                                        "of "
                                                        "type "
                                                        "'user_behavior'. "
                                                        "The "
                                                        "value "
                                                        "specified "
                                                        "in "
                                                        "this "
                                                        "field "
                                                        "is "
                                                        "applied "
                                                        "as "
                                                        "a "
                                                        "risk "
                                                        "tag "
                                                        "to "
                                                        "all "
                                                        "users "
                                                        "affected "
                                                        "by "
                                                        "the "
                                                        "rule.",
                                                        "type": "string",
                                                    },
                                                },
                                                "type": "object",
                                            },
                                            "type": {
                                                "description": "The action type.",
                                                "enum": [
                                                    "block_ip",
                                                    "block_user",
                                                    "user_behavior",
                                                    "flag_ip",
                                                ],
                                                "type": "string",
                                                "x-enum-varnames": [
                                                    "BLOCK_IP",
                                                    "BLOCK_USER",
                                                    "USER_BEHAVIOR",
                                                    "FLAG_IP",
                                                ],
                                            },
                                        },
                                        "type": "object",
                                    },
                                    "type": "array",
                                },
                                "condition": {
                                    "description": "A "
                                    "case "
                                    "contains "
                                    "logical "
                                    "operations "
                                    "(`>`,`>=`, "
                                    "`&&`, "
                                    "`||`) "
                                    "to "
                                    "determine "
                                    "if "
                                    "a "
                                    "signal "
                                    "should "
                                    "be "
                                    "generated\n"
                                    "based "
                                    "on "
                                    "the "
                                    "event "
                                    "counts "
                                    "in "
                                    "the "
                                    "previously "
                                    "defined "
                                    "queries.",
                                    "type": "string",
                                },
                                "name": {"description": "Name of the case.", "type": "string"},
                                "notifications": {
                                    "description": "Notification targets.",
                                    "items": {"description": "Notification.", "type": "string"},
                                    "type": "array",
                                },
                                "status": {
                                    "description": "Severity of the Security Signal.",
                                    "enum": ["info", "low", "medium", "high", "critical"],
                                    "example": "critical",
                                    "type": "string",
                                    "x-enum-varnames": [
                                        "INFO",
                                        "LOW",
                                        "MEDIUM",
                                        "HIGH",
                                        "CRITICAL",
                                    ],
                                },
                            },
                            "required": ["status"],
                            "type": "object",
                        },
                        "type": "array",
                    },
                    "customMessage": {
                        "description": "Custom/Overridden message "
                        "for generated signals "
                        "(used in case of Default "
                        "rule update).",
                        "type": "string",
                    },
                    "customName": {
                        "description": "Custom/Overridden name of "
                        "the rule (used in case of "
                        "Default rule update).",
                        "type": "string",
                    },
                    "filters": {
                        "description": "Additional queries to filter "
                        "matched events before they are "
                        "processed. This field is "
                        "deprecated for log detection, "
                        "signal correlation, and "
                        "workload security rules.",
                        "items": {
                            "description": "The rule's suppression filter.",
                            "properties": {
                                "action": {
                                    "description": "The type of filtering action.",
                                    "enum": ["require", "suppress"],
                                    "type": "string",
                                    "x-enum-varnames": ["REQUIRE", "SUPPRESS"],
                                },
                                "query": {
                                    "description": "Query "
                                    "for "
                                    "selecting "
                                    "logs "
                                    "to "
                                    "apply "
                                    "the "
                                    "filtering "
                                    "action.",
                                    "type": "string",
                                },
                            },
                            "type": "object",
                        },
                        "type": "array",
                    },
                    "hasExtendedTitle": {
                        "description": "Whether the "
                        "notifications include "
                        "the triggering "
                        "group-by values in "
                        "their title.",
                        "example": True,
                        "type": "boolean",
                    },
                    "isEnabled": {
                        "description": "Whether the rule is enabled.",
                        "example": True,
                        "type": "boolean",
                    },
                    "message": {
                        "description": "Message for generated signals.",
                        "example": "",
                        "type": "string",
                    },
                    "name": {
                        "description": "The name of the rule.",
                        "example": "My security monitoring rule.",
                        "type": "string",
                    },
                    "options": {
                        "description": "Options.",
                        "properties": {
                            "complianceRuleOptions": {
                                "additionalProperties": {},
                                "description": "Options "
                                "for "
                                "cloud_configuration "
                                "rules.\n"
                                "Fields "
                                "`resourceType` "
                                "and "
                                "`regoRule` "
                                "are "
                                "mandatory "
                                "when "
                                "managing "
                                "custom "
                                "`cloud_configuration` "
                                "rules.",
                                "properties": {
                                    "complexRule": {
                                        "description": "Whether "
                                        "the "
                                        "rule "
                                        "is "
                                        "a "
                                        "complex "
                                        "one.\n"
                                        "Must "
                                        "be "
                                        "set "
                                        "to "
                                        "true "
                                        "if "
                                        "`regoRule.resourceTypes` "
                                        "contains "
                                        "more "
                                        "than "
                                        "one "
                                        "item. "
                                        "Defaults "
                                        "to "
                                        "false.",
                                        "type": "boolean",
                                    },
                                    "regoRule": {
                                        "description": "Rule details.",
                                        "properties": {
                                            "policy": {
                                                "description": "The "
                                                "policy "
                                                "written "
                                                "in "
                                                "`rego`, "
                                                "see: "
                                                "https://www.openpolicyagent.org/docs/latest/policy-language/",
                                                "example": "package "
                                                "datadog\n"
                                                "\n"
                                                "import "
                                                "data.datadog.output "
                                                "as "
                                                "dd_output\n"
                                                "import "
                                                "future.keywords.contains\n"
                                                "import "
                                                "future.keywords.if\n"
                                                "import "
                                                "future.keywords.in\n"
                                                "\n"
                                                "eval(resource) "
                                                "= "
                                                '"skip" '
                                                "if "
                                                "{\n"
                                                "  "
                                                "# "
                                                "Logic "
                                                "that "
                                                "evaluates "
                                                "to "
                                                "true "
                                                "if "
                                                "the "
                                                "resource "
                                                "should "
                                                "be "
                                                "skipped\n"
                                                "  "
                                                "true\n"
                                                "} "
                                                "else "
                                                "= "
                                                '"pass" '
                                                "{\n"
                                                "  "
                                                "# "
                                                "Logic "
                                                "that "
                                                "evaluates "
                                                "to "
                                                "true "
                                                "if "
                                                "the "
                                                "resource "
                                                "is "
                                                "compliant\n"
                                                "  "
                                                "true\n"
                                                "} "
                                                "else "
                                                "= "
                                                '"fail" '
                                                "{\n"
                                                "  "
                                                "# "
                                                "Logic "
                                                "that "
                                                "evaluates "
                                                "to "
                                                "true "
                                                "if "
                                                "the "
                                                "resource "
                                                "is "
                                                "not "
                                                "compliant\n"
                                                "  "
                                                "true\n"
                                                "}\n"
                                                "\n"
                                                "# "
                                                "This "
                                                "part "
                                                "remains "
                                                "unchanged "
                                                "for "
                                                "all "
                                                "rules\n"
                                                "results "
                                                "contains "
                                                "result "
                                                "if "
                                                "{\n"
                                                "  "
                                                "some "
                                                "resource "
                                                "in "
                                                "input.resources[input.main_resource_type]\n"
                                                "  "
                                                "result "
                                                ":= "
                                                "dd_output.format(resource, "
                                                "eval(resource))\n"
                                                "}",
                                                "type": "string",
                                            },
                                            "resourceTypes": {
                                                "description": "List "
                                                "of "
                                                "resource "
                                                "types "
                                                "that "
                                                "will "
                                                "be "
                                                "evaluated "
                                                "upon. "
                                                "Must "
                                                "have "
                                                "at "
                                                "least "
                                                "one "
                                                "element.",
                                                "example": [
                                                    "gcp_iam_service_account",
                                                    "gcp_iam_policy",
                                                ],
                                                "items": {"type": "string"},
                                                "type": "array",
                                            },
                                        },
                                        "required": ["policy", "resourceTypes"],
                                        "type": "object",
                                    },
                                    "resourceType": {
                                        "description": "Main "
                                        "resource "
                                        "type "
                                        "to "
                                        "be "
                                        "checked "
                                        "by "
                                        "the "
                                        "rule. "
                                        "It "
                                        "should "
                                        "be "
                                        "specified "
                                        "again "
                                        "in "
                                        "`regoRule.resourceTypes`.",
                                        "example": "aws_acm",
                                        "type": "string",
                                    },
                                },
                                "type": "object",
                            },
                            "decreaseCriticalityBasedOnEnv": {
                                "description": "If "
                                "true, "
                                "signals "
                                "in "
                                "non-production "
                                "environments "
                                "have "
                                "a "
                                "lower "
                                "severity "
                                "than "
                                "what "
                                "is "
                                "defined "
                                "by "
                                "the "
                                "rule "
                                "case, "
                                "which "
                                "can "
                                "reduce "
                                "signal "
                                "noise.\n"
                                "The "
                                "severity "
                                "is "
                                "decreased "
                                "by "
                                "one "
                                "level: "
                                "`CRITICAL` "
                                "in "
                                "production "
                                "becomes "
                                "`HIGH` "
                                "in "
                                "non-production, "
                                "`HIGH` "
                                "becomes "
                                "`MEDIUM` "
                                "and "
                                "so "
                                "on. "
                                "`INFO` "
                                "remains "
                                "`INFO`.\n"
                                "The "
                                "decrement "
                                "is "
                                "applied "
                                "when "
                                "the "
                                "environment "
                                "tag "
                                "of "
                                "the "
                                "signal "
                                "starts "
                                "with "
                                "`staging`, "
                                "`test` "
                                "or "
                                "`dev`.",
                                "example": False,
                                "type": "boolean",
                            },
                            "detectionMethod": {
                                "description": "The detection method.",
                                "enum": [
                                    "threshold",
                                    "new_value",
                                    "anomaly_detection",
                                    "impossible_travel",
                                    "hardcoded",
                                    "third_party",
                                    "anomaly_threshold",
                                    "sequence_detection",
                                ],
                                "type": "string",
                                "x-enum-varnames": [
                                    "THRESHOLD",
                                    "NEW_VALUE",
                                    "ANOMALY_DETECTION",
                                    "IMPOSSIBLE_TRAVEL",
                                    "HARDCODED",
                                    "THIRD_PARTY",
                                    "ANOMALY_THRESHOLD",
                                    "SEQUENCE_DETECTION",
                                ],
                            },
                            "evaluationWindow": {
                                "description": "A "
                                "time "
                                "window "
                                "is "
                                "specified "
                                "to "
                                "match "
                                "when "
                                "at "
                                "least "
                                "one "
                                "of "
                                "the "
                                "cases "
                                "matches "
                                "true. "
                                "This "
                                "is "
                                "a "
                                "sliding "
                                "window\n"
                                "and "
                                "evaluates "
                                "in "
                                "real "
                                "time. "
                                "For "
                                "third "
                                "party "
                                "detection "
                                "method, "
                                "this "
                                "field "
                                "is "
                                "not "
                                "used.",
                                "enum": [
                                    0,
                                    60,
                                    300,
                                    600,
                                    900,
                                    1800,
                                    3600,
                                    7200,
                                    10800,
                                    21600,
                                    43200,
                                    86400,
                                ],
                                "format": "int32",
                                "type": "integer",
                                "x-enum-varnames": [
                                    "ZERO_MINUTES",
                                    "ONE_MINUTE",
                                    "FIVE_MINUTES",
                                    "TEN_MINUTES",
                                    "FIFTEEN_MINUTES",
                                    "THIRTY_MINUTES",
                                    "ONE_HOUR",
                                    "TWO_HOURS",
                                    "THREE_HOURS",
                                    "SIX_HOURS",
                                    "TWELVE_HOURS",
                                    "ONE_DAY",
                                ],
                            },
                            "hardcodedEvaluatorType": {
                                "description": "Hardcoded evaluator type.",
                                "enum": ["log4shell"],
                                "type": "string",
                                "x-enum-varnames": ["LOG4SHELL"],
                            },
                            "impossibleTravelOptions": {
                                "description": "Options on impossible travel detection method.",
                                "properties": {
                                    "baselineUserLocations": {
                                        "description": "If "
                                        "true, "
                                        "signals "
                                        "are "
                                        "suppressed "
                                        "for "
                                        "the "
                                        "first "
                                        "24 "
                                        "hours. "
                                        "In "
                                        "that "
                                        "time, "
                                        "Datadog "
                                        "learns "
                                        "the "
                                        "user's "
                                        "regular\n"
                                        "access "
                                        "locations. "
                                        "This "
                                        "can "
                                        "be "
                                        "helpful "
                                        "to "
                                        "reduce "
                                        "noise "
                                        "and "
                                        "infer "
                                        "VPN "
                                        "usage "
                                        "or "
                                        "credentialed "
                                        "API "
                                        "access.",
                                        "example": True,
                                        "type": "boolean",
                                    }
                                },
                                "type": "object",
                            },
                            "keepAlive": {
                                "description": "Once "
                                "a "
                                "signal "
                                "is "
                                "generated, "
                                "the "
                                "signal "
                                "will "
                                "remain "
                                '"open" '
                                "if "
                                "a "
                                "case "
                                "is "
                                "matched "
                                "at "
                                "least "
                                "once "
                                "within\n"
                                "this "
                                "keep "
                                "alive "
                                "window. "
                                "For "
                                "third "
                                "party "
                                "detection "
                                "method, "
                                "this "
                                "field "
                                "is "
                                "not "
                                "used.",
                                "enum": [
                                    0,
                                    60,
                                    300,
                                    600,
                                    900,
                                    1800,
                                    3600,
                                    7200,
                                    10800,
                                    21600,
                                    43200,
                                    86400,
                                ],
                                "format": "int32",
                                "type": "integer",
                                "x-enum-varnames": [
                                    "ZERO_MINUTES",
                                    "ONE_MINUTE",
                                    "FIVE_MINUTES",
                                    "TEN_MINUTES",
                                    "FIFTEEN_MINUTES",
                                    "THIRTY_MINUTES",
                                    "ONE_HOUR",
                                    "TWO_HOURS",
                                    "THREE_HOURS",
                                    "SIX_HOURS",
                                    "TWELVE_HOURS",
                                    "ONE_DAY",
                                ],
                            },
                            "maxSignalDuration": {
                                "description": "A "
                                "signal "
                                "will "
                                '"close" '
                                "regardless "
                                "of "
                                "the "
                                "query "
                                "being "
                                "matched "
                                "once "
                                "the "
                                "time "
                                "exceeds "
                                "the "
                                "maximum "
                                "duration.\n"
                                "This "
                                "time "
                                "is "
                                "calculated "
                                "from "
                                "the "
                                "first "
                                "seen "
                                "timestamp.",
                                "enum": [
                                    0,
                                    60,
                                    300,
                                    600,
                                    900,
                                    1800,
                                    3600,
                                    7200,
                                    10800,
                                    21600,
                                    43200,
                                    86400,
                                ],
                                "format": "int32",
                                "type": "integer",
                                "x-enum-varnames": [
                                    "ZERO_MINUTES",
                                    "ONE_MINUTE",
                                    "FIVE_MINUTES",
                                    "TEN_MINUTES",
                                    "FIFTEEN_MINUTES",
                                    "THIRTY_MINUTES",
                                    "ONE_HOUR",
                                    "TWO_HOURS",
                                    "THREE_HOURS",
                                    "SIX_HOURS",
                                    "TWELVE_HOURS",
                                    "ONE_DAY",
                                ],
                            },
                            "newValueOptions": {
                                "description": "Options on new value detection method.",
                                "properties": {
                                    "forgetAfter": {
                                        "description": "The "
                                        "duration "
                                        "in "
                                        "days "
                                        "after "
                                        "which "
                                        "a "
                                        "learned "
                                        "value "
                                        "is "
                                        "forgotten.",
                                        "enum": [1, 2, 7, 14, 21, 28],
                                        "format": "int32",
                                        "type": "integer",
                                        "x-enum-varnames": [
                                            "ONE_DAY",
                                            "TWO_DAYS",
                                            "ONE_WEEK",
                                            "TWO_WEEKS",
                                            "THREE_WEEKS",
                                            "FOUR_WEEKS",
                                        ],
                                    },
                                    "learningDuration": {
                                        "default": 0,
                                        "description": "The "
                                        "duration "
                                        "in "
                                        "days "
                                        "during "
                                        "which "
                                        "values "
                                        "are "
                                        "learned, "
                                        "and "
                                        "after "
                                        "which "
                                        "signals "
                                        "will "
                                        "be "
                                        "generated "
                                        "for "
                                        "values "
                                        "that\n"
                                        "weren't "
                                        "learned. "
                                        "If "
                                        "set "
                                        "to "
                                        "0, "
                                        "a "
                                        "signal "
                                        "will "
                                        "be "
                                        "generated "
                                        "for "
                                        "all "
                                        "new "
                                        "values "
                                        "after "
                                        "the "
                                        "first "
                                        "value "
                                        "is "
                                        "learned.",
                                        "enum": [0, 1, 7],
                                        "format": "int32",
                                        "type": "integer",
                                        "x-enum-varnames": ["ZERO_DAYS", "ONE_DAY", "SEVEN_DAYS"],
                                    },
                                    "learningMethod": {
                                        "default": "duration",
                                        "description": "The "
                                        "learning "
                                        "method "
                                        "used "
                                        "to "
                                        "determine "
                                        "when "
                                        "signals "
                                        "should "
                                        "be "
                                        "generated "
                                        "for "
                                        "values "
                                        "that "
                                        "weren't "
                                        "learned.",
                                        "enum": ["duration", "threshold"],
                                        "type": "string",
                                        "x-enum-varnames": ["DURATION", "THRESHOLD"],
                                    },
                                    "learningThreshold": {
                                        "default": 0,
                                        "description": "A "
                                        "number "
                                        "of "
                                        "occurrences "
                                        "after "
                                        "which "
                                        "signals "
                                        "will "
                                        "be "
                                        "generated "
                                        "for "
                                        "values "
                                        "that "
                                        "weren't "
                                        "learned.",
                                        "enum": [0, 1],
                                        "format": "int32",
                                        "type": "integer",
                                        "x-enum-varnames": ["ZERO_OCCURRENCES", "ONE_OCCURRENCE"],
                                    },
                                },
                                "type": "object",
                            },
                            "sequenceDetectionOptions": {
                                "description": "Options on sequence detection method.",
                                "properties": {
                                    "stepTransitions": {
                                        "description": "Transitions "
                                        "defining "
                                        "the "
                                        "allowed "
                                        "order "
                                        "of "
                                        "steps "
                                        "and "
                                        "their "
                                        "evaluation "
                                        "windows.",
                                        "items": {
                                            "description": "Transition "
                                            "from "
                                            "a "
                                            "parent "
                                            "step "
                                            "to "
                                            "a "
                                            "child "
                                            "step "
                                            "within "
                                            "a "
                                            "sequence "
                                            "detection "
                                            "rule.",
                                            "properties": {
                                                "child": {
                                                    "description": "Name of the child step.",
                                                    "type": "string",
                                                },
                                                "evaluationWindow": {
                                                    "description": "A "
                                                    "time "
                                                    "window "
                                                    "is "
                                                    "specified "
                                                    "to "
                                                    "match "
                                                    "when "
                                                    "at "
                                                    "least "
                                                    "one "
                                                    "of "
                                                    "the "
                                                    "cases "
                                                    "matches "
                                                    "true. "
                                                    "This "
                                                    "is "
                                                    "a "
                                                    "sliding "
                                                    "window\n"
                                                    "and "
                                                    "evaluates "
                                                    "in "
                                                    "real "
                                                    "time. "
                                                    "For "
                                                    "third "
                                                    "party "
                                                    "detection "
                                                    "method, "
                                                    "this "
                                                    "field "
                                                    "is "
                                                    "not "
                                                    "used.",
                                                    "enum": [
                                                        0,
                                                        60,
                                                        300,
                                                        600,
                                                        900,
                                                        1800,
                                                        3600,
                                                        7200,
                                                        10800,
                                                        21600,
                                                        43200,
                                                        86400,
                                                    ],
                                                    "format": "int32",
                                                    "type": "integer",
                                                    "x-enum-varnames": [
                                                        "ZERO_MINUTES",
                                                        "ONE_MINUTE",
                                                        "FIVE_MINUTES",
                                                        "TEN_MINUTES",
                                                        "FIFTEEN_MINUTES",
                                                        "THIRTY_MINUTES",
                                                        "ONE_HOUR",
                                                        "TWO_HOURS",
                                                        "THREE_HOURS",
                                                        "SIX_HOURS",
                                                        "TWELVE_HOURS",
                                                        "ONE_DAY",
                                                    ],
                                                },
                                                "parent": {
                                                    "description": "Name of the parent step.",
                                                    "type": "string",
                                                },
                                            },
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "steps": {
                                        "description": "Steps "
                                        "that "
                                        "define "
                                        "the "
                                        "conditions "
                                        "to "
                                        "be "
                                        "matched "
                                        "in "
                                        "sequence.",
                                        "items": {
                                            "description": "Step "
                                            "definition "
                                            "for "
                                            "sequence "
                                            "detection "
                                            "containing "
                                            "the "
                                            "step "
                                            "name, "
                                            "condition, "
                                            "and "
                                            "evaluation "
                                            "window.",
                                            "properties": {
                                                "condition": {
                                                    "description": "Condition "
                                                    "referencing "
                                                    "rule "
                                                    "queries "
                                                    "(e.g., "
                                                    "`a "
                                                    "> "
                                                    "0`).",
                                                    "type": "string",
                                                },
                                                "evaluationWindow": {
                                                    "description": "A "
                                                    "time "
                                                    "window "
                                                    "is "
                                                    "specified "
                                                    "to "
                                                    "match "
                                                    "when "
                                                    "at "
                                                    "least "
                                                    "one "
                                                    "of "
                                                    "the "
                                                    "cases "
                                                    "matches "
                                                    "true. "
                                                    "This "
                                                    "is "
                                                    "a "
                                                    "sliding "
                                                    "window\n"
                                                    "and "
                                                    "evaluates "
                                                    "in "
                                                    "real "
                                                    "time. "
                                                    "For "
                                                    "third "
                                                    "party "
                                                    "detection "
                                                    "method, "
                                                    "this "
                                                    "field "
                                                    "is "
                                                    "not "
                                                    "used.",
                                                    "enum": [
                                                        0,
                                                        60,
                                                        300,
                                                        600,
                                                        900,
                                                        1800,
                                                        3600,
                                                        7200,
                                                        10800,
                                                        21600,
                                                        43200,
                                                        86400,
                                                    ],
                                                    "format": "int32",
                                                    "type": "integer",
                                                    "x-enum-varnames": [
                                                        "ZERO_MINUTES",
                                                        "ONE_MINUTE",
                                                        "FIVE_MINUTES",
                                                        "TEN_MINUTES",
                                                        "FIFTEEN_MINUTES",
                                                        "THIRTY_MINUTES",
                                                        "ONE_HOUR",
                                                        "TWO_HOURS",
                                                        "THREE_HOURS",
                                                        "SIX_HOURS",
                                                        "TWELVE_HOURS",
                                                        "ONE_DAY",
                                                    ],
                                                },
                                                "name": {
                                                    "description": "Unique "
                                                    "name "
                                                    "identifying "
                                                    "the "
                                                    "step.",
                                                    "type": "string",
                                                },
                                            },
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                },
                                "type": "object",
                            },
                            "thirdPartyRuleOptions": {
                                "description": "Options on third party detection method.",
                                "properties": {
                                    "defaultNotifications": {
                                        "description": "Notification "
                                        "targets "
                                        "for "
                                        "the "
                                        "logs "
                                        "that "
                                        "do "
                                        "not "
                                        "correspond "
                                        "to "
                                        "any "
                                        "of "
                                        "the "
                                        "cases.",
                                        "items": {"description": "Notification.", "type": "string"},
                                        "type": "array",
                                    },
                                    "defaultStatus": {
                                        "description": "Severity of the Security Signal.",
                                        "enum": ["info", "low", "medium", "high", "critical"],
                                        "example": "critical",
                                        "type": "string",
                                        "x-enum-varnames": [
                                            "INFO",
                                            "LOW",
                                            "MEDIUM",
                                            "HIGH",
                                            "CRITICAL",
                                        ],
                                    },
                                    "rootQueries": {
                                        "description": "Queries "
                                        "to "
                                        "be "
                                        "combined "
                                        "with "
                                        "third "
                                        "party "
                                        "case "
                                        "queries. "
                                        "Each "
                                        "of "
                                        "them "
                                        "can "
                                        "have "
                                        "different "
                                        "group "
                                        "by "
                                        "fields, "
                                        "to "
                                        "aggregate "
                                        "differently "
                                        "based "
                                        "on "
                                        "the "
                                        "type "
                                        "of "
                                        "alert.",
                                        "items": {
                                            "description": "A "
                                            "query "
                                            "to "
                                            "be "
                                            "combined "
                                            "with "
                                            "the "
                                            "third "
                                            "party "
                                            "case "
                                            "query.",
                                            "properties": {
                                                "groupByFields": {
                                                    "description": "Fields to group by.",
                                                    "items": {
                                                        "description": "Field.",
                                                        "type": "string",
                                                    },
                                                    "type": "array",
                                                },
                                                "query": {
                                                    "description": "Query to run on logs.",
                                                    "example": "source:cloudtrail",
                                                    "type": "string",
                                                },
                                            },
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "signalTitleTemplate": {
                                        "description": "A "
                                        "template "
                                        "for "
                                        "the "
                                        "signal "
                                        "title; "
                                        "if "
                                        "omitted, "
                                        "the "
                                        "title "
                                        "is "
                                        "generated "
                                        "based "
                                        "on "
                                        "the "
                                        "case "
                                        "name.",
                                        "type": "string",
                                    },
                                },
                                "type": "object",
                            },
                        },
                        "type": "object",
                    },
                    "queries": {
                        "description": "Queries for selecting signals which are part of the rule.",
                        "example": [],
                        "items": {
                            "description": "Query for matching rule on signals.",
                            "properties": {
                                "aggregation": {
                                    "description": "The aggregation type.",
                                    "enum": [
                                        "count",
                                        "cardinality",
                                        "sum",
                                        "max",
                                        "new_value",
                                        "geo_data",
                                        "event_count",
                                        "none",
                                    ],
                                    "type": "string",
                                    "x-enum-varnames": [
                                        "COUNT",
                                        "CARDINALITY",
                                        "SUM",
                                        "MAX",
                                        "NEW_VALUE",
                                        "GEO_DATA",
                                        "EVENT_COUNT",
                                        "NONE",
                                    ],
                                },
                                "correlatedByFields": {
                                    "description": "Fields to group by.",
                                    "items": {"description": "Field.", "type": "string"},
                                    "type": "array",
                                },
                                "correlatedQueryIndex": {
                                    "description": "Index "
                                    "of "
                                    "the "
                                    "rule "
                                    "query "
                                    "used "
                                    "to "
                                    "retrieve "
                                    "the "
                                    "correlated "
                                    "field.",
                                    "format": "int32",
                                    "maximum": 9,
                                    "type": "integer",
                                },
                                "metrics": {
                                    "description": "Group of target fields to aggregate over.",
                                    "items": {"description": "Field.", "type": "string"},
                                    "type": "array",
                                },
                                "name": {"description": "Name of the query.", "type": "string"},
                                "ruleId": {
                                    "description": "Rule ID to match on signals.",
                                    "example": "org-ru1-e1d",
                                    "type": "string",
                                },
                            },
                            "required": ["ruleId"],
                            "type": "object",
                        },
                        "type": "array",
                    },
                    "tags": {
                        "description": "Tags for generated signals.",
                        "example": ["env:prod", "team:security"],
                        "items": {"description": "Tag.", "type": "string"},
                        "type": "array",
                    },
                    "type": {
                        "description": "The rule type.",
                        "enum": ["signal_correlation"],
                        "type": "string",
                        "x-enum-varnames": ["SIGNAL_CORRELATION"],
                    },
                },
                "required": ["name", "isEnabled", "queries", "options", "cases", "message"],
                "type": "object",
            },
            {
                "description": "The payload of a cloud configuration rule.",
                "properties": {
                    "cases": {
                        "description": "Description of generated findings "
                        "and signals (severity and "
                        "channels to be notified in case "
                        "of a signal). Must contain "
                        "exactly one item.",
                        "items": {
                            "description": "Description of signals.",
                            "properties": {
                                "notifications": {
                                    "description": "Notification targets for each rule case.",
                                    "items": {"description": "Notification.", "type": "string"},
                                    "type": "array",
                                },
                                "status": {
                                    "description": "Severity of the Security Signal.",
                                    "enum": ["info", "low", "medium", "high", "critical"],
                                    "example": "critical",
                                    "type": "string",
                                    "x-enum-varnames": [
                                        "INFO",
                                        "LOW",
                                        "MEDIUM",
                                        "HIGH",
                                        "CRITICAL",
                                    ],
                                },
                            },
                            "required": ["status"],
                            "type": "object",
                        },
                        "type": "array",
                    },
                    "complianceSignalOptions": {
                        "description": "How to generate "
                        "compliance "
                        "signals. Useful "
                        "for "
                        "cloud_configuration "
                        "rules only.",
                        "properties": {
                            "defaultActivationStatus": {
                                "description": "The default activation status.",
                                "nullable": True,
                                "type": "boolean",
                            },
                            "defaultGroupByFields": {
                                "description": "The default group by fields.",
                                "items": {"type": "string"},
                                "nullable": True,
                                "type": "array",
                            },
                            "userActivationStatus": {
                                "description": "Whether signals will be sent.",
                                "nullable": True,
                                "type": "boolean",
                            },
                            "userGroupByFields": {
                                "description": "Fields "
                                "to "
                                "use "
                                "to "
                                "group "
                                "findings "
                                "by "
                                "when "
                                "sending "
                                "signals.",
                                "items": {"type": "string"},
                                "nullable": True,
                                "type": "array",
                            },
                        },
                        "type": "object",
                    },
                    "customMessage": {
                        "description": "Custom/Overridden message "
                        "for generated signals "
                        "(used in case of Default "
                        "rule update).",
                        "type": "string",
                    },
                    "customName": {
                        "description": "Custom/Overridden name of "
                        "the rule (used in case of "
                        "Default rule update).",
                        "type": "string",
                    },
                    "filters": {
                        "description": "Additional queries to filter "
                        "matched events before they are "
                        "processed.",
                        "items": {
                            "description": "The rule's suppression filter.",
                            "properties": {
                                "action": {
                                    "description": "The type of filtering action.",
                                    "enum": ["require", "suppress"],
                                    "type": "string",
                                    "x-enum-varnames": ["REQUIRE", "SUPPRESS"],
                                },
                                "query": {
                                    "description": "Query "
                                    "for "
                                    "selecting "
                                    "logs "
                                    "to "
                                    "apply "
                                    "the "
                                    "filtering "
                                    "action.",
                                    "type": "string",
                                },
                            },
                            "type": "object",
                        },
                        "type": "array",
                    },
                    "isEnabled": {
                        "description": "Whether the rule is enabled.",
                        "example": True,
                        "type": "boolean",
                    },
                    "message": {
                        "description": "Message in markdown format for "
                        "generated findings and signals.",
                        "example": "#Description\n"
                        "Explanation of the rule.\n"
                        "\n"
                        "#Remediation\n"
                        "How to fix the security issue.",
                        "type": "string",
                    },
                    "name": {
                        "description": "The name of the rule.",
                        "example": "My security monitoring rule.",
                        "type": "string",
                    },
                    "options": {
                        "description": "Options on cloud configuration rules.",
                        "properties": {
                            "complianceRuleOptions": {
                                "additionalProperties": {},
                                "description": "Options "
                                "for "
                                "cloud_configuration "
                                "rules.\n"
                                "Fields "
                                "`resourceType` "
                                "and "
                                "`regoRule` "
                                "are "
                                "mandatory "
                                "when "
                                "managing "
                                "custom "
                                "`cloud_configuration` "
                                "rules.",
                                "properties": {
                                    "complexRule": {
                                        "description": "Whether "
                                        "the "
                                        "rule "
                                        "is "
                                        "a "
                                        "complex "
                                        "one.\n"
                                        "Must "
                                        "be "
                                        "set "
                                        "to "
                                        "true "
                                        "if "
                                        "`regoRule.resourceTypes` "
                                        "contains "
                                        "more "
                                        "than "
                                        "one "
                                        "item. "
                                        "Defaults "
                                        "to "
                                        "false.",
                                        "type": "boolean",
                                    },
                                    "regoRule": {
                                        "description": "Rule details.",
                                        "properties": {
                                            "policy": {
                                                "description": "The "
                                                "policy "
                                                "written "
                                                "in "
                                                "`rego`, "
                                                "see: "
                                                "https://www.openpolicyagent.org/docs/latest/policy-language/",
                                                "example": "package "
                                                "datadog\n"
                                                "\n"
                                                "import "
                                                "data.datadog.output "
                                                "as "
                                                "dd_output\n"
                                                "import "
                                                "future.keywords.contains\n"
                                                "import "
                                                "future.keywords.if\n"
                                                "import "
                                                "future.keywords.in\n"
                                                "\n"
                                                "eval(resource) "
                                                "= "
                                                '"skip" '
                                                "if "
                                                "{\n"
                                                "  "
                                                "# "
                                                "Logic "
                                                "that "
                                                "evaluates "
                                                "to "
                                                "true "
                                                "if "
                                                "the "
                                                "resource "
                                                "should "
                                                "be "
                                                "skipped\n"
                                                "  "
                                                "true\n"
                                                "} "
                                                "else "
                                                "= "
                                                '"pass" '
                                                "{\n"
                                                "  "
                                                "# "
                                                "Logic "
                                                "that "
                                                "evaluates "
                                                "to "
                                                "true "
                                                "if "
                                                "the "
                                                "resource "
                                                "is "
                                                "compliant\n"
                                                "  "
                                                "true\n"
                                                "} "
                                                "else "
                                                "= "
                                                '"fail" '
                                                "{\n"
                                                "  "
                                                "# "
                                                "Logic "
                                                "that "
                                                "evaluates "
                                                "to "
                                                "true "
                                                "if "
                                                "the "
                                                "resource "
                                                "is "
                                                "not "
                                                "compliant\n"
                                                "  "
                                                "true\n"
                                                "}\n"
                                                "\n"
                                                "# "
                                                "This "
                                                "part "
                                                "remains "
                                                "unchanged "
                                                "for "
                                                "all "
                                                "rules\n"
                                                "results "
                                                "contains "
                                                "result "
                                                "if "
                                                "{\n"
                                                "  "
                                                "some "
                                                "resource "
                                                "in "
                                                "input.resources[input.main_resource_type]\n"
                                                "  "
                                                "result "
                                                ":= "
                                                "dd_output.format(resource, "
                                                "eval(resource))\n"
                                                "}",
                                                "type": "string",
                                            },
                                            "resourceTypes": {
                                                "description": "List "
                                                "of "
                                                "resource "
                                                "types "
                                                "that "
                                                "will "
                                                "be "
                                                "evaluated "
                                                "upon. "
                                                "Must "
                                                "have "
                                                "at "
                                                "least "
                                                "one "
                                                "element.",
                                                "example": [
                                                    "gcp_iam_service_account",
                                                    "gcp_iam_policy",
                                                ],
                                                "items": {"type": "string"},
                                                "type": "array",
                                            },
                                        },
                                        "required": ["policy", "resourceTypes"],
                                        "type": "object",
                                    },
                                    "resourceType": {
                                        "description": "Main "
                                        "resource "
                                        "type "
                                        "to "
                                        "be "
                                        "checked "
                                        "by "
                                        "the "
                                        "rule. "
                                        "It "
                                        "should "
                                        "be "
                                        "specified "
                                        "again "
                                        "in "
                                        "`regoRule.resourceTypes`.",
                                        "example": "aws_acm",
                                        "type": "string",
                                    },
                                },
                                "type": "object",
                            }
                        },
                        "required": ["complianceRuleOptions"],
                        "type": "object",
                    },
                    "tags": {
                        "description": "Tags for generated findings and signals.",
                        "example": ["env:prod", "team:security"],
                        "items": {"description": "Tag.", "type": "string"},
                        "type": "array",
                    },
                    "type": {
                        "description": "The rule type.",
                        "enum": ["cloud_configuration"],
                        "type": "string",
                        "x-enum-varnames": ["CLOUD_CONFIGURATION"],
                    },
                },
                "required": [
                    "name",
                    "isEnabled",
                    "options",
                    "complianceSignalOptions",
                    "cases",
                    "message",
                ],
                "type": "object",
            },
        ],
    },
    "UPDATESECURITYMONITORINGRULE_REQUEST_BODY_SCHEMA": {
        "description": "Update an existing rule.",
        "properties": {
            "calculatedFields": {
                "description": "Calculated fields. Only allowed "
                "for scheduled rules - in other "
                "words, when schedulingOptions is "
                "also defined.",
                "items": {
                    "description": "Calculated field.",
                    "properties": {
                        "expression": {
                            "description": "Expression.",
                            "example": "@request_end_timestamp - @request_start_timestamp",
                            "type": "string",
                        },
                        "name": {
                            "description": "Field name.",
                            "example": "response_time",
                            "type": "string",
                        },
                    },
                    "required": ["name", "expression"],
                    "type": "object",
                },
                "type": "array",
            },
            "cases": {
                "description": "Cases for generating signals.",
                "items": {
                    "description": "Case when signal is generated.",
                    "properties": {
                        "actions": {
                            "description": "Action to perform for each rule case.",
                            "items": {
                                "description": "Action "
                                "to "
                                "perform "
                                "when "
                                "a "
                                "signal "
                                "is "
                                "triggered. "
                                "Only "
                                "available "
                                "for "
                                "Application "
                                "Security "
                                "rule "
                                "type.",
                                "properties": {
                                    "options": {
                                        "additionalProperties": {},
                                        "description": "Options for the rule action",
                                        "properties": {
                                            "duration": {
                                                "description": "Duration "
                                                "of "
                                                "the "
                                                "action "
                                                "in "
                                                "seconds. "
                                                "0 "
                                                "indicates "
                                                "no "
                                                "expiration.",
                                                "example": 0,
                                                "format": "int64",
                                                "minimum": 0,
                                                "type": "integer",
                                            },
                                            "flaggedIPType": {
                                                "description": "Used "
                                                "with "
                                                "the "
                                                "case "
                                                "action "
                                                "of "
                                                "type "
                                                "'flag_ip'. "
                                                "The "
                                                "value "
                                                "specified "
                                                "in "
                                                "this "
                                                "field "
                                                "is "
                                                "applied "
                                                "as "
                                                "a "
                                                "flag "
                                                "to "
                                                "the "
                                                "IP "
                                                "addresses.",
                                                "enum": ["SUSPICIOUS", "FLAGGED"],
                                                "example": "FLAGGED",
                                                "type": "string",
                                                "x-enum-varnames": ["SUSPICIOUS", "FLAGGED"],
                                            },
                                            "userBehaviorName": {
                                                "description": "Used "
                                                "with "
                                                "the "
                                                "case "
                                                "action "
                                                "of "
                                                "type "
                                                "'user_behavior'. "
                                                "The "
                                                "value "
                                                "specified "
                                                "in "
                                                "this "
                                                "field "
                                                "is "
                                                "applied "
                                                "as "
                                                "a "
                                                "risk "
                                                "tag "
                                                "to "
                                                "all "
                                                "users "
                                                "affected "
                                                "by "
                                                "the "
                                                "rule.",
                                                "type": "string",
                                            },
                                        },
                                        "type": "object",
                                    },
                                    "type": {
                                        "description": "The action type.",
                                        "enum": [
                                            "block_ip",
                                            "block_user",
                                            "user_behavior",
                                            "flag_ip",
                                        ],
                                        "type": "string",
                                        "x-enum-varnames": [
                                            "BLOCK_IP",
                                            "BLOCK_USER",
                                            "USER_BEHAVIOR",
                                            "FLAG_IP",
                                        ],
                                    },
                                },
                                "type": "object",
                            },
                            "type": "array",
                        },
                        "condition": {
                            "description": "A "
                            "rule "
                            "case "
                            "contains "
                            "logical "
                            "operations "
                            "(`>`,`>=`, "
                            "`&&`, "
                            "`||`) "
                            "to "
                            "determine "
                            "if a "
                            "signal "
                            "should "
                            "be "
                            "generated\n"
                            "based "
                            "on "
                            "the "
                            "event "
                            "counts "
                            "in "
                            "the "
                            "previously "
                            "defined "
                            "queries.",
                            "type": "string",
                        },
                        "customStatus": {
                            "description": "Severity of the Security Signal.",
                            "enum": ["info", "low", "medium", "high", "critical"],
                            "example": "critical",
                            "type": "string",
                            "x-enum-varnames": ["INFO", "LOW", "MEDIUM", "HIGH", "CRITICAL"],
                        },
                        "name": {"description": "Name of the case.", "type": "string"},
                        "notifications": {
                            "description": "Notification targets for each rule case.",
                            "items": {"description": "Notification.", "type": "string"},
                            "type": "array",
                        },
                        "status": {
                            "description": "Severity of the Security Signal.",
                            "enum": ["info", "low", "medium", "high", "critical"],
                            "example": "critical",
                            "type": "string",
                            "x-enum-varnames": ["INFO", "LOW", "MEDIUM", "HIGH", "CRITICAL"],
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "complianceSignalOptions": {
                "description": "How to generate compliance "
                "signals. Useful for "
                "cloud_configuration rules "
                "only.",
                "properties": {
                    "defaultActivationStatus": {
                        "description": "The default activation status.",
                        "nullable": True,
                        "type": "boolean",
                    },
                    "defaultGroupByFields": {
                        "description": "The default group by fields.",
                        "items": {"type": "string"},
                        "nullable": True,
                        "type": "array",
                    },
                    "userActivationStatus": {
                        "description": "Whether signals will be sent.",
                        "nullable": True,
                        "type": "boolean",
                    },
                    "userGroupByFields": {
                        "description": "Fields to use to group findings by when sending signals.",
                        "items": {"type": "string"},
                        "nullable": True,
                        "type": "array",
                    },
                },
                "type": "object",
            },
            "customMessage": {
                "description": "Custom/Overridden Message for "
                "generated signals (used in case of "
                "Default rule update).",
                "type": "string",
            },
            "customName": {
                "description": "Custom/Overridden name (used in case of Default rule update).",
                "type": "string",
            },
            "filters": {
                "description": "Additional queries to filter matched "
                "events before they are processed. This "
                "field is deprecated for log detection, "
                "signal correlation, and workload security "
                "rules.",
                "items": {
                    "description": "The rule's suppression filter.",
                    "properties": {
                        "action": {
                            "description": "The type of filtering action.",
                            "enum": ["require", "suppress"],
                            "type": "string",
                            "x-enum-varnames": ["REQUIRE", "SUPPRESS"],
                        },
                        "query": {
                            "description": "Query "
                            "for "
                            "selecting "
                            "logs to "
                            "apply "
                            "the "
                            "filtering "
                            "action.",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "groupSignalsBy": {
                "description": "Additional grouping to perform on "
                "top of the existing groups in the "
                "query section. Must be a subset of "
                "the existing groups.",
                "example": ["service"],
                "items": {"description": "Field to group by.", "type": "string"},
                "type": "array",
            },
            "hasExtendedTitle": {
                "description": "Whether the notifications include "
                "the triggering group-by values in "
                "their title.",
                "example": True,
                "type": "boolean",
            },
            "isEnabled": {"description": "Whether the rule is enabled.", "type": "boolean"},
            "message": {"description": "Message for generated signals.", "type": "string"},
            "name": {"description": "Name of the rule.", "type": "string"},
            "options": {
                "description": "Options.",
                "properties": {
                    "complianceRuleOptions": {
                        "additionalProperties": {},
                        "description": "Options "
                        "for "
                        "cloud_configuration "
                        "rules.\n"
                        "Fields "
                        "`resourceType` "
                        "and "
                        "`regoRule` "
                        "are "
                        "mandatory "
                        "when "
                        "managing "
                        "custom "
                        "`cloud_configuration` "
                        "rules.",
                        "properties": {
                            "complexRule": {
                                "description": "Whether "
                                "the "
                                "rule "
                                "is "
                                "a "
                                "complex "
                                "one.\n"
                                "Must "
                                "be "
                                "set "
                                "to "
                                "true "
                                "if "
                                "`regoRule.resourceTypes` "
                                "contains "
                                "more "
                                "than "
                                "one "
                                "item. "
                                "Defaults "
                                "to "
                                "false.",
                                "type": "boolean",
                            },
                            "regoRule": {
                                "description": "Rule details.",
                                "properties": {
                                    "policy": {
                                        "description": "The "
                                        "policy "
                                        "written "
                                        "in "
                                        "`rego`, "
                                        "see: "
                                        "https://www.openpolicyagent.org/docs/latest/policy-language/",
                                        "example": "package "
                                        "datadog\n"
                                        "\n"
                                        "import "
                                        "data.datadog.output "
                                        "as "
                                        "dd_output\n"
                                        "import "
                                        "future.keywords.contains\n"
                                        "import "
                                        "future.keywords.if\n"
                                        "import "
                                        "future.keywords.in\n"
                                        "\n"
                                        "eval(resource) "
                                        "= "
                                        '"skip" '
                                        "if "
                                        "{\n"
                                        "  "
                                        "# "
                                        "Logic "
                                        "that "
                                        "evaluates "
                                        "to "
                                        "true "
                                        "if "
                                        "the "
                                        "resource "
                                        "should "
                                        "be "
                                        "skipped\n"
                                        "  "
                                        "true\n"
                                        "} "
                                        "else "
                                        "= "
                                        '"pass" '
                                        "{\n"
                                        "  "
                                        "# "
                                        "Logic "
                                        "that "
                                        "evaluates "
                                        "to "
                                        "true "
                                        "if "
                                        "the "
                                        "resource "
                                        "is "
                                        "compliant\n"
                                        "  "
                                        "true\n"
                                        "} "
                                        "else "
                                        "= "
                                        '"fail" '
                                        "{\n"
                                        "  "
                                        "# "
                                        "Logic "
                                        "that "
                                        "evaluates "
                                        "to "
                                        "true "
                                        "if "
                                        "the "
                                        "resource "
                                        "is "
                                        "not "
                                        "compliant\n"
                                        "  "
                                        "true\n"
                                        "}\n"
                                        "\n"
                                        "# "
                                        "This "
                                        "part "
                                        "remains "
                                        "unchanged "
                                        "for "
                                        "all "
                                        "rules\n"
                                        "results "
                                        "contains "
                                        "result "
                                        "if "
                                        "{\n"
                                        "  "
                                        "some "
                                        "resource "
                                        "in "
                                        "input.resources[input.main_resource_type]\n"
                                        "  "
                                        "result "
                                        ":= "
                                        "dd_output.format(resource, "
                                        "eval(resource))\n"
                                        "}",
                                        "type": "string",
                                    },
                                    "resourceTypes": {
                                        "description": "List "
                                        "of "
                                        "resource "
                                        "types "
                                        "that "
                                        "will "
                                        "be "
                                        "evaluated "
                                        "upon. "
                                        "Must "
                                        "have "
                                        "at "
                                        "least "
                                        "one "
                                        "element.",
                                        "example": ["gcp_iam_service_account", "gcp_iam_policy"],
                                        "items": {"type": "string"},
                                        "type": "array",
                                    },
                                },
                                "required": ["policy", "resourceTypes"],
                                "type": "object",
                            },
                            "resourceType": {
                                "description": "Main "
                                "resource "
                                "type "
                                "to "
                                "be "
                                "checked "
                                "by "
                                "the "
                                "rule. "
                                "It "
                                "should "
                                "be "
                                "specified "
                                "again "
                                "in "
                                "`regoRule.resourceTypes`.",
                                "example": "aws_acm",
                                "type": "string",
                            },
                        },
                        "type": "object",
                    },
                    "decreaseCriticalityBasedOnEnv": {
                        "description": "If "
                        "true, "
                        "signals "
                        "in "
                        "non-production "
                        "environments "
                        "have "
                        "a "
                        "lower "
                        "severity "
                        "than "
                        "what "
                        "is "
                        "defined "
                        "by "
                        "the "
                        "rule "
                        "case, "
                        "which "
                        "can "
                        "reduce "
                        "signal "
                        "noise.\n"
                        "The "
                        "severity "
                        "is "
                        "decreased "
                        "by "
                        "one "
                        "level: "
                        "`CRITICAL` "
                        "in "
                        "production "
                        "becomes "
                        "`HIGH` "
                        "in "
                        "non-production, "
                        "`HIGH` "
                        "becomes "
                        "`MEDIUM` "
                        "and "
                        "so "
                        "on. "
                        "`INFO` "
                        "remains "
                        "`INFO`.\n"
                        "The "
                        "decrement "
                        "is "
                        "applied "
                        "when "
                        "the "
                        "environment "
                        "tag "
                        "of "
                        "the "
                        "signal "
                        "starts "
                        "with "
                        "`staging`, "
                        "`test` "
                        "or "
                        "`dev`.",
                        "example": False,
                        "type": "boolean",
                    },
                    "detectionMethod": {
                        "description": "The detection method.",
                        "enum": [
                            "threshold",
                            "new_value",
                            "anomaly_detection",
                            "impossible_travel",
                            "hardcoded",
                            "third_party",
                            "anomaly_threshold",
                            "sequence_detection",
                        ],
                        "type": "string",
                        "x-enum-varnames": [
                            "THRESHOLD",
                            "NEW_VALUE",
                            "ANOMALY_DETECTION",
                            "IMPOSSIBLE_TRAVEL",
                            "HARDCODED",
                            "THIRD_PARTY",
                            "ANOMALY_THRESHOLD",
                            "SEQUENCE_DETECTION",
                        ],
                    },
                    "evaluationWindow": {
                        "description": "A time "
                        "window "
                        "is "
                        "specified "
                        "to "
                        "match "
                        "when "
                        "at "
                        "least "
                        "one of "
                        "the "
                        "cases "
                        "matches "
                        "true. "
                        "This "
                        "is a "
                        "sliding "
                        "window\n"
                        "and "
                        "evaluates "
                        "in "
                        "real "
                        "time. "
                        "For "
                        "third "
                        "party "
                        "detection "
                        "method, "
                        "this "
                        "field "
                        "is not "
                        "used.",
                        "enum": [
                            0,
                            60,
                            300,
                            600,
                            900,
                            1800,
                            3600,
                            7200,
                            10800,
                            21600,
                            43200,
                            86400,
                        ],
                        "format": "int32",
                        "type": "integer",
                        "x-enum-varnames": [
                            "ZERO_MINUTES",
                            "ONE_MINUTE",
                            "FIVE_MINUTES",
                            "TEN_MINUTES",
                            "FIFTEEN_MINUTES",
                            "THIRTY_MINUTES",
                            "ONE_HOUR",
                            "TWO_HOURS",
                            "THREE_HOURS",
                            "SIX_HOURS",
                            "TWELVE_HOURS",
                            "ONE_DAY",
                        ],
                    },
                    "hardcodedEvaluatorType": {
                        "description": "Hardcoded evaluator type.",
                        "enum": ["log4shell"],
                        "type": "string",
                        "x-enum-varnames": ["LOG4SHELL"],
                    },
                    "impossibleTravelOptions": {
                        "description": "Options on impossible travel detection method.",
                        "properties": {
                            "baselineUserLocations": {
                                "description": "If "
                                "true, "
                                "signals "
                                "are "
                                "suppressed "
                                "for "
                                "the "
                                "first "
                                "24 "
                                "hours. "
                                "In "
                                "that "
                                "time, "
                                "Datadog "
                                "learns "
                                "the "
                                "user's "
                                "regular\n"
                                "access "
                                "locations. "
                                "This "
                                "can "
                                "be "
                                "helpful "
                                "to "
                                "reduce "
                                "noise "
                                "and "
                                "infer "
                                "VPN "
                                "usage "
                                "or "
                                "credentialed "
                                "API "
                                "access.",
                                "example": True,
                                "type": "boolean",
                            }
                        },
                        "type": "object",
                    },
                    "keepAlive": {
                        "description": "Once a signal "
                        "is generated, "
                        "the signal "
                        "will remain "
                        '"open" if a '
                        "case is "
                        "matched at "
                        "least once "
                        "within\n"
                        "this keep "
                        "alive window. "
                        "For third "
                        "party "
                        "detection "
                        "method, this "
                        "field is not "
                        "used.",
                        "enum": [
                            0,
                            60,
                            300,
                            600,
                            900,
                            1800,
                            3600,
                            7200,
                            10800,
                            21600,
                            43200,
                            86400,
                        ],
                        "format": "int32",
                        "type": "integer",
                        "x-enum-varnames": [
                            "ZERO_MINUTES",
                            "ONE_MINUTE",
                            "FIVE_MINUTES",
                            "TEN_MINUTES",
                            "FIFTEEN_MINUTES",
                            "THIRTY_MINUTES",
                            "ONE_HOUR",
                            "TWO_HOURS",
                            "THREE_HOURS",
                            "SIX_HOURS",
                            "TWELVE_HOURS",
                            "ONE_DAY",
                        ],
                    },
                    "maxSignalDuration": {
                        "description": "A "
                        "signal "
                        "will "
                        '"close" '
                        "regardless "
                        "of "
                        "the "
                        "query "
                        "being "
                        "matched "
                        "once "
                        "the "
                        "time "
                        "exceeds "
                        "the "
                        "maximum "
                        "duration.\n"
                        "This "
                        "time "
                        "is "
                        "calculated "
                        "from "
                        "the "
                        "first "
                        "seen "
                        "timestamp.",
                        "enum": [
                            0,
                            60,
                            300,
                            600,
                            900,
                            1800,
                            3600,
                            7200,
                            10800,
                            21600,
                            43200,
                            86400,
                        ],
                        "format": "int32",
                        "type": "integer",
                        "x-enum-varnames": [
                            "ZERO_MINUTES",
                            "ONE_MINUTE",
                            "FIVE_MINUTES",
                            "TEN_MINUTES",
                            "FIFTEEN_MINUTES",
                            "THIRTY_MINUTES",
                            "ONE_HOUR",
                            "TWO_HOURS",
                            "THREE_HOURS",
                            "SIX_HOURS",
                            "TWELVE_HOURS",
                            "ONE_DAY",
                        ],
                    },
                    "newValueOptions": {
                        "description": "Options on new value detection method.",
                        "properties": {
                            "forgetAfter": {
                                "description": "The "
                                "duration "
                                "in "
                                "days "
                                "after "
                                "which "
                                "a "
                                "learned "
                                "value "
                                "is "
                                "forgotten.",
                                "enum": [1, 2, 7, 14, 21, 28],
                                "format": "int32",
                                "type": "integer",
                                "x-enum-varnames": [
                                    "ONE_DAY",
                                    "TWO_DAYS",
                                    "ONE_WEEK",
                                    "TWO_WEEKS",
                                    "THREE_WEEKS",
                                    "FOUR_WEEKS",
                                ],
                            },
                            "learningDuration": {
                                "default": 0,
                                "description": "The "
                                "duration "
                                "in "
                                "days "
                                "during "
                                "which "
                                "values "
                                "are "
                                "learned, "
                                "and "
                                "after "
                                "which "
                                "signals "
                                "will "
                                "be "
                                "generated "
                                "for "
                                "values "
                                "that\n"
                                "weren't "
                                "learned. "
                                "If "
                                "set "
                                "to "
                                "0, "
                                "a "
                                "signal "
                                "will "
                                "be "
                                "generated "
                                "for "
                                "all "
                                "new "
                                "values "
                                "after "
                                "the "
                                "first "
                                "value "
                                "is "
                                "learned.",
                                "enum": [0, 1, 7],
                                "format": "int32",
                                "type": "integer",
                                "x-enum-varnames": ["ZERO_DAYS", "ONE_DAY", "SEVEN_DAYS"],
                            },
                            "learningMethod": {
                                "default": "duration",
                                "description": "The "
                                "learning "
                                "method "
                                "used "
                                "to "
                                "determine "
                                "when "
                                "signals "
                                "should "
                                "be "
                                "generated "
                                "for "
                                "values "
                                "that "
                                "weren't "
                                "learned.",
                                "enum": ["duration", "threshold"],
                                "type": "string",
                                "x-enum-varnames": ["DURATION", "THRESHOLD"],
                            },
                            "learningThreshold": {
                                "default": 0,
                                "description": "A "
                                "number "
                                "of "
                                "occurrences "
                                "after "
                                "which "
                                "signals "
                                "will "
                                "be "
                                "generated "
                                "for "
                                "values "
                                "that "
                                "weren't "
                                "learned.",
                                "enum": [0, 1],
                                "format": "int32",
                                "type": "integer",
                                "x-enum-varnames": ["ZERO_OCCURRENCES", "ONE_OCCURRENCE"],
                            },
                        },
                        "type": "object",
                    },
                    "sequenceDetectionOptions": {
                        "description": "Options on sequence detection method.",
                        "properties": {
                            "stepTransitions": {
                                "description": "Transitions "
                                "defining "
                                "the "
                                "allowed "
                                "order "
                                "of "
                                "steps "
                                "and "
                                "their "
                                "evaluation "
                                "windows.",
                                "items": {
                                    "description": "Transition "
                                    "from "
                                    "a "
                                    "parent "
                                    "step "
                                    "to "
                                    "a "
                                    "child "
                                    "step "
                                    "within "
                                    "a "
                                    "sequence "
                                    "detection "
                                    "rule.",
                                    "properties": {
                                        "child": {
                                            "description": "Name of the child step.",
                                            "type": "string",
                                        },
                                        "evaluationWindow": {
                                            "description": "A "
                                            "time "
                                            "window "
                                            "is "
                                            "specified "
                                            "to "
                                            "match "
                                            "when "
                                            "at "
                                            "least "
                                            "one "
                                            "of "
                                            "the "
                                            "cases "
                                            "matches "
                                            "true. "
                                            "This "
                                            "is "
                                            "a "
                                            "sliding "
                                            "window\n"
                                            "and "
                                            "evaluates "
                                            "in "
                                            "real "
                                            "time. "
                                            "For "
                                            "third "
                                            "party "
                                            "detection "
                                            "method, "
                                            "this "
                                            "field "
                                            "is "
                                            "not "
                                            "used.",
                                            "enum": [
                                                0,
                                                60,
                                                300,
                                                600,
                                                900,
                                                1800,
                                                3600,
                                                7200,
                                                10800,
                                                21600,
                                                43200,
                                                86400,
                                            ],
                                            "format": "int32",
                                            "type": "integer",
                                            "x-enum-varnames": [
                                                "ZERO_MINUTES",
                                                "ONE_MINUTE",
                                                "FIVE_MINUTES",
                                                "TEN_MINUTES",
                                                "FIFTEEN_MINUTES",
                                                "THIRTY_MINUTES",
                                                "ONE_HOUR",
                                                "TWO_HOURS",
                                                "THREE_HOURS",
                                                "SIX_HOURS",
                                                "TWELVE_HOURS",
                                                "ONE_DAY",
                                            ],
                                        },
                                        "parent": {
                                            "description": "Name of the parent step.",
                                            "type": "string",
                                        },
                                    },
                                    "type": "object",
                                },
                                "type": "array",
                            },
                            "steps": {
                                "description": "Steps "
                                "that "
                                "define "
                                "the "
                                "conditions "
                                "to "
                                "be "
                                "matched "
                                "in "
                                "sequence.",
                                "items": {
                                    "description": "Step "
                                    "definition "
                                    "for "
                                    "sequence "
                                    "detection "
                                    "containing "
                                    "the "
                                    "step "
                                    "name, "
                                    "condition, "
                                    "and "
                                    "evaluation "
                                    "window.",
                                    "properties": {
                                        "condition": {
                                            "description": "Condition "
                                            "referencing "
                                            "rule "
                                            "queries "
                                            "(e.g., "
                                            "`a "
                                            "> "
                                            "0`).",
                                            "type": "string",
                                        },
                                        "evaluationWindow": {
                                            "description": "A "
                                            "time "
                                            "window "
                                            "is "
                                            "specified "
                                            "to "
                                            "match "
                                            "when "
                                            "at "
                                            "least "
                                            "one "
                                            "of "
                                            "the "
                                            "cases "
                                            "matches "
                                            "true. "
                                            "This "
                                            "is "
                                            "a "
                                            "sliding "
                                            "window\n"
                                            "and "
                                            "evaluates "
                                            "in "
                                            "real "
                                            "time. "
                                            "For "
                                            "third "
                                            "party "
                                            "detection "
                                            "method, "
                                            "this "
                                            "field "
                                            "is "
                                            "not "
                                            "used.",
                                            "enum": [
                                                0,
                                                60,
                                                300,
                                                600,
                                                900,
                                                1800,
                                                3600,
                                                7200,
                                                10800,
                                                21600,
                                                43200,
                                                86400,
                                            ],
                                            "format": "int32",
                                            "type": "integer",
                                            "x-enum-varnames": [
                                                "ZERO_MINUTES",
                                                "ONE_MINUTE",
                                                "FIVE_MINUTES",
                                                "TEN_MINUTES",
                                                "FIFTEEN_MINUTES",
                                                "THIRTY_MINUTES",
                                                "ONE_HOUR",
                                                "TWO_HOURS",
                                                "THREE_HOURS",
                                                "SIX_HOURS",
                                                "TWELVE_HOURS",
                                                "ONE_DAY",
                                            ],
                                        },
                                        "name": {
                                            "description": "Unique name identifying the step.",
                                            "type": "string",
                                        },
                                    },
                                    "type": "object",
                                },
                                "type": "array",
                            },
                        },
                        "type": "object",
                    },
                    "thirdPartyRuleOptions": {
                        "description": "Options on third party detection method.",
                        "properties": {
                            "defaultNotifications": {
                                "description": "Notification "
                                "targets "
                                "for "
                                "the "
                                "logs "
                                "that "
                                "do "
                                "not "
                                "correspond "
                                "to "
                                "any "
                                "of "
                                "the "
                                "cases.",
                                "items": {"description": "Notification.", "type": "string"},
                                "type": "array",
                            },
                            "defaultStatus": {
                                "description": "Severity of the Security Signal.",
                                "enum": ["info", "low", "medium", "high", "critical"],
                                "example": "critical",
                                "type": "string",
                                "x-enum-varnames": ["INFO", "LOW", "MEDIUM", "HIGH", "CRITICAL"],
                            },
                            "rootQueries": {
                                "description": "Queries "
                                "to "
                                "be "
                                "combined "
                                "with "
                                "third "
                                "party "
                                "case "
                                "queries. "
                                "Each "
                                "of "
                                "them "
                                "can "
                                "have "
                                "different "
                                "group "
                                "by "
                                "fields, "
                                "to "
                                "aggregate "
                                "differently "
                                "based "
                                "on "
                                "the "
                                "type "
                                "of "
                                "alert.",
                                "items": {
                                    "description": "A "
                                    "query "
                                    "to "
                                    "be "
                                    "combined "
                                    "with "
                                    "the "
                                    "third "
                                    "party "
                                    "case "
                                    "query.",
                                    "properties": {
                                        "groupByFields": {
                                            "description": "Fields to group by.",
                                            "items": {"description": "Field.", "type": "string"},
                                            "type": "array",
                                        },
                                        "query": {
                                            "description": "Query to run on logs.",
                                            "example": "source:cloudtrail",
                                            "type": "string",
                                        },
                                    },
                                    "type": "object",
                                },
                                "type": "array",
                            },
                            "signalTitleTemplate": {
                                "description": "A "
                                "template "
                                "for "
                                "the "
                                "signal "
                                "title; "
                                "if "
                                "omitted, "
                                "the "
                                "title "
                                "is "
                                "generated "
                                "based "
                                "on "
                                "the "
                                "case "
                                "name.",
                                "type": "string",
                            },
                        },
                        "type": "object",
                    },
                },
                "type": "object",
            },
            "queries": {
                "description": "Queries for selecting logs which are part of the rule.",
                "items": {
                    "description": "Query for matching rule.",
                    "oneOf": [
                        {
                            "description": "Query for matching rule.",
                            "properties": {
                                "aggregation": {
                                    "description": "The aggregation type.",
                                    "enum": [
                                        "count",
                                        "cardinality",
                                        "sum",
                                        "max",
                                        "new_value",
                                        "geo_data",
                                        "event_count",
                                        "none",
                                    ],
                                    "type": "string",
                                    "x-enum-varnames": [
                                        "COUNT",
                                        "CARDINALITY",
                                        "SUM",
                                        "MAX",
                                        "NEW_VALUE",
                                        "GEO_DATA",
                                        "EVENT_COUNT",
                                        "NONE",
                                    ],
                                },
                                "customQueryExtension": {
                                    "description": "Query extension to append to the logs query.",
                                    "example": "a > 3",
                                    "type": "string",
                                },
                                "dataSource": {
                                    "default": "logs",
                                    "description": "Source "
                                    "of "
                                    "events, "
                                    "either "
                                    "logs, "
                                    "audit "
                                    "trail, "
                                    "or "
                                    "Datadog "
                                    "events.",
                                    "enum": [
                                        "logs",
                                        "audit",
                                        "app_sec_spans",
                                        "spans",
                                        "security_runtime",
                                        "network",
                                        "events",
                                    ],
                                    "example": "logs",
                                    "type": "string",
                                    "x-enum-varnames": [
                                        "LOGS",
                                        "AUDIT",
                                        "APP_SEC_SPANS",
                                        "SPANS",
                                        "SECURITY_RUNTIME",
                                        "NETWORK",
                                        "EVENTS",
                                    ],
                                },
                                "distinctFields": {
                                    "description": "Field "
                                    "for "
                                    "which "
                                    "the "
                                    "cardinality "
                                    "is "
                                    "measured. "
                                    "Sent "
                                    "as "
                                    "an "
                                    "array.",
                                    "items": {"description": "Field.", "type": "string"},
                                    "type": "array",
                                },
                                "groupByFields": {
                                    "description": "Fields to group by.",
                                    "items": {"description": "Field.", "type": "string"},
                                    "type": "array",
                                },
                                "hasOptionalGroupByFields": {
                                    "default": False,
                                    "description": "When "
                                    "false, "
                                    "events "
                                    "without "
                                    "a "
                                    "group-by "
                                    "value "
                                    "are "
                                    "ignored "
                                    "by "
                                    "the "
                                    "rule. "
                                    "When "
                                    "true, "
                                    "events "
                                    "with "
                                    "missing "
                                    "group-by "
                                    "fields "
                                    "are "
                                    "processed "
                                    "with "
                                    "`N/A`, "
                                    "replacing "
                                    "the "
                                    "missing "
                                    "values.",
                                    "example": False,
                                    "type": "boolean",
                                },
                                "index": {
                                    "description": "**This "
                                    "field "
                                    "is "
                                    "currently "
                                    "unstable "
                                    "and "
                                    "might "
                                    "be "
                                    "removed "
                                    "in "
                                    "a "
                                    "minor "
                                    "version "
                                    "upgrade.**\n"
                                    "The "
                                    "index "
                                    "to "
                                    "run "
                                    "the "
                                    "query "
                                    "on, "
                                    "if "
                                    "the "
                                    "`dataSource` "
                                    "is "
                                    "`logs`. "
                                    "Only "
                                    "used "
                                    "for "
                                    "scheduled "
                                    "rules "
                                    "- "
                                    "in "
                                    "other "
                                    "words, "
                                    "when "
                                    "the "
                                    "`schedulingOptions` "
                                    "field "
                                    "is "
                                    "present "
                                    "in "
                                    "the "
                                    "rule "
                                    "payload.",
                                    "type": "string",
                                },
                                "indexes": {
                                    "description": "List "
                                    "of "
                                    "indexes "
                                    "to "
                                    "query "
                                    "when "
                                    "the "
                                    "`dataSource` "
                                    "is "
                                    "`logs`. "
                                    "Only "
                                    "used "
                                    "for "
                                    "scheduled "
                                    "rules, "
                                    "such "
                                    "as "
                                    "when "
                                    "the "
                                    "`schedulingOptions` "
                                    "field "
                                    "is "
                                    "present "
                                    "in "
                                    "the "
                                    "rule "
                                    "payload.",
                                    "items": {"description": "Index.", "type": "string"},
                                    "type": "array",
                                },
                                "metric": {
                                    "deprecated": True,
                                    "description": "(Deprecated) "
                                    "The "
                                    "target "
                                    "field "
                                    "to "
                                    "aggregate "
                                    "over "
                                    "when "
                                    "using "
                                    "the "
                                    "sum "
                                    "or "
                                    "max\n"
                                    "aggregations. "
                                    "`metrics` "
                                    "field "
                                    "should "
                                    "be "
                                    "used "
                                    "instead.",
                                    "type": "string",
                                },
                                "metrics": {
                                    "description": "Group "
                                    "of "
                                    "target "
                                    "fields "
                                    "to "
                                    "aggregate "
                                    "over "
                                    "when "
                                    "using "
                                    "the "
                                    "sum, "
                                    "max, "
                                    "geo "
                                    "data, "
                                    "or "
                                    "new "
                                    "value "
                                    "aggregations. "
                                    "The "
                                    "sum, "
                                    "max, "
                                    "and "
                                    "geo "
                                    "data "
                                    "aggregations "
                                    "only "
                                    "accept "
                                    "one "
                                    "value "
                                    "in "
                                    "this "
                                    "list, "
                                    "whereas "
                                    "the "
                                    "new "
                                    "value "
                                    "aggregation "
                                    "accepts "
                                    "up "
                                    "to "
                                    "five "
                                    "values.",
                                    "items": {"description": "Field.", "type": "string"},
                                    "type": "array",
                                },
                                "name": {"description": "Name of the query.", "type": "string"},
                                "query": {
                                    "description": "Query to run on logs.",
                                    "example": "a > 3",
                                    "type": "string",
                                },
                            },
                            "type": "object",
                        },
                        {
                            "description": "Query for matching rule on signals.",
                            "properties": {
                                "aggregation": {
                                    "description": "The aggregation type.",
                                    "enum": [
                                        "count",
                                        "cardinality",
                                        "sum",
                                        "max",
                                        "new_value",
                                        "geo_data",
                                        "event_count",
                                        "none",
                                    ],
                                    "type": "string",
                                    "x-enum-varnames": [
                                        "COUNT",
                                        "CARDINALITY",
                                        "SUM",
                                        "MAX",
                                        "NEW_VALUE",
                                        "GEO_DATA",
                                        "EVENT_COUNT",
                                        "NONE",
                                    ],
                                },
                                "correlatedByFields": {
                                    "description": "Fields to group by.",
                                    "items": {"description": "Field.", "type": "string"},
                                    "type": "array",
                                },
                                "correlatedQueryIndex": {
                                    "description": "Index "
                                    "of "
                                    "the "
                                    "rule "
                                    "query "
                                    "used "
                                    "to "
                                    "retrieve "
                                    "the "
                                    "correlated "
                                    "field.",
                                    "format": "int32",
                                    "maximum": 9,
                                    "type": "integer",
                                },
                                "metrics": {
                                    "description": "Group of target fields to aggregate over.",
                                    "items": {"description": "Field.", "type": "string"},
                                    "type": "array",
                                },
                                "name": {"description": "Name of the query.", "type": "string"},
                                "ruleId": {
                                    "description": "Rule ID to match on signals.",
                                    "example": "org-ru1-e1d",
                                    "type": "string",
                                },
                            },
                            "required": ["ruleId"],
                            "type": "object",
                        },
                    ],
                },
                "type": "array",
            },
            "referenceTables": {
                "description": "Reference tables for the rule.",
                "items": {
                    "description": "Reference tables used in the queries.",
                    "properties": {
                        "checkPresence": {
                            "description": "Whether to include or exclude the matched values.",
                            "type": "boolean",
                        },
                        "columnName": {
                            "description": "The name of the column in the reference table.",
                            "type": "string",
                        },
                        "logFieldPath": {
                            "description": "The "
                            "field "
                            "in "
                            "the "
                            "log "
                            "to "
                            "match "
                            "against "
                            "the "
                            "reference "
                            "table.",
                            "type": "string",
                        },
                        "ruleQueryName": {
                            "description": "The name of the query to apply the reference table to.",
                            "type": "string",
                        },
                        "tableName": {
                            "description": "The name of the reference table.",
                            "type": "string",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "schedulingOptions": {
                "description": "Options for scheduled rules. "
                "When this field is present, the "
                "rule runs based on the schedule. "
                "When absent, it runs real-time "
                "on ingested logs.",
                "nullable": True,
                "properties": {
                    "rrule": {
                        "description": "Schedule "
                        "for the "
                        "rule "
                        "queries, "
                        "written "
                        "in "
                        "RRULE "
                        "syntax. "
                        "See "
                        "[RFC](https://icalendar.org/iCalendar-RFC-5545/3-8-5-3-recurrence-rule.html) "
                        "for "
                        "syntax "
                        "reference.",
                        "example": "FREQ=HOURLY;INTERVAL=1;",
                        "type": "string",
                    },
                    "start": {
                        "description": "Start "
                        "date "
                        "for the "
                        "schedule, "
                        "in ISO "
                        "8601 "
                        "format "
                        "without "
                        "timezone.",
                        "example": "2025-07-14T12:00:00",
                        "type": "string",
                    },
                    "timezone": {
                        "description": "Time "
                        "zone "
                        "of "
                        "the "
                        "start "
                        "date, "
                        "in "
                        "the "
                        "[tz "
                        "database](https://en.wikipedia.org/wiki/List_of_tz_database_time_zones) "
                        "format.",
                        "example": "America/New_York",
                        "type": "string",
                    },
                },
                "type": "object",
            },
            "tags": {
                "description": "Tags for generated signals.",
                "items": {"description": "Tag.", "type": "string"},
                "type": "array",
            },
            "thirdPartyCases": {
                "description": "Cases for generating signals from "
                "third-party rules. Only available "
                "for third-party rules.",
                "example": [],
                "items": {
                    "description": "Case when signal is generated by a third party rule.",
                    "properties": {
                        "customStatus": {
                            "description": "Severity of the Security Signal.",
                            "enum": ["info", "low", "medium", "high", "critical"],
                            "example": "critical",
                            "type": "string",
                            "x-enum-varnames": ["INFO", "LOW", "MEDIUM", "HIGH", "CRITICAL"],
                        },
                        "name": {"description": "Name of the case.", "type": "string"},
                        "notifications": {
                            "description": "Notification targets for each rule case.",
                            "items": {"description": "Notification.", "type": "string"},
                            "type": "array",
                        },
                        "query": {
                            "description": "A query to map a third party event to this case.",
                            "type": "string",
                        },
                        "status": {
                            "description": "Severity of the Security Signal.",
                            "enum": ["info", "low", "medium", "high", "critical"],
                            "example": "critical",
                            "type": "string",
                            "x-enum-varnames": ["INFO", "LOW", "MEDIUM", "HIGH", "CRITICAL"],
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
            "version": {
                "description": "The version of the rule being updated.",
                "example": 1,
                "format": "int32",
                "maximum": 2147483647,
                "type": "integer",
            },
        },
        "type": "object",
    },
    "TESTSECURITYMONITORINGRULE_REQUEST_BODY_SCHEMA": {
        "description": "Test the rule queries of a rule (rule property is ignored when "
        "applied to an existing rule)",
        "properties": {
            "rule": {
                "description": "Test a rule.",
                "oneOf": [
                    {
                        "description": "The payload of a rule to test",
                        "properties": {
                            "calculatedFields": {
                                "description": "Calculated "
                                "fields. "
                                "Only "
                                "allowed "
                                "for "
                                "scheduled "
                                "rules "
                                "- "
                                "in "
                                "other "
                                "words, "
                                "when "
                                "schedulingOptions "
                                "is "
                                "also "
                                "defined.",
                                "items": {
                                    "description": "Calculated field.",
                                    "properties": {
                                        "expression": {
                                            "description": "Expression.",
                                            "example": "@request_end_timestamp "
                                            "- "
                                            "@request_start_timestamp",
                                            "type": "string",
                                        },
                                        "name": {
                                            "description": "Field name.",
                                            "example": "response_time",
                                            "type": "string",
                                        },
                                    },
                                    "required": ["name", "expression"],
                                    "type": "object",
                                },
                                "type": "array",
                            },
                            "cases": {
                                "description": "Cases for generating signals.",
                                "example": [],
                                "items": {
                                    "description": "Case when signal is generated.",
                                    "properties": {
                                        "actions": {
                                            "description": "Action to perform for each rule case.",
                                            "items": {
                                                "description": "Action "
                                                "to "
                                                "perform "
                                                "when "
                                                "a "
                                                "signal "
                                                "is "
                                                "triggered. "
                                                "Only "
                                                "available "
                                                "for "
                                                "Application "
                                                "Security "
                                                "rule "
                                                "type.",
                                                "properties": {
                                                    "options": {
                                                        "additionalProperties": {},
                                                        "description": "Options "
                                                        "for "
                                                        "the "
                                                        "rule "
                                                        "action",
                                                        "properties": {
                                                            "duration": {
                                                                "description": "Duration "
                                                                "of "
                                                                "the "
                                                                "action "
                                                                "in "
                                                                "seconds. "
                                                                "0 "
                                                                "indicates "
                                                                "no "
                                                                "expiration.",
                                                                "example": 0,
                                                                "format": "int64",
                                                                "minimum": 0,
                                                                "type": "integer",
                                                            },
                                                            "flaggedIPType": {
                                                                "description": "Used "
                                                                "with "
                                                                "the "
                                                                "case "
                                                                "action "
                                                                "of "
                                                                "type "
                                                                "'flag_ip'. "
                                                                "The "
                                                                "value "
                                                                "specified "
                                                                "in "
                                                                "this "
                                                                "field "
                                                                "is "
                                                                "applied "
                                                                "as "
                                                                "a "
                                                                "flag "
                                                                "to "
                                                                "the "
                                                                "IP "
                                                                "addresses.",
                                                                "enum": ["SUSPICIOUS", "FLAGGED"],
                                                                "example": "FLAGGED",
                                                                "type": "string",
                                                                "x-enum-varnames": [
                                                                    "SUSPICIOUS",
                                                                    "FLAGGED",
                                                                ],
                                                            },
                                                            "userBehaviorName": {
                                                                "description": "Used "
                                                                "with "
                                                                "the "
                                                                "case "
                                                                "action "
                                                                "of "
                                                                "type "
                                                                "'user_behavior'. "
                                                                "The "
                                                                "value "
                                                                "specified "
                                                                "in "
                                                                "this "
                                                                "field "
                                                                "is "
                                                                "applied "
                                                                "as "
                                                                "a "
                                                                "risk "
                                                                "tag "
                                                                "to "
                                                                "all "
                                                                "users "
                                                                "affected "
                                                                "by "
                                                                "the "
                                                                "rule.",
                                                                "type": "string",
                                                            },
                                                        },
                                                        "type": "object",
                                                    },
                                                    "type": {
                                                        "description": "The action type.",
                                                        "enum": [
                                                            "block_ip",
                                                            "block_user",
                                                            "user_behavior",
                                                            "flag_ip",
                                                        ],
                                                        "type": "string",
                                                        "x-enum-varnames": [
                                                            "BLOCK_IP",
                                                            "BLOCK_USER",
                                                            "USER_BEHAVIOR",
                                                            "FLAG_IP",
                                                        ],
                                                    },
                                                },
                                                "type": "object",
                                            },
                                            "type": "array",
                                        },
                                        "condition": {
                                            "description": "A "
                                            "case "
                                            "contains "
                                            "logical "
                                            "operations "
                                            "(`>`,`>=`, "
                                            "`&&`, "
                                            "`||`) "
                                            "to "
                                            "determine "
                                            "if "
                                            "a "
                                            "signal "
                                            "should "
                                            "be "
                                            "generated\n"
                                            "based "
                                            "on "
                                            "the "
                                            "event "
                                            "counts "
                                            "in "
                                            "the "
                                            "previously "
                                            "defined "
                                            "queries.",
                                            "type": "string",
                                        },
                                        "name": {
                                            "description": "Name of the case.",
                                            "type": "string",
                                        },
                                        "notifications": {
                                            "description": "Notification targets.",
                                            "items": {
                                                "description": "Notification.",
                                                "type": "string",
                                            },
                                            "type": "array",
                                        },
                                        "status": {
                                            "description": "Severity of the Security Signal.",
                                            "enum": ["info", "low", "medium", "high", "critical"],
                                            "example": "critical",
                                            "type": "string",
                                            "x-enum-varnames": [
                                                "INFO",
                                                "LOW",
                                                "MEDIUM",
                                                "HIGH",
                                                "CRITICAL",
                                            ],
                                        },
                                    },
                                    "required": ["status"],
                                    "type": "object",
                                },
                                "type": "array",
                            },
                            "filters": {
                                "description": "Additional "
                                "queries "
                                "to "
                                "filter "
                                "matched "
                                "events "
                                "before "
                                "they "
                                "are "
                                "processed. "
                                "This "
                                "field "
                                "is "
                                "deprecated "
                                "for log "
                                "detection, "
                                "signal "
                                "correlation, "
                                "and "
                                "workload "
                                "security "
                                "rules.",
                                "items": {
                                    "description": "The rule's suppression filter.",
                                    "properties": {
                                        "action": {
                                            "description": "The type of filtering action.",
                                            "enum": ["require", "suppress"],
                                            "type": "string",
                                            "x-enum-varnames": ["REQUIRE", "SUPPRESS"],
                                        },
                                        "query": {
                                            "description": "Query "
                                            "for "
                                            "selecting "
                                            "logs "
                                            "to "
                                            "apply "
                                            "the "
                                            "filtering "
                                            "action.",
                                            "type": "string",
                                        },
                                    },
                                    "type": "object",
                                },
                                "type": "array",
                            },
                            "groupSignalsBy": {
                                "description": "Additional "
                                "grouping "
                                "to "
                                "perform "
                                "on "
                                "top "
                                "of "
                                "the "
                                "existing "
                                "groups "
                                "in "
                                "the "
                                "query "
                                "section. "
                                "Must "
                                "be "
                                "a "
                                "subset "
                                "of "
                                "the "
                                "existing "
                                "groups.",
                                "example": ["service"],
                                "items": {"description": "Field to group by.", "type": "string"},
                                "type": "array",
                            },
                            "hasExtendedTitle": {
                                "description": "Whether "
                                "the "
                                "notifications "
                                "include "
                                "the "
                                "triggering "
                                "group-by "
                                "values "
                                "in "
                                "their "
                                "title.",
                                "example": True,
                                "type": "boolean",
                            },
                            "isEnabled": {
                                "description": "Whether the rule is enabled.",
                                "example": True,
                                "type": "boolean",
                            },
                            "message": {
                                "description": "Message for generated signals.",
                                "example": "",
                                "type": "string",
                            },
                            "name": {
                                "description": "The name of the rule.",
                                "example": "My security monitoring rule.",
                                "type": "string",
                            },
                            "options": {
                                "description": "Options.",
                                "properties": {
                                    "complianceRuleOptions": {
                                        "additionalProperties": {},
                                        "description": "Options "
                                        "for "
                                        "cloud_configuration "
                                        "rules.\n"
                                        "Fields "
                                        "`resourceType` "
                                        "and "
                                        "`regoRule` "
                                        "are "
                                        "mandatory "
                                        "when "
                                        "managing "
                                        "custom "
                                        "`cloud_configuration` "
                                        "rules.",
                                        "properties": {
                                            "complexRule": {
                                                "description": "Whether "
                                                "the "
                                                "rule "
                                                "is "
                                                "a "
                                                "complex "
                                                "one.\n"
                                                "Must "
                                                "be "
                                                "set "
                                                "to "
                                                "true "
                                                "if "
                                                "`regoRule.resourceTypes` "
                                                "contains "
                                                "more "
                                                "than "
                                                "one "
                                                "item. "
                                                "Defaults "
                                                "to "
                                                "false.",
                                                "type": "boolean",
                                            },
                                            "regoRule": {
                                                "description": "Rule details.",
                                                "properties": {
                                                    "policy": {
                                                        "description": "The "
                                                        "policy "
                                                        "written "
                                                        "in "
                                                        "`rego`, "
                                                        "see: "
                                                        "https://www.openpolicyagent.org/docs/latest/policy-language/",
                                                        "example": "package "
                                                        "datadog\n"
                                                        "\n"
                                                        "import "
                                                        "data.datadog.output "
                                                        "as "
                                                        "dd_output\n"
                                                        "import "
                                                        "future.keywords.contains\n"
                                                        "import "
                                                        "future.keywords.if\n"
                                                        "import "
                                                        "future.keywords.in\n"
                                                        "\n"
                                                        "eval(resource) "
                                                        "= "
                                                        '"skip" '
                                                        "if "
                                                        "{\n"
                                                        "  "
                                                        "# "
                                                        "Logic "
                                                        "that "
                                                        "evaluates "
                                                        "to "
                                                        "true "
                                                        "if "
                                                        "the "
                                                        "resource "
                                                        "should "
                                                        "be "
                                                        "skipped\n"
                                                        "  "
                                                        "true\n"
                                                        "} "
                                                        "else "
                                                        "= "
                                                        '"pass" '
                                                        "{\n"
                                                        "  "
                                                        "# "
                                                        "Logic "
                                                        "that "
                                                        "evaluates "
                                                        "to "
                                                        "true "
                                                        "if "
                                                        "the "
                                                        "resource "
                                                        "is "
                                                        "compliant\n"
                                                        "  "
                                                        "true\n"
                                                        "} "
                                                        "else "
                                                        "= "
                                                        '"fail" '
                                                        "{\n"
                                                        "  "
                                                        "# "
                                                        "Logic "
                                                        "that "
                                                        "evaluates "
                                                        "to "
                                                        "true "
                                                        "if "
                                                        "the "
                                                        "resource "
                                                        "is "
                                                        "not "
                                                        "compliant\n"
                                                        "  "
                                                        "true\n"
                                                        "}\n"
                                                        "\n"
                                                        "# "
                                                        "This "
                                                        "part "
                                                        "remains "
                                                        "unchanged "
                                                        "for "
                                                        "all "
                                                        "rules\n"
                                                        "results "
                                                        "contains "
                                                        "result "
                                                        "if "
                                                        "{\n"
                                                        "  "
                                                        "some "
                                                        "resource "
                                                        "in "
                                                        "input.resources[input.main_resource_type]\n"
                                                        "  "
                                                        "result "
                                                        ":= "
                                                        "dd_output.format(resource, "
                                                        "eval(resource))\n"
                                                        "}",
                                                        "type": "string",
                                                    },
                                                    "resourceTypes": {
                                                        "description": "List "
                                                        "of "
                                                        "resource "
                                                        "types "
                                                        "that "
                                                        "will "
                                                        "be "
                                                        "evaluated "
                                                        "upon. "
                                                        "Must "
                                                        "have "
                                                        "at "
                                                        "least "
                                                        "one "
                                                        "element.",
                                                        "example": [
                                                            "gcp_iam_service_account",
                                                            "gcp_iam_policy",
                                                        ],
                                                        "items": {"type": "string"},
                                                        "type": "array",
                                                    },
                                                },
                                                "required": ["policy", "resourceTypes"],
                                                "type": "object",
                                            },
                                            "resourceType": {
                                                "description": "Main "
                                                "resource "
                                                "type "
                                                "to "
                                                "be "
                                                "checked "
                                                "by "
                                                "the "
                                                "rule. "
                                                "It "
                                                "should "
                                                "be "
                                                "specified "
                                                "again "
                                                "in "
                                                "`regoRule.resourceTypes`.",
                                                "example": "aws_acm",
                                                "type": "string",
                                            },
                                        },
                                        "type": "object",
                                    },
                                    "decreaseCriticalityBasedOnEnv": {
                                        "description": "If "
                                        "true, "
                                        "signals "
                                        "in "
                                        "non-production "
                                        "environments "
                                        "have "
                                        "a "
                                        "lower "
                                        "severity "
                                        "than "
                                        "what "
                                        "is "
                                        "defined "
                                        "by "
                                        "the "
                                        "rule "
                                        "case, "
                                        "which "
                                        "can "
                                        "reduce "
                                        "signal "
                                        "noise.\n"
                                        "The "
                                        "severity "
                                        "is "
                                        "decreased "
                                        "by "
                                        "one "
                                        "level: "
                                        "`CRITICAL` "
                                        "in "
                                        "production "
                                        "becomes "
                                        "`HIGH` "
                                        "in "
                                        "non-production, "
                                        "`HIGH` "
                                        "becomes "
                                        "`MEDIUM` "
                                        "and "
                                        "so "
                                        "on. "
                                        "`INFO` "
                                        "remains "
                                        "`INFO`.\n"
                                        "The "
                                        "decrement "
                                        "is "
                                        "applied "
                                        "when "
                                        "the "
                                        "environment "
                                        "tag "
                                        "of "
                                        "the "
                                        "signal "
                                        "starts "
                                        "with "
                                        "`staging`, "
                                        "`test` "
                                        "or "
                                        "`dev`.",
                                        "example": False,
                                        "type": "boolean",
                                    },
                                    "detectionMethod": {
                                        "description": "The detection method.",
                                        "enum": [
                                            "threshold",
                                            "new_value",
                                            "anomaly_detection",
                                            "impossible_travel",
                                            "hardcoded",
                                            "third_party",
                                            "anomaly_threshold",
                                            "sequence_detection",
                                        ],
                                        "type": "string",
                                        "x-enum-varnames": [
                                            "THRESHOLD",
                                            "NEW_VALUE",
                                            "ANOMALY_DETECTION",
                                            "IMPOSSIBLE_TRAVEL",
                                            "HARDCODED",
                                            "THIRD_PARTY",
                                            "ANOMALY_THRESHOLD",
                                            "SEQUENCE_DETECTION",
                                        ],
                                    },
                                    "evaluationWindow": {
                                        "description": "A "
                                        "time "
                                        "window "
                                        "is "
                                        "specified "
                                        "to "
                                        "match "
                                        "when "
                                        "at "
                                        "least "
                                        "one "
                                        "of "
                                        "the "
                                        "cases "
                                        "matches "
                                        "true. "
                                        "This "
                                        "is "
                                        "a "
                                        "sliding "
                                        "window\n"
                                        "and "
                                        "evaluates "
                                        "in "
                                        "real "
                                        "time. "
                                        "For "
                                        "third "
                                        "party "
                                        "detection "
                                        "method, "
                                        "this "
                                        "field "
                                        "is "
                                        "not "
                                        "used.",
                                        "enum": [
                                            0,
                                            60,
                                            300,
                                            600,
                                            900,
                                            1800,
                                            3600,
                                            7200,
                                            10800,
                                            21600,
                                            43200,
                                            86400,
                                        ],
                                        "format": "int32",
                                        "type": "integer",
                                        "x-enum-varnames": [
                                            "ZERO_MINUTES",
                                            "ONE_MINUTE",
                                            "FIVE_MINUTES",
                                            "TEN_MINUTES",
                                            "FIFTEEN_MINUTES",
                                            "THIRTY_MINUTES",
                                            "ONE_HOUR",
                                            "TWO_HOURS",
                                            "THREE_HOURS",
                                            "SIX_HOURS",
                                            "TWELVE_HOURS",
                                            "ONE_DAY",
                                        ],
                                    },
                                    "hardcodedEvaluatorType": {
                                        "description": "Hardcoded evaluator type.",
                                        "enum": ["log4shell"],
                                        "type": "string",
                                        "x-enum-varnames": ["LOG4SHELL"],
                                    },
                                    "impossibleTravelOptions": {
                                        "description": "Options "
                                        "on "
                                        "impossible "
                                        "travel "
                                        "detection "
                                        "method.",
                                        "properties": {
                                            "baselineUserLocations": {
                                                "description": "If "
                                                "true, "
                                                "signals "
                                                "are "
                                                "suppressed "
                                                "for "
                                                "the "
                                                "first "
                                                "24 "
                                                "hours. "
                                                "In "
                                                "that "
                                                "time, "
                                                "Datadog "
                                                "learns "
                                                "the "
                                                "user's "
                                                "regular\n"
                                                "access "
                                                "locations. "
                                                "This "
                                                "can "
                                                "be "
                                                "helpful "
                                                "to "
                                                "reduce "
                                                "noise "
                                                "and "
                                                "infer "
                                                "VPN "
                                                "usage "
                                                "or "
                                                "credentialed "
                                                "API "
                                                "access.",
                                                "example": True,
                                                "type": "boolean",
                                            }
                                        },
                                        "type": "object",
                                    },
                                    "keepAlive": {
                                        "description": "Once "
                                        "a "
                                        "signal "
                                        "is "
                                        "generated, "
                                        "the "
                                        "signal "
                                        "will "
                                        "remain "
                                        '"open" '
                                        "if "
                                        "a "
                                        "case "
                                        "is "
                                        "matched "
                                        "at "
                                        "least "
                                        "once "
                                        "within\n"
                                        "this "
                                        "keep "
                                        "alive "
                                        "window. "
                                        "For "
                                        "third "
                                        "party "
                                        "detection "
                                        "method, "
                                        "this "
                                        "field "
                                        "is "
                                        "not "
                                        "used.",
                                        "enum": [
                                            0,
                                            60,
                                            300,
                                            600,
                                            900,
                                            1800,
                                            3600,
                                            7200,
                                            10800,
                                            21600,
                                            43200,
                                            86400,
                                        ],
                                        "format": "int32",
                                        "type": "integer",
                                        "x-enum-varnames": [
                                            "ZERO_MINUTES",
                                            "ONE_MINUTE",
                                            "FIVE_MINUTES",
                                            "TEN_MINUTES",
                                            "FIFTEEN_MINUTES",
                                            "THIRTY_MINUTES",
                                            "ONE_HOUR",
                                            "TWO_HOURS",
                                            "THREE_HOURS",
                                            "SIX_HOURS",
                                            "TWELVE_HOURS",
                                            "ONE_DAY",
                                        ],
                                    },
                                    "maxSignalDuration": {
                                        "description": "A "
                                        "signal "
                                        "will "
                                        '"close" '
                                        "regardless "
                                        "of "
                                        "the "
                                        "query "
                                        "being "
                                        "matched "
                                        "once "
                                        "the "
                                        "time "
                                        "exceeds "
                                        "the "
                                        "maximum "
                                        "duration.\n"
                                        "This "
                                        "time "
                                        "is "
                                        "calculated "
                                        "from "
                                        "the "
                                        "first "
                                        "seen "
                                        "timestamp.",
                                        "enum": [
                                            0,
                                            60,
                                            300,
                                            600,
                                            900,
                                            1800,
                                            3600,
                                            7200,
                                            10800,
                                            21600,
                                            43200,
                                            86400,
                                        ],
                                        "format": "int32",
                                        "type": "integer",
                                        "x-enum-varnames": [
                                            "ZERO_MINUTES",
                                            "ONE_MINUTE",
                                            "FIVE_MINUTES",
                                            "TEN_MINUTES",
                                            "FIFTEEN_MINUTES",
                                            "THIRTY_MINUTES",
                                            "ONE_HOUR",
                                            "TWO_HOURS",
                                            "THREE_HOURS",
                                            "SIX_HOURS",
                                            "TWELVE_HOURS",
                                            "ONE_DAY",
                                        ],
                                    },
                                    "newValueOptions": {
                                        "description": "Options on new value detection method.",
                                        "properties": {
                                            "forgetAfter": {
                                                "description": "The "
                                                "duration "
                                                "in "
                                                "days "
                                                "after "
                                                "which "
                                                "a "
                                                "learned "
                                                "value "
                                                "is "
                                                "forgotten.",
                                                "enum": [1, 2, 7, 14, 21, 28],
                                                "format": "int32",
                                                "type": "integer",
                                                "x-enum-varnames": [
                                                    "ONE_DAY",
                                                    "TWO_DAYS",
                                                    "ONE_WEEK",
                                                    "TWO_WEEKS",
                                                    "THREE_WEEKS",
                                                    "FOUR_WEEKS",
                                                ],
                                            },
                                            "learningDuration": {
                                                "default": 0,
                                                "description": "The "
                                                "duration "
                                                "in "
                                                "days "
                                                "during "
                                                "which "
                                                "values "
                                                "are "
                                                "learned, "
                                                "and "
                                                "after "
                                                "which "
                                                "signals "
                                                "will "
                                                "be "
                                                "generated "
                                                "for "
                                                "values "
                                                "that\n"
                                                "weren't "
                                                "learned. "
                                                "If "
                                                "set "
                                                "to "
                                                "0, "
                                                "a "
                                                "signal "
                                                "will "
                                                "be "
                                                "generated "
                                                "for "
                                                "all "
                                                "new "
                                                "values "
                                                "after "
                                                "the "
                                                "first "
                                                "value "
                                                "is "
                                                "learned.",
                                                "enum": [0, 1, 7],
                                                "format": "int32",
                                                "type": "integer",
                                                "x-enum-varnames": [
                                                    "ZERO_DAYS",
                                                    "ONE_DAY",
                                                    "SEVEN_DAYS",
                                                ],
                                            },
                                            "learningMethod": {
                                                "default": "duration",
                                                "description": "The "
                                                "learning "
                                                "method "
                                                "used "
                                                "to "
                                                "determine "
                                                "when "
                                                "signals "
                                                "should "
                                                "be "
                                                "generated "
                                                "for "
                                                "values "
                                                "that "
                                                "weren't "
                                                "learned.",
                                                "enum": ["duration", "threshold"],
                                                "type": "string",
                                                "x-enum-varnames": ["DURATION", "THRESHOLD"],
                                            },
                                            "learningThreshold": {
                                                "default": 0,
                                                "description": "A "
                                                "number "
                                                "of "
                                                "occurrences "
                                                "after "
                                                "which "
                                                "signals "
                                                "will "
                                                "be "
                                                "generated "
                                                "for "
                                                "values "
                                                "that "
                                                "weren't "
                                                "learned.",
                                                "enum": [0, 1],
                                                "format": "int32",
                                                "type": "integer",
                                                "x-enum-varnames": [
                                                    "ZERO_OCCURRENCES",
                                                    "ONE_OCCURRENCE",
                                                ],
                                            },
                                        },
                                        "type": "object",
                                    },
                                    "sequenceDetectionOptions": {
                                        "description": "Options on sequence detection method.",
                                        "properties": {
                                            "stepTransitions": {
                                                "description": "Transitions "
                                                "defining "
                                                "the "
                                                "allowed "
                                                "order "
                                                "of "
                                                "steps "
                                                "and "
                                                "their "
                                                "evaluation "
                                                "windows.",
                                                "items": {
                                                    "description": "Transition "
                                                    "from "
                                                    "a "
                                                    "parent "
                                                    "step "
                                                    "to "
                                                    "a "
                                                    "child "
                                                    "step "
                                                    "within "
                                                    "a "
                                                    "sequence "
                                                    "detection "
                                                    "rule.",
                                                    "properties": {
                                                        "child": {
                                                            "description": "Name "
                                                            "of "
                                                            "the "
                                                            "child "
                                                            "step.",
                                                            "type": "string",
                                                        },
                                                        "evaluationWindow": {
                                                            "description": "A "
                                                            "time "
                                                            "window "
                                                            "is "
                                                            "specified "
                                                            "to "
                                                            "match "
                                                            "when "
                                                            "at "
                                                            "least "
                                                            "one "
                                                            "of "
                                                            "the "
                                                            "cases "
                                                            "matches "
                                                            "true. "
                                                            "This "
                                                            "is "
                                                            "a "
                                                            "sliding "
                                                            "window\n"
                                                            "and "
                                                            "evaluates "
                                                            "in "
                                                            "real "
                                                            "time. "
                                                            "For "
                                                            "third "
                                                            "party "
                                                            "detection "
                                                            "method, "
                                                            "this "
                                                            "field "
                                                            "is "
                                                            "not "
                                                            "used.",
                                                            "enum": [
                                                                0,
                                                                60,
                                                                300,
                                                                600,
                                                                900,
                                                                1800,
                                                                3600,
                                                                7200,
                                                                10800,
                                                                21600,
                                                                43200,
                                                                86400,
                                                            ],
                                                            "format": "int32",
                                                            "type": "integer",
                                                            "x-enum-varnames": [
                                                                "ZERO_MINUTES",
                                                                "ONE_MINUTE",
                                                                "FIVE_MINUTES",
                                                                "TEN_MINUTES",
                                                                "FIFTEEN_MINUTES",
                                                                "THIRTY_MINUTES",
                                                                "ONE_HOUR",
                                                                "TWO_HOURS",
                                                                "THREE_HOURS",
                                                                "SIX_HOURS",
                                                                "TWELVE_HOURS",
                                                                "ONE_DAY",
                                                            ],
                                                        },
                                                        "parent": {
                                                            "description": "Name "
                                                            "of "
                                                            "the "
                                                            "parent "
                                                            "step.",
                                                            "type": "string",
                                                        },
                                                    },
                                                    "type": "object",
                                                },
                                                "type": "array",
                                            },
                                            "steps": {
                                                "description": "Steps "
                                                "that "
                                                "define "
                                                "the "
                                                "conditions "
                                                "to "
                                                "be "
                                                "matched "
                                                "in "
                                                "sequence.",
                                                "items": {
                                                    "description": "Step "
                                                    "definition "
                                                    "for "
                                                    "sequence "
                                                    "detection "
                                                    "containing "
                                                    "the "
                                                    "step "
                                                    "name, "
                                                    "condition, "
                                                    "and "
                                                    "evaluation "
                                                    "window.",
                                                    "properties": {
                                                        "condition": {
                                                            "description": "Condition "
                                                            "referencing "
                                                            "rule "
                                                            "queries "
                                                            "(e.g., "
                                                            "`a "
                                                            "> "
                                                            "0`).",
                                                            "type": "string",
                                                        },
                                                        "evaluationWindow": {
                                                            "description": "A "
                                                            "time "
                                                            "window "
                                                            "is "
                                                            "specified "
                                                            "to "
                                                            "match "
                                                            "when "
                                                            "at "
                                                            "least "
                                                            "one "
                                                            "of "
                                                            "the "
                                                            "cases "
                                                            "matches "
                                                            "true. "
                                                            "This "
                                                            "is "
                                                            "a "
                                                            "sliding "
                                                            "window\n"
                                                            "and "
                                                            "evaluates "
                                                            "in "
                                                            "real "
                                                            "time. "
                                                            "For "
                                                            "third "
                                                            "party "
                                                            "detection "
                                                            "method, "
                                                            "this "
                                                            "field "
                                                            "is "
                                                            "not "
                                                            "used.",
                                                            "enum": [
                                                                0,
                                                                60,
                                                                300,
                                                                600,
                                                                900,
                                                                1800,
                                                                3600,
                                                                7200,
                                                                10800,
                                                                21600,
                                                                43200,
                                                                86400,
                                                            ],
                                                            "format": "int32",
                                                            "type": "integer",
                                                            "x-enum-varnames": [
                                                                "ZERO_MINUTES",
                                                                "ONE_MINUTE",
                                                                "FIVE_MINUTES",
                                                                "TEN_MINUTES",
                                                                "FIFTEEN_MINUTES",
                                                                "THIRTY_MINUTES",
                                                                "ONE_HOUR",
                                                                "TWO_HOURS",
                                                                "THREE_HOURS",
                                                                "SIX_HOURS",
                                                                "TWELVE_HOURS",
                                                                "ONE_DAY",
                                                            ],
                                                        },
                                                        "name": {
                                                            "description": "Unique "
                                                            "name "
                                                            "identifying "
                                                            "the "
                                                            "step.",
                                                            "type": "string",
                                                        },
                                                    },
                                                    "type": "object",
                                                },
                                                "type": "array",
                                            },
                                        },
                                        "type": "object",
                                    },
                                    "thirdPartyRuleOptions": {
                                        "description": "Options on third party detection method.",
                                        "properties": {
                                            "defaultNotifications": {
                                                "description": "Notification "
                                                "targets "
                                                "for "
                                                "the "
                                                "logs "
                                                "that "
                                                "do "
                                                "not "
                                                "correspond "
                                                "to "
                                                "any "
                                                "of "
                                                "the "
                                                "cases.",
                                                "items": {
                                                    "description": "Notification.",
                                                    "type": "string",
                                                },
                                                "type": "array",
                                            },
                                            "defaultStatus": {
                                                "description": "Severity of the Security Signal.",
                                                "enum": [
                                                    "info",
                                                    "low",
                                                    "medium",
                                                    "high",
                                                    "critical",
                                                ],
                                                "example": "critical",
                                                "type": "string",
                                                "x-enum-varnames": [
                                                    "INFO",
                                                    "LOW",
                                                    "MEDIUM",
                                                    "HIGH",
                                                    "CRITICAL",
                                                ],
                                            },
                                            "rootQueries": {
                                                "description": "Queries "
                                                "to "
                                                "be "
                                                "combined "
                                                "with "
                                                "third "
                                                "party "
                                                "case "
                                                "queries. "
                                                "Each "
                                                "of "
                                                "them "
                                                "can "
                                                "have "
                                                "different "
                                                "group "
                                                "by "
                                                "fields, "
                                                "to "
                                                "aggregate "
                                                "differently "
                                                "based "
                                                "on "
                                                "the "
                                                "type "
                                                "of "
                                                "alert.",
                                                "items": {
                                                    "description": "A "
                                                    "query "
                                                    "to "
                                                    "be "
                                                    "combined "
                                                    "with "
                                                    "the "
                                                    "third "
                                                    "party "
                                                    "case "
                                                    "query.",
                                                    "properties": {
                                                        "groupByFields": {
                                                            "description": "Fields to group by.",
                                                            "items": {
                                                                "description": "Field.",
                                                                "type": "string",
                                                            },
                                                            "type": "array",
                                                        },
                                                        "query": {
                                                            "description": "Query to run on logs.",
                                                            "example": "source:cloudtrail",
                                                            "type": "string",
                                                        },
                                                    },
                                                    "type": "object",
                                                },
                                                "type": "array",
                                            },
                                            "signalTitleTemplate": {
                                                "description": "A "
                                                "template "
                                                "for "
                                                "the "
                                                "signal "
                                                "title; "
                                                "if "
                                                "omitted, "
                                                "the "
                                                "title "
                                                "is "
                                                "generated "
                                                "based "
                                                "on "
                                                "the "
                                                "case "
                                                "name.",
                                                "type": "string",
                                            },
                                        },
                                        "type": "object",
                                    },
                                },
                                "type": "object",
                            },
                            "queries": {
                                "description": "Queries "
                                "for "
                                "selecting "
                                "logs "
                                "which "
                                "are "
                                "part of "
                                "the "
                                "rule.",
                                "example": [],
                                "items": {
                                    "description": "Query for matching rule.",
                                    "properties": {
                                        "aggregation": {
                                            "description": "The aggregation type.",
                                            "enum": [
                                                "count",
                                                "cardinality",
                                                "sum",
                                                "max",
                                                "new_value",
                                                "geo_data",
                                                "event_count",
                                                "none",
                                            ],
                                            "type": "string",
                                            "x-enum-varnames": [
                                                "COUNT",
                                                "CARDINALITY",
                                                "SUM",
                                                "MAX",
                                                "NEW_VALUE",
                                                "GEO_DATA",
                                                "EVENT_COUNT",
                                                "NONE",
                                            ],
                                        },
                                        "customQueryExtension": {
                                            "description": "Query "
                                            "extension "
                                            "to "
                                            "append "
                                            "to "
                                            "the "
                                            "logs "
                                            "query.",
                                            "example": "a > 3",
                                            "type": "string",
                                        },
                                        "dataSource": {
                                            "default": "logs",
                                            "description": "Source "
                                            "of "
                                            "events, "
                                            "either "
                                            "logs, "
                                            "audit "
                                            "trail, "
                                            "or "
                                            "Datadog "
                                            "events.",
                                            "enum": [
                                                "logs",
                                                "audit",
                                                "app_sec_spans",
                                                "spans",
                                                "security_runtime",
                                                "network",
                                                "events",
                                            ],
                                            "example": "logs",
                                            "type": "string",
                                            "x-enum-varnames": [
                                                "LOGS",
                                                "AUDIT",
                                                "APP_SEC_SPANS",
                                                "SPANS",
                                                "SECURITY_RUNTIME",
                                                "NETWORK",
                                                "EVENTS",
                                            ],
                                        },
                                        "distinctFields": {
                                            "description": "Field "
                                            "for "
                                            "which "
                                            "the "
                                            "cardinality "
                                            "is "
                                            "measured. "
                                            "Sent "
                                            "as "
                                            "an "
                                            "array.",
                                            "items": {"description": "Field.", "type": "string"},
                                            "type": "array",
                                        },
                                        "groupByFields": {
                                            "description": "Fields to group by.",
                                            "items": {"description": "Field.", "type": "string"},
                                            "type": "array",
                                        },
                                        "hasOptionalGroupByFields": {
                                            "default": False,
                                            "description": "When "
                                            "false, "
                                            "events "
                                            "without "
                                            "a "
                                            "group-by "
                                            "value "
                                            "are "
                                            "ignored "
                                            "by "
                                            "the "
                                            "rule. "
                                            "When "
                                            "true, "
                                            "events "
                                            "with "
                                            "missing "
                                            "group-by "
                                            "fields "
                                            "are "
                                            "processed "
                                            "with "
                                            "`N/A`, "
                                            "replacing "
                                            "the "
                                            "missing "
                                            "values.",
                                            "example": False,
                                            "type": "boolean",
                                        },
                                        "index": {
                                            "description": "**This "
                                            "field "
                                            "is "
                                            "currently "
                                            "unstable "
                                            "and "
                                            "might "
                                            "be "
                                            "removed "
                                            "in "
                                            "a "
                                            "minor "
                                            "version "
                                            "upgrade.**\n"
                                            "The "
                                            "index "
                                            "to "
                                            "run "
                                            "the "
                                            "query "
                                            "on, "
                                            "if "
                                            "the "
                                            "`dataSource` "
                                            "is "
                                            "`logs`. "
                                            "Only "
                                            "used "
                                            "for "
                                            "scheduled "
                                            "rules "
                                            "- "
                                            "in "
                                            "other "
                                            "words, "
                                            "when "
                                            "the "
                                            "`schedulingOptions` "
                                            "field "
                                            "is "
                                            "present "
                                            "in "
                                            "the "
                                            "rule "
                                            "payload.",
                                            "type": "string",
                                        },
                                        "indexes": {
                                            "description": "List "
                                            "of "
                                            "indexes "
                                            "to "
                                            "query "
                                            "when "
                                            "the "
                                            "`dataSource` "
                                            "is "
                                            "`logs`. "
                                            "Only "
                                            "used "
                                            "for "
                                            "scheduled "
                                            "rules, "
                                            "such "
                                            "as "
                                            "when "
                                            "the "
                                            "`schedulingOptions` "
                                            "field "
                                            "is "
                                            "present "
                                            "in "
                                            "the "
                                            "rule "
                                            "payload.",
                                            "items": {"description": "Index.", "type": "string"},
                                            "type": "array",
                                        },
                                        "metric": {
                                            "deprecated": True,
                                            "description": "(Deprecated) "
                                            "The "
                                            "target "
                                            "field "
                                            "to "
                                            "aggregate "
                                            "over "
                                            "when "
                                            "using "
                                            "the "
                                            "sum "
                                            "or "
                                            "max\n"
                                            "aggregations. "
                                            "`metrics` "
                                            "field "
                                            "should "
                                            "be "
                                            "used "
                                            "instead.",
                                            "type": "string",
                                        },
                                        "metrics": {
                                            "description": "Group "
                                            "of "
                                            "target "
                                            "fields "
                                            "to "
                                            "aggregate "
                                            "over "
                                            "when "
                                            "using "
                                            "the "
                                            "sum, "
                                            "max, "
                                            "geo "
                                            "data, "
                                            "or "
                                            "new "
                                            "value "
                                            "aggregations. "
                                            "The "
                                            "sum, "
                                            "max, "
                                            "and "
                                            "geo "
                                            "data "
                                            "aggregations "
                                            "only "
                                            "accept "
                                            "one "
                                            "value "
                                            "in "
                                            "this "
                                            "list, "
                                            "whereas "
                                            "the "
                                            "new "
                                            "value "
                                            "aggregation "
                                            "accepts "
                                            "up "
                                            "to "
                                            "five "
                                            "values.",
                                            "items": {"description": "Field.", "type": "string"},
                                            "type": "array",
                                        },
                                        "name": {
                                            "description": "Name of the query.",
                                            "type": "string",
                                        },
                                        "query": {
                                            "description": "Query to run on logs.",
                                            "example": "a > 3",
                                            "type": "string",
                                        },
                                    },
                                    "type": "object",
                                },
                                "type": "array",
                            },
                            "referenceTables": {
                                "description": "Reference tables for the rule.",
                                "items": {
                                    "description": "Reference tables used in the queries.",
                                    "properties": {
                                        "checkPresence": {
                                            "description": "Whether "
                                            "to "
                                            "include "
                                            "or "
                                            "exclude "
                                            "the "
                                            "matched "
                                            "values.",
                                            "type": "boolean",
                                        },
                                        "columnName": {
                                            "description": "The "
                                            "name "
                                            "of "
                                            "the "
                                            "column "
                                            "in "
                                            "the "
                                            "reference "
                                            "table.",
                                            "type": "string",
                                        },
                                        "logFieldPath": {
                                            "description": "The "
                                            "field "
                                            "in "
                                            "the "
                                            "log "
                                            "to "
                                            "match "
                                            "against "
                                            "the "
                                            "reference "
                                            "table.",
                                            "type": "string",
                                        },
                                        "ruleQueryName": {
                                            "description": "The "
                                            "name "
                                            "of "
                                            "the "
                                            "query "
                                            "to "
                                            "apply "
                                            "the "
                                            "reference "
                                            "table "
                                            "to.",
                                            "type": "string",
                                        },
                                        "tableName": {
                                            "description": "The name of the reference table.",
                                            "type": "string",
                                        },
                                    },
                                    "type": "object",
                                },
                                "type": "array",
                            },
                            "schedulingOptions": {
                                "description": "Options "
                                "for "
                                "scheduled "
                                "rules. "
                                "When "
                                "this "
                                "field "
                                "is "
                                "present, "
                                "the "
                                "rule "
                                "runs "
                                "based "
                                "on "
                                "the "
                                "schedule. "
                                "When "
                                "absent, "
                                "it "
                                "runs "
                                "real-time "
                                "on "
                                "ingested "
                                "logs.",
                                "nullable": True,
                                "properties": {
                                    "rrule": {
                                        "description": "Schedule "
                                        "for "
                                        "the "
                                        "rule "
                                        "queries, "
                                        "written "
                                        "in "
                                        "RRULE "
                                        "syntax. "
                                        "See "
                                        "[RFC](https://icalendar.org/iCalendar-RFC-5545/3-8-5-3-recurrence-rule.html) "
                                        "for "
                                        "syntax "
                                        "reference.",
                                        "example": "FREQ=HOURLY;INTERVAL=1;",
                                        "type": "string",
                                    },
                                    "start": {
                                        "description": "Start "
                                        "date "
                                        "for "
                                        "the "
                                        "schedule, "
                                        "in "
                                        "ISO "
                                        "8601 "
                                        "format "
                                        "without "
                                        "timezone.",
                                        "example": "2025-07-14T12:00:00",
                                        "type": "string",
                                    },
                                    "timezone": {
                                        "description": "Time "
                                        "zone "
                                        "of "
                                        "the "
                                        "start "
                                        "date, "
                                        "in "
                                        "the "
                                        "[tz "
                                        "database](https://en.wikipedia.org/wiki/List_of_tz_database_time_zones) "
                                        "format.",
                                        "example": "America/New_York",
                                        "type": "string",
                                    },
                                },
                                "type": "object",
                            },
                            "tags": {
                                "description": "Tags for generated signals.",
                                "example": ["env:prod", "team:security"],
                                "items": {"description": "Tag.", "type": "string"},
                                "type": "array",
                            },
                            "thirdPartyCases": {
                                "description": "Cases "
                                "for "
                                "generating "
                                "signals "
                                "from "
                                "third-party "
                                "rules. "
                                "Only "
                                "available "
                                "for "
                                "third-party "
                                "rules.",
                                "example": [],
                                "items": {
                                    "description": "Case "
                                    "when "
                                    "a "
                                    "signal "
                                    "is "
                                    "generated "
                                    "by "
                                    "a "
                                    "third "
                                    "party "
                                    "rule.",
                                    "properties": {
                                        "name": {
                                            "description": "Name of the case.",
                                            "type": "string",
                                        },
                                        "notifications": {
                                            "description": "Notification targets for each case.",
                                            "items": {
                                                "description": "Notification.",
                                                "type": "string",
                                            },
                                            "type": "array",
                                        },
                                        "query": {
                                            "description": "A "
                                            "query "
                                            "to "
                                            "map "
                                            "a "
                                            "third "
                                            "party "
                                            "event "
                                            "to "
                                            "this "
                                            "case.",
                                            "type": "string",
                                        },
                                        "status": {
                                            "description": "Severity of the Security Signal.",
                                            "enum": ["info", "low", "medium", "high", "critical"],
                                            "example": "critical",
                                            "type": "string",
                                            "x-enum-varnames": [
                                                "INFO",
                                                "LOW",
                                                "MEDIUM",
                                                "HIGH",
                                                "CRITICAL",
                                            ],
                                        },
                                    },
                                    "required": ["status"],
                                    "type": "object",
                                },
                                "type": "array",
                            },
                            "type": {
                                "description": "The rule type.",
                                "enum": ["log_detection"],
                                "type": "string",
                                "x-enum-varnames": ["LOG_DETECTION"],
                            },
                        },
                        "required": ["name", "isEnabled", "queries", "options", "cases", "message"],
                        "type": "object",
                    }
                ],
            },
            "ruleQueryPayloads": {
                "description": "Data payloads used to test rules query with the expected result.",
                "items": {
                    "description": "Payload to test a rule query with the expected result.",
                    "properties": {
                        "expectedResult": {
                            "description": "Expected result of the test.",
                            "example": True,
                            "type": "boolean",
                        },
                        "index": {
                            "description": "Index of the query under test.",
                            "example": 0,
                            "format": "int64",
                            "minimum": 0,
                            "type": "integer",
                        },
                        "payload": {
                            "additionalProperties": {},
                            "description": "Payload used to test the rule query.",
                            "properties": {
                                "ddsource": {
                                    "description": "Source of the payload.",
                                    "example": "nginx",
                                    "type": "string",
                                },
                                "ddtags": {
                                    "description": "Tags associated with your data.",
                                    "example": "env:staging,version:5.1",
                                    "type": "string",
                                },
                                "hostname": {
                                    "description": "The name of the originating host of the log.",
                                    "example": "i-012345678",
                                    "type": "string",
                                },
                                "message": {
                                    "description": "The message of the payload.",
                                    "example": "2019-11-19T14:37:58,995 "
                                    "INFO "
                                    "[process.name][20081] "
                                    "Hello "
                                    "World",
                                    "type": "string",
                                },
                                "service": {
                                    "description": "The "
                                    "name "
                                    "of "
                                    "the "
                                    "application "
                                    "or "
                                    "service "
                                    "generating "
                                    "the "
                                    "data.",
                                    "example": "payment",
                                    "type": "string",
                                },
                            },
                            "type": "object",
                        },
                    },
                    "type": "object",
                },
                "type": "array",
            },
        },
        "type": "object",
    },
    "REORDERSCANNINGGROUPS_REQUEST_BODY_SCHEMA": {
        "description": "Group reorder request.",
        "properties": {
            "data": {
                "description": "Data related to the reordering of scanning groups.",
                "properties": {
                    "id": {"description": "ID of the configuration.", "type": "string"},
                    "relationships": {
                        "description": "Relationships of the configuration.",
                        "properties": {
                            "groups": {
                                "description": "List of groups, ordered.",
                                "properties": {
                                    "data": {
                                        "description": "List of groups. The order is important.",
                                        "items": {
                                            "description": "Data "
                                            "related "
                                            "to "
                                            "a "
                                            "Sensitive "
                                            "Data "
                                            "Scanner "
                                            "Group.",
                                            "properties": {
                                                "id": {
                                                    "description": "ID of the group.",
                                                    "type": "string",
                                                },
                                                "type": {
                                                    "default": "sensitive_data_scanner_group",
                                                    "description": "Sensitive "
                                                    "Data "
                                                    "Scanner "
                                                    "group "
                                                    "type.",
                                                    "enum": ["sensitive_data_scanner_group"],
                                                    "example": "sensitive_data_scanner_group",
                                                    "type": "string",
                                                    "x-enum-varnames": [
                                                        "SENSITIVE_DATA_SCANNER_GROUP"
                                                    ],
                                                },
                                            },
                                            "type": "object",
                                        },
                                        "type": "array",
                                    }
                                },
                                "type": "object",
                            }
                        },
                        "type": "object",
                    },
                    "type": {
                        "default": "sensitive_data_scanner_configuration",
                        "description": "Sensitive Data Scanner configuration type.",
                        "enum": ["sensitive_data_scanner_configuration"],
                        "example": "sensitive_data_scanner_configuration",
                        "type": "string",
                        "x-enum-varnames": ["SENSITIVE_DATA_SCANNER_CONFIGURATIONS"],
                    },
                },
                "type": "object",
            },
            "meta": {
                "description": "Meta payload containing information about the API.",
                "properties": {
                    "version": {
                        "description": "Version of the API (optional).",
                        "example": 0,
                        "format": "int64",
                        "minimum": 0,
                        "type": "integer",
                    }
                },
                "type": "object",
            },
        },
        "required": ["data", "meta"],
        "type": "object",
    },
    "CREATESCANNINGGROUP_REQUEST_BODY_SCHEMA": {
        "description": "Create group request.",
        "properties": {
            "data": {
                "description": "Data related to the creation of a group.",
                "properties": {
                    "attributes": {
                        "description": "Attributes of the Sensitive Data Scanner group.",
                        "properties": {
                            "description": {
                                "description": "Description of the group.",
                                "type": "string",
                            },
                            "filter": {
                                "description": "Filter for the Scanning Group.",
                                "properties": {
                                    "query": {
                                        "description": "Query to filter the events.",
                                        "type": "string",
                                    }
                                },
                                "type": "object",
                            },
                            "is_enabled": {
                                "description": "Whether or not the group is enabled.",
                                "type": "boolean",
                            },
                            "name": {"description": "Name of the group.", "type": "string"},
                            "product_list": {
                                "description": "List of products the scanning group applies.",
                                "items": {
                                    "default": "logs",
                                    "description": "Datadog "
                                    "product "
                                    "onto "
                                    "which "
                                    "Sensitive "
                                    "Data "
                                    "Scanner "
                                    "can "
                                    "be "
                                    "activated.",
                                    "enum": ["logs", "rum", "events", "apm"],
                                    "type": "string",
                                    "x-enum-varnames": ["LOGS", "RUM", "EVENTS", "APM"],
                                },
                                "type": "array",
                            },
                            "samplings": {
                                "description": "List of sampling rates per product type.",
                                "items": {
                                    "description": "Sampling "
                                    "configurations "
                                    "for "
                                    "the "
                                    "Scanning "
                                    "Group.",
                                    "properties": {
                                        "product": {
                                            "default": "logs",
                                            "description": "Datadog "
                                            "product "
                                            "onto "
                                            "which "
                                            "Sensitive "
                                            "Data "
                                            "Scanner "
                                            "can "
                                            "be "
                                            "activated.",
                                            "enum": ["logs", "rum", "events", "apm"],
                                            "type": "string",
                                            "x-enum-varnames": ["LOGS", "RUM", "EVENTS", "APM"],
                                        },
                                        "rate": {
                                            "description": "Rate "
                                            "at "
                                            "which "
                                            "data "
                                            "in "
                                            "product "
                                            "type "
                                            "will "
                                            "be "
                                            "scanned, "
                                            "as "
                                            "a "
                                            "percentage.",
                                            "example": 100.0,
                                            "format": "double",
                                            "maximum": 100.0,
                                            "minimum": 0.0,
                                            "type": "number",
                                        },
                                    },
                                    "type": "object",
                                },
                                "type": "array",
                            },
                        },
                        "type": "object",
                    },
                    "relationships": {
                        "description": "Relationships of the group.",
                        "properties": {
                            "configuration": {
                                "description": "A Sensitive Data Scanner configuration data.",
                                "properties": {
                                    "data": {
                                        "description": "A Sensitive Data Scanner configuration.",
                                        "properties": {
                                            "id": {
                                                "description": "ID of the configuration.",
                                                "type": "string",
                                            },
                                            "type": {
                                                "default": "sensitive_data_scanner_configuration",
                                                "description": "Sensitive "
                                                "Data "
                                                "Scanner "
                                                "configuration "
                                                "type.",
                                                "enum": ["sensitive_data_scanner_configuration"],
                                                "example": "sensitive_data_scanner_configuration",
                                                "type": "string",
                                                "x-enum-varnames": [
                                                    "SENSITIVE_DATA_SCANNER_CONFIGURATIONS"
                                                ],
                                            },
                                        },
                                        "type": "object",
                                    }
                                },
                                "type": "object",
                            },
                            "rules": {
                                "description": "Rules included in the group.",
                                "properties": {
                                    "data": {
                                        "description": "Rules "
                                        "included "
                                        "in "
                                        "the "
                                        "group. "
                                        "The "
                                        "order "
                                        "is "
                                        "important.",
                                        "items": {
                                            "description": "Rule item included in the group.",
                                            "properties": {
                                                "id": {
                                                    "description": "ID of the rule.",
                                                    "type": "string",
                                                },
                                                "type": {
                                                    "default": "sensitive_data_scanner_rule",
                                                    "description": "Sensitive "
                                                    "Data "
                                                    "Scanner "
                                                    "rule "
                                                    "type.",
                                                    "enum": ["sensitive_data_scanner_rule"],
                                                    "example": "sensitive_data_scanner_rule",
                                                    "type": "string",
                                                    "x-enum-varnames": [
                                                        "SENSITIVE_DATA_SCANNER_RULE"
                                                    ],
                                                },
                                            },
                                            "type": "object",
                                        },
                                        "type": "array",
                                    }
                                },
                                "type": "object",
                            },
                        },
                        "type": "object",
                    },
                    "type": {
                        "default": "sensitive_data_scanner_group",
                        "description": "Sensitive Data Scanner group type.",
                        "enum": ["sensitive_data_scanner_group"],
                        "example": "sensitive_data_scanner_group",
                        "type": "string",
                        "x-enum-varnames": ["SENSITIVE_DATA_SCANNER_GROUP"],
                    },
                },
                "required": ["type", "attributes"],
                "type": "object",
            },
            "meta": {
                "description": "Meta payload containing information about the API.",
                "properties": {
                    "version": {
                        "description": "Version of the API (optional).",
                        "example": 0,
                        "format": "int64",
                        "minimum": 0,
                        "type": "integer",
                    }
                },
                "type": "object",
            },
        },
        "type": "object",
    },
    "UPDATESCANNINGGROUP_REQUEST_BODY_SCHEMA": {
        "description": "Update group request.",
        "properties": {
            "data": {
                "description": "Data related to the update of a group.",
                "properties": {
                    "attributes": {
                        "description": "Attributes of the Sensitive Data Scanner group.",
                        "properties": {
                            "description": {
                                "description": "Description of the group.",
                                "type": "string",
                            },
                            "filter": {
                                "description": "Filter for the Scanning Group.",
                                "properties": {
                                    "query": {
                                        "description": "Query to filter the events.",
                                        "type": "string",
                                    }
                                },
                                "type": "object",
                            },
                            "is_enabled": {
                                "description": "Whether or not the group is enabled.",
                                "type": "boolean",
                            },
                            "name": {"description": "Name of the group.", "type": "string"},
                            "product_list": {
                                "description": "List of products the scanning group applies.",
                                "items": {
                                    "default": "logs",
                                    "description": "Datadog "
                                    "product "
                                    "onto "
                                    "which "
                                    "Sensitive "
                                    "Data "
                                    "Scanner "
                                    "can "
                                    "be "
                                    "activated.",
                                    "enum": ["logs", "rum", "events", "apm"],
                                    "type": "string",
                                    "x-enum-varnames": ["LOGS", "RUM", "EVENTS", "APM"],
                                },
                                "type": "array",
                            },
                            "samplings": {
                                "description": "List of sampling rates per product type.",
                                "items": {
                                    "description": "Sampling "
                                    "configurations "
                                    "for "
                                    "the "
                                    "Scanning "
                                    "Group.",
                                    "properties": {
                                        "product": {
                                            "default": "logs",
                                            "description": "Datadog "
                                            "product "
                                            "onto "
                                            "which "
                                            "Sensitive "
                                            "Data "
                                            "Scanner "
                                            "can "
                                            "be "
                                            "activated.",
                                            "enum": ["logs", "rum", "events", "apm"],
                                            "type": "string",
                                            "x-enum-varnames": ["LOGS", "RUM", "EVENTS", "APM"],
                                        },
                                        "rate": {
                                            "description": "Rate "
                                            "at "
                                            "which "
                                            "data "
                                            "in "
                                            "product "
                                            "type "
                                            "will "
                                            "be "
                                            "scanned, "
                                            "as "
                                            "a "
                                            "percentage.",
                                            "example": 100.0,
                                            "format": "double",
                                            "maximum": 100.0,
                                            "minimum": 0.0,
                                            "type": "number",
                                        },
                                    },
                                    "type": "object",
                                },
                                "type": "array",
                            },
                        },
                        "type": "object",
                    },
                    "id": {"description": "ID of the group.", "type": "string"},
                    "relationships": {
                        "description": "Relationships of the group.",
                        "properties": {
                            "configuration": {
                                "description": "A Sensitive Data Scanner configuration data.",
                                "properties": {
                                    "data": {
                                        "description": "A Sensitive Data Scanner configuration.",
                                        "properties": {
                                            "id": {
                                                "description": "ID of the configuration.",
                                                "type": "string",
                                            },
                                            "type": {
                                                "default": "sensitive_data_scanner_configuration",
                                                "description": "Sensitive "
                                                "Data "
                                                "Scanner "
                                                "configuration "
                                                "type.",
                                                "enum": ["sensitive_data_scanner_configuration"],
                                                "example": "sensitive_data_scanner_configuration",
                                                "type": "string",
                                                "x-enum-varnames": [
                                                    "SENSITIVE_DATA_SCANNER_CONFIGURATIONS"
                                                ],
                                            },
                                        },
                                        "type": "object",
                                    }
                                },
                                "type": "object",
                            },
                            "rules": {
                                "description": "Rules included in the group.",
                                "properties": {
                                    "data": {
                                        "description": "Rules "
                                        "included "
                                        "in "
                                        "the "
                                        "group. "
                                        "The "
                                        "order "
                                        "is "
                                        "important.",
                                        "items": {
                                            "description": "Rule item included in the group.",
                                            "properties": {
                                                "id": {
                                                    "description": "ID of the rule.",
                                                    "type": "string",
                                                },
                                                "type": {
                                                    "default": "sensitive_data_scanner_rule",
                                                    "description": "Sensitive "
                                                    "Data "
                                                    "Scanner "
                                                    "rule "
                                                    "type.",
                                                    "enum": ["sensitive_data_scanner_rule"],
                                                    "example": "sensitive_data_scanner_rule",
                                                    "type": "string",
                                                    "x-enum-varnames": [
                                                        "SENSITIVE_DATA_SCANNER_RULE"
                                                    ],
                                                },
                                            },
                                            "type": "object",
                                        },
                                        "type": "array",
                                    }
                                },
                                "type": "object",
                            },
                        },
                        "type": "object",
                    },
                    "type": {
                        "default": "sensitive_data_scanner_group",
                        "description": "Sensitive Data Scanner group type.",
                        "enum": ["sensitive_data_scanner_group"],
                        "example": "sensitive_data_scanner_group",
                        "type": "string",
                        "x-enum-varnames": ["SENSITIVE_DATA_SCANNER_GROUP"],
                    },
                },
                "type": "object",
            },
            "meta": {
                "description": "Meta payload containing information about the API.",
                "properties": {
                    "version": {
                        "description": "Version of the API (optional).",
                        "example": 0,
                        "format": "int64",
                        "minimum": 0,
                        "type": "integer",
                    }
                },
                "type": "object",
            },
        },
        "required": ["data", "meta"],
        "type": "object",
    },
    "CREATESCANNINGRULE_REQUEST_BODY_SCHEMA": {
        "description": "Create rule request.",
        "properties": {
            "data": {
                "description": "Data related to the creation of a rule.",
                "properties": {
                    "attributes": {
                        "description": "Attributes of the Sensitive Data Scanner rule.",
                        "properties": {
                            "description": {
                                "description": "Description of the rule.",
                                "type": "string",
                            },
                            "excluded_namespaces": {
                                "description": "Attributes "
                                "excluded "
                                "from "
                                "the "
                                "scan. "
                                "If "
                                "namespaces "
                                "is "
                                "provided, "
                                "it "
                                "has "
                                "to "
                                "be "
                                "a "
                                "sub-path "
                                "of "
                                "the "
                                "namespaces "
                                "array.",
                                "example": ["admin.name"],
                                "items": {"type": "string"},
                                "type": "array",
                            },
                            "included_keyword_configuration": {
                                "description": "Object "
                                "defining "
                                "a "
                                "set "
                                "of "
                                "keywords "
                                "and "
                                "a "
                                "number "
                                "of "
                                "characters "
                                "that "
                                "help "
                                "reduce "
                                "noise.\n"
                                "You "
                                "can "
                                "provide "
                                "a "
                                "list "
                                "of "
                                "keywords "
                                "you "
                                "would "
                                "like "
                                "to "
                                "check "
                                "within "
                                "a "
                                "defined "
                                "proximity "
                                "of "
                                "the "
                                "matching "
                                "pattern.\n"
                                "If "
                                "any "
                                "of "
                                "the "
                                "keywords "
                                "are "
                                "found "
                                "within "
                                "the "
                                "proximity "
                                "check, "
                                "the "
                                "match "
                                "is "
                                "kept.\n"
                                "If "
                                "none "
                                "are "
                                "found, "
                                "the "
                                "match "
                                "is "
                                "discarded.",
                                "properties": {
                                    "character_count": {
                                        "description": "The "
                                        "number "
                                        "of "
                                        "characters "
                                        "behind "
                                        "a "
                                        "match "
                                        "detected "
                                        "by "
                                        "Sensitive "
                                        "Data "
                                        "Scanner "
                                        "to "
                                        "look "
                                        "for "
                                        "the "
                                        "keywords "
                                        "defined.\n"
                                        "`character_count` "
                                        "should "
                                        "be "
                                        "greater "
                                        "than "
                                        "the "
                                        "maximum "
                                        "length "
                                        "of "
                                        "a "
                                        "keyword "
                                        "defined "
                                        "for "
                                        "a "
                                        "rule.",
                                        "example": 30,
                                        "format": "int64",
                                        "maximum": 50,
                                        "minimum": 1,
                                        "type": "integer",
                                    },
                                    "keywords": {
                                        "description": "Keyword "
                                        "list "
                                        "that "
                                        "will "
                                        "be "
                                        "checked "
                                        "during "
                                        "scanning "
                                        "in "
                                        "order "
                                        "to "
                                        "validate "
                                        "a "
                                        "match.\n"
                                        "The "
                                        "number "
                                        "of "
                                        "keywords "
                                        "in "
                                        "the "
                                        "list "
                                        "must "
                                        "be "
                                        "less "
                                        "than "
                                        "or "
                                        "equal "
                                        "to "
                                        "30.",
                                        "example": ["credit card", "cc"],
                                        "items": {"type": "string"},
                                        "type": "array",
                                    },
                                    "use_recommended_keywords": {
                                        "description": "Should "
                                        "the "
                                        "rule "
                                        "use "
                                        "the "
                                        "underlying "
                                        "standard "
                                        "pattern "
                                        "keyword "
                                        "configuration. "
                                        "If "
                                        "set "
                                        "to "
                                        "`true`, "
                                        "the "
                                        "rule "
                                        "must "
                                        "be "
                                        "tied\n"
                                        "to "
                                        "a "
                                        "standard "
                                        "pattern. "
                                        "If "
                                        "set "
                                        "to "
                                        "`false`, "
                                        "the "
                                        "specified "
                                        "keywords "
                                        "and "
                                        "`character_count` "
                                        "are "
                                        "applied.",
                                        "type": "boolean",
                                    },
                                },
                                "required": ["keywords", "character_count"],
                                "type": "object",
                            },
                            "is_enabled": {
                                "description": "Whether or not the rule is enabled.",
                                "type": "boolean",
                            },
                            "name": {"description": "Name of the rule.", "type": "string"},
                            "namespaces": {
                                "description": "Attributes "
                                "included "
                                "in "
                                "the "
                                "scan. "
                                "If "
                                "namespaces "
                                "is "
                                "empty "
                                "or "
                                "missing, "
                                "all "
                                "attributes "
                                "except "
                                "excluded_namespaces "
                                "are "
                                "scanned.\n"
                                "If "
                                "both "
                                "are "
                                "missing "
                                "the "
                                "whole "
                                "event "
                                "is "
                                "scanned.",
                                "example": ["admin"],
                                "items": {"type": "string"},
                                "type": "array",
                            },
                            "pattern": {
                                "description": "Not "
                                "included "
                                "if "
                                "there "
                                "is "
                                "a "
                                "relationship "
                                "to "
                                "a "
                                "standard "
                                "pattern.",
                                "type": "string",
                            },
                            "priority": {
                                "description": "Integer "
                                "from "
                                "1 "
                                "(high) "
                                "to "
                                "5 "
                                "(low) "
                                "indicating "
                                "rule "
                                "issue "
                                "severity.",
                                "format": "int64",
                                "maximum": 5,
                                "minimum": 1,
                                "type": "integer",
                            },
                            "tags": {
                                "description": "List of tags.",
                                "items": {"type": "string"},
                                "type": "array",
                            },
                            "text_replacement": {
                                "description": "Object "
                                "describing "
                                "how "
                                "the "
                                "scanned "
                                "event "
                                "will "
                                "be "
                                "replaced.",
                                "properties": {
                                    "number_of_chars": {
                                        "description": "Required "
                                        "if "
                                        "type "
                                        "== "
                                        "'partial_replacement_from_beginning'\n"
                                        "or "
                                        "'partial_replacement_from_end'. "
                                        "It "
                                        "must "
                                        "be "
                                        "> "
                                        "0.",
                                        "format": "int64",
                                        "minimum": 0,
                                        "type": "integer",
                                    },
                                    "replacement_string": {
                                        "description": "Required if type == 'replacement_string'.",
                                        "type": "string",
                                    },
                                    "should_save_match": {
                                        "description": "Only "
                                        "valid "
                                        "when "
                                        "type "
                                        "== "
                                        "`replacement_string`. "
                                        "When "
                                        "enabled, "
                                        "matches "
                                        "can "
                                        "be "
                                        "unmasked "
                                        "in "
                                        "logs "
                                        "by "
                                        "users "
                                        "with "
                                        "‘Data "
                                        "Scanner "
                                        "Unmask’ "
                                        "permission. "
                                        "As "
                                        "a "
                                        "security "
                                        "best "
                                        "practice, "
                                        "avoid "
                                        "masking "
                                        "for "
                                        "highly-sensitive, "
                                        "long-lived "
                                        "data.",
                                        "type": "boolean",
                                    },
                                    "type": {
                                        "default": "none",
                                        "description": "Type "
                                        "of "
                                        "the "
                                        "replacement "
                                        "text. "
                                        "None "
                                        "means "
                                        "no "
                                        "replacement.\n"
                                        "hash "
                                        "means "
                                        "the "
                                        "data "
                                        "will "
                                        "be "
                                        "stubbed. "
                                        "replacement_string "
                                        "means "
                                        "that\n"
                                        "one "
                                        "can "
                                        "chose "
                                        "a "
                                        "text "
                                        "to "
                                        "replace "
                                        "the "
                                        "data. "
                                        "partial_replacement_from_beginning\n"
                                        "allows "
                                        "a "
                                        "user "
                                        "to "
                                        "partially "
                                        "replace "
                                        "the "
                                        "data "
                                        "from "
                                        "the "
                                        "beginning, "
                                        "and\n"
                                        "partial_replacement_from_end "
                                        "on "
                                        "the "
                                        "other "
                                        "hand, "
                                        "allows "
                                        "to "
                                        "replace "
                                        "data "
                                        "from\n"
                                        "the "
                                        "end.",
                                        "enum": [
                                            "none",
                                            "hash",
                                            "replacement_string",
                                            "partial_replacement_from_beginning",
                                            "partial_replacement_from_end",
                                        ],
                                        "type": "string",
                                        "x-enum-varnames": [
                                            "NONE",
                                            "HASH",
                                            "REPLACEMENT_STRING",
                                            "PARTIAL_REPLACEMENT_FROM_BEGINNING",
                                            "PARTIAL_REPLACEMENT_FROM_END",
                                        ],
                                    },
                                },
                                "type": "object",
                            },
                        },
                        "type": "object",
                    },
                    "relationships": {
                        "description": "Relationships of a scanning rule.",
                        "properties": {
                            "group": {
                                "description": "A scanning group data.",
                                "properties": {
                                    "data": {
                                        "description": "A scanning group.",
                                        "properties": {
                                            "id": {
                                                "description": "ID of the group.",
                                                "type": "string",
                                            },
                                            "type": {
                                                "default": "sensitive_data_scanner_group",
                                                "description": "Sensitive Data Scanner group type.",
                                                "enum": ["sensitive_data_scanner_group"],
                                                "example": "sensitive_data_scanner_group",
                                                "type": "string",
                                                "x-enum-varnames": ["SENSITIVE_DATA_SCANNER_GROUP"],
                                            },
                                        },
                                        "type": "object",
                                    }
                                },
                                "type": "object",
                            },
                            "standard_pattern": {
                                "description": "A standard pattern.",
                                "properties": {
                                    "data": {
                                        "description": "Data containing the standard pattern id.",
                                        "properties": {
                                            "id": {
                                                "description": "ID of the standard pattern.",
                                                "type": "string",
                                            },
                                            "type": {
                                                "default": "sensitive_data_scanner_standard_pattern",
                                                "description": "Sensitive "
                                                "Data "
                                                "Scanner "
                                                "standard "
                                                "pattern "
                                                "type.",
                                                "enum": ["sensitive_data_scanner_standard_pattern"],
                                                "example": "sensitive_data_scanner_standard_pattern",
                                                "type": "string",
                                                "x-enum-varnames": [
                                                    "SENSITIVE_DATA_SCANNER_STANDARD_PATTERN"
                                                ],
                                            },
                                        },
                                        "type": "object",
                                    }
                                },
                                "type": "object",
                            },
                        },
                        "type": "object",
                    },
                    "type": {
                        "default": "sensitive_data_scanner_rule",
                        "description": "Sensitive Data Scanner rule type.",
                        "enum": ["sensitive_data_scanner_rule"],
                        "example": "sensitive_data_scanner_rule",
                        "type": "string",
                        "x-enum-varnames": ["SENSITIVE_DATA_SCANNER_RULE"],
                    },
                },
                "required": ["type", "attributes", "relationships"],
                "type": "object",
            },
            "meta": {
                "description": "Meta payload containing information about the API.",
                "properties": {
                    "version": {
                        "description": "Version of the API (optional).",
                        "example": 0,
                        "format": "int64",
                        "minimum": 0,
                        "type": "integer",
                    }
                },
                "type": "object",
            },
        },
        "required": ["data", "meta"],
        "type": "object",
    },
    "UPDATESCANNINGRULE_REQUEST_BODY_SCHEMA": {
        "description": "Update rule request.",
        "properties": {
            "data": {
                "description": "Data related to the update of a rule.",
                "properties": {
                    "attributes": {
                        "description": "Attributes of the Sensitive Data Scanner rule.",
                        "properties": {
                            "description": {
                                "description": "Description of the rule.",
                                "type": "string",
                            },
                            "excluded_namespaces": {
                                "description": "Attributes "
                                "excluded "
                                "from "
                                "the "
                                "scan. "
                                "If "
                                "namespaces "
                                "is "
                                "provided, "
                                "it "
                                "has "
                                "to "
                                "be "
                                "a "
                                "sub-path "
                                "of "
                                "the "
                                "namespaces "
                                "array.",
                                "example": ["admin.name"],
                                "items": {"type": "string"},
                                "type": "array",
                            },
                            "included_keyword_configuration": {
                                "description": "Object "
                                "defining "
                                "a "
                                "set "
                                "of "
                                "keywords "
                                "and "
                                "a "
                                "number "
                                "of "
                                "characters "
                                "that "
                                "help "
                                "reduce "
                                "noise.\n"
                                "You "
                                "can "
                                "provide "
                                "a "
                                "list "
                                "of "
                                "keywords "
                                "you "
                                "would "
                                "like "
                                "to "
                                "check "
                                "within "
                                "a "
                                "defined "
                                "proximity "
                                "of "
                                "the "
                                "matching "
                                "pattern.\n"
                                "If "
                                "any "
                                "of "
                                "the "
                                "keywords "
                                "are "
                                "found "
                                "within "
                                "the "
                                "proximity "
                                "check, "
                                "the "
                                "match "
                                "is "
                                "kept.\n"
                                "If "
                                "none "
                                "are "
                                "found, "
                                "the "
                                "match "
                                "is "
                                "discarded.",
                                "properties": {
                                    "character_count": {
                                        "description": "The "
                                        "number "
                                        "of "
                                        "characters "
                                        "behind "
                                        "a "
                                        "match "
                                        "detected "
                                        "by "
                                        "Sensitive "
                                        "Data "
                                        "Scanner "
                                        "to "
                                        "look "
                                        "for "
                                        "the "
                                        "keywords "
                                        "defined.\n"
                                        "`character_count` "
                                        "should "
                                        "be "
                                        "greater "
                                        "than "
                                        "the "
                                        "maximum "
                                        "length "
                                        "of "
                                        "a "
                                        "keyword "
                                        "defined "
                                        "for "
                                        "a "
                                        "rule.",
                                        "example": 30,
                                        "format": "int64",
                                        "maximum": 50,
                                        "minimum": 1,
                                        "type": "integer",
                                    },
                                    "keywords": {
                                        "description": "Keyword "
                                        "list "
                                        "that "
                                        "will "
                                        "be "
                                        "checked "
                                        "during "
                                        "scanning "
                                        "in "
                                        "order "
                                        "to "
                                        "validate "
                                        "a "
                                        "match.\n"
                                        "The "
                                        "number "
                                        "of "
                                        "keywords "
                                        "in "
                                        "the "
                                        "list "
                                        "must "
                                        "be "
                                        "less "
                                        "than "
                                        "or "
                                        "equal "
                                        "to "
                                        "30.",
                                        "example": ["credit card", "cc"],
                                        "items": {"type": "string"},
                                        "type": "array",
                                    },
                                    "use_recommended_keywords": {
                                        "description": "Should "
                                        "the "
                                        "rule "
                                        "use "
                                        "the "
                                        "underlying "
                                        "standard "
                                        "pattern "
                                        "keyword "
                                        "configuration. "
                                        "If "
                                        "set "
                                        "to "
                                        "`true`, "
                                        "the "
                                        "rule "
                                        "must "
                                        "be "
                                        "tied\n"
                                        "to "
                                        "a "
                                        "standard "
                                        "pattern. "
                                        "If "
                                        "set "
                                        "to "
                                        "`false`, "
                                        "the "
                                        "specified "
                                        "keywords "
                                        "and "
                                        "`character_count` "
                                        "are "
                                        "applied.",
                                        "type": "boolean",
                                    },
                                },
                                "required": ["keywords", "character_count"],
                                "type": "object",
                            },
                            "is_enabled": {
                                "description": "Whether or not the rule is enabled.",
                                "type": "boolean",
                            },
                            "name": {"description": "Name of the rule.", "type": "string"},
                            "namespaces": {
                                "description": "Attributes "
                                "included "
                                "in "
                                "the "
                                "scan. "
                                "If "
                                "namespaces "
                                "is "
                                "empty "
                                "or "
                                "missing, "
                                "all "
                                "attributes "
                                "except "
                                "excluded_namespaces "
                                "are "
                                "scanned.\n"
                                "If "
                                "both "
                                "are "
                                "missing "
                                "the "
                                "whole "
                                "event "
                                "is "
                                "scanned.",
                                "example": ["admin"],
                                "items": {"type": "string"},
                                "type": "array",
                            },
                            "pattern": {
                                "description": "Not "
                                "included "
                                "if "
                                "there "
                                "is "
                                "a "
                                "relationship "
                                "to "
                                "a "
                                "standard "
                                "pattern.",
                                "type": "string",
                            },
                            "priority": {
                                "description": "Integer "
                                "from "
                                "1 "
                                "(high) "
                                "to "
                                "5 "
                                "(low) "
                                "indicating "
                                "rule "
                                "issue "
                                "severity.",
                                "format": "int64",
                                "maximum": 5,
                                "minimum": 1,
                                "type": "integer",
                            },
                            "tags": {
                                "description": "List of tags.",
                                "items": {"type": "string"},
                                "type": "array",
                            },
                            "text_replacement": {
                                "description": "Object "
                                "describing "
                                "how "
                                "the "
                                "scanned "
                                "event "
                                "will "
                                "be "
                                "replaced.",
                                "properties": {
                                    "number_of_chars": {
                                        "description": "Required "
                                        "if "
                                        "type "
                                        "== "
                                        "'partial_replacement_from_beginning'\n"
                                        "or "
                                        "'partial_replacement_from_end'. "
                                        "It "
                                        "must "
                                        "be "
                                        "> "
                                        "0.",
                                        "format": "int64",
                                        "minimum": 0,
                                        "type": "integer",
                                    },
                                    "replacement_string": {
                                        "description": "Required if type == 'replacement_string'.",
                                        "type": "string",
                                    },
                                    "should_save_match": {
                                        "description": "Only "
                                        "valid "
                                        "when "
                                        "type "
                                        "== "
                                        "`replacement_string`. "
                                        "When "
                                        "enabled, "
                                        "matches "
                                        "can "
                                        "be "
                                        "unmasked "
                                        "in "
                                        "logs "
                                        "by "
                                        "users "
                                        "with "
                                        "‘Data "
                                        "Scanner "
                                        "Unmask’ "
                                        "permission. "
                                        "As "
                                        "a "
                                        "security "
                                        "best "
                                        "practice, "
                                        "avoid "
                                        "masking "
                                        "for "
                                        "highly-sensitive, "
                                        "long-lived "
                                        "data.",
                                        "type": "boolean",
                                    },
                                    "type": {
                                        "default": "none",
                                        "description": "Type "
                                        "of "
                                        "the "
                                        "replacement "
                                        "text. "
                                        "None "
                                        "means "
                                        "no "
                                        "replacement.\n"
                                        "hash "
                                        "means "
                                        "the "
                                        "data "
                                        "will "
                                        "be "
                                        "stubbed. "
                                        "replacement_string "
                                        "means "
                                        "that\n"
                                        "one "
                                        "can "
                                        "chose "
                                        "a "
                                        "text "
                                        "to "
                                        "replace "
                                        "the "
                                        "data. "
                                        "partial_replacement_from_beginning\n"
                                        "allows "
                                        "a "
                                        "user "
                                        "to "
                                        "partially "
                                        "replace "
                                        "the "
                                        "data "
                                        "from "
                                        "the "
                                        "beginning, "
                                        "and\n"
                                        "partial_replacement_from_end "
                                        "on "
                                        "the "
                                        "other "
                                        "hand, "
                                        "allows "
                                        "to "
                                        "replace "
                                        "data "
                                        "from\n"
                                        "the "
                                        "end.",
                                        "enum": [
                                            "none",
                                            "hash",
                                            "replacement_string",
                                            "partial_replacement_from_beginning",
                                            "partial_replacement_from_end",
                                        ],
                                        "type": "string",
                                        "x-enum-varnames": [
                                            "NONE",
                                            "HASH",
                                            "REPLACEMENT_STRING",
                                            "PARTIAL_REPLACEMENT_FROM_BEGINNING",
                                            "PARTIAL_REPLACEMENT_FROM_END",
                                        ],
                                    },
                                },
                                "type": "object",
                            },
                        },
                        "type": "object",
                    },
                    "id": {"description": "ID of the rule.", "type": "string"},
                    "relationships": {
                        "description": "Relationships of a scanning rule.",
                        "properties": {
                            "group": {
                                "description": "A scanning group data.",
                                "properties": {
                                    "data": {
                                        "description": "A scanning group.",
                                        "properties": {
                                            "id": {
                                                "description": "ID of the group.",
                                                "type": "string",
                                            },
                                            "type": {
                                                "default": "sensitive_data_scanner_group",
                                                "description": "Sensitive Data Scanner group type.",
                                                "enum": ["sensitive_data_scanner_group"],
                                                "example": "sensitive_data_scanner_group",
                                                "type": "string",
                                                "x-enum-varnames": ["SENSITIVE_DATA_SCANNER_GROUP"],
                                            },
                                        },
                                        "type": "object",
                                    }
                                },
                                "type": "object",
                            },
                            "standard_pattern": {
                                "description": "A standard pattern.",
                                "properties": {
                                    "data": {
                                        "description": "Data containing the standard pattern id.",
                                        "properties": {
                                            "id": {
                                                "description": "ID of the standard pattern.",
                                                "type": "string",
                                            },
                                            "type": {
                                                "default": "sensitive_data_scanner_standard_pattern",
                                                "description": "Sensitive "
                                                "Data "
                                                "Scanner "
                                                "standard "
                                                "pattern "
                                                "type.",
                                                "enum": ["sensitive_data_scanner_standard_pattern"],
                                                "example": "sensitive_data_scanner_standard_pattern",
                                                "type": "string",
                                                "x-enum-varnames": [
                                                    "SENSITIVE_DATA_SCANNER_STANDARD_PATTERN"
                                                ],
                                            },
                                        },
                                        "type": "object",
                                    }
                                },
                                "type": "object",
                            },
                        },
                        "type": "object",
                    },
                    "type": {
                        "default": "sensitive_data_scanner_rule",
                        "description": "Sensitive Data Scanner rule type.",
                        "enum": ["sensitive_data_scanner_rule"],
                        "example": "sensitive_data_scanner_rule",
                        "type": "string",
                        "x-enum-varnames": ["SENSITIVE_DATA_SCANNER_RULE"],
                    },
                },
                "type": "object",
            },
            "meta": {
                "description": "Meta payload containing information about the API.",
                "properties": {
                    "version": {
                        "description": "Version of the API (optional).",
                        "example": 0,
                        "format": "int64",
                        "minimum": 0,
                        "type": "integer",
                    }
                },
                "type": "object",
            },
        },
        "required": ["data", "meta"],
        "type": "object",
    },
    "CREATESERVICEACCOUNT_REQUEST_BODY_SCHEMA": {
        "description": "Create a service account.",
        "properties": {
            "data": {
                "description": "Object to create a service account User.",
                "properties": {
                    "attributes": {
                        "description": "Attributes of the created user.",
                        "properties": {
                            "email": {
                                "description": "The email of the user.",
                                "example": "jane.doe@example.com",
                                "type": "string",
                            },
                            "name": {"description": "The name of the user.", "type": "string"},
                            "service_account": {
                                "description": "Whether "
                                "the "
                                "user "
                                "is "
                                "a "
                                "service "
                                "account. "
                                "Must "
                                "be "
                                "true.",
                                "example": True,
                                "type": "boolean",
                            },
                            "title": {"description": "The title of the user.", "type": "string"},
                        },
                        "required": ["email", "service_account"],
                        "type": "object",
                    },
                    "relationships": {
                        "description": "Relationships of the user object.",
                        "properties": {
                            "roles": {
                                "description": "Relationship to roles.",
                                "properties": {
                                    "data": {
                                        "description": "An "
                                        "array "
                                        "containing "
                                        "type "
                                        "and "
                                        "the "
                                        "unique "
                                        "identifier "
                                        "of "
                                        "a "
                                        "role.",
                                        "items": {
                                            "description": "Relationship to role object.",
                                            "properties": {
                                                "id": {
                                                    "description": "The "
                                                    "unique "
                                                    "identifier "
                                                    "of "
                                                    "the "
                                                    "role.",
                                                    "example": "3653d3c6-0c75-11ea-ad28-fb5701eabc7d",
                                                    "type": "string",
                                                },
                                                "type": {
                                                    "default": "roles",
                                                    "description": "Roles type.",
                                                    "enum": ["roles"],
                                                    "example": "roles",
                                                    "type": "string",
                                                    "x-enum-varnames": ["ROLES"],
                                                },
                                            },
                                            "type": "object",
                                        },
                                        "type": "array",
                                    }
                                },
                                "type": "object",
                            }
                        },
                        "type": "object",
                    },
                    "type": {
                        "default": "users",
                        "description": "Users resource type.",
                        "enum": ["users"],
                        "example": "users",
                        "type": "string",
                        "x-enum-varnames": ["USERS"],
                    },
                },
                "required": ["attributes", "type"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "CREATEORUPDATESERVICEDEFINITIONS_REQUEST_BODY_SCHEMA": {
        "description": "Create service definitions request.",
        "oneOf": [
            {
                "description": "Service definition v2.2 for providing service metadata and "
                "integrations.",
                "properties": {
                    "application": {
                        "description": "Identifier for a group of "
                        "related services serving a "
                        "product feature, which the "
                        "service is a part of.",
                        "example": "my-app",
                        "type": "string",
                    },
                    "ci-pipeline-fingerprints": {
                        "description": "A set of CI fingerprints.",
                        "example": ["j88xdEy0J5lc", "eZ7LMljCk8vo"],
                        "items": {"type": "string"},
                        "type": "array",
                    },
                    "contacts": {
                        "description": "A list of contacts related to the services.",
                        "items": {
                            "description": "Service owner's contacts information.",
                            "properties": {
                                "contact": {
                                    "description": "Contact value.",
                                    "example": "https://teams.microsoft.com/myteam",
                                    "type": "string",
                                },
                                "name": {
                                    "description": "Contact Name.",
                                    "example": "My team channel",
                                    "type": "string",
                                },
                                "type": {
                                    "description": "Contact "
                                    "type. "
                                    "Datadog "
                                    "recognizes "
                                    "the "
                                    "following "
                                    "types: "
                                    "`email`, "
                                    "`slack`, "
                                    "and "
                                    "`microsoft-teams`.",
                                    "example": "slack",
                                    "type": "string",
                                },
                            },
                            "required": ["type", "contact"],
                            "type": "object",
                        },
                        "type": "array",
                    },
                    "dd-service": {
                        "description": "Unique identifier of the "
                        "service. Must be unique "
                        "across all services and is "
                        "used to match with a service "
                        "in Datadog.",
                        "example": "my-service",
                        "type": "string",
                    },
                    "description": {
                        "description": "A short description of the service.",
                        "example": "My service description",
                        "type": "string",
                    },
                    "extensions": {
                        "additionalProperties": {},
                        "description": "Extensions to v2.2 schema.",
                        "example": {"myorg/extension": "extensionValue"},
                        "type": "object",
                    },
                    "integrations": {
                        "description": "Third party integrations that Datadog supports.",
                        "properties": {
                            "opsgenie": {
                                "description": "Opsgenie integration for the service.",
                                "properties": {
                                    "region": {
                                        "description": "Opsgenie instance region.",
                                        "enum": ["US", "EU"],
                                        "example": "US",
                                        "type": "string",
                                        "x-enum-varnames": ["US", "EU"],
                                    },
                                    "service-url": {
                                        "description": "Opsgenie service url.",
                                        "example": "https://my-org.opsgenie.com/service/123e4567-e89b-12d3-a456-426614174000",
                                        "type": "string",
                                    },
                                },
                                "required": ["service-url"],
                                "type": "object",
                            },
                            "pagerduty": {
                                "description": "PagerDuty integration for the service.",
                                "properties": {
                                    "service-url": {
                                        "description": "PagerDuty service url.",
                                        "example": "https://my-org.pagerduty.com/service-directory/PMyService",
                                        "type": "string",
                                    }
                                },
                                "type": "object",
                            },
                        },
                        "type": "object",
                    },
                    "languages": {
                        "description": "The service's programming "
                        "language. Datadog recognizes "
                        "the following languages: "
                        "`dotnet`, `go`, `java`, `js`, "
                        "`php`, `python`, `ruby`, and "
                        "`c++`.",
                        "example": ["dotnet", "go", "java", "js", "php", "python", "ruby", "c++"],
                        "items": {"type": "string"},
                        "type": "array",
                    },
                    "lifecycle": {
                        "description": "The current life cycle phase of the service.",
                        "example": "sandbox",
                        "type": "string",
                    },
                    "links": {
                        "description": "A list of links related to the services.",
                        "items": {
                            "description": "Service's external links.",
                            "properties": {
                                "name": {
                                    "description": "Link name.",
                                    "example": "Runbook",
                                    "type": "string",
                                },
                                "provider": {
                                    "description": "Link provider.",
                                    "example": "Github",
                                    "type": "string",
                                },
                                "type": {
                                    "description": "Link "
                                    "type. "
                                    "Datadog "
                                    "recognizes "
                                    "the "
                                    "following "
                                    "types: "
                                    "`runbook`, "
                                    "`doc`, "
                                    "`repo`, "
                                    "`dashboard`, "
                                    "and "
                                    "`other`.",
                                    "example": "runbook",
                                    "type": "string",
                                },
                                "url": {
                                    "description": "Link URL.",
                                    "example": "https://my-runbook",
                                    "type": "string",
                                },
                            },
                            "required": ["name", "type", "url"],
                            "type": "object",
                        },
                        "type": "array",
                    },
                    "schema-version": {
                        "default": "v2.2",
                        "description": "Schema version being used.",
                        "enum": ["v2.2"],
                        "example": "v2.2",
                        "type": "string",
                        "x-enum-varnames": ["V2_2"],
                    },
                    "tags": {
                        "description": "A set of custom tags.",
                        "example": ["my:tag", "service:tag"],
                        "items": {"type": "string"},
                        "type": "array",
                    },
                    "team": {
                        "description": "Team that owns the service. It is "
                        "used to locate a team defined in "
                        "Datadog Teams if it exists.",
                        "example": "my-team",
                        "type": "string",
                    },
                    "tier": {
                        "description": "Importance of the service.",
                        "example": "High",
                        "type": "string",
                    },
                    "type": {
                        "description": "The type of service.",
                        "example": "web",
                        "type": "string",
                    },
                },
                "required": ["schema-version", "dd-service"],
                "type": "object",
            },
            {
                "description": "Service definition v2.1 for providing service metadata and "
                "integrations.",
                "properties": {
                    "application": {
                        "description": "Identifier for a group of "
                        "related services serving a "
                        "product feature, which the "
                        "service is a part of.",
                        "example": "my-app",
                        "type": "string",
                    },
                    "contacts": {
                        "description": "A list of contacts related to the services.",
                        "items": {
                            "description": "Service owner's contacts information.",
                            "oneOf": [
                                {
                                    "description": "Service owner's email.",
                                    "properties": {
                                        "contact": {
                                            "description": "Contact value.",
                                            "example": "contact@datadoghq.com",
                                            "type": "string",
                                        },
                                        "name": {
                                            "description": "Contact email.",
                                            "example": "Team Email",
                                            "type": "string",
                                        },
                                        "type": {
                                            "description": "Contact type.",
                                            "enum": ["email"],
                                            "example": "email",
                                            "type": "string",
                                            "x-enum-varnames": ["EMAIL"],
                                        },
                                    },
                                    "required": ["type", "contact"],
                                    "type": "object",
                                },
                                {
                                    "description": "Service owner's Slack channel.",
                                    "properties": {
                                        "contact": {
                                            "description": "Slack Channel.",
                                            "example": "https://yourcompany.slack.com/archives/channel123",
                                            "type": "string",
                                        },
                                        "name": {
                                            "description": "Contact Slack.",
                                            "example": "Team Slack",
                                            "type": "string",
                                        },
                                        "type": {
                                            "description": "Contact type.",
                                            "enum": ["slack"],
                                            "example": "slack",
                                            "type": "string",
                                            "x-enum-varnames": ["SLACK"],
                                        },
                                    },
                                    "required": ["type", "contact"],
                                    "type": "object",
                                },
                                {
                                    "description": "Service owner's Microsoft Teams.",
                                    "properties": {
                                        "contact": {
                                            "description": "Contact value.",
                                            "example": "https://teams.microsoft.com/myteam",
                                            "type": "string",
                                        },
                                        "name": {
                                            "description": "Contact Microsoft Teams.",
                                            "example": "My team channel",
                                            "type": "string",
                                        },
                                        "type": {
                                            "description": "Contact type.",
                                            "enum": ["microsoft-teams"],
                                            "example": "microsoft-teams",
                                            "type": "string",
                                            "x-enum-varnames": ["MICROSOFT_TEAMS"],
                                        },
                                    },
                                    "required": ["type", "contact"],
                                    "type": "object",
                                },
                            ],
                        },
                        "type": "array",
                    },
                    "dd-service": {
                        "description": "Unique identifier of the "
                        "service. Must be unique "
                        "across all services and is "
                        "used to match with a service "
                        "in Datadog.",
                        "example": "my-service",
                        "type": "string",
                    },
                    "description": {
                        "description": "A short description of the service.",
                        "example": "My service description",
                        "type": "string",
                    },
                    "extensions": {
                        "additionalProperties": {},
                        "description": "Extensions to v2.1 schema.",
                        "example": {"myorg/extension": "extensionValue"},
                        "type": "object",
                    },
                    "integrations": {
                        "description": "Third party integrations that Datadog supports.",
                        "properties": {
                            "opsgenie": {
                                "description": "Opsgenie integration for the service.",
                                "properties": {
                                    "region": {
                                        "description": "Opsgenie instance region.",
                                        "enum": ["US", "EU"],
                                        "example": "US",
                                        "type": "string",
                                        "x-enum-varnames": ["US", "EU"],
                                    },
                                    "service-url": {
                                        "description": "Opsgenie service url.",
                                        "example": "https://my-org.opsgenie.com/service/123e4567-e89b-12d3-a456-426614174000",
                                        "type": "string",
                                    },
                                },
                                "required": ["service-url"],
                                "type": "object",
                            },
                            "pagerduty": {
                                "description": "PagerDuty integration for the service.",
                                "properties": {
                                    "service-url": {
                                        "description": "PagerDuty service url.",
                                        "example": "https://my-org.pagerduty.com/service-directory/PMyService",
                                        "type": "string",
                                    }
                                },
                                "type": "object",
                            },
                        },
                        "type": "object",
                    },
                    "lifecycle": {
                        "description": "The current life cycle phase of the service.",
                        "example": "sandbox",
                        "type": "string",
                    },
                    "links": {
                        "description": "A list of links related to the services.",
                        "items": {
                            "description": "Service's external links.",
                            "properties": {
                                "name": {
                                    "description": "Link name.",
                                    "example": "Runbook",
                                    "type": "string",
                                },
                                "provider": {
                                    "description": "Link provider.",
                                    "example": "Github",
                                    "type": "string",
                                },
                                "type": {
                                    "description": "Link type.",
                                    "enum": ["doc", "repo", "runbook", "dashboard", "other"],
                                    "example": "runbook",
                                    "type": "string",
                                    "x-enum-varnames": [
                                        "DOC",
                                        "REPO",
                                        "RUNBOOK",
                                        "DASHBOARD",
                                        "OTHER",
                                    ],
                                },
                                "url": {
                                    "description": "Link URL.",
                                    "example": "https://my-runbook",
                                    "type": "string",
                                },
                            },
                            "required": ["name", "type", "url"],
                            "type": "object",
                        },
                        "type": "array",
                    },
                    "schema-version": {
                        "default": "v2.1",
                        "description": "Schema version being used.",
                        "enum": ["v2.1"],
                        "example": "v2.1",
                        "type": "string",
                        "x-enum-varnames": ["V2_1"],
                    },
                    "tags": {
                        "description": "A set of custom tags.",
                        "example": ["my:tag", "service:tag"],
                        "items": {"type": "string"},
                        "type": "array",
                    },
                    "team": {
                        "description": "Team that owns the service. It is "
                        "used to locate a team defined in "
                        "Datadog Teams if it exists.",
                        "example": "my-team",
                        "type": "string",
                    },
                    "tier": {
                        "description": "Importance of the service.",
                        "example": "High",
                        "type": "string",
                    },
                },
                "required": ["schema-version", "dd-service"],
                "type": "object",
            },
            {
                "description": "Service definition V2 for providing service metadata and "
                "integrations.",
                "properties": {
                    "contacts": {
                        "description": "A list of contacts related to the services.",
                        "items": {
                            "description": "Service owner's contacts information.",
                            "oneOf": [
                                {
                                    "description": "Service owner's email.",
                                    "properties": {
                                        "contact": {
                                            "description": "Contact value.",
                                            "example": "contact@datadoghq.com",
                                            "type": "string",
                                        },
                                        "name": {
                                            "description": "Contact email.",
                                            "example": "Team Email",
                                            "type": "string",
                                        },
                                        "type": {
                                            "description": "Contact type.",
                                            "enum": ["email"],
                                            "example": "email",
                                            "type": "string",
                                            "x-enum-varnames": ["EMAIL"],
                                        },
                                    },
                                    "required": ["type", "contact"],
                                    "type": "object",
                                },
                                {
                                    "description": "Service owner's Slack channel.",
                                    "properties": {
                                        "contact": {
                                            "description": "Slack Channel.",
                                            "example": "https://yourcompany.slack.com/archives/channel123",
                                            "type": "string",
                                        },
                                        "name": {
                                            "description": "Contact Slack.",
                                            "example": "Team Slack",
                                            "type": "string",
                                        },
                                        "type": {
                                            "description": "Contact type.",
                                            "enum": ["slack"],
                                            "example": "slack",
                                            "type": "string",
                                            "x-enum-varnames": ["SLACK"],
                                        },
                                    },
                                    "required": ["type", "contact"],
                                    "type": "object",
                                },
                                {
                                    "description": "Service owner's Microsoft Teams.",
                                    "properties": {
                                        "contact": {
                                            "description": "Contact value.",
                                            "example": "https://teams.microsoft.com/myteam",
                                            "type": "string",
                                        },
                                        "name": {
                                            "description": "Contact Microsoft Teams.",
                                            "example": "My team channel",
                                            "type": "string",
                                        },
                                        "type": {
                                            "description": "Contact type.",
                                            "enum": ["microsoft-teams"],
                                            "example": "microsoft-teams",
                                            "type": "string",
                                            "x-enum-varnames": ["MICROSOFT_TEAMS"],
                                        },
                                    },
                                    "required": ["type", "contact"],
                                    "type": "object",
                                },
                            ],
                        },
                        "type": "array",
                    },
                    "dd-service": {
                        "description": "Unique identifier of the "
                        "service. Must be unique "
                        "across all services and is "
                        "used to match with a service "
                        "in Datadog.",
                        "example": "my-service",
                        "type": "string",
                    },
                    "dd-team": {
                        "description": "Experimental feature. A Team "
                        "handle that matches a Team in "
                        "the Datadog Teams product.",
                        "example": "my-team",
                        "type": "string",
                    },
                    "docs": {
                        "description": "A list of documentation related to the services.",
                        "items": {
                            "description": "Service documents.",
                            "properties": {
                                "name": {
                                    "description": "Document name.",
                                    "example": "Architecture",
                                    "type": "string",
                                },
                                "provider": {
                                    "description": "Document provider.",
                                    "example": "google drive",
                                    "type": "string",
                                },
                                "url": {
                                    "description": "Document URL.",
                                    "example": "https://gdrive/mydoc",
                                    "type": "string",
                                },
                            },
                            "required": ["name", "url"],
                            "type": "object",
                        },
                        "type": "array",
                    },
                    "extensions": {
                        "additionalProperties": {},
                        "description": "Extensions to V2 schema.",
                        "example": {"myorg/extension": "extensionValue"},
                        "type": "object",
                    },
                    "integrations": {
                        "description": "Third party integrations that Datadog supports.",
                        "properties": {
                            "opsgenie": {
                                "description": "Opsgenie integration for the service.",
                                "properties": {
                                    "region": {
                                        "description": "Opsgenie instance region.",
                                        "enum": ["US", "EU"],
                                        "example": "US",
                                        "type": "string",
                                        "x-enum-varnames": ["US", "EU"],
                                    },
                                    "service-url": {
                                        "description": "Opsgenie service url.",
                                        "example": "https://my-org.opsgenie.com/service/123e4567-e89b-12d3-a456-426614174000",
                                        "type": "string",
                                    },
                                },
                                "required": ["service-url"],
                                "type": "object",
                            },
                            "pagerduty": {
                                "description": "PagerDuty service URL for the service.",
                                "example": "https://my-org.pagerduty.com/service-directory/PMyService",
                                "type": "string",
                            },
                        },
                        "type": "object",
                    },
                    "links": {
                        "description": "A list of links related to the services.",
                        "items": {
                            "description": "Service's external links.",
                            "properties": {
                                "name": {
                                    "description": "Link name.",
                                    "example": "Runbook",
                                    "type": "string",
                                },
                                "type": {
                                    "description": "Link type.",
                                    "enum": [
                                        "doc",
                                        "wiki",
                                        "runbook",
                                        "url",
                                        "repo",
                                        "dashboard",
                                        "oncall",
                                        "code",
                                        "link",
                                    ],
                                    "example": "runbook",
                                    "type": "string",
                                    "x-enum-varnames": [
                                        "DOC",
                                        "WIKI",
                                        "RUNBOOK",
                                        "URL",
                                        "REPO",
                                        "DASHBOARD",
                                        "ONCALL",
                                        "CODE",
                                        "LINK",
                                    ],
                                },
                                "url": {
                                    "description": "Link URL.",
                                    "example": "https://my-runbook",
                                    "type": "string",
                                },
                            },
                            "required": ["name", "type", "url"],
                            "type": "object",
                        },
                        "type": "array",
                    },
                    "repos": {
                        "description": "A list of code repositories related to the services.",
                        "items": {
                            "description": "Service code repositories.",
                            "properties": {
                                "name": {
                                    "description": "Repository name.",
                                    "example": "Source Code",
                                    "type": "string",
                                },
                                "provider": {
                                    "description": "Repository provider.",
                                    "example": "GitHub",
                                    "type": "string",
                                },
                                "url": {
                                    "description": "Repository URL.",
                                    "example": "https://github.com/DataDog/schema",
                                    "type": "string",
                                },
                            },
                            "required": ["name", "url"],
                            "type": "object",
                        },
                        "type": "array",
                    },
                    "schema-version": {
                        "default": "v2",
                        "description": "Schema version being used.",
                        "enum": ["v2"],
                        "example": "v2",
                        "type": "string",
                        "x-enum-varnames": ["V2"],
                    },
                    "tags": {
                        "description": "A set of custom tags.",
                        "example": ["my:tag", "service:tag"],
                        "items": {"type": "string"},
                        "type": "array",
                    },
                    "team": {
                        "description": "Team that owns the service.",
                        "example": "my-team",
                        "type": "string",
                    },
                },
                "required": ["schema-version", "dd-service"],
                "type": "object",
            },
            {
                "description": "Service Definition in raw JSON/YAML representation.",
                "example": "---\nschema-version: v2\ndd-service: my-service",
                "type": "string",
            },
        ],
    },
    "RUNHISTORICALDETECTIONJOB_REQUEST_BODY_SCHEMA": {
        "description": "Run a historical job request.",
        "properties": {
            "data": {
                "description": "Data for running a historical job request.",
                "properties": {
                    "attributes": {
                        "description": "Run a historical job request.",
                        "properties": {
                            "fromRule": {
                                "description": "Definition "
                                "of "
                                "a "
                                "historical "
                                "job "
                                "based "
                                "on "
                                "a "
                                "security "
                                "monitoring "
                                "rule.",
                                "properties": {
                                    "from": {
                                        "description": "Starting time of data analyzed by the job.",
                                        "example": 1729843470000,
                                        "format": "int64",
                                        "type": "integer",
                                    },
                                    "id": {
                                        "description": "ID "
                                        "of "
                                        "the "
                                        "detection "
                                        "rule "
                                        "used "
                                        "to "
                                        "create "
                                        "the "
                                        "job.",
                                        "example": "abc-def-ghi",
                                        "type": "string",
                                    },
                                    "index": {
                                        "description": "Index used to load the data.",
                                        "example": "cloud_siem",
                                        "type": "string",
                                    },
                                    "notifications": {
                                        "description": "Notifications "
                                        "sent "
                                        "when "
                                        "the "
                                        "job "
                                        "is "
                                        "completed.",
                                        "example": ["@sns-cloudtrail-results"],
                                        "items": {"type": "string"},
                                        "type": "array",
                                    },
                                    "to": {
                                        "description": "Ending time of data analyzed by the job.",
                                        "example": 1729847070000,
                                        "format": "int64",
                                        "type": "integer",
                                    },
                                },
                                "required": ["id", "from", "to", "index"],
                                "type": "object",
                            },
                            "id": {"description": "Request ID.", "type": "string"},
                            "jobDefinition": {
                                "description": "Definition of a historical job.",
                                "properties": {
                                    "calculatedFields": {
                                        "description": "Calculated fields.",
                                        "items": {
                                            "description": "Calculated field.",
                                            "properties": {
                                                "expression": {
                                                    "description": "Expression.",
                                                    "example": "@request_end_timestamp "
                                                    "- "
                                                    "@request_start_timestamp",
                                                    "type": "string",
                                                },
                                                "name": {
                                                    "description": "Field name.",
                                                    "example": "response_time",
                                                    "type": "string",
                                                },
                                            },
                                            "required": ["name", "expression"],
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "cases": {
                                        "description": "Cases used for generating job results.",
                                        "items": {
                                            "description": "Case when signal is generated.",
                                            "properties": {
                                                "actions": {
                                                    "description": "Action "
                                                    "to "
                                                    "perform "
                                                    "for "
                                                    "each "
                                                    "rule "
                                                    "case.",
                                                    "items": {
                                                        "description": "Action "
                                                        "to "
                                                        "perform "
                                                        "when "
                                                        "a "
                                                        "signal "
                                                        "is "
                                                        "triggered. "
                                                        "Only "
                                                        "available "
                                                        "for "
                                                        "Application "
                                                        "Security "
                                                        "rule "
                                                        "type.",
                                                        "properties": {
                                                            "options": {
                                                                "additionalProperties": {},
                                                                "description": "Options "
                                                                "for "
                                                                "the "
                                                                "rule "
                                                                "action",
                                                                "properties": {
                                                                    "duration": {
                                                                        "description": "Duration "
                                                                        "of "
                                                                        "the "
                                                                        "action "
                                                                        "in "
                                                                        "seconds. "
                                                                        "0 "
                                                                        "indicates "
                                                                        "no "
                                                                        "expiration.",
                                                                        "example": 0,
                                                                        "format": "int64",
                                                                        "minimum": 0,
                                                                        "type": "integer",
                                                                    },
                                                                    "flaggedIPType": {
                                                                        "description": "Used "
                                                                        "with "
                                                                        "the "
                                                                        "case "
                                                                        "action "
                                                                        "of "
                                                                        "type "
                                                                        "'flag_ip'. "
                                                                        "The "
                                                                        "value "
                                                                        "specified "
                                                                        "in "
                                                                        "this "
                                                                        "field "
                                                                        "is "
                                                                        "applied "
                                                                        "as "
                                                                        "a "
                                                                        "flag "
                                                                        "to "
                                                                        "the "
                                                                        "IP "
                                                                        "addresses.",
                                                                        "enum": [
                                                                            "SUSPICIOUS",
                                                                            "FLAGGED",
                                                                        ],
                                                                        "example": "FLAGGED",
                                                                        "type": "string",
                                                                        "x-enum-varnames": [
                                                                            "SUSPICIOUS",
                                                                            "FLAGGED",
                                                                        ],
                                                                    },
                                                                    "userBehaviorName": {
                                                                        "description": "Used "
                                                                        "with "
                                                                        "the "
                                                                        "case "
                                                                        "action "
                                                                        "of "
                                                                        "type "
                                                                        "'user_behavior'. "
                                                                        "The "
                                                                        "value "
                                                                        "specified "
                                                                        "in "
                                                                        "this "
                                                                        "field "
                                                                        "is "
                                                                        "applied "
                                                                        "as "
                                                                        "a "
                                                                        "risk "
                                                                        "tag "
                                                                        "to "
                                                                        "all "
                                                                        "users "
                                                                        "affected "
                                                                        "by "
                                                                        "the "
                                                                        "rule.",
                                                                        "type": "string",
                                                                    },
                                                                },
                                                                "type": "object",
                                                            },
                                                            "type": {
                                                                "description": "The action type.",
                                                                "enum": [
                                                                    "block_ip",
                                                                    "block_user",
                                                                    "user_behavior",
                                                                    "flag_ip",
                                                                ],
                                                                "type": "string",
                                                                "x-enum-varnames": [
                                                                    "BLOCK_IP",
                                                                    "BLOCK_USER",
                                                                    "USER_BEHAVIOR",
                                                                    "FLAG_IP",
                                                                ],
                                                            },
                                                        },
                                                        "type": "object",
                                                    },
                                                    "type": "array",
                                                },
                                                "condition": {
                                                    "description": "A "
                                                    "case "
                                                    "contains "
                                                    "logical "
                                                    "operations "
                                                    "(`>`,`>=`, "
                                                    "`&&`, "
                                                    "`||`) "
                                                    "to "
                                                    "determine "
                                                    "if "
                                                    "a "
                                                    "signal "
                                                    "should "
                                                    "be "
                                                    "generated\n"
                                                    "based "
                                                    "on "
                                                    "the "
                                                    "event "
                                                    "counts "
                                                    "in "
                                                    "the "
                                                    "previously "
                                                    "defined "
                                                    "queries.",
                                                    "type": "string",
                                                },
                                                "name": {
                                                    "description": "Name of the case.",
                                                    "type": "string",
                                                },
                                                "notifications": {
                                                    "description": "Notification targets.",
                                                    "items": {
                                                        "description": "Notification.",
                                                        "type": "string",
                                                    },
                                                    "type": "array",
                                                },
                                                "status": {
                                                    "description": "Severity "
                                                    "of "
                                                    "the "
                                                    "Security "
                                                    "Signal.",
                                                    "enum": [
                                                        "info",
                                                        "low",
                                                        "medium",
                                                        "high",
                                                        "critical",
                                                    ],
                                                    "example": "critical",
                                                    "type": "string",
                                                    "x-enum-varnames": [
                                                        "INFO",
                                                        "LOW",
                                                        "MEDIUM",
                                                        "HIGH",
                                                        "CRITICAL",
                                                    ],
                                                },
                                            },
                                            "required": ["status"],
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "from": {
                                        "description": "Starting time of data analyzed by the job.",
                                        "example": 1729843470000,
                                        "format": "int64",
                                        "type": "integer",
                                    },
                                    "groupSignalsBy": {
                                        "description": "Additional "
                                        "grouping "
                                        "to "
                                        "perform "
                                        "on "
                                        "top "
                                        "of "
                                        "the "
                                        "existing "
                                        "groups "
                                        "in "
                                        "the "
                                        "query "
                                        "section. "
                                        "Must "
                                        "be "
                                        "a "
                                        "subset "
                                        "of "
                                        "the "
                                        "existing "
                                        "groups.",
                                        "example": ["service"],
                                        "items": {
                                            "description": "Field to group by.",
                                            "type": "string",
                                        },
                                        "type": "array",
                                    },
                                    "index": {
                                        "description": "Index used to load the data.",
                                        "example": "cloud_siem",
                                        "type": "string",
                                    },
                                    "message": {
                                        "description": "Message for generated results.",
                                        "example": "A large number of failed login attempts.",
                                        "type": "string",
                                    },
                                    "name": {
                                        "description": "Job name.",
                                        "example": "Excessive number of failed attempts.",
                                        "type": "string",
                                    },
                                    "options": {
                                        "description": "Job options.",
                                        "properties": {
                                            "detectionMethod": {
                                                "description": "The detection method.",
                                                "enum": [
                                                    "threshold",
                                                    "new_value",
                                                    "anomaly_detection",
                                                    "impossible_travel",
                                                    "hardcoded",
                                                    "third_party",
                                                    "anomaly_threshold",
                                                    "sequence_detection",
                                                ],
                                                "type": "string",
                                                "x-enum-varnames": [
                                                    "THRESHOLD",
                                                    "NEW_VALUE",
                                                    "ANOMALY_DETECTION",
                                                    "IMPOSSIBLE_TRAVEL",
                                                    "HARDCODED",
                                                    "THIRD_PARTY",
                                                    "ANOMALY_THRESHOLD",
                                                    "SEQUENCE_DETECTION",
                                                ],
                                            },
                                            "evaluationWindow": {
                                                "description": "A "
                                                "time "
                                                "window "
                                                "is "
                                                "specified "
                                                "to "
                                                "match "
                                                "when "
                                                "at "
                                                "least "
                                                "one "
                                                "of "
                                                "the "
                                                "cases "
                                                "matches "
                                                "true. "
                                                "This "
                                                "is "
                                                "a "
                                                "sliding "
                                                "window\n"
                                                "and "
                                                "evaluates "
                                                "in "
                                                "real "
                                                "time. "
                                                "For "
                                                "third "
                                                "party "
                                                "detection "
                                                "method, "
                                                "this "
                                                "field "
                                                "is "
                                                "not "
                                                "used.",
                                                "enum": [
                                                    0,
                                                    60,
                                                    300,
                                                    600,
                                                    900,
                                                    1800,
                                                    3600,
                                                    7200,
                                                    10800,
                                                    21600,
                                                    43200,
                                                    86400,
                                                ],
                                                "format": "int32",
                                                "type": "integer",
                                                "x-enum-varnames": [
                                                    "ZERO_MINUTES",
                                                    "ONE_MINUTE",
                                                    "FIVE_MINUTES",
                                                    "TEN_MINUTES",
                                                    "FIFTEEN_MINUTES",
                                                    "THIRTY_MINUTES",
                                                    "ONE_HOUR",
                                                    "TWO_HOURS",
                                                    "THREE_HOURS",
                                                    "SIX_HOURS",
                                                    "TWELVE_HOURS",
                                                    "ONE_DAY",
                                                ],
                                            },
                                            "impossibleTravelOptions": {
                                                "description": "Options "
                                                "on "
                                                "impossible "
                                                "travel "
                                                "detection "
                                                "method.",
                                                "properties": {
                                                    "baselineUserLocations": {
                                                        "description": "If "
                                                        "true, "
                                                        "signals "
                                                        "are "
                                                        "suppressed "
                                                        "for "
                                                        "the "
                                                        "first "
                                                        "24 "
                                                        "hours. "
                                                        "In "
                                                        "that "
                                                        "time, "
                                                        "Datadog "
                                                        "learns "
                                                        "the "
                                                        "user's "
                                                        "regular\n"
                                                        "access "
                                                        "locations. "
                                                        "This "
                                                        "can "
                                                        "be "
                                                        "helpful "
                                                        "to "
                                                        "reduce "
                                                        "noise "
                                                        "and "
                                                        "infer "
                                                        "VPN "
                                                        "usage "
                                                        "or "
                                                        "credentialed "
                                                        "API "
                                                        "access.",
                                                        "example": True,
                                                        "type": "boolean",
                                                    }
                                                },
                                                "type": "object",
                                            },
                                            "keepAlive": {
                                                "description": "Once "
                                                "a "
                                                "signal "
                                                "is "
                                                "generated, "
                                                "the "
                                                "signal "
                                                "will "
                                                "remain "
                                                '"open" '
                                                "if "
                                                "a "
                                                "case "
                                                "is "
                                                "matched "
                                                "at "
                                                "least "
                                                "once "
                                                "within\n"
                                                "this "
                                                "keep "
                                                "alive "
                                                "window. "
                                                "For "
                                                "third "
                                                "party "
                                                "detection "
                                                "method, "
                                                "this "
                                                "field "
                                                "is "
                                                "not "
                                                "used.",
                                                "enum": [
                                                    0,
                                                    60,
                                                    300,
                                                    600,
                                                    900,
                                                    1800,
                                                    3600,
                                                    7200,
                                                    10800,
                                                    21600,
                                                    43200,
                                                    86400,
                                                ],
                                                "format": "int32",
                                                "type": "integer",
                                                "x-enum-varnames": [
                                                    "ZERO_MINUTES",
                                                    "ONE_MINUTE",
                                                    "FIVE_MINUTES",
                                                    "TEN_MINUTES",
                                                    "FIFTEEN_MINUTES",
                                                    "THIRTY_MINUTES",
                                                    "ONE_HOUR",
                                                    "TWO_HOURS",
                                                    "THREE_HOURS",
                                                    "SIX_HOURS",
                                                    "TWELVE_HOURS",
                                                    "ONE_DAY",
                                                ],
                                            },
                                            "maxSignalDuration": {
                                                "description": "A "
                                                "signal "
                                                "will "
                                                '"close" '
                                                "regardless "
                                                "of "
                                                "the "
                                                "query "
                                                "being "
                                                "matched "
                                                "once "
                                                "the "
                                                "time "
                                                "exceeds "
                                                "the "
                                                "maximum "
                                                "duration.\n"
                                                "This "
                                                "time "
                                                "is "
                                                "calculated "
                                                "from "
                                                "the "
                                                "first "
                                                "seen "
                                                "timestamp.",
                                                "enum": [
                                                    0,
                                                    60,
                                                    300,
                                                    600,
                                                    900,
                                                    1800,
                                                    3600,
                                                    7200,
                                                    10800,
                                                    21600,
                                                    43200,
                                                    86400,
                                                ],
                                                "format": "int32",
                                                "type": "integer",
                                                "x-enum-varnames": [
                                                    "ZERO_MINUTES",
                                                    "ONE_MINUTE",
                                                    "FIVE_MINUTES",
                                                    "TEN_MINUTES",
                                                    "FIFTEEN_MINUTES",
                                                    "THIRTY_MINUTES",
                                                    "ONE_HOUR",
                                                    "TWO_HOURS",
                                                    "THREE_HOURS",
                                                    "SIX_HOURS",
                                                    "TWELVE_HOURS",
                                                    "ONE_DAY",
                                                ],
                                            },
                                            "newValueOptions": {
                                                "description": "Options "
                                                "on "
                                                "new "
                                                "value "
                                                "detection "
                                                "method.",
                                                "properties": {
                                                    "forgetAfter": {
                                                        "description": "The "
                                                        "duration "
                                                        "in "
                                                        "days "
                                                        "after "
                                                        "which "
                                                        "a "
                                                        "learned "
                                                        "value "
                                                        "is "
                                                        "forgotten.",
                                                        "enum": [1, 2, 7, 14, 21, 28],
                                                        "format": "int32",
                                                        "type": "integer",
                                                        "x-enum-varnames": [
                                                            "ONE_DAY",
                                                            "TWO_DAYS",
                                                            "ONE_WEEK",
                                                            "TWO_WEEKS",
                                                            "THREE_WEEKS",
                                                            "FOUR_WEEKS",
                                                        ],
                                                    },
                                                    "learningDuration": {
                                                        "default": 0,
                                                        "description": "The "
                                                        "duration "
                                                        "in "
                                                        "days "
                                                        "during "
                                                        "which "
                                                        "values "
                                                        "are "
                                                        "learned, "
                                                        "and "
                                                        "after "
                                                        "which "
                                                        "signals "
                                                        "will "
                                                        "be "
                                                        "generated "
                                                        "for "
                                                        "values "
                                                        "that\n"
                                                        "weren't "
                                                        "learned. "
                                                        "If "
                                                        "set "
                                                        "to "
                                                        "0, "
                                                        "a "
                                                        "signal "
                                                        "will "
                                                        "be "
                                                        "generated "
                                                        "for "
                                                        "all "
                                                        "new "
                                                        "values "
                                                        "after "
                                                        "the "
                                                        "first "
                                                        "value "
                                                        "is "
                                                        "learned.",
                                                        "enum": [0, 1, 7],
                                                        "format": "int32",
                                                        "type": "integer",
                                                        "x-enum-varnames": [
                                                            "ZERO_DAYS",
                                                            "ONE_DAY",
                                                            "SEVEN_DAYS",
                                                        ],
                                                    },
                                                    "learningMethod": {
                                                        "default": "duration",
                                                        "description": "The "
                                                        "learning "
                                                        "method "
                                                        "used "
                                                        "to "
                                                        "determine "
                                                        "when "
                                                        "signals "
                                                        "should "
                                                        "be "
                                                        "generated "
                                                        "for "
                                                        "values "
                                                        "that "
                                                        "weren't "
                                                        "learned.",
                                                        "enum": ["duration", "threshold"],
                                                        "type": "string",
                                                        "x-enum-varnames": [
                                                            "DURATION",
                                                            "THRESHOLD",
                                                        ],
                                                    },
                                                    "learningThreshold": {
                                                        "default": 0,
                                                        "description": "A "
                                                        "number "
                                                        "of "
                                                        "occurrences "
                                                        "after "
                                                        "which "
                                                        "signals "
                                                        "will "
                                                        "be "
                                                        "generated "
                                                        "for "
                                                        "values "
                                                        "that "
                                                        "weren't "
                                                        "learned.",
                                                        "enum": [0, 1],
                                                        "format": "int32",
                                                        "type": "integer",
                                                        "x-enum-varnames": [
                                                            "ZERO_OCCURRENCES",
                                                            "ONE_OCCURRENCE",
                                                        ],
                                                    },
                                                },
                                                "type": "object",
                                            },
                                            "sequenceDetectionOptions": {
                                                "description": "Options "
                                                "on "
                                                "sequence "
                                                "detection "
                                                "method.",
                                                "properties": {
                                                    "stepTransitions": {
                                                        "description": "Transitions "
                                                        "defining "
                                                        "the "
                                                        "allowed "
                                                        "order "
                                                        "of "
                                                        "steps "
                                                        "and "
                                                        "their "
                                                        "evaluation "
                                                        "windows.",
                                                        "items": {
                                                            "description": "Transition "
                                                            "from "
                                                            "a "
                                                            "parent "
                                                            "step "
                                                            "to "
                                                            "a "
                                                            "child "
                                                            "step "
                                                            "within "
                                                            "a "
                                                            "sequence "
                                                            "detection "
                                                            "rule.",
                                                            "properties": {
                                                                "child": {
                                                                    "description": "Name "
                                                                    "of "
                                                                    "the "
                                                                    "child "
                                                                    "step.",
                                                                    "type": "string",
                                                                },
                                                                "evaluationWindow": {
                                                                    "description": "A "
                                                                    "time "
                                                                    "window "
                                                                    "is "
                                                                    "specified "
                                                                    "to "
                                                                    "match "
                                                                    "when "
                                                                    "at "
                                                                    "least "
                                                                    "one "
                                                                    "of "
                                                                    "the "
                                                                    "cases "
                                                                    "matches "
                                                                    "true. "
                                                                    "This "
                                                                    "is "
                                                                    "a "
                                                                    "sliding "
                                                                    "window\n"
                                                                    "and "
                                                                    "evaluates "
                                                                    "in "
                                                                    "real "
                                                                    "time. "
                                                                    "For "
                                                                    "third "
                                                                    "party "
                                                                    "detection "
                                                                    "method, "
                                                                    "this "
                                                                    "field "
                                                                    "is "
                                                                    "not "
                                                                    "used.",
                                                                    "enum": [
                                                                        0,
                                                                        60,
                                                                        300,
                                                                        600,
                                                                        900,
                                                                        1800,
                                                                        3600,
                                                                        7200,
                                                                        10800,
                                                                        21600,
                                                                        43200,
                                                                        86400,
                                                                    ],
                                                                    "format": "int32",
                                                                    "type": "integer",
                                                                    "x-enum-varnames": [
                                                                        "ZERO_MINUTES",
                                                                        "ONE_MINUTE",
                                                                        "FIVE_MINUTES",
                                                                        "TEN_MINUTES",
                                                                        "FIFTEEN_MINUTES",
                                                                        "THIRTY_MINUTES",
                                                                        "ONE_HOUR",
                                                                        "TWO_HOURS",
                                                                        "THREE_HOURS",
                                                                        "SIX_HOURS",
                                                                        "TWELVE_HOURS",
                                                                        "ONE_DAY",
                                                                    ],
                                                                },
                                                                "parent": {
                                                                    "description": "Name "
                                                                    "of "
                                                                    "the "
                                                                    "parent "
                                                                    "step.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "type": "object",
                                                        },
                                                        "type": "array",
                                                    },
                                                    "steps": {
                                                        "description": "Steps "
                                                        "that "
                                                        "define "
                                                        "the "
                                                        "conditions "
                                                        "to "
                                                        "be "
                                                        "matched "
                                                        "in "
                                                        "sequence.",
                                                        "items": {
                                                            "description": "Step "
                                                            "definition "
                                                            "for "
                                                            "sequence "
                                                            "detection "
                                                            "containing "
                                                            "the "
                                                            "step "
                                                            "name, "
                                                            "condition, "
                                                            "and "
                                                            "evaluation "
                                                            "window.",
                                                            "properties": {
                                                                "condition": {
                                                                    "description": "Condition "
                                                                    "referencing "
                                                                    "rule "
                                                                    "queries "
                                                                    "(e.g., "
                                                                    "`a "
                                                                    "> "
                                                                    "0`).",
                                                                    "type": "string",
                                                                },
                                                                "evaluationWindow": {
                                                                    "description": "A "
                                                                    "time "
                                                                    "window "
                                                                    "is "
                                                                    "specified "
                                                                    "to "
                                                                    "match "
                                                                    "when "
                                                                    "at "
                                                                    "least "
                                                                    "one "
                                                                    "of "
                                                                    "the "
                                                                    "cases "
                                                                    "matches "
                                                                    "true. "
                                                                    "This "
                                                                    "is "
                                                                    "a "
                                                                    "sliding "
                                                                    "window\n"
                                                                    "and "
                                                                    "evaluates "
                                                                    "in "
                                                                    "real "
                                                                    "time. "
                                                                    "For "
                                                                    "third "
                                                                    "party "
                                                                    "detection "
                                                                    "method, "
                                                                    "this "
                                                                    "field "
                                                                    "is "
                                                                    "not "
                                                                    "used.",
                                                                    "enum": [
                                                                        0,
                                                                        60,
                                                                        300,
                                                                        600,
                                                                        900,
                                                                        1800,
                                                                        3600,
                                                                        7200,
                                                                        10800,
                                                                        21600,
                                                                        43200,
                                                                        86400,
                                                                    ],
                                                                    "format": "int32",
                                                                    "type": "integer",
                                                                    "x-enum-varnames": [
                                                                        "ZERO_MINUTES",
                                                                        "ONE_MINUTE",
                                                                        "FIVE_MINUTES",
                                                                        "TEN_MINUTES",
                                                                        "FIFTEEN_MINUTES",
                                                                        "THIRTY_MINUTES",
                                                                        "ONE_HOUR",
                                                                        "TWO_HOURS",
                                                                        "THREE_HOURS",
                                                                        "SIX_HOURS",
                                                                        "TWELVE_HOURS",
                                                                        "ONE_DAY",
                                                                    ],
                                                                },
                                                                "name": {
                                                                    "description": "Unique "
                                                                    "name "
                                                                    "identifying "
                                                                    "the "
                                                                    "step.",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "type": "object",
                                                        },
                                                        "type": "array",
                                                    },
                                                },
                                                "type": "object",
                                            },
                                            "thirdPartyRuleOptions": {
                                                "description": "Options "
                                                "on "
                                                "third "
                                                "party "
                                                "detection "
                                                "method.",
                                                "properties": {
                                                    "defaultNotifications": {
                                                        "description": "Notification "
                                                        "targets "
                                                        "for "
                                                        "the "
                                                        "logs "
                                                        "that "
                                                        "do "
                                                        "not "
                                                        "correspond "
                                                        "to "
                                                        "any "
                                                        "of "
                                                        "the "
                                                        "cases.",
                                                        "items": {
                                                            "description": "Notification.",
                                                            "type": "string",
                                                        },
                                                        "type": "array",
                                                    },
                                                    "defaultStatus": {
                                                        "description": "Severity "
                                                        "of "
                                                        "the "
                                                        "Security "
                                                        "Signal.",
                                                        "enum": [
                                                            "info",
                                                            "low",
                                                            "medium",
                                                            "high",
                                                            "critical",
                                                        ],
                                                        "example": "critical",
                                                        "type": "string",
                                                        "x-enum-varnames": [
                                                            "INFO",
                                                            "LOW",
                                                            "MEDIUM",
                                                            "HIGH",
                                                            "CRITICAL",
                                                        ],
                                                    },
                                                    "rootQueries": {
                                                        "description": "Queries "
                                                        "to "
                                                        "be "
                                                        "combined "
                                                        "with "
                                                        "third "
                                                        "party "
                                                        "case "
                                                        "queries. "
                                                        "Each "
                                                        "of "
                                                        "them "
                                                        "can "
                                                        "have "
                                                        "different "
                                                        "group "
                                                        "by "
                                                        "fields, "
                                                        "to "
                                                        "aggregate "
                                                        "differently "
                                                        "based "
                                                        "on "
                                                        "the "
                                                        "type "
                                                        "of "
                                                        "alert.",
                                                        "items": {
                                                            "description": "A "
                                                            "query "
                                                            "to "
                                                            "be "
                                                            "combined "
                                                            "with "
                                                            "the "
                                                            "third "
                                                            "party "
                                                            "case "
                                                            "query.",
                                                            "properties": {
                                                                "groupByFields": {
                                                                    "description": "Fields "
                                                                    "to "
                                                                    "group "
                                                                    "by.",
                                                                    "items": {
                                                                        "description": "Field.",
                                                                        "type": "string",
                                                                    },
                                                                    "type": "array",
                                                                },
                                                                "query": {
                                                                    "description": "Query "
                                                                    "to "
                                                                    "run "
                                                                    "on "
                                                                    "logs.",
                                                                    "example": "source:cloudtrail",
                                                                    "type": "string",
                                                                },
                                                            },
                                                            "type": "object",
                                                        },
                                                        "type": "array",
                                                    },
                                                    "signalTitleTemplate": {
                                                        "description": "A "
                                                        "template "
                                                        "for "
                                                        "the "
                                                        "signal "
                                                        "title; "
                                                        "if "
                                                        "omitted, "
                                                        "the "
                                                        "title "
                                                        "is "
                                                        "generated "
                                                        "based "
                                                        "on "
                                                        "the "
                                                        "case "
                                                        "name.",
                                                        "type": "string",
                                                    },
                                                },
                                                "type": "object",
                                            },
                                        },
                                        "type": "object",
                                    },
                                    "queries": {
                                        "description": "Queries "
                                        "for "
                                        "selecting "
                                        "logs "
                                        "analyzed "
                                        "by "
                                        "the "
                                        "job.",
                                        "items": {
                                            "description": "Query "
                                            "for "
                                            "selecting "
                                            "logs "
                                            "analyzed "
                                            "by "
                                            "the "
                                            "historical "
                                            "job.",
                                            "properties": {
                                                "aggregation": {
                                                    "description": "The aggregation type.",
                                                    "enum": [
                                                        "count",
                                                        "cardinality",
                                                        "sum",
                                                        "max",
                                                        "new_value",
                                                        "geo_data",
                                                        "event_count",
                                                        "none",
                                                    ],
                                                    "type": "string",
                                                    "x-enum-varnames": [
                                                        "COUNT",
                                                        "CARDINALITY",
                                                        "SUM",
                                                        "MAX",
                                                        "NEW_VALUE",
                                                        "GEO_DATA",
                                                        "EVENT_COUNT",
                                                        "NONE",
                                                    ],
                                                },
                                                "dataSource": {
                                                    "default": "logs",
                                                    "description": "Source "
                                                    "of "
                                                    "events, "
                                                    "either "
                                                    "logs, "
                                                    "audit "
                                                    "trail, "
                                                    "or "
                                                    "Datadog "
                                                    "events.",
                                                    "enum": [
                                                        "logs",
                                                        "audit",
                                                        "app_sec_spans",
                                                        "spans",
                                                        "security_runtime",
                                                        "network",
                                                        "events",
                                                    ],
                                                    "example": "logs",
                                                    "type": "string",
                                                    "x-enum-varnames": [
                                                        "LOGS",
                                                        "AUDIT",
                                                        "APP_SEC_SPANS",
                                                        "SPANS",
                                                        "SECURITY_RUNTIME",
                                                        "NETWORK",
                                                        "EVENTS",
                                                    ],
                                                },
                                                "distinctFields": {
                                                    "description": "Field "
                                                    "for "
                                                    "which "
                                                    "the "
                                                    "cardinality "
                                                    "is "
                                                    "measured. "
                                                    "Sent "
                                                    "as "
                                                    "an "
                                                    "array.",
                                                    "items": {
                                                        "description": "Field.",
                                                        "type": "string",
                                                    },
                                                    "type": "array",
                                                },
                                                "groupByFields": {
                                                    "description": "Fields to group by.",
                                                    "items": {
                                                        "description": "Field.",
                                                        "type": "string",
                                                    },
                                                    "type": "array",
                                                },
                                                "hasOptionalGroupByFields": {
                                                    "default": False,
                                                    "description": "When "
                                                    "false, "
                                                    "events "
                                                    "without "
                                                    "a "
                                                    "group-by "
                                                    "value "
                                                    "are "
                                                    "ignored "
                                                    "by "
                                                    "the "
                                                    "query. "
                                                    "When "
                                                    "true, "
                                                    "events "
                                                    "with "
                                                    "missing "
                                                    "group-by "
                                                    "fields "
                                                    "are "
                                                    "processed "
                                                    "with "
                                                    "`N/A`, "
                                                    "replacing "
                                                    "the "
                                                    "missing "
                                                    "values.",
                                                    "example": False,
                                                    "type": "boolean",
                                                },
                                                "metrics": {
                                                    "description": "Group "
                                                    "of "
                                                    "target "
                                                    "fields "
                                                    "to "
                                                    "aggregate "
                                                    "over "
                                                    "when "
                                                    "using "
                                                    "the "
                                                    "sum, "
                                                    "max, "
                                                    "geo "
                                                    "data, "
                                                    "or "
                                                    "new "
                                                    "value "
                                                    "aggregations. "
                                                    "The "
                                                    "sum, "
                                                    "max, "
                                                    "and "
                                                    "geo "
                                                    "data "
                                                    "aggregations "
                                                    "only "
                                                    "accept "
                                                    "one "
                                                    "value "
                                                    "in "
                                                    "this "
                                                    "list, "
                                                    "whereas "
                                                    "the "
                                                    "new "
                                                    "value "
                                                    "aggregation "
                                                    "accepts "
                                                    "up "
                                                    "to "
                                                    "five "
                                                    "values.",
                                                    "items": {
                                                        "description": "Field.",
                                                        "type": "string",
                                                    },
                                                    "type": "array",
                                                },
                                                "name": {
                                                    "description": "Name of the query.",
                                                    "type": "string",
                                                },
                                                "query": {
                                                    "description": "Query to run on logs.",
                                                    "example": "a > 3",
                                                    "type": "string",
                                                },
                                            },
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "referenceTables": {
                                        "description": "Reference tables used in the queries.",
                                        "items": {
                                            "description": "Reference tables used in the queries.",
                                            "properties": {
                                                "checkPresence": {
                                                    "description": "Whether "
                                                    "to "
                                                    "include "
                                                    "or "
                                                    "exclude "
                                                    "the "
                                                    "matched "
                                                    "values.",
                                                    "type": "boolean",
                                                },
                                                "columnName": {
                                                    "description": "The "
                                                    "name "
                                                    "of "
                                                    "the "
                                                    "column "
                                                    "in "
                                                    "the "
                                                    "reference "
                                                    "table.",
                                                    "type": "string",
                                                },
                                                "logFieldPath": {
                                                    "description": "The "
                                                    "field "
                                                    "in "
                                                    "the "
                                                    "log "
                                                    "to "
                                                    "match "
                                                    "against "
                                                    "the "
                                                    "reference "
                                                    "table.",
                                                    "type": "string",
                                                },
                                                "ruleQueryName": {
                                                    "description": "The "
                                                    "name "
                                                    "of "
                                                    "the "
                                                    "query "
                                                    "to "
                                                    "apply "
                                                    "the "
                                                    "reference "
                                                    "table "
                                                    "to.",
                                                    "type": "string",
                                                },
                                                "tableName": {
                                                    "description": "The "
                                                    "name "
                                                    "of "
                                                    "the "
                                                    "reference "
                                                    "table.",
                                                    "type": "string",
                                                },
                                            },
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "tags": {
                                        "description": "Tags for generated signals.",
                                        "items": {"type": "string"},
                                        "type": "array",
                                    },
                                    "thirdPartyCases": {
                                        "description": "Cases "
                                        "for "
                                        "generating "
                                        "results "
                                        "from "
                                        "third-party "
                                        "detection "
                                        "method. "
                                        "Only "
                                        "available "
                                        "for "
                                        "third-party "
                                        "detection "
                                        "method.",
                                        "example": [],
                                        "items": {
                                            "description": "Case "
                                            "when "
                                            "a "
                                            "signal "
                                            "is "
                                            "generated "
                                            "by "
                                            "a "
                                            "third "
                                            "party "
                                            "rule.",
                                            "properties": {
                                                "name": {
                                                    "description": "Name of the case.",
                                                    "type": "string",
                                                },
                                                "notifications": {
                                                    "description": "Notification "
                                                    "targets "
                                                    "for "
                                                    "each "
                                                    "case.",
                                                    "items": {
                                                        "description": "Notification.",
                                                        "type": "string",
                                                    },
                                                    "type": "array",
                                                },
                                                "query": {
                                                    "description": "A "
                                                    "query "
                                                    "to "
                                                    "map "
                                                    "a "
                                                    "third "
                                                    "party "
                                                    "event "
                                                    "to "
                                                    "this "
                                                    "case.",
                                                    "type": "string",
                                                },
                                                "status": {
                                                    "description": "Severity "
                                                    "of "
                                                    "the "
                                                    "Security "
                                                    "Signal.",
                                                    "enum": [
                                                        "info",
                                                        "low",
                                                        "medium",
                                                        "high",
                                                        "critical",
                                                    ],
                                                    "example": "critical",
                                                    "type": "string",
                                                    "x-enum-varnames": [
                                                        "INFO",
                                                        "LOW",
                                                        "MEDIUM",
                                                        "HIGH",
                                                        "CRITICAL",
                                                    ],
                                                },
                                            },
                                            "required": ["status"],
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "to": {
                                        "description": "Ending time of data analyzed by the job.",
                                        "example": 1729847070000,
                                        "format": "int64",
                                        "type": "integer",
                                    },
                                    "type": {"description": "Job type.", "type": "string"},
                                },
                                "required": [
                                    "from",
                                    "to",
                                    "index",
                                    "name",
                                    "cases",
                                    "queries",
                                    "message",
                                ],
                                "type": "object",
                            },
                        },
                        "type": "object",
                    },
                    "type": {
                        "description": "Type of data.",
                        "enum": ["historicalDetectionsJobCreate"],
                        "type": "string",
                        "x-enum-varnames": ["HISTORICALDETECTIONSJOBCREATE"],
                    },
                },
                "type": "object",
            }
        },
        "type": "object",
    },
    "AGGREGATESPANSMETRICS_REQUEST_BODY_SCHEMA": {
        "description": "The object sent with the request to retrieve a list of aggregated "
        "spans from your organization.",
        "properties": {
            "data": {
                "description": "The object containing the query content.",
                "properties": {
                    "attributes": {
                        "description": "The object containing all the query parameters.",
                        "properties": {
                            "compute": {
                                "description": "The "
                                "list "
                                "of "
                                "metrics "
                                "or "
                                "timeseries "
                                "to "
                                "compute "
                                "for "
                                "the "
                                "retrieved "
                                "buckets.",
                                "items": {
                                    "description": "A "
                                    "compute "
                                    "rule "
                                    "to "
                                    "compute "
                                    "metrics "
                                    "or "
                                    "timeseries.",
                                    "properties": {
                                        "aggregation": {
                                            "description": "An aggregation function.",
                                            "enum": [
                                                "count",
                                                "cardinality",
                                                "pc75",
                                                "pc90",
                                                "pc95",
                                                "pc98",
                                                "pc99",
                                                "sum",
                                                "min",
                                                "max",
                                                "avg",
                                                "median",
                                            ],
                                            "example": "pc90",
                                            "type": "string",
                                            "x-enum-varnames": [
                                                "COUNT",
                                                "CARDINALITY",
                                                "PERCENTILE_75",
                                                "PERCENTILE_90",
                                                "PERCENTILE_95",
                                                "PERCENTILE_98",
                                                "PERCENTILE_99",
                                                "SUM",
                                                "MIN",
                                                "MAX",
                                                "AVG",
                                                "MEDIAN",
                                            ],
                                        },
                                        "interval": {
                                            "description": "The "
                                            "time "
                                            "buckets' "
                                            "size "
                                            "(only "
                                            "used "
                                            "for "
                                            "type=timeseries)\n"
                                            "Defaults "
                                            "to "
                                            "a "
                                            "resolution "
                                            "of "
                                            "150 "
                                            "points.",
                                            "example": "5m",
                                            "type": "string",
                                        },
                                        "metric": {
                                            "description": "The metric to use.",
                                            "example": "@duration",
                                            "type": "string",
                                        },
                                        "type": {
                                            "default": "total",
                                            "description": "The type of compute.",
                                            "enum": ["timeseries", "total"],
                                            "type": "string",
                                            "x-enum-varnames": ["TIMESERIES", "TOTAL"],
                                        },
                                    },
                                    "required": ["aggregation"],
                                    "type": "object",
                                },
                                "type": "array",
                            },
                            "filter": {
                                "description": "The search and filter query settings.",
                                "properties": {
                                    "from": {
                                        "default": "now-15m",
                                        "description": "The "
                                        "minimum "
                                        "time "
                                        "for "
                                        "the "
                                        "requested "
                                        "spans, "
                                        "supports "
                                        "date-time "
                                        "ISO8601, "
                                        "date "
                                        "math, "
                                        "and "
                                        "regular "
                                        "timestamps "
                                        "(milliseconds).",
                                        "example": "now-15m",
                                        "type": "string",
                                    },
                                    "query": {
                                        "default": "*",
                                        "description": "The "
                                        "search "
                                        "query "
                                        "- "
                                        "following "
                                        "the "
                                        "span "
                                        "search "
                                        "syntax.",
                                        "example": "service:web* "
                                        "AND "
                                        "@http.status_code:[200 "
                                        "TO "
                                        "299]",
                                        "type": "string",
                                    },
                                    "to": {
                                        "default": "now",
                                        "description": "The "
                                        "maximum "
                                        "time "
                                        "for "
                                        "the "
                                        "requested "
                                        "spans, "
                                        "supports "
                                        "date-time "
                                        "ISO8601, "
                                        "date "
                                        "math, "
                                        "and "
                                        "regular "
                                        "timestamps "
                                        "(milliseconds).",
                                        "example": "now",
                                        "type": "string",
                                    },
                                },
                                "type": "object",
                            },
                            "group_by": {
                                "description": "The rules for the group by.",
                                "items": {
                                    "description": "A group by rule.",
                                    "properties": {
                                        "facet": {
                                            "description": "The "
                                            "name "
                                            "of "
                                            "the "
                                            "facet "
                                            "to "
                                            "use "
                                            "(required).",
                                            "example": "host",
                                            "type": "string",
                                        },
                                        "histogram": {
                                            "description": "Used "
                                            "to "
                                            "perform "
                                            "a "
                                            "histogram "
                                            "computation "
                                            "(only "
                                            "for "
                                            "measure "
                                            "facets).\n"
                                            "Note: "
                                            "At "
                                            "most "
                                            "100 "
                                            "buckets "
                                            "are "
                                            "allowed, "
                                            "the "
                                            "number "
                                            "of "
                                            "buckets "
                                            "is "
                                            "(max "
                                            "- "
                                            "min)/interval.",
                                            "properties": {
                                                "interval": {
                                                    "description": "The "
                                                    "bin "
                                                    "size "
                                                    "of "
                                                    "the "
                                                    "histogram "
                                                    "buckets.",
                                                    "example": 10,
                                                    "format": "double",
                                                    "type": "number",
                                                },
                                                "max": {
                                                    "description": "The "
                                                    "maximum "
                                                    "value "
                                                    "for "
                                                    "the "
                                                    "measure "
                                                    "used "
                                                    "in "
                                                    "the "
                                                    "histogram\n"
                                                    "(values "
                                                    "greater "
                                                    "than "
                                                    "this "
                                                    "one "
                                                    "are "
                                                    "filtered "
                                                    "out).",
                                                    "example": 100,
                                                    "format": "double",
                                                    "type": "number",
                                                },
                                                "min": {
                                                    "description": "The "
                                                    "minimum "
                                                    "value "
                                                    "for "
                                                    "the "
                                                    "measure "
                                                    "used "
                                                    "in "
                                                    "the "
                                                    "histogram\n"
                                                    "(values "
                                                    "smaller "
                                                    "than "
                                                    "this "
                                                    "one "
                                                    "are "
                                                    "filtered "
                                                    "out).",
                                                    "example": 50,
                                                    "format": "double",
                                                    "type": "number",
                                                },
                                            },
                                            "required": ["interval", "min", "max"],
                                            "type": "object",
                                        },
                                        "limit": {
                                            "default": 10,
                                            "description": "The "
                                            "maximum "
                                            "buckets "
                                            "to "
                                            "return "
                                            "for "
                                            "this "
                                            "group "
                                            "by.",
                                            "format": "int64",
                                            "type": "integer",
                                        },
                                        "missing": {
                                            "description": "The "
                                            "value "
                                            "to "
                                            "use "
                                            "for "
                                            "spans "
                                            "that "
                                            "don't "
                                            "have "
                                            "the "
                                            "facet "
                                            "used "
                                            "to "
                                            "group "
                                            "by.",
                                            "oneOf": [
                                                {
                                                    "description": "The "
                                                    "missing "
                                                    "value "
                                                    "to "
                                                    "use "
                                                    "if "
                                                    "there "
                                                    "is "
                                                    "string "
                                                    "valued "
                                                    "facet.",
                                                    "type": "string",
                                                },
                                                {
                                                    "description": "The "
                                                    "missing "
                                                    "value "
                                                    "to "
                                                    "use "
                                                    "if "
                                                    "there "
                                                    "is "
                                                    "a "
                                                    "number "
                                                    "valued "
                                                    "facet.",
                                                    "format": "double",
                                                    "type": "number",
                                                },
                                            ],
                                        },
                                        "sort": {
                                            "description": "A sort rule.",
                                            "example": {"aggregation": "count", "order": "asc"},
                                            "properties": {
                                                "aggregation": {
                                                    "description": "An aggregation function.",
                                                    "enum": [
                                                        "count",
                                                        "cardinality",
                                                        "pc75",
                                                        "pc90",
                                                        "pc95",
                                                        "pc98",
                                                        "pc99",
                                                        "sum",
                                                        "min",
                                                        "max",
                                                        "avg",
                                                        "median",
                                                    ],
                                                    "example": "pc90",
                                                    "type": "string",
                                                    "x-enum-varnames": [
                                                        "COUNT",
                                                        "CARDINALITY",
                                                        "PERCENTILE_75",
                                                        "PERCENTILE_90",
                                                        "PERCENTILE_95",
                                                        "PERCENTILE_98",
                                                        "PERCENTILE_99",
                                                        "SUM",
                                                        "MIN",
                                                        "MAX",
                                                        "AVG",
                                                        "MEDIAN",
                                                    ],
                                                },
                                                "metric": {
                                                    "description": "The "
                                                    "metric "
                                                    "to "
                                                    "sort "
                                                    "by "
                                                    "(only "
                                                    "used "
                                                    "for "
                                                    "`type=measure`).",
                                                    "example": "@duration",
                                                    "type": "string",
                                                },
                                                "order": {
                                                    "description": "The "
                                                    "order "
                                                    "to "
                                                    "use, "
                                                    "ascending "
                                                    "or "
                                                    "descending.",
                                                    "enum": ["asc", "desc"],
                                                    "example": "asc",
                                                    "type": "string",
                                                    "x-enum-varnames": ["ASCENDING", "DESCENDING"],
                                                },
                                                "type": {
                                                    "default": "alphabetical",
                                                    "description": "The type of sorting algorithm.",
                                                    "enum": ["alphabetical", "measure"],
                                                    "type": "string",
                                                    "x-enum-varnames": ["ALPHABETICAL", "MEASURE"],
                                                },
                                            },
                                            "type": "object",
                                        },
                                        "total": {
                                            "default": False,
                                            "description": "A "
                                            "resulting "
                                            "object "
                                            "to "
                                            "put "
                                            "the "
                                            "given "
                                            "computes "
                                            "in "
                                            "over "
                                            "all "
                                            "the "
                                            "matching "
                                            "records.",
                                            "oneOf": [
                                                {
                                                    "description": "If "
                                                    "set "
                                                    "to "
                                                    "true, "
                                                    "creates "
                                                    "an "
                                                    "additional "
                                                    "bucket "
                                                    "labeled "
                                                    '"$facet_total".',
                                                    "type": "boolean",
                                                },
                                                {
                                                    "description": "A "
                                                    "string "
                                                    "to "
                                                    "use "
                                                    "as "
                                                    "the "
                                                    "key "
                                                    "value "
                                                    "for "
                                                    "the "
                                                    "total "
                                                    "bucket.",
                                                    "type": "string",
                                                },
                                                {
                                                    "description": "A "
                                                    "number "
                                                    "to "
                                                    "use "
                                                    "as "
                                                    "the "
                                                    "key "
                                                    "value "
                                                    "for "
                                                    "the "
                                                    "total "
                                                    "bucket.",
                                                    "format": "double",
                                                    "type": "number",
                                                },
                                            ],
                                        },
                                    },
                                    "required": ["facet"],
                                    "type": "object",
                                },
                                "type": "array",
                            },
                            "options": {
                                "description": "Global "
                                "query "
                                "options "
                                "that "
                                "are "
                                "used "
                                "during "
                                "the "
                                "query.\n"
                                "Note: "
                                "You "
                                "should "
                                "only "
                                "supply "
                                "timezone "
                                "or "
                                "time "
                                "offset "
                                "but "
                                "not "
                                "both "
                                "otherwise "
                                "the "
                                "query "
                                "will "
                                "fail.",
                                "properties": {
                                    "timeOffset": {
                                        "description": "The "
                                        "time "
                                        "offset "
                                        "(in "
                                        "seconds) "
                                        "to "
                                        "apply "
                                        "to "
                                        "the "
                                        "query.",
                                        "format": "int64",
                                        "type": "integer",
                                    },
                                    "timezone": {
                                        "default": "UTC",
                                        "description": "The "
                                        "timezone "
                                        "can "
                                        "be "
                                        "specified "
                                        "as "
                                        "GMT, "
                                        "UTC, "
                                        "an "
                                        "offset "
                                        "from "
                                        "UTC "
                                        "(like "
                                        "UTC+1), "
                                        "or "
                                        "as "
                                        "a "
                                        "Timezone "
                                        "Database "
                                        "identifier "
                                        "(like "
                                        "America/New_York).",
                                        "example": "GMT",
                                        "type": "string",
                                    },
                                },
                                "type": "object",
                            },
                        },
                        "type": "object",
                    },
                    "type": {
                        "default": "aggregate_request",
                        "description": "The type of resource. "
                        "The value should "
                        "always be "
                        "aggregate_request.",
                        "enum": ["aggregate_request"],
                        "example": "aggregate_request",
                        "type": "string",
                        "x-enum-varnames": ["AGGREGATE_REQUEST"],
                    },
                },
                "type": "object",
            }
        },
        "type": "object",
    },
    "CREATETAGPIPELINERULESET_REQUEST_BODY_SCHEMA": {
        "description": "The definition of `CreateRulesetRequest` object.",
        "example": {
            "data": {
                "attributes": {
                    "enabled": True,
                    "rules": [
                        {
                            "enabled": True,
                            "mapping": None,
                            "metadata": None,
                            "name": "Add Cost Center Tag",
                            "query": {
                                "addition": {"key": "cost_center", "value": "engineering"},
                                "case_insensitivity": False,
                                "if_not_exists": True,
                                "query": 'account_id:"123456789" AND service:"web-api"',
                            },
                            "reference_table": None,
                        }
                    ],
                },
                "id": "New Ruleset",
                "type": "create_ruleset",
            }
        },
        "properties": {
            "data": {
                "description": "The definition of `CreateRulesetRequestData` object.",
                "properties": {
                    "attributes": {
                        "description": "The definition "
                        "of "
                        "`CreateRulesetRequestDataAttributes` "
                        "object.",
                        "properties": {
                            "enabled": {
                                "description": "The `attributes` `enabled`.",
                                "type": "boolean",
                            },
                            "rules": {
                                "description": "The `attributes` `rules`.",
                                "items": {
                                    "description": "The "
                                    "definition "
                                    "of "
                                    "`CreateRulesetRequestDataAttributesRulesItems` "
                                    "object.",
                                    "properties": {
                                        "enabled": {
                                            "description": "The `items` `enabled`.",
                                            "example": False,
                                            "type": "boolean",
                                        },
                                        "mapping": {
                                            "description": "The "
                                            "definition "
                                            "of "
                                            "`CreateRulesetRequestDataAttributesRulesItemsMapping` "
                                            "object.",
                                            "nullable": True,
                                            "properties": {
                                                "destination_key": {
                                                    "description": "The "
                                                    "`mapping` "
                                                    "`destination_key`.",
                                                    "example": "",
                                                    "type": "string",
                                                },
                                                "if_not_exists": {
                                                    "description": "The `mapping` `if_not_exists`.",
                                                    "example": False,
                                                    "type": "boolean",
                                                },
                                                "source_keys": {
                                                    "description": "The `mapping` `source_keys`.",
                                                    "example": [""],
                                                    "items": {"type": "string"},
                                                    "type": "array",
                                                },
                                            },
                                            "required": [
                                                "destination_key",
                                                "if_not_exists",
                                                "source_keys",
                                            ],
                                            "type": "object",
                                        },
                                        "metadata": {
                                            "additionalProperties": {"type": "string"},
                                            "description": "The `items` `metadata`.",
                                            "nullable": True,
                                            "type": "object",
                                        },
                                        "name": {
                                            "description": "The `items` `name`.",
                                            "example": "",
                                            "type": "string",
                                        },
                                        "query": {
                                            "description": "The "
                                            "definition "
                                            "of "
                                            "`CreateRulesetRequestDataAttributesRulesItemsQuery` "
                                            "object.",
                                            "nullable": True,
                                            "properties": {
                                                "addition": {
                                                    "description": "The "
                                                    "definition "
                                                    "of "
                                                    "`CreateRulesetRequestDataAttributesRulesItemsQueryAddition` "
                                                    "object.",
                                                    "nullable": True,
                                                    "properties": {
                                                        "key": {
                                                            "description": "The `addition` `key`.",
                                                            "example": "",
                                                            "type": "string",
                                                        },
                                                        "value": {
                                                            "description": "The "
                                                            "`addition` "
                                                            "`value`.",
                                                            "example": "",
                                                            "type": "string",
                                                        },
                                                    },
                                                    "required": ["key", "value"],
                                                    "type": "object",
                                                },
                                                "case_insensitivity": {
                                                    "description": "The "
                                                    "`query` "
                                                    "`case_insensitivity`.",
                                                    "type": "boolean",
                                                },
                                                "if_not_exists": {
                                                    "description": "The `query` `if_not_exists`.",
                                                    "example": False,
                                                    "type": "boolean",
                                                },
                                                "query": {
                                                    "description": "The `query` `query`.",
                                                    "example": "",
                                                    "type": "string",
                                                },
                                            },
                                            "required": ["addition", "if_not_exists", "query"],
                                            "type": "object",
                                        },
                                        "reference_table": {
                                            "description": "The "
                                            "definition "
                                            "of "
                                            "`CreateRulesetRequestDataAttributesRulesItemsReferenceTable` "
                                            "object.",
                                            "nullable": True,
                                            "properties": {
                                                "case_insensitivity": {
                                                    "description": "The "
                                                    "`reference_table` "
                                                    "`case_insensitivity`.",
                                                    "type": "boolean",
                                                },
                                                "field_pairs": {
                                                    "description": "The "
                                                    "`reference_table` "
                                                    "`field_pairs`.",
                                                    "items": {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "`CreateRulesetRequestDataAttributesRulesItemsReferenceTableFieldPairsItems` "
                                                        "object.",
                                                        "properties": {
                                                            "input_column": {
                                                                "description": "The "
                                                                "`items` "
                                                                "`input_column`.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                            "output_key": {
                                                                "description": "The "
                                                                "`items` "
                                                                "`output_key`.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                        },
                                                        "required": ["input_column", "output_key"],
                                                        "type": "object",
                                                    },
                                                    "type": "array",
                                                },
                                                "if_not_exists": {
                                                    "description": "The "
                                                    "`reference_table` "
                                                    "`if_not_exists`.",
                                                    "type": "boolean",
                                                },
                                                "source_keys": {
                                                    "description": "The "
                                                    "`reference_table` "
                                                    "`source_keys`.",
                                                    "example": [""],
                                                    "items": {"type": "string"},
                                                    "type": "array",
                                                },
                                                "table_name": {
                                                    "description": "The "
                                                    "`reference_table` "
                                                    "`table_name`.",
                                                    "example": "",
                                                    "type": "string",
                                                },
                                            },
                                            "required": [
                                                "field_pairs",
                                                "source_keys",
                                                "table_name",
                                            ],
                                            "type": "object",
                                        },
                                    },
                                    "required": ["enabled", "name"],
                                    "type": "object",
                                },
                                "type": "array",
                            },
                        },
                        "required": ["rules"],
                        "type": "object",
                    },
                    "id": {"description": "The `CreateRulesetRequestData` `id`.", "type": "string"},
                    "type": {
                        "default": "create_ruleset",
                        "description": "Create ruleset resource type.",
                        "enum": ["create_ruleset"],
                        "example": "create_ruleset",
                        "type": "string",
                        "x-enum-varnames": ["CREATE_RULESET"],
                    },
                },
                "required": ["type"],
                "type": "object",
            }
        },
        "type": "object",
    },
    "REORDERTAGPIPELINERULESETS_REQUEST_BODY_SCHEMA": {
        "description": "The definition of `ReorderRulesetResourceArray` object.",
        "example": {
            "data": [
                {"id": "55ef2385-9ae1-4410-90c4-5ac1b60fec10", "type": "ruleset"},
                {"id": "a7b8c9d0-1234-5678-9abc-def012345678", "type": "ruleset"},
                {"id": "f1e2d3c4-b5a6-9780-1234-567890abcdef", "type": "ruleset"},
            ]
        },
        "properties": {
            "data": {
                "description": "The `ReorderRulesetResourceArray` `data`.",
                "items": {
                    "description": "The definition of `ReorderRulesetResourceData` object.",
                    "properties": {
                        "id": {
                            "description": "The `ReorderRulesetResourceData` `id`.",
                            "type": "string",
                        },
                        "type": {
                            "default": "ruleset",
                            "description": "Ruleset resource type.",
                            "enum": ["ruleset"],
                            "example": "ruleset",
                            "type": "string",
                            "x-enum-varnames": ["RULESET"],
                        },
                    },
                    "required": ["type"],
                    "type": "object",
                },
                "type": "array",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "UPDATETAGPIPELINERULESET_REQUEST_BODY_SCHEMA": {
        "description": "The definition of `UpdateRulesetRequest` object.",
        "example": {
            "data": {
                "attributes": {
                    "enabled": True,
                    "last_version": 1,
                    "name": "Updated Ruleset",
                    "rules": [
                        {
                            "enabled": True,
                            "mapping": None,
                            "metadata": None,
                            "name": "Add Cost Center Tag",
                            "query": {
                                "addition": {"key": "cost_center", "value": "engineering"},
                                "case_insensitivity": False,
                                "if_not_exists": True,
                                "query": 'account_id:"123456789" AND service:"web-api"',
                            },
                            "reference_table": None,
                        },
                        {
                            "enabled": True,
                            "mapping": {
                                "destination_key": "team_owner",
                                "if_not_exists": True,
                                "source_keys": ["account_name", "account_id"],
                            },
                            "metadata": None,
                            "name": "Account Name Mapping",
                            "query": None,
                            "reference_table": None,
                        },
                        {
                            "enabled": True,
                            "mapping": None,
                            "metadata": None,
                            "name": "New table rule with new UI",
                            "query": None,
                            "reference_table": {
                                "case_insensitivity": True,
                                "field_pairs": [
                                    {"input_column": "status_type", "output_key": "status"},
                                    {"input_column": "status_description", "output_key": "dess"},
                                ],
                                "if_not_exists": False,
                                "source_keys": ["http_status", "status_description"],
                                "table_name": "http_status_codes",
                            },
                        },
                    ],
                },
                "type": "update_ruleset",
            }
        },
        "properties": {
            "data": {
                "description": "The definition of `UpdateRulesetRequestData` object.",
                "properties": {
                    "attributes": {
                        "description": "The definition "
                        "of "
                        "`UpdateRulesetRequestDataAttributes` "
                        "object.",
                        "properties": {
                            "enabled": {
                                "description": "The `attributes` `enabled`.",
                                "example": False,
                                "type": "boolean",
                            },
                            "last_version": {
                                "description": "The `attributes` `last_version`.",
                                "format": "int64",
                                "type": "integer",
                            },
                            "rules": {
                                "description": "The `attributes` `rules`.",
                                "items": {
                                    "description": "The "
                                    "definition "
                                    "of "
                                    "`UpdateRulesetRequestDataAttributesRulesItems` "
                                    "object.",
                                    "properties": {
                                        "enabled": {
                                            "description": "The `items` `enabled`.",
                                            "example": False,
                                            "type": "boolean",
                                        },
                                        "mapping": {
                                            "description": "The "
                                            "definition "
                                            "of "
                                            "`UpdateRulesetRequestDataAttributesRulesItemsMapping` "
                                            "object.",
                                            "nullable": True,
                                            "properties": {
                                                "destination_key": {
                                                    "description": "The "
                                                    "`mapping` "
                                                    "`destination_key`.",
                                                    "example": "",
                                                    "type": "string",
                                                },
                                                "if_not_exists": {
                                                    "description": "The `mapping` `if_not_exists`.",
                                                    "example": False,
                                                    "type": "boolean",
                                                },
                                                "source_keys": {
                                                    "description": "The `mapping` `source_keys`.",
                                                    "example": [""],
                                                    "items": {"type": "string"},
                                                    "type": "array",
                                                },
                                            },
                                            "required": [
                                                "destination_key",
                                                "if_not_exists",
                                                "source_keys",
                                            ],
                                            "type": "object",
                                        },
                                        "metadata": {
                                            "additionalProperties": {"type": "string"},
                                            "description": "The `items` `metadata`.",
                                            "nullable": True,
                                            "type": "object",
                                        },
                                        "name": {
                                            "description": "The `items` `name`.",
                                            "example": "",
                                            "type": "string",
                                        },
                                        "query": {
                                            "description": "The "
                                            "definition "
                                            "of "
                                            "`UpdateRulesetRequestDataAttributesRulesItemsQuery` "
                                            "object.",
                                            "nullable": True,
                                            "properties": {
                                                "addition": {
                                                    "description": "The "
                                                    "definition "
                                                    "of "
                                                    "`UpdateRulesetRequestDataAttributesRulesItemsQueryAddition` "
                                                    "object.",
                                                    "nullable": True,
                                                    "properties": {
                                                        "key": {
                                                            "description": "The `addition` `key`.",
                                                            "example": "",
                                                            "type": "string",
                                                        },
                                                        "value": {
                                                            "description": "The "
                                                            "`addition` "
                                                            "`value`.",
                                                            "example": "",
                                                            "type": "string",
                                                        },
                                                    },
                                                    "required": ["key", "value"],
                                                    "type": "object",
                                                },
                                                "case_insensitivity": {
                                                    "description": "The "
                                                    "`query` "
                                                    "`case_insensitivity`.",
                                                    "type": "boolean",
                                                },
                                                "if_not_exists": {
                                                    "description": "The `query` `if_not_exists`.",
                                                    "example": False,
                                                    "type": "boolean",
                                                },
                                                "query": {
                                                    "description": "The `query` `query`.",
                                                    "example": "",
                                                    "type": "string",
                                                },
                                            },
                                            "required": ["addition", "if_not_exists", "query"],
                                            "type": "object",
                                        },
                                        "reference_table": {
                                            "description": "The "
                                            "definition "
                                            "of "
                                            "`UpdateRulesetRequestDataAttributesRulesItemsReferenceTable` "
                                            "object.",
                                            "nullable": True,
                                            "properties": {
                                                "case_insensitivity": {
                                                    "description": "The "
                                                    "`reference_table` "
                                                    "`case_insensitivity`.",
                                                    "type": "boolean",
                                                },
                                                "field_pairs": {
                                                    "description": "The "
                                                    "`reference_table` "
                                                    "`field_pairs`.",
                                                    "items": {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "`UpdateRulesetRequestDataAttributesRulesItemsReferenceTableFieldPairsItems` "
                                                        "object.",
                                                        "properties": {
                                                            "input_column": {
                                                                "description": "The "
                                                                "`items` "
                                                                "`input_column`.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                            "output_key": {
                                                                "description": "The "
                                                                "`items` "
                                                                "`output_key`.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                        },
                                                        "required": ["input_column", "output_key"],
                                                        "type": "object",
                                                    },
                                                    "type": "array",
                                                },
                                                "if_not_exists": {
                                                    "description": "The "
                                                    "`reference_table` "
                                                    "`if_not_exists`.",
                                                    "type": "boolean",
                                                },
                                                "source_keys": {
                                                    "description": "The "
                                                    "`reference_table` "
                                                    "`source_keys`.",
                                                    "example": [""],
                                                    "items": {"type": "string"},
                                                    "type": "array",
                                                },
                                                "table_name": {
                                                    "description": "The "
                                                    "`reference_table` "
                                                    "`table_name`.",
                                                    "example": "",
                                                    "type": "string",
                                                },
                                            },
                                            "required": [
                                                "field_pairs",
                                                "source_keys",
                                                "table_name",
                                            ],
                                            "type": "object",
                                        },
                                    },
                                    "required": ["enabled", "name"],
                                    "type": "object",
                                },
                                "type": "array",
                            },
                        },
                        "required": ["enabled", "rules"],
                        "type": "object",
                    },
                    "id": {"description": "The `UpdateRulesetRequestData` `id`.", "type": "string"},
                    "type": {
                        "default": "update_ruleset",
                        "description": "Update ruleset resource type.",
                        "enum": ["update_ruleset"],
                        "example": "update_ruleset",
                        "type": "string",
                        "x-enum-varnames": ["UPDATE_RULESET"],
                    },
                },
                "required": ["type"],
                "type": "object",
            }
        },
        "type": "object",
    },
    "CREATENEWTEAM_REQUEST_BODY_SCHEMA": {
        "description": "Request to create a team",
        "properties": {
            "data": {
                "description": "Team create",
                "properties": {
                    "attributes": {
                        "description": "Team creation attributes",
                        "properties": {
                            "avatar": {
                                "description": "Unicode "
                                "representation "
                                "of "
                                "the "
                                "avatar "
                                "for "
                                "the "
                                "team, "
                                "limited "
                                "to "
                                "a "
                                "single "
                                "grapheme",
                                "example": "🥑",
                                "nullable": True,
                                "type": "string",
                            },
                            "banner": {
                                "description": "Banner selection for the team",
                                "format": "int64",
                                "nullable": True,
                                "type": "integer",
                            },
                            "description": {
                                "description": "Free-form "
                                "markdown "
                                "description/content "
                                "for "
                                "the "
                                "team's "
                                "homepage",
                                "type": "string",
                            },
                            "handle": {
                                "description": "The team's identifier",
                                "example": "example-team",
                                "maxLength": 195,
                                "type": "string",
                            },
                            "hidden_modules": {
                                "description": "Collection of hidden modules for the team",
                                "items": {
                                    "description": "String identifier of the module",
                                    "type": "string",
                                },
                                "type": "array",
                            },
                            "name": {
                                "description": "The name of the team",
                                "example": "Example Team",
                                "maxLength": 200,
                                "type": "string",
                            },
                            "visible_modules": {
                                "description": "Collection of visible modules for the team",
                                "items": {
                                    "description": "String identifier of the module",
                                    "type": "string",
                                },
                                "type": "array",
                            },
                        },
                        "required": ["handle", "name"],
                        "type": "object",
                    },
                    "relationships": {
                        "description": "Relationships formed with the team on creation",
                        "properties": {
                            "users": {
                                "description": "Relationship to users.",
                                "properties": {
                                    "data": {
                                        "description": "Relationships to user objects.",
                                        "example": [],
                                        "items": {
                                            "description": "Relationship to user object.",
                                            "properties": {
                                                "id": {
                                                    "description": "A "
                                                    "unique "
                                                    "identifier "
                                                    "that "
                                                    "represents "
                                                    "the "
                                                    "user.",
                                                    "example": "00000000-0000-0000-2345-000000000000",
                                                    "type": "string",
                                                },
                                                "type": {
                                                    "default": "users",
                                                    "description": "Users resource type.",
                                                    "enum": ["users"],
                                                    "example": "users",
                                                    "type": "string",
                                                    "x-enum-varnames": ["USERS"],
                                                },
                                            },
                                            "required": ["id", "type"],
                                            "type": "object",
                                        },
                                        "type": "array",
                                    }
                                },
                                "required": ["data"],
                                "type": "object",
                            }
                        },
                        "type": "object",
                    },
                    "type": {
                        "default": "team",
                        "description": "Team type",
                        "enum": ["team"],
                        "example": "team",
                        "type": "string",
                        "x-enum-varnames": ["TEAM"],
                    },
                },
                "required": ["attributes", "type"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "UPDATETEAMINFO_REQUEST_BODY_SCHEMA": {
        "description": "Team update request",
        "properties": {
            "data": {
                "description": "Team update request",
                "properties": {
                    "attributes": {
                        "description": "Team update attributes",
                        "properties": {
                            "avatar": {
                                "description": "Unicode "
                                "representation "
                                "of "
                                "the "
                                "avatar "
                                "for "
                                "the "
                                "team, "
                                "limited "
                                "to "
                                "a "
                                "single "
                                "grapheme",
                                "example": "🥑",
                                "nullable": True,
                                "type": "string",
                            },
                            "banner": {
                                "description": "Banner selection for the team",
                                "format": "int64",
                                "nullable": True,
                                "type": "integer",
                            },
                            "description": {
                                "description": "Free-form "
                                "markdown "
                                "description/content "
                                "for "
                                "the "
                                "team's "
                                "homepage",
                                "type": "string",
                            },
                            "handle": {
                                "description": "The team's identifier",
                                "example": "example-team",
                                "maxLength": 195,
                                "type": "string",
                            },
                            "hidden_modules": {
                                "description": "Collection of hidden modules for the team",
                                "items": {
                                    "description": "String identifier of the module",
                                    "type": "string",
                                },
                                "type": "array",
                            },
                            "name": {
                                "description": "The name of the team",
                                "example": "Example Team",
                                "maxLength": 200,
                                "type": "string",
                            },
                            "visible_modules": {
                                "description": "Collection of visible modules for the team",
                                "items": {
                                    "description": "String identifier of the module",
                                    "type": "string",
                                },
                                "type": "array",
                            },
                        },
                        "required": ["handle", "name"],
                        "type": "object",
                    },
                    "relationships": {
                        "description": "Team update relationships",
                        "properties": {
                            "team_links": {
                                "description": "Relationship between a team and a team link",
                                "properties": {
                                    "data": {
                                        "description": "Related team links",
                                        "items": {
                                            "description": "Relationship between a link and a team",
                                            "properties": {
                                                "id": {
                                                    "description": "The team link's identifier",
                                                    "example": "f9bb8444-af7f-11ec-ac2c-da7ad0900001",
                                                    "type": "string",
                                                },
                                                "type": {
                                                    "default": "team_links",
                                                    "description": "Team link type",
                                                    "enum": ["team_links"],
                                                    "example": "team_links",
                                                    "type": "string",
                                                    "x-enum-varnames": ["TEAM_LINKS"],
                                                },
                                            },
                                            "required": ["id", "type"],
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "links": {
                                        "description": "Links attributes.",
                                        "properties": {
                                            "related": {
                                                "description": "Related link.",
                                                "example": "/api/v2/team/c75a4a8e-20c7-11ee-a3a5-da7ad0900002/links",
                                                "type": "string",
                                            }
                                        },
                                        "type": "object",
                                    },
                                },
                                "type": "object",
                            }
                        },
                        "type": "object",
                    },
                    "type": {
                        "default": "team",
                        "description": "Team type",
                        "enum": ["team"],
                        "example": "team",
                        "type": "string",
                        "x-enum-varnames": ["TEAM"],
                    },
                },
                "required": ["attributes", "type"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "SENDINVITATIONS_REQUEST_BODY_SCHEMA": {
        "description": "Object to invite users to join the organization.",
        "properties": {
            "data": {
                "description": "List of user invitations.",
                "example": [],
                "items": {
                    "description": "Object to create a user invitation.",
                    "properties": {
                        "relationships": {
                            "description": "Relationships data for user invitation.",
                            "properties": {
                                "user": {
                                    "description": "Relationship to user.",
                                    "properties": {
                                        "data": {
                                            "description": "Relationship to user object.",
                                            "properties": {
                                                "id": {
                                                    "description": "A "
                                                    "unique "
                                                    "identifier "
                                                    "that "
                                                    "represents "
                                                    "the "
                                                    "user.",
                                                    "example": "00000000-0000-0000-2345-000000000000",
                                                    "type": "string",
                                                },
                                                "type": {
                                                    "default": "users",
                                                    "description": "Users resource type.",
                                                    "enum": ["users"],
                                                    "example": "users",
                                                    "type": "string",
                                                    "x-enum-varnames": ["USERS"],
                                                },
                                            },
                                            "required": ["id", "type"],
                                            "type": "object",
                                        }
                                    },
                                    "required": ["data"],
                                    "type": "object",
                                }
                            },
                            "required": ["user"],
                            "type": "object",
                        },
                        "type": {
                            "default": "user_invitations",
                            "description": "User invitations type.",
                            "enum": ["user_invitations"],
                            "example": "user_invitations",
                            "type": "string",
                            "x-enum-varnames": ["USER_INVITATIONS"],
                        },
                    },
                    "required": ["type", "relationships"],
                    "type": "object",
                },
                "type": "array",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "CREATEORGANIZATIONUSER_REQUEST_BODY_SCHEMA": {
        "description": "Create a user.",
        "properties": {
            "data": {
                "description": "Object to create a user.",
                "properties": {
                    "attributes": {
                        "description": "Attributes of the created user.",
                        "properties": {
                            "email": {
                                "description": "The email of the user.",
                                "example": "jane.doe@example.com",
                                "type": "string",
                            },
                            "name": {"description": "The name of the user.", "type": "string"},
                            "title": {"description": "The title of the user.", "type": "string"},
                        },
                        "required": ["email"],
                        "type": "object",
                    },
                    "relationships": {
                        "description": "Relationships of the user object.",
                        "properties": {
                            "roles": {
                                "description": "Relationship to roles.",
                                "properties": {
                                    "data": {
                                        "description": "An "
                                        "array "
                                        "containing "
                                        "type "
                                        "and "
                                        "the "
                                        "unique "
                                        "identifier "
                                        "of "
                                        "a "
                                        "role.",
                                        "items": {
                                            "description": "Relationship to role object.",
                                            "properties": {
                                                "id": {
                                                    "description": "The "
                                                    "unique "
                                                    "identifier "
                                                    "of "
                                                    "the "
                                                    "role.",
                                                    "example": "3653d3c6-0c75-11ea-ad28-fb5701eabc7d",
                                                    "type": "string",
                                                },
                                                "type": {
                                                    "default": "roles",
                                                    "description": "Roles type.",
                                                    "enum": ["roles"],
                                                    "example": "roles",
                                                    "type": "string",
                                                    "x-enum-varnames": ["ROLES"],
                                                },
                                            },
                                            "type": "object",
                                        },
                                        "type": "array",
                                    }
                                },
                                "type": "object",
                            }
                        },
                        "type": "object",
                    },
                    "type": {
                        "default": "users",
                        "description": "Users resource type.",
                        "enum": ["users"],
                        "example": "users",
                        "type": "string",
                        "x-enum-varnames": ["USERS"],
                    },
                },
                "required": ["attributes", "type"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "CREATEDATADOGWORKFLOW_REQUEST_BODY_SCHEMA": {
        "description": "A request object for creating a new workflow.",
        "example": {
            "data": {
                "attributes": {
                    "description": "A sample workflow.",
                    "name": "Example Workflow",
                    "published": True,
                    "spec": {
                        "annotations": [
                            {
                                "display": {
                                    "bounds": {"height": 150, "width": 300, "x": -375, "y": -0.5}
                                },
                                "id": "99999999-9999-9999-9999-999999999999",
                                "markdownTextAnnotation": {"text": "Example annotation."},
                            }
                        ],
                        "connectionEnvs": [
                            {
                                "connections": [
                                    {
                                        "connectionId": "11111111-1111-1111-1111-111111111111",
                                        "label": "INTEGRATION_DATADOG",
                                    }
                                ],
                                "env": "default",
                            }
                        ],
                        "handle": "my-handle",
                        "inputSchema": {
                            "parameters": [
                                {"defaultValue": "default", "name": "input", "type": "STRING"}
                            ]
                        },
                        "outputSchema": {
                            "parameters": [
                                {
                                    "name": "output",
                                    "type": "ARRAY_OBJECT",
                                    "value": "{{ Steps.Step1 }}",
                                }
                            ]
                        },
                        "steps": [
                            {
                                "actionId": "com.datadoghq.dd.monitor.listMonitors",
                                "connectionLabel": "INTEGRATION_DATADOG",
                                "name": "Step1",
                                "outboundEdges": [{"branchName": "main", "nextStepName": "Step2"}],
                                "parameters": [{"name": "tags", "value": "service:monitoring"}],
                            },
                            {"actionId": "com.datadoghq.core.noop", "name": "Step2"},
                        ],
                        "triggers": [
                            {
                                "monitorTrigger": {"rateLimit": {"count": 1, "interval": "3600s"}},
                                "startStepNames": ["Step1"],
                            },
                            {"githubWebhookTrigger": {}, "startStepNames": ["Step1"]},
                        ],
                    },
                    "tags": ["team:infra", "service:monitoring", "foo:bar"],
                },
                "type": "workflows",
            }
        },
        "properties": {
            "data": {
                "description": "Data related to the workflow.",
                "properties": {
                    "attributes": {
                        "description": "The definition of `WorkflowDataAttributes` object.",
                        "properties": {
                            "createdAt": {
                                "description": "When the workflow was created.",
                                "format": "date-time",
                                "readOnly": True,
                                "type": "string",
                            },
                            "description": {
                                "description": "Description of the workflow.",
                                "type": "string",
                            },
                            "name": {
                                "description": "Name of the workflow.",
                                "example": "",
                                "type": "string",
                            },
                            "published": {
                                "description": "Set "
                                "the "
                                "workflow "
                                "to "
                                "published "
                                "or "
                                "unpublished. "
                                "Workflows "
                                "in "
                                "an "
                                "unpublished "
                                "state "
                                "will "
                                "only "
                                "be "
                                "executable "
                                "via "
                                "manual "
                                "runs. "
                                "Automatic "
                                "triggers "
                                "such "
                                "as "
                                "Schedule "
                                "will "
                                "not "
                                "execute "
                                "the "
                                "workflow "
                                "until "
                                "it "
                                "is "
                                "published.",
                                "type": "boolean",
                            },
                            "spec": {
                                "description": "The spec defines what the workflow does.",
                                "properties": {
                                    "annotations": {
                                        "description": "A "
                                        "list "
                                        "of "
                                        "annotations "
                                        "used "
                                        "in "
                                        "the "
                                        "workflow. "
                                        "These "
                                        "are "
                                        "like "
                                        "sticky "
                                        "notes "
                                        "for "
                                        "your "
                                        "workflow!",
                                        "items": {
                                            "description": "A "
                                            "list "
                                            "of "
                                            "annotations "
                                            "used "
                                            "in "
                                            "the "
                                            "workflow. "
                                            "These "
                                            "are "
                                            "like "
                                            "sticky "
                                            "notes "
                                            "for "
                                            "your "
                                            "workflow!",
                                            "properties": {
                                                "display": {
                                                    "description": "The "
                                                    "definition "
                                                    "of "
                                                    "`AnnotationDisplay` "
                                                    "object.",
                                                    "properties": {
                                                        "bounds": {
                                                            "description": "The "
                                                            "definition "
                                                            "of "
                                                            "`AnnotationDisplayBounds` "
                                                            "object.",
                                                            "properties": {
                                                                "height": {
                                                                    "description": "The "
                                                                    "`bounds` "
                                                                    "`height`.",
                                                                    "format": "double",
                                                                    "type": "number",
                                                                },
                                                                "width": {
                                                                    "description": "The "
                                                                    "`bounds` "
                                                                    "`width`.",
                                                                    "format": "double",
                                                                    "type": "number",
                                                                },
                                                                "x": {
                                                                    "description": "The "
                                                                    "`bounds` "
                                                                    "`x`.",
                                                                    "format": "double",
                                                                    "type": "number",
                                                                },
                                                                "y": {
                                                                    "description": "The "
                                                                    "`bounds` "
                                                                    "`y`.",
                                                                    "format": "double",
                                                                    "type": "number",
                                                                },
                                                            },
                                                            "type": "object",
                                                        }
                                                    },
                                                    "type": "object",
                                                },
                                                "id": {
                                                    "description": "The `Annotation` `id`.",
                                                    "example": "",
                                                    "type": "string",
                                                },
                                                "markdownTextAnnotation": {
                                                    "description": "The "
                                                    "definition "
                                                    "of "
                                                    "`AnnotationMarkdownTextAnnotation` "
                                                    "object.",
                                                    "properties": {
                                                        "text": {
                                                            "description": "The "
                                                            "`markdownTextAnnotation` "
                                                            "`text`.",
                                                            "type": "string",
                                                        }
                                                    },
                                                    "type": "object",
                                                },
                                            },
                                            "required": ["id", "display", "markdownTextAnnotation"],
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "connectionEnvs": {
                                        "description": "A "
                                        "list "
                                        "of "
                                        "connections "
                                        "or "
                                        "connection "
                                        "groups "
                                        "used "
                                        "in "
                                        "the "
                                        "workflow.",
                                        "items": {
                                            "description": "A "
                                            "list "
                                            "of "
                                            "connections "
                                            "or "
                                            "connection "
                                            "groups "
                                            "used "
                                            "in "
                                            "the "
                                            "workflow.",
                                            "properties": {
                                                "connectionGroups": {
                                                    "description": "The "
                                                    "`ConnectionEnv` "
                                                    "`connectionGroups`.",
                                                    "items": {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "`ConnectionGroup` "
                                                        "object.",
                                                        "properties": {
                                                            "connectionGroupId": {
                                                                "description": "The "
                                                                "`ConnectionGroup` "
                                                                "`connectionGroupId`.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                            "label": {
                                                                "description": "The "
                                                                "`ConnectionGroup` "
                                                                "`label`.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                            "tags": {
                                                                "description": "The "
                                                                "`ConnectionGroup` "
                                                                "`tags`.",
                                                                "example": [""],
                                                                "items": {"type": "string"},
                                                                "type": "array",
                                                            },
                                                        },
                                                        "required": [
                                                            "connectionGroupId",
                                                            "label",
                                                            "tags",
                                                        ],
                                                        "type": "object",
                                                    },
                                                    "type": "array",
                                                },
                                                "connections": {
                                                    "description": "The "
                                                    "`ConnectionEnv` "
                                                    "`connections`.",
                                                    "items": {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "`Connection` "
                                                        "object.",
                                                        "properties": {
                                                            "connectionId": {
                                                                "description": "The "
                                                                "`Connection` "
                                                                "`connectionId`.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                            "label": {
                                                                "description": "The "
                                                                "`Connection` "
                                                                "`label`.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                        },
                                                        "required": ["connectionId", "label"],
                                                        "type": "object",
                                                    },
                                                    "type": "array",
                                                },
                                                "env": {
                                                    "description": "The "
                                                    "definition "
                                                    "of "
                                                    "`ConnectionEnvEnv` "
                                                    "object.",
                                                    "enum": ["default"],
                                                    "example": "default",
                                                    "type": "string",
                                                    "x-enum-varnames": ["DEFAULT"],
                                                },
                                            },
                                            "required": ["env"],
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "handle": {
                                        "description": "Unique "
                                        "identifier "
                                        "used "
                                        "to "
                                        "trigger "
                                        "workflows "
                                        "automatically "
                                        "in "
                                        "Datadog.",
                                        "type": "string",
                                    },
                                    "inputSchema": {
                                        "description": "A "
                                        "list "
                                        "of "
                                        "input "
                                        "parameters "
                                        "for "
                                        "the "
                                        "workflow. "
                                        "These "
                                        "can "
                                        "be "
                                        "used "
                                        "as "
                                        "dynamic "
                                        "runtime "
                                        "values "
                                        "in "
                                        "your "
                                        "workflow.",
                                        "properties": {
                                            "parameters": {
                                                "description": "The `InputSchema` `parameters`.",
                                                "items": {
                                                    "description": "The "
                                                    "definition "
                                                    "of "
                                                    "`InputSchemaParameters` "
                                                    "object.",
                                                    "properties": {
                                                        "defaultValue": {
                                                            "description": "The "
                                                            "`InputSchemaParameters` "
                                                            "`defaultValue`."
                                                        },
                                                        "description": {
                                                            "description": "The "
                                                            "`InputSchemaParameters` "
                                                            "`description`.",
                                                            "type": "string",
                                                        },
                                                        "label": {
                                                            "description": "The "
                                                            "`InputSchemaParameters` "
                                                            "`label`.",
                                                            "type": "string",
                                                        },
                                                        "name": {
                                                            "description": "The "
                                                            "`InputSchemaParameters` "
                                                            "`name`.",
                                                            "example": "",
                                                            "type": "string",
                                                        },
                                                        "type": {
                                                            "description": "The "
                                                            "definition "
                                                            "of "
                                                            "`InputSchemaParametersType` "
                                                            "object.",
                                                            "enum": [
                                                                "STRING",
                                                                "NUMBER",
                                                                "BOOLEAN",
                                                                "OBJECT",
                                                                "ARRAY_STRING",
                                                                "ARRAY_NUMBER",
                                                                "ARRAY_BOOLEAN",
                                                                "ARRAY_OBJECT",
                                                            ],
                                                            "example": "STRING",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "STRING",
                                                                "NUMBER",
                                                                "BOOLEAN",
                                                                "OBJECT",
                                                                "ARRAY_STRING",
                                                                "ARRAY_NUMBER",
                                                                "ARRAY_BOOLEAN",
                                                                "ARRAY_OBJECT",
                                                            ],
                                                        },
                                                    },
                                                    "required": ["name", "type"],
                                                    "type": "object",
                                                },
                                                "type": "array",
                                            }
                                        },
                                        "type": "object",
                                    },
                                    "outputSchema": {
                                        "description": "A "
                                        "list "
                                        "of "
                                        "output "
                                        "parameters "
                                        "for "
                                        "the "
                                        "workflow.",
                                        "properties": {
                                            "parameters": {
                                                "description": "The `OutputSchema` `parameters`.",
                                                "items": {
                                                    "description": "The "
                                                    "definition "
                                                    "of "
                                                    "`OutputSchemaParameters` "
                                                    "object.",
                                                    "properties": {
                                                        "defaultValue": {
                                                            "description": "The "
                                                            "`OutputSchemaParameters` "
                                                            "`defaultValue`."
                                                        },
                                                        "description": {
                                                            "description": "The "
                                                            "`OutputSchemaParameters` "
                                                            "`description`.",
                                                            "type": "string",
                                                        },
                                                        "label": {
                                                            "description": "The "
                                                            "`OutputSchemaParameters` "
                                                            "`label`.",
                                                            "type": "string",
                                                        },
                                                        "name": {
                                                            "description": "The "
                                                            "`OutputSchemaParameters` "
                                                            "`name`.",
                                                            "example": "",
                                                            "type": "string",
                                                        },
                                                        "type": {
                                                            "description": "The "
                                                            "definition "
                                                            "of "
                                                            "`OutputSchemaParametersType` "
                                                            "object.",
                                                            "enum": [
                                                                "STRING",
                                                                "NUMBER",
                                                                "BOOLEAN",
                                                                "OBJECT",
                                                                "ARRAY_STRING",
                                                                "ARRAY_NUMBER",
                                                                "ARRAY_BOOLEAN",
                                                                "ARRAY_OBJECT",
                                                            ],
                                                            "example": "STRING",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "STRING",
                                                                "NUMBER",
                                                                "BOOLEAN",
                                                                "OBJECT",
                                                                "ARRAY_STRING",
                                                                "ARRAY_NUMBER",
                                                                "ARRAY_BOOLEAN",
                                                                "ARRAY_OBJECT",
                                                            ],
                                                        },
                                                        "value": {
                                                            "description": "The "
                                                            "`OutputSchemaParameters` "
                                                            "`value`."
                                                        },
                                                    },
                                                    "required": ["name", "type"],
                                                    "type": "object",
                                                },
                                                "type": "array",
                                            }
                                        },
                                        "type": "object",
                                    },
                                    "steps": {
                                        "description": "A "
                                        "`Step` "
                                        "is "
                                        "a "
                                        "sub-component "
                                        "of "
                                        "a "
                                        "workflow. "
                                        "Each "
                                        "`Step` "
                                        "performs "
                                        "an "
                                        "action.",
                                        "items": {
                                            "description": "A "
                                            "Step "
                                            "is "
                                            "a "
                                            "sub-component "
                                            "of "
                                            "a "
                                            "workflow. "
                                            "Each "
                                            "Step "
                                            "performs "
                                            "an "
                                            "action.",
                                            "properties": {
                                                "actionId": {
                                                    "description": "The "
                                                    "unique "
                                                    "identifier "
                                                    "of "
                                                    "an "
                                                    "action.",
                                                    "example": "",
                                                    "type": "string",
                                                },
                                                "completionGate": {
                                                    "description": "Used "
                                                    "to "
                                                    "create "
                                                    "conditions "
                                                    "before "
                                                    "running "
                                                    "subsequent "
                                                    "actions.",
                                                    "properties": {
                                                        "completionCondition": {
                                                            "description": "The "
                                                            "definition "
                                                            "of "
                                                            "`CompletionCondition` "
                                                            "object.",
                                                            "properties": {
                                                                "operand1": {
                                                                    "description": "The "
                                                                    "`CompletionCondition` "
                                                                    "`operand1`."
                                                                },
                                                                "operand2": {
                                                                    "description": "The "
                                                                    "`CompletionCondition` "
                                                                    "`operand2`."
                                                                },
                                                                "operator": {
                                                                    "description": "The "
                                                                    "definition "
                                                                    "of "
                                                                    "`CompletionConditionOperator` "
                                                                    "object.",
                                                                    "enum": [
                                                                        "OPERATOR_EQUAL",
                                                                        "OPERATOR_NOT_EQUAL",
                                                                        "OPERATOR_GREATER_THAN",
                                                                        "OPERATOR_LESS_THAN",
                                                                        "OPERATOR_GREATER_THAN_OR_EQUAL_TO",
                                                                        "OPERATOR_LESS_THAN_OR_EQUAL_TO",
                                                                        "OPERATOR_CONTAINS",
                                                                        "OPERATOR_DOES_NOT_CONTAIN",
                                                                        "OPERATOR_IS_NULL",
                                                                        "OPERATOR_IS_NOT_NULL",
                                                                        "OPERATOR_IS_EMPTY",
                                                                        "OPERATOR_IS_NOT_EMPTY",
                                                                    ],
                                                                    "example": "OPERATOR_EQUAL",
                                                                    "type": "string",
                                                                    "x-enum-varnames": [
                                                                        "OPERATOR_EQUAL",
                                                                        "OPERATOR_NOT_EQUAL",
                                                                        "OPERATOR_GREATER_THAN",
                                                                        "OPERATOR_LESS_THAN",
                                                                        "OPERATOR_GREATER_THAN_OR_EQUAL_TO",
                                                                        "OPERATOR_LESS_THAN_OR_EQUAL_TO",
                                                                        "OPERATOR_CONTAINS",
                                                                        "OPERATOR_DOES_NOT_CONTAIN",
                                                                        "OPERATOR_IS_NULL",
                                                                        "OPERATOR_IS_NOT_NULL",
                                                                        "OPERATOR_IS_EMPTY",
                                                                        "OPERATOR_IS_NOT_EMPTY",
                                                                    ],
                                                                },
                                                            },
                                                            "required": ["operand1", "operator"],
                                                            "type": "object",
                                                        },
                                                        "retryStrategy": {
                                                            "description": "The "
                                                            "definition "
                                                            "of "
                                                            "`RetryStrategy` "
                                                            "object.",
                                                            "properties": {
                                                                "kind": {
                                                                    "description": "The "
                                                                    "definition "
                                                                    "of "
                                                                    "`RetryStrategyKind` "
                                                                    "object.",
                                                                    "enum": [
                                                                        "RETRY_STRATEGY_LINEAR"
                                                                    ],
                                                                    "example": "RETRY_STRATEGY_LINEAR",
                                                                    "type": "string",
                                                                    "x-enum-varnames": [
                                                                        "RETRY_STRATEGY_LINEAR"
                                                                    ],
                                                                },
                                                                "linear": {
                                                                    "description": "The "
                                                                    "definition "
                                                                    "of "
                                                                    "`RetryStrategyLinear` "
                                                                    "object.",
                                                                    "properties": {
                                                                        "interval": {
                                                                            "description": "The "
                                                                            "`RetryStrategyLinear` "
                                                                            "`interval`. "
                                                                            "The "
                                                                            "expected "
                                                                            "format "
                                                                            "is "
                                                                            "the "
                                                                            "number "
                                                                            "of "
                                                                            "seconds "
                                                                            "ending "
                                                                            "with "
                                                                            "an "
                                                                            "s. "
                                                                            "For "
                                                                            "example, "
                                                                            "1 "
                                                                            "day "
                                                                            "is "
                                                                            "86400s",
                                                                            "example": "",
                                                                            "type": "string",
                                                                        },
                                                                        "maxRetries": {
                                                                            "description": "The "
                                                                            "`RetryStrategyLinear` "
                                                                            "`maxRetries`.",
                                                                            "example": 0.0,
                                                                            "format": "double",
                                                                            "type": "number",
                                                                        },
                                                                    },
                                                                    "required": [
                                                                        "interval",
                                                                        "maxRetries",
                                                                    ],
                                                                    "type": "object",
                                                                },
                                                            },
                                                            "required": ["kind"],
                                                            "type": "object",
                                                        },
                                                    },
                                                    "required": [
                                                        "completionCondition",
                                                        "retryStrategy",
                                                    ],
                                                    "type": "object",
                                                },
                                                "connectionLabel": {
                                                    "description": "The "
                                                    "unique "
                                                    "identifier "
                                                    "of "
                                                    "a "
                                                    "connection "
                                                    "defined "
                                                    "in "
                                                    "the "
                                                    "spec.",
                                                    "type": "string",
                                                },
                                                "display": {
                                                    "description": "The "
                                                    "definition "
                                                    "of "
                                                    "`StepDisplay` "
                                                    "object.",
                                                    "properties": {
                                                        "bounds": {
                                                            "description": "The "
                                                            "definition "
                                                            "of "
                                                            "`StepDisplayBounds` "
                                                            "object.",
                                                            "properties": {
                                                                "x": {
                                                                    "description": "The "
                                                                    "`bounds` "
                                                                    "`x`.",
                                                                    "format": "double",
                                                                    "type": "number",
                                                                },
                                                                "y": {
                                                                    "description": "The "
                                                                    "`bounds` "
                                                                    "`y`.",
                                                                    "format": "double",
                                                                    "type": "number",
                                                                },
                                                            },
                                                            "type": "object",
                                                        }
                                                    },
                                                    "type": "object",
                                                },
                                                "errorHandlers": {
                                                    "description": "The `Step` `errorHandlers`.",
                                                    "items": {
                                                        "description": "Used "
                                                        "to "
                                                        "handle "
                                                        "errors "
                                                        "in "
                                                        "an "
                                                        "action.",
                                                        "properties": {
                                                            "fallbackStepName": {
                                                                "description": "The "
                                                                "`ErrorHandler` "
                                                                "`fallbackStepName`.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                            "retryStrategy": {
                                                                "description": "The "
                                                                "definition "
                                                                "of "
                                                                "`RetryStrategy` "
                                                                "object.",
                                                                "properties": {
                                                                    "kind": {
                                                                        "description": "The "
                                                                        "definition "
                                                                        "of "
                                                                        "`RetryStrategyKind` "
                                                                        "object.",
                                                                        "enum": [
                                                                            "RETRY_STRATEGY_LINEAR"
                                                                        ],
                                                                        "example": "RETRY_STRATEGY_LINEAR",
                                                                        "type": "string",
                                                                        "x-enum-varnames": [
                                                                            "RETRY_STRATEGY_LINEAR"
                                                                        ],
                                                                    },
                                                                    "linear": {
                                                                        "description": "The "
                                                                        "definition "
                                                                        "of "
                                                                        "`RetryStrategyLinear` "
                                                                        "object.",
                                                                        "properties": {
                                                                            "interval": {
                                                                                "description": "The "
                                                                                "`RetryStrategyLinear` "
                                                                                "`interval`. "
                                                                                "The "
                                                                                "expected "
                                                                                "format "
                                                                                "is "
                                                                                "the "
                                                                                "number "
                                                                                "of "
                                                                                "seconds "
                                                                                "ending "
                                                                                "with "
                                                                                "an "
                                                                                "s. "
                                                                                "For "
                                                                                "example, "
                                                                                "1 "
                                                                                "day "
                                                                                "is "
                                                                                "86400s",
                                                                                "example": "",
                                                                                "type": "string",
                                                                            },
                                                                            "maxRetries": {
                                                                                "description": "The "
                                                                                "`RetryStrategyLinear` "
                                                                                "`maxRetries`.",
                                                                                "example": 0.0,
                                                                                "format": "double",
                                                                                "type": "number",
                                                                            },
                                                                        },
                                                                        "required": [
                                                                            "interval",
                                                                            "maxRetries",
                                                                        ],
                                                                        "type": "object",
                                                                    },
                                                                },
                                                                "required": ["kind"],
                                                                "type": "object",
                                                            },
                                                        },
                                                        "required": [
                                                            "retryStrategy",
                                                            "fallbackStepName",
                                                        ],
                                                        "type": "object",
                                                    },
                                                    "type": "array",
                                                },
                                                "name": {
                                                    "description": "Name of the step.",
                                                    "example": "",
                                                    "type": "string",
                                                },
                                                "outboundEdges": {
                                                    "description": "A "
                                                    "list "
                                                    "of "
                                                    "subsequent "
                                                    "actions "
                                                    "to "
                                                    "run.",
                                                    "items": {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "`OutboundEdge` "
                                                        "object.",
                                                        "properties": {
                                                            "branchName": {
                                                                "description": "The "
                                                                "`OutboundEdge` "
                                                                "`branchName`.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                            "nextStepName": {
                                                                "description": "The "
                                                                "`OutboundEdge` "
                                                                "`nextStepName`.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                        },
                                                        "required": ["nextStepName", "branchName"],
                                                        "type": "object",
                                                    },
                                                    "type": "array",
                                                },
                                                "parameters": {
                                                    "description": "A "
                                                    "list "
                                                    "of "
                                                    "inputs "
                                                    "for "
                                                    "an "
                                                    "action.",
                                                    "items": {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "`Parameter` "
                                                        "object.",
                                                        "properties": {
                                                            "name": {
                                                                "description": "The "
                                                                "`Parameter` "
                                                                "`name`.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                            "value": {
                                                                "description": "The "
                                                                "`Parameter` "
                                                                "`value`."
                                                            },
                                                        },
                                                        "required": ["name", "value"],
                                                        "type": "object",
                                                    },
                                                    "type": "array",
                                                },
                                                "readinessGate": {
                                                    "description": "Used "
                                                    "to "
                                                    "merge "
                                                    "multiple "
                                                    "branches "
                                                    "into "
                                                    "a "
                                                    "single "
                                                    "branch.",
                                                    "properties": {
                                                        "thresholdType": {
                                                            "description": "The "
                                                            "definition "
                                                            "of "
                                                            "`ReadinessGateThresholdType` "
                                                            "object.",
                                                            "enum": ["ANY", "ALL"],
                                                            "example": "ANY",
                                                            "type": "string",
                                                            "x-enum-varnames": ["ANY", "ALL"],
                                                        }
                                                    },
                                                    "required": ["thresholdType"],
                                                    "type": "object",
                                                },
                                            },
                                            "required": ["name", "actionId"],
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "triggers": {
                                        "description": "The "
                                        "list "
                                        "of "
                                        "triggers "
                                        "that "
                                        "activate "
                                        "this "
                                        "workflow. "
                                        "At "
                                        "least "
                                        "one "
                                        "trigger "
                                        "is "
                                        "required, "
                                        "and "
                                        "each "
                                        "trigger "
                                        "type "
                                        "may "
                                        "appear "
                                        "at "
                                        "most "
                                        "once.",
                                        "items": {
                                            "description": "One "
                                            "of "
                                            "the "
                                            "triggers "
                                            "that "
                                            "can "
                                            "start "
                                            "the "
                                            "execution "
                                            "of "
                                            "a "
                                            "workflow.",
                                            "oneOf": [
                                                {
                                                    "description": "Schema "
                                                    "for "
                                                    "an "
                                                    "API-based "
                                                    "trigger.",
                                                    "properties": {
                                                        "apiTrigger": {
                                                            "description": "Trigger "
                                                            "a "
                                                            "workflow "
                                                            "from "
                                                            "an "
                                                            "API "
                                                            "request. "
                                                            "The "
                                                            "workflow "
                                                            "must "
                                                            "be "
                                                            "published.",
                                                            "properties": {
                                                                "rateLimit": {
                                                                    "description": "Defines "
                                                                    "a "
                                                                    "rate "
                                                                    "limit "
                                                                    "for "
                                                                    "a "
                                                                    "trigger.",
                                                                    "properties": {
                                                                        "count": {
                                                                            "description": "The "
                                                                            "`TriggerRateLimit` "
                                                                            "`count`.",
                                                                            "format": "int64",
                                                                            "type": "integer",
                                                                        },
                                                                        "interval": {
                                                                            "description": "The "
                                                                            "`TriggerRateLimit` "
                                                                            "`interval`. "
                                                                            "The "
                                                                            "expected "
                                                                            "format "
                                                                            "is "
                                                                            "the "
                                                                            "number "
                                                                            "of "
                                                                            "seconds "
                                                                            "ending "
                                                                            "with "
                                                                            "an "
                                                                            "s. "
                                                                            "For "
                                                                            "example, "
                                                                            "1 "
                                                                            "day "
                                                                            "is "
                                                                            "86400s",
                                                                            "type": "string",
                                                                        },
                                                                    },
                                                                    "type": "object",
                                                                }
                                                            },
                                                            "type": "object",
                                                        },
                                                        "startStepNames": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "steps "
                                                            "that "
                                                            "run "
                                                            "first "
                                                            "after "
                                                            "a "
                                                            "trigger "
                                                            "fires.",
                                                            "example": [""],
                                                            "items": {
                                                                "description": "The "
                                                                "`StartStepNames` "
                                                                "`items`.",
                                                                "type": "string",
                                                            },
                                                            "type": "array",
                                                        },
                                                    },
                                                    "required": ["apiTrigger"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "Schema "
                                                    "for "
                                                    "an "
                                                    "App-based "
                                                    "trigger.",
                                                    "properties": {
                                                        "appTrigger": {
                                                            "description": "Trigger "
                                                            "a "
                                                            "workflow "
                                                            "from "
                                                            "an "
                                                            "App.",
                                                            "type": "object",
                                                        },
                                                        "startStepNames": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "steps "
                                                            "that "
                                                            "run "
                                                            "first "
                                                            "after "
                                                            "a "
                                                            "trigger "
                                                            "fires.",
                                                            "example": [""],
                                                            "items": {
                                                                "description": "The "
                                                                "`StartStepNames` "
                                                                "`items`.",
                                                                "type": "string",
                                                            },
                                                            "type": "array",
                                                        },
                                                    },
                                                    "required": ["appTrigger"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "Schema "
                                                    "for "
                                                    "a "
                                                    "Case-based "
                                                    "trigger.",
                                                    "properties": {
                                                        "caseTrigger": {
                                                            "description": "Trigger "
                                                            "a "
                                                            "workflow "
                                                            "from "
                                                            "a "
                                                            "Case. "
                                                            "For "
                                                            "automatic "
                                                            "triggering "
                                                            "a "
                                                            "handle "
                                                            "must "
                                                            "be "
                                                            "configured "
                                                            "and "
                                                            "the "
                                                            "workflow "
                                                            "must "
                                                            "be "
                                                            "published.",
                                                            "properties": {
                                                                "rateLimit": {
                                                                    "description": "Defines "
                                                                    "a "
                                                                    "rate "
                                                                    "limit "
                                                                    "for "
                                                                    "a "
                                                                    "trigger.",
                                                                    "properties": {
                                                                        "count": {
                                                                            "description": "The "
                                                                            "`TriggerRateLimit` "
                                                                            "`count`.",
                                                                            "format": "int64",
                                                                            "type": "integer",
                                                                        },
                                                                        "interval": {
                                                                            "description": "The "
                                                                            "`TriggerRateLimit` "
                                                                            "`interval`. "
                                                                            "The "
                                                                            "expected "
                                                                            "format "
                                                                            "is "
                                                                            "the "
                                                                            "number "
                                                                            "of "
                                                                            "seconds "
                                                                            "ending "
                                                                            "with "
                                                                            "an "
                                                                            "s. "
                                                                            "For "
                                                                            "example, "
                                                                            "1 "
                                                                            "day "
                                                                            "is "
                                                                            "86400s",
                                                                            "type": "string",
                                                                        },
                                                                    },
                                                                    "type": "object",
                                                                }
                                                            },
                                                            "type": "object",
                                                        },
                                                        "startStepNames": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "steps "
                                                            "that "
                                                            "run "
                                                            "first "
                                                            "after "
                                                            "a "
                                                            "trigger "
                                                            "fires.",
                                                            "example": [""],
                                                            "items": {
                                                                "description": "The "
                                                                "`StartStepNames` "
                                                                "`items`.",
                                                                "type": "string",
                                                            },
                                                            "type": "array",
                                                        },
                                                    },
                                                    "required": ["caseTrigger"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "Schema "
                                                    "for "
                                                    "a "
                                                    "Change "
                                                    "Event-based "
                                                    "trigger.",
                                                    "properties": {
                                                        "changeEventTrigger": {
                                                            "description": "Trigger "
                                                            "a "
                                                            "workflow "
                                                            "from "
                                                            "a "
                                                            "Change "
                                                            "Event.",
                                                            "type": "object",
                                                        },
                                                        "startStepNames": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "steps "
                                                            "that "
                                                            "run "
                                                            "first "
                                                            "after "
                                                            "a "
                                                            "trigger "
                                                            "fires.",
                                                            "example": [""],
                                                            "items": {
                                                                "description": "The "
                                                                "`StartStepNames` "
                                                                "`items`.",
                                                                "type": "string",
                                                            },
                                                            "type": "array",
                                                        },
                                                    },
                                                    "required": ["changeEventTrigger"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "Schema "
                                                    "for "
                                                    "a "
                                                    "Database "
                                                    "Monitoring-based "
                                                    "trigger.",
                                                    "properties": {
                                                        "databaseMonitoringTrigger": {
                                                            "description": "Trigger "
                                                            "a "
                                                            "workflow "
                                                            "from "
                                                            "Database "
                                                            "Monitoring.",
                                                            "type": "object",
                                                        },
                                                        "startStepNames": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "steps "
                                                            "that "
                                                            "run "
                                                            "first "
                                                            "after "
                                                            "a "
                                                            "trigger "
                                                            "fires.",
                                                            "example": [""],
                                                            "items": {
                                                                "description": "The "
                                                                "`StartStepNames` "
                                                                "`items`.",
                                                                "type": "string",
                                                            },
                                                            "type": "array",
                                                        },
                                                    },
                                                    "required": ["databaseMonitoringTrigger"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "Schema "
                                                    "for "
                                                    "a "
                                                    "Datastore-based "
                                                    "trigger.",
                                                    "properties": {
                                                        "datastoreTrigger": {
                                                            "description": "Trigger "
                                                            "a "
                                                            "workflow "
                                                            "from "
                                                            "a "
                                                            "Datastore. "
                                                            "For "
                                                            "automatic "
                                                            "triggering "
                                                            "a "
                                                            "handle "
                                                            "must "
                                                            "be "
                                                            "configured "
                                                            "and "
                                                            "the "
                                                            "workflow "
                                                            "must "
                                                            "be "
                                                            "published.",
                                                            "properties": {
                                                                "rateLimit": {
                                                                    "description": "Defines "
                                                                    "a "
                                                                    "rate "
                                                                    "limit "
                                                                    "for "
                                                                    "a "
                                                                    "trigger.",
                                                                    "properties": {
                                                                        "count": {
                                                                            "description": "The "
                                                                            "`TriggerRateLimit` "
                                                                            "`count`.",
                                                                            "format": "int64",
                                                                            "type": "integer",
                                                                        },
                                                                        "interval": {
                                                                            "description": "The "
                                                                            "`TriggerRateLimit` "
                                                                            "`interval`. "
                                                                            "The "
                                                                            "expected "
                                                                            "format "
                                                                            "is "
                                                                            "the "
                                                                            "number "
                                                                            "of "
                                                                            "seconds "
                                                                            "ending "
                                                                            "with "
                                                                            "an "
                                                                            "s. "
                                                                            "For "
                                                                            "example, "
                                                                            "1 "
                                                                            "day "
                                                                            "is "
                                                                            "86400s",
                                                                            "type": "string",
                                                                        },
                                                                    },
                                                                    "type": "object",
                                                                }
                                                            },
                                                            "type": "object",
                                                        },
                                                        "startStepNames": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "steps "
                                                            "that "
                                                            "run "
                                                            "first "
                                                            "after "
                                                            "a "
                                                            "trigger "
                                                            "fires.",
                                                            "example": [""],
                                                            "items": {
                                                                "description": "The "
                                                                "`StartStepNames` "
                                                                "`items`.",
                                                                "type": "string",
                                                            },
                                                            "type": "array",
                                                        },
                                                    },
                                                    "required": ["datastoreTrigger"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "Schema "
                                                    "for "
                                                    "a "
                                                    "Dashboard-based "
                                                    "trigger.",
                                                    "properties": {
                                                        "dashboardTrigger": {
                                                            "description": "Trigger "
                                                            "a "
                                                            "workflow "
                                                            "from "
                                                            "a "
                                                            "Dashboard.",
                                                            "type": "object",
                                                        },
                                                        "startStepNames": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "steps "
                                                            "that "
                                                            "run "
                                                            "first "
                                                            "after "
                                                            "a "
                                                            "trigger "
                                                            "fires.",
                                                            "example": [""],
                                                            "items": {
                                                                "description": "The "
                                                                "`StartStepNames` "
                                                                "`items`.",
                                                                "type": "string",
                                                            },
                                                            "type": "array",
                                                        },
                                                    },
                                                    "required": ["dashboardTrigger"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "Schema "
                                                    "for "
                                                    "a "
                                                    "GitHub "
                                                    "webhook-based "
                                                    "trigger.",
                                                    "properties": {
                                                        "githubWebhookTrigger": {
                                                            "description": "Trigger "
                                                            "a "
                                                            "workflow "
                                                            "from "
                                                            "a "
                                                            "GitHub "
                                                            "webhook. "
                                                            "To "
                                                            "trigger "
                                                            "a "
                                                            "workflow "
                                                            "from "
                                                            "GitHub, "
                                                            "you "
                                                            "must "
                                                            "set "
                                                            "a "
                                                            "`webhookSecret`. "
                                                            "In "
                                                            "your "
                                                            "GitHub "
                                                            "Webhook "
                                                            "Settings, "
                                                            "set "
                                                            "the "
                                                            "Payload "
                                                            "URL "
                                                            "to "
                                                            '"base_url"/api/v2/workflows/"workflow_id"/webhook?orgId="org_id", '
                                                            "select "
                                                            "application/json "
                                                            "for "
                                                            "the "
                                                            "content "
                                                            "type, "
                                                            "and "
                                                            "be "
                                                            "highly "
                                                            "recommend "
                                                            "enabling "
                                                            "SSL "
                                                            "verification "
                                                            "for "
                                                            "security. "
                                                            "The "
                                                            "workflow "
                                                            "must "
                                                            "be "
                                                            "published.",
                                                            "properties": {
                                                                "rateLimit": {
                                                                    "description": "Defines "
                                                                    "a "
                                                                    "rate "
                                                                    "limit "
                                                                    "for "
                                                                    "a "
                                                                    "trigger.",
                                                                    "properties": {
                                                                        "count": {
                                                                            "description": "The "
                                                                            "`TriggerRateLimit` "
                                                                            "`count`.",
                                                                            "format": "int64",
                                                                            "type": "integer",
                                                                        },
                                                                        "interval": {
                                                                            "description": "The "
                                                                            "`TriggerRateLimit` "
                                                                            "`interval`. "
                                                                            "The "
                                                                            "expected "
                                                                            "format "
                                                                            "is "
                                                                            "the "
                                                                            "number "
                                                                            "of "
                                                                            "seconds "
                                                                            "ending "
                                                                            "with "
                                                                            "an "
                                                                            "s. "
                                                                            "For "
                                                                            "example, "
                                                                            "1 "
                                                                            "day "
                                                                            "is "
                                                                            "86400s",
                                                                            "type": "string",
                                                                        },
                                                                    },
                                                                    "type": "object",
                                                                }
                                                            },
                                                            "type": "object",
                                                        },
                                                        "startStepNames": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "steps "
                                                            "that "
                                                            "run "
                                                            "first "
                                                            "after "
                                                            "a "
                                                            "trigger "
                                                            "fires.",
                                                            "example": [""],
                                                            "items": {
                                                                "description": "The "
                                                                "`StartStepNames` "
                                                                "`items`.",
                                                                "type": "string",
                                                            },
                                                            "type": "array",
                                                        },
                                                    },
                                                    "required": ["githubWebhookTrigger"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "Schema "
                                                    "for "
                                                    "an "
                                                    "Incident-based "
                                                    "trigger.",
                                                    "properties": {
                                                        "incidentTrigger": {
                                                            "description": "Trigger "
                                                            "a "
                                                            "workflow "
                                                            "from "
                                                            "an "
                                                            "Incident. "
                                                            "For "
                                                            "automatic "
                                                            "triggering "
                                                            "a "
                                                            "handle "
                                                            "must "
                                                            "be "
                                                            "configured "
                                                            "and "
                                                            "the "
                                                            "workflow "
                                                            "must "
                                                            "be "
                                                            "published.",
                                                            "properties": {
                                                                "rateLimit": {
                                                                    "description": "Defines "
                                                                    "a "
                                                                    "rate "
                                                                    "limit "
                                                                    "for "
                                                                    "a "
                                                                    "trigger.",
                                                                    "properties": {
                                                                        "count": {
                                                                            "description": "The "
                                                                            "`TriggerRateLimit` "
                                                                            "`count`.",
                                                                            "format": "int64",
                                                                            "type": "integer",
                                                                        },
                                                                        "interval": {
                                                                            "description": "The "
                                                                            "`TriggerRateLimit` "
                                                                            "`interval`. "
                                                                            "The "
                                                                            "expected "
                                                                            "format "
                                                                            "is "
                                                                            "the "
                                                                            "number "
                                                                            "of "
                                                                            "seconds "
                                                                            "ending "
                                                                            "with "
                                                                            "an "
                                                                            "s. "
                                                                            "For "
                                                                            "example, "
                                                                            "1 "
                                                                            "day "
                                                                            "is "
                                                                            "86400s",
                                                                            "type": "string",
                                                                        },
                                                                    },
                                                                    "type": "object",
                                                                }
                                                            },
                                                            "type": "object",
                                                        },
                                                        "startStepNames": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "steps "
                                                            "that "
                                                            "run "
                                                            "first "
                                                            "after "
                                                            "a "
                                                            "trigger "
                                                            "fires.",
                                                            "example": [""],
                                                            "items": {
                                                                "description": "The "
                                                                "`StartStepNames` "
                                                                "`items`.",
                                                                "type": "string",
                                                            },
                                                            "type": "array",
                                                        },
                                                    },
                                                    "required": ["incidentTrigger"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "Schema "
                                                    "for "
                                                    "a "
                                                    "Monitor-based "
                                                    "trigger.",
                                                    "properties": {
                                                        "monitorTrigger": {
                                                            "description": "Trigger "
                                                            "a "
                                                            "workflow "
                                                            "from "
                                                            "a "
                                                            "Monitor. "
                                                            "For "
                                                            "automatic "
                                                            "triggering "
                                                            "a "
                                                            "handle "
                                                            "must "
                                                            "be "
                                                            "configured "
                                                            "and "
                                                            "the "
                                                            "workflow "
                                                            "must "
                                                            "be "
                                                            "published.",
                                                            "properties": {
                                                                "rateLimit": {
                                                                    "description": "Defines "
                                                                    "a "
                                                                    "rate "
                                                                    "limit "
                                                                    "for "
                                                                    "a "
                                                                    "trigger.",
                                                                    "properties": {
                                                                        "count": {
                                                                            "description": "The "
                                                                            "`TriggerRateLimit` "
                                                                            "`count`.",
                                                                            "format": "int64",
                                                                            "type": "integer",
                                                                        },
                                                                        "interval": {
                                                                            "description": "The "
                                                                            "`TriggerRateLimit` "
                                                                            "`interval`. "
                                                                            "The "
                                                                            "expected "
                                                                            "format "
                                                                            "is "
                                                                            "the "
                                                                            "number "
                                                                            "of "
                                                                            "seconds "
                                                                            "ending "
                                                                            "with "
                                                                            "an "
                                                                            "s. "
                                                                            "For "
                                                                            "example, "
                                                                            "1 "
                                                                            "day "
                                                                            "is "
                                                                            "86400s",
                                                                            "type": "string",
                                                                        },
                                                                    },
                                                                    "type": "object",
                                                                }
                                                            },
                                                            "type": "object",
                                                        },
                                                        "startStepNames": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "steps "
                                                            "that "
                                                            "run "
                                                            "first "
                                                            "after "
                                                            "a "
                                                            "trigger "
                                                            "fires.",
                                                            "example": [""],
                                                            "items": {
                                                                "description": "The "
                                                                "`StartStepNames` "
                                                                "`items`.",
                                                                "type": "string",
                                                            },
                                                            "type": "array",
                                                        },
                                                    },
                                                    "required": ["monitorTrigger"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "Schema "
                                                    "for "
                                                    "a "
                                                    "Notebook-based "
                                                    "trigger.",
                                                    "properties": {
                                                        "notebookTrigger": {
                                                            "description": "Trigger "
                                                            "a "
                                                            "workflow "
                                                            "from "
                                                            "a "
                                                            "Notebook.",
                                                            "type": "object",
                                                        },
                                                        "startStepNames": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "steps "
                                                            "that "
                                                            "run "
                                                            "first "
                                                            "after "
                                                            "a "
                                                            "trigger "
                                                            "fires.",
                                                            "example": [""],
                                                            "items": {
                                                                "description": "The "
                                                                "`StartStepNames` "
                                                                "`items`.",
                                                                "type": "string",
                                                            },
                                                            "type": "array",
                                                        },
                                                    },
                                                    "required": ["notebookTrigger"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "Schema "
                                                    "for "
                                                    "a "
                                                    "Schedule-based "
                                                    "trigger.",
                                                    "properties": {
                                                        "scheduleTrigger": {
                                                            "description": "Trigger "
                                                            "a "
                                                            "workflow "
                                                            "from "
                                                            "a "
                                                            "Schedule. "
                                                            "The "
                                                            "workflow "
                                                            "must "
                                                            "be "
                                                            "published.",
                                                            "properties": {
                                                                "rruleExpression": {
                                                                    "description": "Recurrence "
                                                                    "rule "
                                                                    "expression "
                                                                    "for "
                                                                    "scheduling.",
                                                                    "example": "",
                                                                    "type": "string",
                                                                }
                                                            },
                                                            "required": ["rruleExpression"],
                                                            "type": "object",
                                                        },
                                                        "startStepNames": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "steps "
                                                            "that "
                                                            "run "
                                                            "first "
                                                            "after "
                                                            "a "
                                                            "trigger "
                                                            "fires.",
                                                            "example": [""],
                                                            "items": {
                                                                "description": "The "
                                                                "`StartStepNames` "
                                                                "`items`.",
                                                                "type": "string",
                                                            },
                                                            "type": "array",
                                                        },
                                                    },
                                                    "required": ["scheduleTrigger"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "Schema "
                                                    "for "
                                                    "a "
                                                    "Security-based "
                                                    "trigger.",
                                                    "properties": {
                                                        "securityTrigger": {
                                                            "description": "Trigger "
                                                            "a "
                                                            "workflow "
                                                            "from "
                                                            "a "
                                                            "Security "
                                                            "Signal "
                                                            "or "
                                                            "Finding. "
                                                            "For "
                                                            "automatic "
                                                            "triggering "
                                                            "a "
                                                            "handle "
                                                            "must "
                                                            "be "
                                                            "configured "
                                                            "and "
                                                            "the "
                                                            "workflow "
                                                            "must "
                                                            "be "
                                                            "published.",
                                                            "properties": {
                                                                "rateLimit": {
                                                                    "description": "Defines "
                                                                    "a "
                                                                    "rate "
                                                                    "limit "
                                                                    "for "
                                                                    "a "
                                                                    "trigger.",
                                                                    "properties": {
                                                                        "count": {
                                                                            "description": "The "
                                                                            "`TriggerRateLimit` "
                                                                            "`count`.",
                                                                            "format": "int64",
                                                                            "type": "integer",
                                                                        },
                                                                        "interval": {
                                                                            "description": "The "
                                                                            "`TriggerRateLimit` "
                                                                            "`interval`. "
                                                                            "The "
                                                                            "expected "
                                                                            "format "
                                                                            "is "
                                                                            "the "
                                                                            "number "
                                                                            "of "
                                                                            "seconds "
                                                                            "ending "
                                                                            "with "
                                                                            "an "
                                                                            "s. "
                                                                            "For "
                                                                            "example, "
                                                                            "1 "
                                                                            "day "
                                                                            "is "
                                                                            "86400s",
                                                                            "type": "string",
                                                                        },
                                                                    },
                                                                    "type": "object",
                                                                }
                                                            },
                                                            "type": "object",
                                                        },
                                                        "startStepNames": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "steps "
                                                            "that "
                                                            "run "
                                                            "first "
                                                            "after "
                                                            "a "
                                                            "trigger "
                                                            "fires.",
                                                            "example": [""],
                                                            "items": {
                                                                "description": "The "
                                                                "`StartStepNames` "
                                                                "`items`.",
                                                                "type": "string",
                                                            },
                                                            "type": "array",
                                                        },
                                                    },
                                                    "required": ["securityTrigger"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "Schema "
                                                    "for "
                                                    "a "
                                                    "Self "
                                                    "Service-based "
                                                    "trigger.",
                                                    "properties": {
                                                        "selfServiceTrigger": {
                                                            "description": "Trigger "
                                                            "a "
                                                            "workflow "
                                                            "from "
                                                            "Self "
                                                            "Service.",
                                                            "type": "object",
                                                        },
                                                        "startStepNames": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "steps "
                                                            "that "
                                                            "run "
                                                            "first "
                                                            "after "
                                                            "a "
                                                            "trigger "
                                                            "fires.",
                                                            "example": [""],
                                                            "items": {
                                                                "description": "The "
                                                                "`StartStepNames` "
                                                                "`items`.",
                                                                "type": "string",
                                                            },
                                                            "type": "array",
                                                        },
                                                    },
                                                    "required": ["selfServiceTrigger"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "Schema "
                                                    "for "
                                                    "a "
                                                    "Slack-based "
                                                    "trigger.",
                                                    "properties": {
                                                        "slackTrigger": {
                                                            "description": "Trigger "
                                                            "a "
                                                            "workflow "
                                                            "from "
                                                            "Slack. "
                                                            "The "
                                                            "workflow "
                                                            "must "
                                                            "be "
                                                            "published.",
                                                            "type": "object",
                                                        },
                                                        "startStepNames": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "steps "
                                                            "that "
                                                            "run "
                                                            "first "
                                                            "after "
                                                            "a "
                                                            "trigger "
                                                            "fires.",
                                                            "example": [""],
                                                            "items": {
                                                                "description": "The "
                                                                "`StartStepNames` "
                                                                "`items`.",
                                                                "type": "string",
                                                            },
                                                            "type": "array",
                                                        },
                                                    },
                                                    "required": ["slackTrigger"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "Schema "
                                                    "for "
                                                    "a "
                                                    "Software "
                                                    "Catalog-based "
                                                    "trigger.",
                                                    "properties": {
                                                        "softwareCatalogTrigger": {
                                                            "description": "Trigger "
                                                            "a "
                                                            "workflow "
                                                            "from "
                                                            "Software "
                                                            "Catalog.",
                                                            "type": "object",
                                                        },
                                                        "startStepNames": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "steps "
                                                            "that "
                                                            "run "
                                                            "first "
                                                            "after "
                                                            "a "
                                                            "trigger "
                                                            "fires.",
                                                            "example": [""],
                                                            "items": {
                                                                "description": "The "
                                                                "`StartStepNames` "
                                                                "`items`.",
                                                                "type": "string",
                                                            },
                                                            "type": "array",
                                                        },
                                                    },
                                                    "required": ["softwareCatalogTrigger"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "Schema "
                                                    "for "
                                                    "a "
                                                    "Workflow-based "
                                                    "trigger.",
                                                    "properties": {
                                                        "startStepNames": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "steps "
                                                            "that "
                                                            "run "
                                                            "first "
                                                            "after "
                                                            "a "
                                                            "trigger "
                                                            "fires.",
                                                            "example": [""],
                                                            "items": {
                                                                "description": "The "
                                                                "`StartStepNames` "
                                                                "`items`.",
                                                                "type": "string",
                                                            },
                                                            "type": "array",
                                                        },
                                                        "workflowTrigger": {
                                                            "description": "Trigger "
                                                            "a "
                                                            "workflow "
                                                            "from "
                                                            "the "
                                                            "Datadog "
                                                            "UI. "
                                                            "Only "
                                                            "required "
                                                            "if "
                                                            "no "
                                                            "other "
                                                            "trigger "
                                                            "exists.",
                                                            "type": "object",
                                                        },
                                                    },
                                                    "required": ["workflowTrigger"],
                                                    "type": "object",
                                                },
                                            ],
                                        },
                                        "type": "array",
                                    },
                                },
                                "type": "object",
                            },
                            "tags": {
                                "description": "Tags of the workflow.",
                                "items": {"type": "string"},
                                "type": "array",
                            },
                            "updatedAt": {
                                "description": "When the workflow was last updated.",
                                "format": "date-time",
                                "readOnly": True,
                                "type": "string",
                            },
                            "webhookSecret": {
                                "description": "If "
                                "a "
                                "Webhook "
                                "trigger "
                                "is "
                                "defined "
                                "on "
                                "this "
                                "workflow, "
                                "a "
                                "webhookSecret "
                                "is "
                                "required "
                                "and "
                                "should "
                                "be "
                                "provided "
                                "here.",
                                "type": "string",
                                "writeOnly": True,
                            },
                        },
                        "required": ["name", "spec"],
                        "type": "object",
                    },
                    "id": {
                        "description": "The workflow identifier",
                        "readOnly": True,
                        "type": "string",
                    },
                    "relationships": {
                        "description": "The definition of `WorkflowDataRelationships` object.",
                        "properties": {
                            "creator": {
                                "description": "The "
                                "definition "
                                "of "
                                "`WorkflowUserRelationship` "
                                "object.",
                                "properties": {
                                    "data": {
                                        "description": "The "
                                        "definition "
                                        "of "
                                        "`WorkflowUserRelationshipData` "
                                        "object.",
                                        "properties": {
                                            "id": {
                                                "description": "The user identifier",
                                                "example": "",
                                                "type": "string",
                                            },
                                            "type": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "`WorkflowUserRelationshipType` "
                                                "object.",
                                                "enum": ["users"],
                                                "example": "users",
                                                "type": "string",
                                                "x-enum-varnames": ["USERS"],
                                            },
                                        },
                                        "required": ["type", "id"],
                                        "type": "object",
                                    }
                                },
                                "type": "object",
                            },
                            "owner": {
                                "description": "The "
                                "definition "
                                "of "
                                "`WorkflowUserRelationship` "
                                "object.",
                                "properties": {
                                    "data": {
                                        "description": "The "
                                        "definition "
                                        "of "
                                        "`WorkflowUserRelationshipData` "
                                        "object.",
                                        "properties": {
                                            "id": {
                                                "description": "The user identifier",
                                                "example": "",
                                                "type": "string",
                                            },
                                            "type": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "`WorkflowUserRelationshipType` "
                                                "object.",
                                                "enum": ["users"],
                                                "example": "users",
                                                "type": "string",
                                                "x-enum-varnames": ["USERS"],
                                            },
                                        },
                                        "required": ["type", "id"],
                                        "type": "object",
                                    }
                                },
                                "type": "object",
                            },
                        },
                        "readOnly": True,
                        "type": "object",
                    },
                    "type": {
                        "description": "The definition of `WorkflowDataType` object.",
                        "enum": ["workflows"],
                        "example": "workflows",
                        "type": "string",
                        "x-enum-varnames": ["WORKFLOWS"],
                    },
                },
                "required": ["type", "attributes"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "UPDATEWORKFLOWBYID_REQUEST_BODY_SCHEMA": {
        "description": "A request object for updating an existing workflow.",
        "example": {
            "data": {
                "attributes": {
                    "description": "A sample workflow.",
                    "name": "Example Workflow",
                    "published": True,
                    "spec": {
                        "annotations": [
                            {
                                "display": {
                                    "bounds": {"height": 150, "width": 300, "x": -375, "y": -0.5}
                                },
                                "id": "99999999-9999-9999-9999-999999999999",
                                "markdownTextAnnotation": {"text": "Example annotation."},
                            }
                        ],
                        "connectionEnvs": [
                            {
                                "connections": [
                                    {
                                        "connectionId": "11111111-1111-1111-1111-111111111111",
                                        "label": "INTEGRATION_DATADOG",
                                    }
                                ],
                                "env": "default",
                            }
                        ],
                        "handle": "my-handle",
                        "inputSchema": {
                            "parameters": [
                                {"defaultValue": "default", "name": "input", "type": "STRING"}
                            ]
                        },
                        "outputSchema": {
                            "parameters": [
                                {
                                    "name": "output",
                                    "type": "ARRAY_OBJECT",
                                    "value": "{{ Steps.Step1 }}",
                                }
                            ]
                        },
                        "steps": [
                            {
                                "actionId": "com.datadoghq.dd.monitor.listMonitors",
                                "connectionLabel": "INTEGRATION_DATADOG",
                                "name": "Step1",
                                "outboundEdges": [{"branchName": "main", "nextStepName": "Step2"}],
                                "parameters": [{"name": "tags", "value": "service:monitoring"}],
                            },
                            {"actionId": "com.datadoghq.core.noop", "name": "Step2"},
                        ],
                        "triggers": [
                            {
                                "monitorTrigger": {"rateLimit": {"count": 1, "interval": "3600s"}},
                                "startStepNames": ["Step1"],
                            },
                            {"githubWebhookTrigger": {}, "startStepNames": ["Step1"]},
                        ],
                    },
                    "tags": ["team:infra", "service:monitoring", "foo:bar"],
                },
                "id": "22222222-2222-2222-2222-222222222222",
                "type": "workflows",
            }
        },
        "properties": {
            "data": {
                "description": "Data related to the workflow being updated.",
                "properties": {
                    "attributes": {
                        "description": "The definition of `WorkflowDataUpdateAttributes` object.",
                        "properties": {
                            "createdAt": {
                                "description": "When the workflow was created.",
                                "format": "date-time",
                                "readOnly": True,
                                "type": "string",
                            },
                            "description": {
                                "description": "Description of the workflow.",
                                "type": "string",
                            },
                            "name": {"description": "Name of the workflow.", "type": "string"},
                            "published": {
                                "description": "Set "
                                "the "
                                "workflow "
                                "to "
                                "published "
                                "or "
                                "unpublished. "
                                "Workflows "
                                "in "
                                "an "
                                "unpublished "
                                "state "
                                "will "
                                "only "
                                "be "
                                "executable "
                                "via "
                                "manual "
                                "runs. "
                                "Automatic "
                                "triggers "
                                "such "
                                "as "
                                "Schedule "
                                "will "
                                "not "
                                "execute "
                                "the "
                                "workflow "
                                "until "
                                "it "
                                "is "
                                "published.",
                                "type": "boolean",
                            },
                            "spec": {
                                "description": "The spec defines what the workflow does.",
                                "properties": {
                                    "annotations": {
                                        "description": "A "
                                        "list "
                                        "of "
                                        "annotations "
                                        "used "
                                        "in "
                                        "the "
                                        "workflow. "
                                        "These "
                                        "are "
                                        "like "
                                        "sticky "
                                        "notes "
                                        "for "
                                        "your "
                                        "workflow!",
                                        "items": {
                                            "description": "A "
                                            "list "
                                            "of "
                                            "annotations "
                                            "used "
                                            "in "
                                            "the "
                                            "workflow. "
                                            "These "
                                            "are "
                                            "like "
                                            "sticky "
                                            "notes "
                                            "for "
                                            "your "
                                            "workflow!",
                                            "properties": {
                                                "display": {
                                                    "description": "The "
                                                    "definition "
                                                    "of "
                                                    "`AnnotationDisplay` "
                                                    "object.",
                                                    "properties": {
                                                        "bounds": {
                                                            "description": "The "
                                                            "definition "
                                                            "of "
                                                            "`AnnotationDisplayBounds` "
                                                            "object.",
                                                            "properties": {
                                                                "height": {
                                                                    "description": "The "
                                                                    "`bounds` "
                                                                    "`height`.",
                                                                    "format": "double",
                                                                    "type": "number",
                                                                },
                                                                "width": {
                                                                    "description": "The "
                                                                    "`bounds` "
                                                                    "`width`.",
                                                                    "format": "double",
                                                                    "type": "number",
                                                                },
                                                                "x": {
                                                                    "description": "The "
                                                                    "`bounds` "
                                                                    "`x`.",
                                                                    "format": "double",
                                                                    "type": "number",
                                                                },
                                                                "y": {
                                                                    "description": "The "
                                                                    "`bounds` "
                                                                    "`y`.",
                                                                    "format": "double",
                                                                    "type": "number",
                                                                },
                                                            },
                                                            "type": "object",
                                                        }
                                                    },
                                                    "type": "object",
                                                },
                                                "id": {
                                                    "description": "The `Annotation` `id`.",
                                                    "example": "",
                                                    "type": "string",
                                                },
                                                "markdownTextAnnotation": {
                                                    "description": "The "
                                                    "definition "
                                                    "of "
                                                    "`AnnotationMarkdownTextAnnotation` "
                                                    "object.",
                                                    "properties": {
                                                        "text": {
                                                            "description": "The "
                                                            "`markdownTextAnnotation` "
                                                            "`text`.",
                                                            "type": "string",
                                                        }
                                                    },
                                                    "type": "object",
                                                },
                                            },
                                            "required": ["id", "display", "markdownTextAnnotation"],
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "connectionEnvs": {
                                        "description": "A "
                                        "list "
                                        "of "
                                        "connections "
                                        "or "
                                        "connection "
                                        "groups "
                                        "used "
                                        "in "
                                        "the "
                                        "workflow.",
                                        "items": {
                                            "description": "A "
                                            "list "
                                            "of "
                                            "connections "
                                            "or "
                                            "connection "
                                            "groups "
                                            "used "
                                            "in "
                                            "the "
                                            "workflow.",
                                            "properties": {
                                                "connectionGroups": {
                                                    "description": "The "
                                                    "`ConnectionEnv` "
                                                    "`connectionGroups`.",
                                                    "items": {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "`ConnectionGroup` "
                                                        "object.",
                                                        "properties": {
                                                            "connectionGroupId": {
                                                                "description": "The "
                                                                "`ConnectionGroup` "
                                                                "`connectionGroupId`.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                            "label": {
                                                                "description": "The "
                                                                "`ConnectionGroup` "
                                                                "`label`.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                            "tags": {
                                                                "description": "The "
                                                                "`ConnectionGroup` "
                                                                "`tags`.",
                                                                "example": [""],
                                                                "items": {"type": "string"},
                                                                "type": "array",
                                                            },
                                                        },
                                                        "required": [
                                                            "connectionGroupId",
                                                            "label",
                                                            "tags",
                                                        ],
                                                        "type": "object",
                                                    },
                                                    "type": "array",
                                                },
                                                "connections": {
                                                    "description": "The "
                                                    "`ConnectionEnv` "
                                                    "`connections`.",
                                                    "items": {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "`Connection` "
                                                        "object.",
                                                        "properties": {
                                                            "connectionId": {
                                                                "description": "The "
                                                                "`Connection` "
                                                                "`connectionId`.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                            "label": {
                                                                "description": "The "
                                                                "`Connection` "
                                                                "`label`.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                        },
                                                        "required": ["connectionId", "label"],
                                                        "type": "object",
                                                    },
                                                    "type": "array",
                                                },
                                                "env": {
                                                    "description": "The "
                                                    "definition "
                                                    "of "
                                                    "`ConnectionEnvEnv` "
                                                    "object.",
                                                    "enum": ["default"],
                                                    "example": "default",
                                                    "type": "string",
                                                    "x-enum-varnames": ["DEFAULT"],
                                                },
                                            },
                                            "required": ["env"],
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "handle": {
                                        "description": "Unique "
                                        "identifier "
                                        "used "
                                        "to "
                                        "trigger "
                                        "workflows "
                                        "automatically "
                                        "in "
                                        "Datadog.",
                                        "type": "string",
                                    },
                                    "inputSchema": {
                                        "description": "A "
                                        "list "
                                        "of "
                                        "input "
                                        "parameters "
                                        "for "
                                        "the "
                                        "workflow. "
                                        "These "
                                        "can "
                                        "be "
                                        "used "
                                        "as "
                                        "dynamic "
                                        "runtime "
                                        "values "
                                        "in "
                                        "your "
                                        "workflow.",
                                        "properties": {
                                            "parameters": {
                                                "description": "The `InputSchema` `parameters`.",
                                                "items": {
                                                    "description": "The "
                                                    "definition "
                                                    "of "
                                                    "`InputSchemaParameters` "
                                                    "object.",
                                                    "properties": {
                                                        "defaultValue": {
                                                            "description": "The "
                                                            "`InputSchemaParameters` "
                                                            "`defaultValue`."
                                                        },
                                                        "description": {
                                                            "description": "The "
                                                            "`InputSchemaParameters` "
                                                            "`description`.",
                                                            "type": "string",
                                                        },
                                                        "label": {
                                                            "description": "The "
                                                            "`InputSchemaParameters` "
                                                            "`label`.",
                                                            "type": "string",
                                                        },
                                                        "name": {
                                                            "description": "The "
                                                            "`InputSchemaParameters` "
                                                            "`name`.",
                                                            "example": "",
                                                            "type": "string",
                                                        },
                                                        "type": {
                                                            "description": "The "
                                                            "definition "
                                                            "of "
                                                            "`InputSchemaParametersType` "
                                                            "object.",
                                                            "enum": [
                                                                "STRING",
                                                                "NUMBER",
                                                                "BOOLEAN",
                                                                "OBJECT",
                                                                "ARRAY_STRING",
                                                                "ARRAY_NUMBER",
                                                                "ARRAY_BOOLEAN",
                                                                "ARRAY_OBJECT",
                                                            ],
                                                            "example": "STRING",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "STRING",
                                                                "NUMBER",
                                                                "BOOLEAN",
                                                                "OBJECT",
                                                                "ARRAY_STRING",
                                                                "ARRAY_NUMBER",
                                                                "ARRAY_BOOLEAN",
                                                                "ARRAY_OBJECT",
                                                            ],
                                                        },
                                                    },
                                                    "required": ["name", "type"],
                                                    "type": "object",
                                                },
                                                "type": "array",
                                            }
                                        },
                                        "type": "object",
                                    },
                                    "outputSchema": {
                                        "description": "A "
                                        "list "
                                        "of "
                                        "output "
                                        "parameters "
                                        "for "
                                        "the "
                                        "workflow.",
                                        "properties": {
                                            "parameters": {
                                                "description": "The `OutputSchema` `parameters`.",
                                                "items": {
                                                    "description": "The "
                                                    "definition "
                                                    "of "
                                                    "`OutputSchemaParameters` "
                                                    "object.",
                                                    "properties": {
                                                        "defaultValue": {
                                                            "description": "The "
                                                            "`OutputSchemaParameters` "
                                                            "`defaultValue`."
                                                        },
                                                        "description": {
                                                            "description": "The "
                                                            "`OutputSchemaParameters` "
                                                            "`description`.",
                                                            "type": "string",
                                                        },
                                                        "label": {
                                                            "description": "The "
                                                            "`OutputSchemaParameters` "
                                                            "`label`.",
                                                            "type": "string",
                                                        },
                                                        "name": {
                                                            "description": "The "
                                                            "`OutputSchemaParameters` "
                                                            "`name`.",
                                                            "example": "",
                                                            "type": "string",
                                                        },
                                                        "type": {
                                                            "description": "The "
                                                            "definition "
                                                            "of "
                                                            "`OutputSchemaParametersType` "
                                                            "object.",
                                                            "enum": [
                                                                "STRING",
                                                                "NUMBER",
                                                                "BOOLEAN",
                                                                "OBJECT",
                                                                "ARRAY_STRING",
                                                                "ARRAY_NUMBER",
                                                                "ARRAY_BOOLEAN",
                                                                "ARRAY_OBJECT",
                                                            ],
                                                            "example": "STRING",
                                                            "type": "string",
                                                            "x-enum-varnames": [
                                                                "STRING",
                                                                "NUMBER",
                                                                "BOOLEAN",
                                                                "OBJECT",
                                                                "ARRAY_STRING",
                                                                "ARRAY_NUMBER",
                                                                "ARRAY_BOOLEAN",
                                                                "ARRAY_OBJECT",
                                                            ],
                                                        },
                                                        "value": {
                                                            "description": "The "
                                                            "`OutputSchemaParameters` "
                                                            "`value`."
                                                        },
                                                    },
                                                    "required": ["name", "type"],
                                                    "type": "object",
                                                },
                                                "type": "array",
                                            }
                                        },
                                        "type": "object",
                                    },
                                    "steps": {
                                        "description": "A "
                                        "`Step` "
                                        "is "
                                        "a "
                                        "sub-component "
                                        "of "
                                        "a "
                                        "workflow. "
                                        "Each "
                                        "`Step` "
                                        "performs "
                                        "an "
                                        "action.",
                                        "items": {
                                            "description": "A "
                                            "Step "
                                            "is "
                                            "a "
                                            "sub-component "
                                            "of "
                                            "a "
                                            "workflow. "
                                            "Each "
                                            "Step "
                                            "performs "
                                            "an "
                                            "action.",
                                            "properties": {
                                                "actionId": {
                                                    "description": "The "
                                                    "unique "
                                                    "identifier "
                                                    "of "
                                                    "an "
                                                    "action.",
                                                    "example": "",
                                                    "type": "string",
                                                },
                                                "completionGate": {
                                                    "description": "Used "
                                                    "to "
                                                    "create "
                                                    "conditions "
                                                    "before "
                                                    "running "
                                                    "subsequent "
                                                    "actions.",
                                                    "properties": {
                                                        "completionCondition": {
                                                            "description": "The "
                                                            "definition "
                                                            "of "
                                                            "`CompletionCondition` "
                                                            "object.",
                                                            "properties": {
                                                                "operand1": {
                                                                    "description": "The "
                                                                    "`CompletionCondition` "
                                                                    "`operand1`."
                                                                },
                                                                "operand2": {
                                                                    "description": "The "
                                                                    "`CompletionCondition` "
                                                                    "`operand2`."
                                                                },
                                                                "operator": {
                                                                    "description": "The "
                                                                    "definition "
                                                                    "of "
                                                                    "`CompletionConditionOperator` "
                                                                    "object.",
                                                                    "enum": [
                                                                        "OPERATOR_EQUAL",
                                                                        "OPERATOR_NOT_EQUAL",
                                                                        "OPERATOR_GREATER_THAN",
                                                                        "OPERATOR_LESS_THAN",
                                                                        "OPERATOR_GREATER_THAN_OR_EQUAL_TO",
                                                                        "OPERATOR_LESS_THAN_OR_EQUAL_TO",
                                                                        "OPERATOR_CONTAINS",
                                                                        "OPERATOR_DOES_NOT_CONTAIN",
                                                                        "OPERATOR_IS_NULL",
                                                                        "OPERATOR_IS_NOT_NULL",
                                                                        "OPERATOR_IS_EMPTY",
                                                                        "OPERATOR_IS_NOT_EMPTY",
                                                                    ],
                                                                    "example": "OPERATOR_EQUAL",
                                                                    "type": "string",
                                                                    "x-enum-varnames": [
                                                                        "OPERATOR_EQUAL",
                                                                        "OPERATOR_NOT_EQUAL",
                                                                        "OPERATOR_GREATER_THAN",
                                                                        "OPERATOR_LESS_THAN",
                                                                        "OPERATOR_GREATER_THAN_OR_EQUAL_TO",
                                                                        "OPERATOR_LESS_THAN_OR_EQUAL_TO",
                                                                        "OPERATOR_CONTAINS",
                                                                        "OPERATOR_DOES_NOT_CONTAIN",
                                                                        "OPERATOR_IS_NULL",
                                                                        "OPERATOR_IS_NOT_NULL",
                                                                        "OPERATOR_IS_EMPTY",
                                                                        "OPERATOR_IS_NOT_EMPTY",
                                                                    ],
                                                                },
                                                            },
                                                            "required": ["operand1", "operator"],
                                                            "type": "object",
                                                        },
                                                        "retryStrategy": {
                                                            "description": "The "
                                                            "definition "
                                                            "of "
                                                            "`RetryStrategy` "
                                                            "object.",
                                                            "properties": {
                                                                "kind": {
                                                                    "description": "The "
                                                                    "definition "
                                                                    "of "
                                                                    "`RetryStrategyKind` "
                                                                    "object.",
                                                                    "enum": [
                                                                        "RETRY_STRATEGY_LINEAR"
                                                                    ],
                                                                    "example": "RETRY_STRATEGY_LINEAR",
                                                                    "type": "string",
                                                                    "x-enum-varnames": [
                                                                        "RETRY_STRATEGY_LINEAR"
                                                                    ],
                                                                },
                                                                "linear": {
                                                                    "description": "The "
                                                                    "definition "
                                                                    "of "
                                                                    "`RetryStrategyLinear` "
                                                                    "object.",
                                                                    "properties": {
                                                                        "interval": {
                                                                            "description": "The "
                                                                            "`RetryStrategyLinear` "
                                                                            "`interval`. "
                                                                            "The "
                                                                            "expected "
                                                                            "format "
                                                                            "is "
                                                                            "the "
                                                                            "number "
                                                                            "of "
                                                                            "seconds "
                                                                            "ending "
                                                                            "with "
                                                                            "an "
                                                                            "s. "
                                                                            "For "
                                                                            "example, "
                                                                            "1 "
                                                                            "day "
                                                                            "is "
                                                                            "86400s",
                                                                            "example": "",
                                                                            "type": "string",
                                                                        },
                                                                        "maxRetries": {
                                                                            "description": "The "
                                                                            "`RetryStrategyLinear` "
                                                                            "`maxRetries`.",
                                                                            "example": 0.0,
                                                                            "format": "double",
                                                                            "type": "number",
                                                                        },
                                                                    },
                                                                    "required": [
                                                                        "interval",
                                                                        "maxRetries",
                                                                    ],
                                                                    "type": "object",
                                                                },
                                                            },
                                                            "required": ["kind"],
                                                            "type": "object",
                                                        },
                                                    },
                                                    "required": [
                                                        "completionCondition",
                                                        "retryStrategy",
                                                    ],
                                                    "type": "object",
                                                },
                                                "connectionLabel": {
                                                    "description": "The "
                                                    "unique "
                                                    "identifier "
                                                    "of "
                                                    "a "
                                                    "connection "
                                                    "defined "
                                                    "in "
                                                    "the "
                                                    "spec.",
                                                    "type": "string",
                                                },
                                                "display": {
                                                    "description": "The "
                                                    "definition "
                                                    "of "
                                                    "`StepDisplay` "
                                                    "object.",
                                                    "properties": {
                                                        "bounds": {
                                                            "description": "The "
                                                            "definition "
                                                            "of "
                                                            "`StepDisplayBounds` "
                                                            "object.",
                                                            "properties": {
                                                                "x": {
                                                                    "description": "The "
                                                                    "`bounds` "
                                                                    "`x`.",
                                                                    "format": "double",
                                                                    "type": "number",
                                                                },
                                                                "y": {
                                                                    "description": "The "
                                                                    "`bounds` "
                                                                    "`y`.",
                                                                    "format": "double",
                                                                    "type": "number",
                                                                },
                                                            },
                                                            "type": "object",
                                                        }
                                                    },
                                                    "type": "object",
                                                },
                                                "errorHandlers": {
                                                    "description": "The `Step` `errorHandlers`.",
                                                    "items": {
                                                        "description": "Used "
                                                        "to "
                                                        "handle "
                                                        "errors "
                                                        "in "
                                                        "an "
                                                        "action.",
                                                        "properties": {
                                                            "fallbackStepName": {
                                                                "description": "The "
                                                                "`ErrorHandler` "
                                                                "`fallbackStepName`.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                            "retryStrategy": {
                                                                "description": "The "
                                                                "definition "
                                                                "of "
                                                                "`RetryStrategy` "
                                                                "object.",
                                                                "properties": {
                                                                    "kind": {
                                                                        "description": "The "
                                                                        "definition "
                                                                        "of "
                                                                        "`RetryStrategyKind` "
                                                                        "object.",
                                                                        "enum": [
                                                                            "RETRY_STRATEGY_LINEAR"
                                                                        ],
                                                                        "example": "RETRY_STRATEGY_LINEAR",
                                                                        "type": "string",
                                                                        "x-enum-varnames": [
                                                                            "RETRY_STRATEGY_LINEAR"
                                                                        ],
                                                                    },
                                                                    "linear": {
                                                                        "description": "The "
                                                                        "definition "
                                                                        "of "
                                                                        "`RetryStrategyLinear` "
                                                                        "object.",
                                                                        "properties": {
                                                                            "interval": {
                                                                                "description": "The "
                                                                                "`RetryStrategyLinear` "
                                                                                "`interval`. "
                                                                                "The "
                                                                                "expected "
                                                                                "format "
                                                                                "is "
                                                                                "the "
                                                                                "number "
                                                                                "of "
                                                                                "seconds "
                                                                                "ending "
                                                                                "with "
                                                                                "an "
                                                                                "s. "
                                                                                "For "
                                                                                "example, "
                                                                                "1 "
                                                                                "day "
                                                                                "is "
                                                                                "86400s",
                                                                                "example": "",
                                                                                "type": "string",
                                                                            },
                                                                            "maxRetries": {
                                                                                "description": "The "
                                                                                "`RetryStrategyLinear` "
                                                                                "`maxRetries`.",
                                                                                "example": 0.0,
                                                                                "format": "double",
                                                                                "type": "number",
                                                                            },
                                                                        },
                                                                        "required": [
                                                                            "interval",
                                                                            "maxRetries",
                                                                        ],
                                                                        "type": "object",
                                                                    },
                                                                },
                                                                "required": ["kind"],
                                                                "type": "object",
                                                            },
                                                        },
                                                        "required": [
                                                            "retryStrategy",
                                                            "fallbackStepName",
                                                        ],
                                                        "type": "object",
                                                    },
                                                    "type": "array",
                                                },
                                                "name": {
                                                    "description": "Name of the step.",
                                                    "example": "",
                                                    "type": "string",
                                                },
                                                "outboundEdges": {
                                                    "description": "A "
                                                    "list "
                                                    "of "
                                                    "subsequent "
                                                    "actions "
                                                    "to "
                                                    "run.",
                                                    "items": {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "`OutboundEdge` "
                                                        "object.",
                                                        "properties": {
                                                            "branchName": {
                                                                "description": "The "
                                                                "`OutboundEdge` "
                                                                "`branchName`.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                            "nextStepName": {
                                                                "description": "The "
                                                                "`OutboundEdge` "
                                                                "`nextStepName`.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                        },
                                                        "required": ["nextStepName", "branchName"],
                                                        "type": "object",
                                                    },
                                                    "type": "array",
                                                },
                                                "parameters": {
                                                    "description": "A "
                                                    "list "
                                                    "of "
                                                    "inputs "
                                                    "for "
                                                    "an "
                                                    "action.",
                                                    "items": {
                                                        "description": "The "
                                                        "definition "
                                                        "of "
                                                        "`Parameter` "
                                                        "object.",
                                                        "properties": {
                                                            "name": {
                                                                "description": "The "
                                                                "`Parameter` "
                                                                "`name`.",
                                                                "example": "",
                                                                "type": "string",
                                                            },
                                                            "value": {
                                                                "description": "The "
                                                                "`Parameter` "
                                                                "`value`."
                                                            },
                                                        },
                                                        "required": ["name", "value"],
                                                        "type": "object",
                                                    },
                                                    "type": "array",
                                                },
                                                "readinessGate": {
                                                    "description": "Used "
                                                    "to "
                                                    "merge "
                                                    "multiple "
                                                    "branches "
                                                    "into "
                                                    "a "
                                                    "single "
                                                    "branch.",
                                                    "properties": {
                                                        "thresholdType": {
                                                            "description": "The "
                                                            "definition "
                                                            "of "
                                                            "`ReadinessGateThresholdType` "
                                                            "object.",
                                                            "enum": ["ANY", "ALL"],
                                                            "example": "ANY",
                                                            "type": "string",
                                                            "x-enum-varnames": ["ANY", "ALL"],
                                                        }
                                                    },
                                                    "required": ["thresholdType"],
                                                    "type": "object",
                                                },
                                            },
                                            "required": ["name", "actionId"],
                                            "type": "object",
                                        },
                                        "type": "array",
                                    },
                                    "triggers": {
                                        "description": "The "
                                        "list "
                                        "of "
                                        "triggers "
                                        "that "
                                        "activate "
                                        "this "
                                        "workflow. "
                                        "At "
                                        "least "
                                        "one "
                                        "trigger "
                                        "is "
                                        "required, "
                                        "and "
                                        "each "
                                        "trigger "
                                        "type "
                                        "may "
                                        "appear "
                                        "at "
                                        "most "
                                        "once.",
                                        "items": {
                                            "description": "One "
                                            "of "
                                            "the "
                                            "triggers "
                                            "that "
                                            "can "
                                            "start "
                                            "the "
                                            "execution "
                                            "of "
                                            "a "
                                            "workflow.",
                                            "oneOf": [
                                                {
                                                    "description": "Schema "
                                                    "for "
                                                    "an "
                                                    "API-based "
                                                    "trigger.",
                                                    "properties": {
                                                        "apiTrigger": {
                                                            "description": "Trigger "
                                                            "a "
                                                            "workflow "
                                                            "from "
                                                            "an "
                                                            "API "
                                                            "request. "
                                                            "The "
                                                            "workflow "
                                                            "must "
                                                            "be "
                                                            "published.",
                                                            "properties": {
                                                                "rateLimit": {
                                                                    "description": "Defines "
                                                                    "a "
                                                                    "rate "
                                                                    "limit "
                                                                    "for "
                                                                    "a "
                                                                    "trigger.",
                                                                    "properties": {
                                                                        "count": {
                                                                            "description": "The "
                                                                            "`TriggerRateLimit` "
                                                                            "`count`.",
                                                                            "format": "int64",
                                                                            "type": "integer",
                                                                        },
                                                                        "interval": {
                                                                            "description": "The "
                                                                            "`TriggerRateLimit` "
                                                                            "`interval`. "
                                                                            "The "
                                                                            "expected "
                                                                            "format "
                                                                            "is "
                                                                            "the "
                                                                            "number "
                                                                            "of "
                                                                            "seconds "
                                                                            "ending "
                                                                            "with "
                                                                            "an "
                                                                            "s. "
                                                                            "For "
                                                                            "example, "
                                                                            "1 "
                                                                            "day "
                                                                            "is "
                                                                            "86400s",
                                                                            "type": "string",
                                                                        },
                                                                    },
                                                                    "type": "object",
                                                                }
                                                            },
                                                            "type": "object",
                                                        },
                                                        "startStepNames": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "steps "
                                                            "that "
                                                            "run "
                                                            "first "
                                                            "after "
                                                            "a "
                                                            "trigger "
                                                            "fires.",
                                                            "example": [""],
                                                            "items": {
                                                                "description": "The "
                                                                "`StartStepNames` "
                                                                "`items`.",
                                                                "type": "string",
                                                            },
                                                            "type": "array",
                                                        },
                                                    },
                                                    "required": ["apiTrigger"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "Schema "
                                                    "for "
                                                    "an "
                                                    "App-based "
                                                    "trigger.",
                                                    "properties": {
                                                        "appTrigger": {
                                                            "description": "Trigger "
                                                            "a "
                                                            "workflow "
                                                            "from "
                                                            "an "
                                                            "App.",
                                                            "type": "object",
                                                        },
                                                        "startStepNames": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "steps "
                                                            "that "
                                                            "run "
                                                            "first "
                                                            "after "
                                                            "a "
                                                            "trigger "
                                                            "fires.",
                                                            "example": [""],
                                                            "items": {
                                                                "description": "The "
                                                                "`StartStepNames` "
                                                                "`items`.",
                                                                "type": "string",
                                                            },
                                                            "type": "array",
                                                        },
                                                    },
                                                    "required": ["appTrigger"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "Schema "
                                                    "for "
                                                    "a "
                                                    "Case-based "
                                                    "trigger.",
                                                    "properties": {
                                                        "caseTrigger": {
                                                            "description": "Trigger "
                                                            "a "
                                                            "workflow "
                                                            "from "
                                                            "a "
                                                            "Case. "
                                                            "For "
                                                            "automatic "
                                                            "triggering "
                                                            "a "
                                                            "handle "
                                                            "must "
                                                            "be "
                                                            "configured "
                                                            "and "
                                                            "the "
                                                            "workflow "
                                                            "must "
                                                            "be "
                                                            "published.",
                                                            "properties": {
                                                                "rateLimit": {
                                                                    "description": "Defines "
                                                                    "a "
                                                                    "rate "
                                                                    "limit "
                                                                    "for "
                                                                    "a "
                                                                    "trigger.",
                                                                    "properties": {
                                                                        "count": {
                                                                            "description": "The "
                                                                            "`TriggerRateLimit` "
                                                                            "`count`.",
                                                                            "format": "int64",
                                                                            "type": "integer",
                                                                        },
                                                                        "interval": {
                                                                            "description": "The "
                                                                            "`TriggerRateLimit` "
                                                                            "`interval`. "
                                                                            "The "
                                                                            "expected "
                                                                            "format "
                                                                            "is "
                                                                            "the "
                                                                            "number "
                                                                            "of "
                                                                            "seconds "
                                                                            "ending "
                                                                            "with "
                                                                            "an "
                                                                            "s. "
                                                                            "For "
                                                                            "example, "
                                                                            "1 "
                                                                            "day "
                                                                            "is "
                                                                            "86400s",
                                                                            "type": "string",
                                                                        },
                                                                    },
                                                                    "type": "object",
                                                                }
                                                            },
                                                            "type": "object",
                                                        },
                                                        "startStepNames": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "steps "
                                                            "that "
                                                            "run "
                                                            "first "
                                                            "after "
                                                            "a "
                                                            "trigger "
                                                            "fires.",
                                                            "example": [""],
                                                            "items": {
                                                                "description": "The "
                                                                "`StartStepNames` "
                                                                "`items`.",
                                                                "type": "string",
                                                            },
                                                            "type": "array",
                                                        },
                                                    },
                                                    "required": ["caseTrigger"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "Schema "
                                                    "for "
                                                    "a "
                                                    "Change "
                                                    "Event-based "
                                                    "trigger.",
                                                    "properties": {
                                                        "changeEventTrigger": {
                                                            "description": "Trigger "
                                                            "a "
                                                            "workflow "
                                                            "from "
                                                            "a "
                                                            "Change "
                                                            "Event.",
                                                            "type": "object",
                                                        },
                                                        "startStepNames": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "steps "
                                                            "that "
                                                            "run "
                                                            "first "
                                                            "after "
                                                            "a "
                                                            "trigger "
                                                            "fires.",
                                                            "example": [""],
                                                            "items": {
                                                                "description": "The "
                                                                "`StartStepNames` "
                                                                "`items`.",
                                                                "type": "string",
                                                            },
                                                            "type": "array",
                                                        },
                                                    },
                                                    "required": ["changeEventTrigger"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "Schema "
                                                    "for "
                                                    "a "
                                                    "Database "
                                                    "Monitoring-based "
                                                    "trigger.",
                                                    "properties": {
                                                        "databaseMonitoringTrigger": {
                                                            "description": "Trigger "
                                                            "a "
                                                            "workflow "
                                                            "from "
                                                            "Database "
                                                            "Monitoring.",
                                                            "type": "object",
                                                        },
                                                        "startStepNames": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "steps "
                                                            "that "
                                                            "run "
                                                            "first "
                                                            "after "
                                                            "a "
                                                            "trigger "
                                                            "fires.",
                                                            "example": [""],
                                                            "items": {
                                                                "description": "The "
                                                                "`StartStepNames` "
                                                                "`items`.",
                                                                "type": "string",
                                                            },
                                                            "type": "array",
                                                        },
                                                    },
                                                    "required": ["databaseMonitoringTrigger"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "Schema "
                                                    "for "
                                                    "a "
                                                    "Datastore-based "
                                                    "trigger.",
                                                    "properties": {
                                                        "datastoreTrigger": {
                                                            "description": "Trigger "
                                                            "a "
                                                            "workflow "
                                                            "from "
                                                            "a "
                                                            "Datastore. "
                                                            "For "
                                                            "automatic "
                                                            "triggering "
                                                            "a "
                                                            "handle "
                                                            "must "
                                                            "be "
                                                            "configured "
                                                            "and "
                                                            "the "
                                                            "workflow "
                                                            "must "
                                                            "be "
                                                            "published.",
                                                            "properties": {
                                                                "rateLimit": {
                                                                    "description": "Defines "
                                                                    "a "
                                                                    "rate "
                                                                    "limit "
                                                                    "for "
                                                                    "a "
                                                                    "trigger.",
                                                                    "properties": {
                                                                        "count": {
                                                                            "description": "The "
                                                                            "`TriggerRateLimit` "
                                                                            "`count`.",
                                                                            "format": "int64",
                                                                            "type": "integer",
                                                                        },
                                                                        "interval": {
                                                                            "description": "The "
                                                                            "`TriggerRateLimit` "
                                                                            "`interval`. "
                                                                            "The "
                                                                            "expected "
                                                                            "format "
                                                                            "is "
                                                                            "the "
                                                                            "number "
                                                                            "of "
                                                                            "seconds "
                                                                            "ending "
                                                                            "with "
                                                                            "an "
                                                                            "s. "
                                                                            "For "
                                                                            "example, "
                                                                            "1 "
                                                                            "day "
                                                                            "is "
                                                                            "86400s",
                                                                            "type": "string",
                                                                        },
                                                                    },
                                                                    "type": "object",
                                                                }
                                                            },
                                                            "type": "object",
                                                        },
                                                        "startStepNames": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "steps "
                                                            "that "
                                                            "run "
                                                            "first "
                                                            "after "
                                                            "a "
                                                            "trigger "
                                                            "fires.",
                                                            "example": [""],
                                                            "items": {
                                                                "description": "The "
                                                                "`StartStepNames` "
                                                                "`items`.",
                                                                "type": "string",
                                                            },
                                                            "type": "array",
                                                        },
                                                    },
                                                    "required": ["datastoreTrigger"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "Schema "
                                                    "for "
                                                    "a "
                                                    "Dashboard-based "
                                                    "trigger.",
                                                    "properties": {
                                                        "dashboardTrigger": {
                                                            "description": "Trigger "
                                                            "a "
                                                            "workflow "
                                                            "from "
                                                            "a "
                                                            "Dashboard.",
                                                            "type": "object",
                                                        },
                                                        "startStepNames": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "steps "
                                                            "that "
                                                            "run "
                                                            "first "
                                                            "after "
                                                            "a "
                                                            "trigger "
                                                            "fires.",
                                                            "example": [""],
                                                            "items": {
                                                                "description": "The "
                                                                "`StartStepNames` "
                                                                "`items`.",
                                                                "type": "string",
                                                            },
                                                            "type": "array",
                                                        },
                                                    },
                                                    "required": ["dashboardTrigger"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "Schema "
                                                    "for "
                                                    "a "
                                                    "GitHub "
                                                    "webhook-based "
                                                    "trigger.",
                                                    "properties": {
                                                        "githubWebhookTrigger": {
                                                            "description": "Trigger "
                                                            "a "
                                                            "workflow "
                                                            "from "
                                                            "a "
                                                            "GitHub "
                                                            "webhook. "
                                                            "To "
                                                            "trigger "
                                                            "a "
                                                            "workflow "
                                                            "from "
                                                            "GitHub, "
                                                            "you "
                                                            "must "
                                                            "set "
                                                            "a "
                                                            "`webhookSecret`. "
                                                            "In "
                                                            "your "
                                                            "GitHub "
                                                            "Webhook "
                                                            "Settings, "
                                                            "set "
                                                            "the "
                                                            "Payload "
                                                            "URL "
                                                            "to "
                                                            '"base_url"/api/v2/workflows/"workflow_id"/webhook?orgId="org_id", '
                                                            "select "
                                                            "application/json "
                                                            "for "
                                                            "the "
                                                            "content "
                                                            "type, "
                                                            "and "
                                                            "be "
                                                            "highly "
                                                            "recommend "
                                                            "enabling "
                                                            "SSL "
                                                            "verification "
                                                            "for "
                                                            "security. "
                                                            "The "
                                                            "workflow "
                                                            "must "
                                                            "be "
                                                            "published.",
                                                            "properties": {
                                                                "rateLimit": {
                                                                    "description": "Defines "
                                                                    "a "
                                                                    "rate "
                                                                    "limit "
                                                                    "for "
                                                                    "a "
                                                                    "trigger.",
                                                                    "properties": {
                                                                        "count": {
                                                                            "description": "The "
                                                                            "`TriggerRateLimit` "
                                                                            "`count`.",
                                                                            "format": "int64",
                                                                            "type": "integer",
                                                                        },
                                                                        "interval": {
                                                                            "description": "The "
                                                                            "`TriggerRateLimit` "
                                                                            "`interval`. "
                                                                            "The "
                                                                            "expected "
                                                                            "format "
                                                                            "is "
                                                                            "the "
                                                                            "number "
                                                                            "of "
                                                                            "seconds "
                                                                            "ending "
                                                                            "with "
                                                                            "an "
                                                                            "s. "
                                                                            "For "
                                                                            "example, "
                                                                            "1 "
                                                                            "day "
                                                                            "is "
                                                                            "86400s",
                                                                            "type": "string",
                                                                        },
                                                                    },
                                                                    "type": "object",
                                                                }
                                                            },
                                                            "type": "object",
                                                        },
                                                        "startStepNames": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "steps "
                                                            "that "
                                                            "run "
                                                            "first "
                                                            "after "
                                                            "a "
                                                            "trigger "
                                                            "fires.",
                                                            "example": [""],
                                                            "items": {
                                                                "description": "The "
                                                                "`StartStepNames` "
                                                                "`items`.",
                                                                "type": "string",
                                                            },
                                                            "type": "array",
                                                        },
                                                    },
                                                    "required": ["githubWebhookTrigger"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "Schema "
                                                    "for "
                                                    "an "
                                                    "Incident-based "
                                                    "trigger.",
                                                    "properties": {
                                                        "incidentTrigger": {
                                                            "description": "Trigger "
                                                            "a "
                                                            "workflow "
                                                            "from "
                                                            "an "
                                                            "Incident. "
                                                            "For "
                                                            "automatic "
                                                            "triggering "
                                                            "a "
                                                            "handle "
                                                            "must "
                                                            "be "
                                                            "configured "
                                                            "and "
                                                            "the "
                                                            "workflow "
                                                            "must "
                                                            "be "
                                                            "published.",
                                                            "properties": {
                                                                "rateLimit": {
                                                                    "description": "Defines "
                                                                    "a "
                                                                    "rate "
                                                                    "limit "
                                                                    "for "
                                                                    "a "
                                                                    "trigger.",
                                                                    "properties": {
                                                                        "count": {
                                                                            "description": "The "
                                                                            "`TriggerRateLimit` "
                                                                            "`count`.",
                                                                            "format": "int64",
                                                                            "type": "integer",
                                                                        },
                                                                        "interval": {
                                                                            "description": "The "
                                                                            "`TriggerRateLimit` "
                                                                            "`interval`. "
                                                                            "The "
                                                                            "expected "
                                                                            "format "
                                                                            "is "
                                                                            "the "
                                                                            "number "
                                                                            "of "
                                                                            "seconds "
                                                                            "ending "
                                                                            "with "
                                                                            "an "
                                                                            "s. "
                                                                            "For "
                                                                            "example, "
                                                                            "1 "
                                                                            "day "
                                                                            "is "
                                                                            "86400s",
                                                                            "type": "string",
                                                                        },
                                                                    },
                                                                    "type": "object",
                                                                }
                                                            },
                                                            "type": "object",
                                                        },
                                                        "startStepNames": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "steps "
                                                            "that "
                                                            "run "
                                                            "first "
                                                            "after "
                                                            "a "
                                                            "trigger "
                                                            "fires.",
                                                            "example": [""],
                                                            "items": {
                                                                "description": "The "
                                                                "`StartStepNames` "
                                                                "`items`.",
                                                                "type": "string",
                                                            },
                                                            "type": "array",
                                                        },
                                                    },
                                                    "required": ["incidentTrigger"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "Schema "
                                                    "for "
                                                    "a "
                                                    "Monitor-based "
                                                    "trigger.",
                                                    "properties": {
                                                        "monitorTrigger": {
                                                            "description": "Trigger "
                                                            "a "
                                                            "workflow "
                                                            "from "
                                                            "a "
                                                            "Monitor. "
                                                            "For "
                                                            "automatic "
                                                            "triggering "
                                                            "a "
                                                            "handle "
                                                            "must "
                                                            "be "
                                                            "configured "
                                                            "and "
                                                            "the "
                                                            "workflow "
                                                            "must "
                                                            "be "
                                                            "published.",
                                                            "properties": {
                                                                "rateLimit": {
                                                                    "description": "Defines "
                                                                    "a "
                                                                    "rate "
                                                                    "limit "
                                                                    "for "
                                                                    "a "
                                                                    "trigger.",
                                                                    "properties": {
                                                                        "count": {
                                                                            "description": "The "
                                                                            "`TriggerRateLimit` "
                                                                            "`count`.",
                                                                            "format": "int64",
                                                                            "type": "integer",
                                                                        },
                                                                        "interval": {
                                                                            "description": "The "
                                                                            "`TriggerRateLimit` "
                                                                            "`interval`. "
                                                                            "The "
                                                                            "expected "
                                                                            "format "
                                                                            "is "
                                                                            "the "
                                                                            "number "
                                                                            "of "
                                                                            "seconds "
                                                                            "ending "
                                                                            "with "
                                                                            "an "
                                                                            "s. "
                                                                            "For "
                                                                            "example, "
                                                                            "1 "
                                                                            "day "
                                                                            "is "
                                                                            "86400s",
                                                                            "type": "string",
                                                                        },
                                                                    },
                                                                    "type": "object",
                                                                }
                                                            },
                                                            "type": "object",
                                                        },
                                                        "startStepNames": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "steps "
                                                            "that "
                                                            "run "
                                                            "first "
                                                            "after "
                                                            "a "
                                                            "trigger "
                                                            "fires.",
                                                            "example": [""],
                                                            "items": {
                                                                "description": "The "
                                                                "`StartStepNames` "
                                                                "`items`.",
                                                                "type": "string",
                                                            },
                                                            "type": "array",
                                                        },
                                                    },
                                                    "required": ["monitorTrigger"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "Schema "
                                                    "for "
                                                    "a "
                                                    "Notebook-based "
                                                    "trigger.",
                                                    "properties": {
                                                        "notebookTrigger": {
                                                            "description": "Trigger "
                                                            "a "
                                                            "workflow "
                                                            "from "
                                                            "a "
                                                            "Notebook.",
                                                            "type": "object",
                                                        },
                                                        "startStepNames": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "steps "
                                                            "that "
                                                            "run "
                                                            "first "
                                                            "after "
                                                            "a "
                                                            "trigger "
                                                            "fires.",
                                                            "example": [""],
                                                            "items": {
                                                                "description": "The "
                                                                "`StartStepNames` "
                                                                "`items`.",
                                                                "type": "string",
                                                            },
                                                            "type": "array",
                                                        },
                                                    },
                                                    "required": ["notebookTrigger"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "Schema "
                                                    "for "
                                                    "a "
                                                    "Schedule-based "
                                                    "trigger.",
                                                    "properties": {
                                                        "scheduleTrigger": {
                                                            "description": "Trigger "
                                                            "a "
                                                            "workflow "
                                                            "from "
                                                            "a "
                                                            "Schedule. "
                                                            "The "
                                                            "workflow "
                                                            "must "
                                                            "be "
                                                            "published.",
                                                            "properties": {
                                                                "rruleExpression": {
                                                                    "description": "Recurrence "
                                                                    "rule "
                                                                    "expression "
                                                                    "for "
                                                                    "scheduling.",
                                                                    "example": "",
                                                                    "type": "string",
                                                                }
                                                            },
                                                            "required": ["rruleExpression"],
                                                            "type": "object",
                                                        },
                                                        "startStepNames": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "steps "
                                                            "that "
                                                            "run "
                                                            "first "
                                                            "after "
                                                            "a "
                                                            "trigger "
                                                            "fires.",
                                                            "example": [""],
                                                            "items": {
                                                                "description": "The "
                                                                "`StartStepNames` "
                                                                "`items`.",
                                                                "type": "string",
                                                            },
                                                            "type": "array",
                                                        },
                                                    },
                                                    "required": ["scheduleTrigger"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "Schema "
                                                    "for "
                                                    "a "
                                                    "Security-based "
                                                    "trigger.",
                                                    "properties": {
                                                        "securityTrigger": {
                                                            "description": "Trigger "
                                                            "a "
                                                            "workflow "
                                                            "from "
                                                            "a "
                                                            "Security "
                                                            "Signal "
                                                            "or "
                                                            "Finding. "
                                                            "For "
                                                            "automatic "
                                                            "triggering "
                                                            "a "
                                                            "handle "
                                                            "must "
                                                            "be "
                                                            "configured "
                                                            "and "
                                                            "the "
                                                            "workflow "
                                                            "must "
                                                            "be "
                                                            "published.",
                                                            "properties": {
                                                                "rateLimit": {
                                                                    "description": "Defines "
                                                                    "a "
                                                                    "rate "
                                                                    "limit "
                                                                    "for "
                                                                    "a "
                                                                    "trigger.",
                                                                    "properties": {
                                                                        "count": {
                                                                            "description": "The "
                                                                            "`TriggerRateLimit` "
                                                                            "`count`.",
                                                                            "format": "int64",
                                                                            "type": "integer",
                                                                        },
                                                                        "interval": {
                                                                            "description": "The "
                                                                            "`TriggerRateLimit` "
                                                                            "`interval`. "
                                                                            "The "
                                                                            "expected "
                                                                            "format "
                                                                            "is "
                                                                            "the "
                                                                            "number "
                                                                            "of "
                                                                            "seconds "
                                                                            "ending "
                                                                            "with "
                                                                            "an "
                                                                            "s. "
                                                                            "For "
                                                                            "example, "
                                                                            "1 "
                                                                            "day "
                                                                            "is "
                                                                            "86400s",
                                                                            "type": "string",
                                                                        },
                                                                    },
                                                                    "type": "object",
                                                                }
                                                            },
                                                            "type": "object",
                                                        },
                                                        "startStepNames": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "steps "
                                                            "that "
                                                            "run "
                                                            "first "
                                                            "after "
                                                            "a "
                                                            "trigger "
                                                            "fires.",
                                                            "example": [""],
                                                            "items": {
                                                                "description": "The "
                                                                "`StartStepNames` "
                                                                "`items`.",
                                                                "type": "string",
                                                            },
                                                            "type": "array",
                                                        },
                                                    },
                                                    "required": ["securityTrigger"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "Schema "
                                                    "for "
                                                    "a "
                                                    "Self "
                                                    "Service-based "
                                                    "trigger.",
                                                    "properties": {
                                                        "selfServiceTrigger": {
                                                            "description": "Trigger "
                                                            "a "
                                                            "workflow "
                                                            "from "
                                                            "Self "
                                                            "Service.",
                                                            "type": "object",
                                                        },
                                                        "startStepNames": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "steps "
                                                            "that "
                                                            "run "
                                                            "first "
                                                            "after "
                                                            "a "
                                                            "trigger "
                                                            "fires.",
                                                            "example": [""],
                                                            "items": {
                                                                "description": "The "
                                                                "`StartStepNames` "
                                                                "`items`.",
                                                                "type": "string",
                                                            },
                                                            "type": "array",
                                                        },
                                                    },
                                                    "required": ["selfServiceTrigger"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "Schema "
                                                    "for "
                                                    "a "
                                                    "Slack-based "
                                                    "trigger.",
                                                    "properties": {
                                                        "slackTrigger": {
                                                            "description": "Trigger "
                                                            "a "
                                                            "workflow "
                                                            "from "
                                                            "Slack. "
                                                            "The "
                                                            "workflow "
                                                            "must "
                                                            "be "
                                                            "published.",
                                                            "type": "object",
                                                        },
                                                        "startStepNames": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "steps "
                                                            "that "
                                                            "run "
                                                            "first "
                                                            "after "
                                                            "a "
                                                            "trigger "
                                                            "fires.",
                                                            "example": [""],
                                                            "items": {
                                                                "description": "The "
                                                                "`StartStepNames` "
                                                                "`items`.",
                                                                "type": "string",
                                                            },
                                                            "type": "array",
                                                        },
                                                    },
                                                    "required": ["slackTrigger"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "Schema "
                                                    "for "
                                                    "a "
                                                    "Software "
                                                    "Catalog-based "
                                                    "trigger.",
                                                    "properties": {
                                                        "softwareCatalogTrigger": {
                                                            "description": "Trigger "
                                                            "a "
                                                            "workflow "
                                                            "from "
                                                            "Software "
                                                            "Catalog.",
                                                            "type": "object",
                                                        },
                                                        "startStepNames": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "steps "
                                                            "that "
                                                            "run "
                                                            "first "
                                                            "after "
                                                            "a "
                                                            "trigger "
                                                            "fires.",
                                                            "example": [""],
                                                            "items": {
                                                                "description": "The "
                                                                "`StartStepNames` "
                                                                "`items`.",
                                                                "type": "string",
                                                            },
                                                            "type": "array",
                                                        },
                                                    },
                                                    "required": ["softwareCatalogTrigger"],
                                                    "type": "object",
                                                },
                                                {
                                                    "description": "Schema "
                                                    "for "
                                                    "a "
                                                    "Workflow-based "
                                                    "trigger.",
                                                    "properties": {
                                                        "startStepNames": {
                                                            "description": "A "
                                                            "list "
                                                            "of "
                                                            "steps "
                                                            "that "
                                                            "run "
                                                            "first "
                                                            "after "
                                                            "a "
                                                            "trigger "
                                                            "fires.",
                                                            "example": [""],
                                                            "items": {
                                                                "description": "The "
                                                                "`StartStepNames` "
                                                                "`items`.",
                                                                "type": "string",
                                                            },
                                                            "type": "array",
                                                        },
                                                        "workflowTrigger": {
                                                            "description": "Trigger "
                                                            "a "
                                                            "workflow "
                                                            "from "
                                                            "the "
                                                            "Datadog "
                                                            "UI. "
                                                            "Only "
                                                            "required "
                                                            "if "
                                                            "no "
                                                            "other "
                                                            "trigger "
                                                            "exists.",
                                                            "type": "object",
                                                        },
                                                    },
                                                    "required": ["workflowTrigger"],
                                                    "type": "object",
                                                },
                                            ],
                                        },
                                        "type": "array",
                                    },
                                },
                                "type": "object",
                            },
                            "tags": {
                                "description": "Tags of the workflow.",
                                "items": {"type": "string"},
                                "type": "array",
                            },
                            "updatedAt": {
                                "description": "When the workflow was last updated.",
                                "format": "date-time",
                                "readOnly": True,
                                "type": "string",
                            },
                            "webhookSecret": {
                                "description": "If "
                                "a "
                                "Webhook "
                                "trigger "
                                "is "
                                "defined "
                                "on "
                                "this "
                                "workflow, "
                                "a "
                                "webhookSecret "
                                "is "
                                "required "
                                "and "
                                "should "
                                "be "
                                "provided "
                                "here.",
                                "type": "string",
                                "writeOnly": True,
                            },
                        },
                        "type": "object",
                    },
                    "id": {"description": "The workflow identifier", "type": "string"},
                    "relationships": {
                        "description": "The definition of `WorkflowDataRelationships` object.",
                        "properties": {
                            "creator": {
                                "description": "The "
                                "definition "
                                "of "
                                "`WorkflowUserRelationship` "
                                "object.",
                                "properties": {
                                    "data": {
                                        "description": "The "
                                        "definition "
                                        "of "
                                        "`WorkflowUserRelationshipData` "
                                        "object.",
                                        "properties": {
                                            "id": {
                                                "description": "The user identifier",
                                                "example": "",
                                                "type": "string",
                                            },
                                            "type": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "`WorkflowUserRelationshipType` "
                                                "object.",
                                                "enum": ["users"],
                                                "example": "users",
                                                "type": "string",
                                                "x-enum-varnames": ["USERS"],
                                            },
                                        },
                                        "required": ["type", "id"],
                                        "type": "object",
                                    }
                                },
                                "type": "object",
                            },
                            "owner": {
                                "description": "The "
                                "definition "
                                "of "
                                "`WorkflowUserRelationship` "
                                "object.",
                                "properties": {
                                    "data": {
                                        "description": "The "
                                        "definition "
                                        "of "
                                        "`WorkflowUserRelationshipData` "
                                        "object.",
                                        "properties": {
                                            "id": {
                                                "description": "The user identifier",
                                                "example": "",
                                                "type": "string",
                                            },
                                            "type": {
                                                "description": "The "
                                                "definition "
                                                "of "
                                                "`WorkflowUserRelationshipType` "
                                                "object.",
                                                "enum": ["users"],
                                                "example": "users",
                                                "type": "string",
                                                "x-enum-varnames": ["USERS"],
                                            },
                                        },
                                        "required": ["type", "id"],
                                        "type": "object",
                                    }
                                },
                                "type": "object",
                            },
                        },
                        "readOnly": True,
                        "type": "object",
                    },
                    "type": {
                        "description": "The definition of `WorkflowDataType` object.",
                        "enum": ["workflows"],
                        "example": "workflows",
                        "type": "string",
                        "x-enum-varnames": ["WORKFLOWS"],
                    },
                },
                "required": ["type", "attributes"],
                "type": "object",
            }
        },
        "required": ["data"],
        "type": "object",
    },
    "EXECUTEWORKFLOW_REQUEST_BODY_SCHEMA": {
        "description": "Request used to create a workflow instance.",
        "properties": {
            "meta": {
                "description": "Additional information for creating a workflow instance.",
                "properties": {
                    "payload": {
                        "additionalProperties": {},
                        "description": "The input parameters to the workflow.",
                        "type": "object",
                    }
                },
                "type": "object",
            }
        },
        "type": "object",
    },
}
